From 22d981da8f2ca3d89e99d0636cb7add3e7ff0acf Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Tue, 28 Jan 2020 21:19:43 +0100
Subject: [PATCH v3 2/2] Add SQL functions for Unicode normalization

This adds SQL expressions NORMALIZE() and IS NORMALIZED to convert and
check Unicode normal forms, per SQL standard.
---
 doc/src/sgml/charset.sgml                     |    10 +
 doc/src/sgml/func.sgml                        |    48 +
 src/backend/catalog/sql_features.txt          |     2 +-
 src/backend/catalog/system_views.sql          |    15 +
 src/backend/parser/gram.y                     |    41 +-
 src/backend/utils/adt/varlena.c               |   150 +
 src/common/unicode/.gitignore                 |     1 +
 src/common/unicode/Makefile                   |     9 +-
 .../generate-unicode_normprops_table.pl       |    79 +
 src/common/unicode_norm.c                     |   101 +
 src/include/catalog/pg_proc.dat               |     8 +
 src/include/common/unicode_norm.h             |    10 +
 src/include/common/unicode_normprops_table.h  | 36285 ++++++++++++++++
 src/include/parser/kwlist.h                   |     6 +
 src/test/regress/expected/unicode.out         |    81 +
 src/test/regress/expected/unicode_1.out       |     3 +
 src/test/regress/parallel_schedule            |     2 +-
 src/test/regress/serial_schedule              |     1 +
 src/test/regress/sql/unicode.sql              |    32 +
 19 files changed, 36878 insertions(+), 6 deletions(-)
 create mode 100644 src/common/unicode/generate-unicode_normprops_table.pl
 create mode 100644 src/include/common/unicode_normprops_table.h
 create mode 100644 src/test/regress/expected/unicode.out
 create mode 100644 src/test/regress/expected/unicode_1.out
 create mode 100644 src/test/regress/sql/unicode.sql

diff --git a/doc/src/sgml/charset.sgml b/doc/src/sgml/charset.sgml
index 057a6bb81a..73f5352b18 100644
--- a/doc/src/sgml/charset.sgml
+++ b/doc/src/sgml/charset.sgml
@@ -933,6 +933,16 @@ <title>Nondeterministic Collations</title>
      Therefore, they should be used only in cases where they are specifically
      wanted.
     </para>
+
+    <tip>
+     <para>
+      To deal with text in different Unicode normalization forms, it is also
+      an option to use the functions/expressions
+      <function>normalize</function> and <literal>is normalized</literal> to
+      preprocess or check the strings, instead of using nondeterministic
+      collations.  There are different trade-offs for each approach.
+     </para>
+    </tip>
    </sect3>
   </sect2>
  </sect1>
diff --git a/doc/src/sgml/func.sgml b/doc/src/sgml/func.sgml
index 895b4b7b1b..f3d991126b 100644
--- a/doc/src/sgml/func.sgml
+++ b/doc/src/sgml/func.sgml
@@ -1561,6 +1561,30 @@ <title><acronym>SQL</acronym> String Functions and Operators</title>
        <entry><literal>Value: 42</literal></entry>
       </row>
 
+      <row>
+       <entry>
+        <indexterm>
+         <primary>normalized</primary>
+        </indexterm>
+        <indexterm>
+         <primary>Unicode normalization</primary>
+        </indexterm>
+        <literal><parameter>string</parameter> is <optional>not</optional> <optional><parameter>form</parameter></optional> normalized</literal>
+       </entry>
+       <entry><type>boolean</type></entry>
+       <entry>
+        Checks whether the string is in the specified Unicode normalization
+        form.  The optional parameter specifies the form:
+        <literal>NFC</literal> (default), <literal>NFD</literal>,
+        <literal>NFKC</literal>, <literal>NFKD</literal>.  This expression can
+        only be used if the server encoding is <literal>UTF8</literal>.  Note
+        that checking for normalization using this expression is often faster
+        than normalizing possibly already normalized strings.
+       </entry>
+       <entry><literal>U&amp;'\0061\0308bc' IS NFD NORMALIZED</literal></entry>
+       <entry><literal>true</literal></entry>
+      </row>
+
       <row>
        <entry>
         <indexterm>
@@ -1611,6 +1635,30 @@ <title><acronym>SQL</acronym> String Functions and Operators</title>
        <entry><literal>tom</literal></entry>
       </row>
 
+      <row>
+       <entry>
+        <indexterm>
+         <primary>normalize</primary>
+        </indexterm>
+        <indexterm>
+         <primary>Unicode normalization</primary>
+        </indexterm>
+        <literal><function>normalize(<parameter>string</parameter> <type>text</type>
+        <optional>, <parameter>form</parameter> </optional>)</function></literal>
+       </entry>
+       <entry><type>text</type></entry>
+       <entry>
+        Converts the string in the first argument to the specified Unicode
+        normalization form.  The optional second argument specifies the form
+        as an identifier: <literal>NFC</literal> (default),
+        <literal>NFD</literal>, <literal>NFKC</literal>,
+        <literal>NFKD</literal>.  This function can only be used if the server
+        encoding is <literal>UTF8</literal>.
+       </entry>
+       <entry><literal>normalize(U&amp;'\0061\0308bc', NFC)</literal></entry>
+       <entry><literal>U&amp;'\00E4bc'</literal></entry>
+      </row>
+
       <row>
        <entry>
         <indexterm>
diff --git a/src/backend/catalog/sql_features.txt b/src/backend/catalog/sql_features.txt
index 9f840ddfd2..b0f541dc6b 100644
--- a/src/backend/catalog/sql_features.txt
+++ b/src/backend/catalog/sql_features.txt
@@ -257,7 +257,7 @@ F386	Set identity column generation clause			YES
 F391	Long identifiers			YES	
 F392	Unicode escapes in identifiers			YES	
 F393	Unicode escapes in literals			YES	
-F394	Optional normal form specification			NO	
+F394	Optional normal form specification			YES	
 F401	Extended joined table			YES	
 F401	Extended joined table	01	NATURAL JOIN	YES	
 F401	Extended joined table	02	FULL OUTER JOIN	YES	
diff --git a/src/backend/catalog/system_views.sql b/src/backend/catalog/system_views.sql
index c9e75f4370..0be9a75887 100644
--- a/src/backend/catalog/system_views.sql
+++ b/src/backend/catalog/system_views.sql
@@ -1368,6 +1368,21 @@ CREATE OR REPLACE FUNCTION
 STRICT STABLE PARALLEL SAFE
 AS 'jsonb_path_query_first_tz';
 
+-- default normalization form is NFC, per SQL standard
+CREATE OR REPLACE FUNCTION
+  "normalize"(text, text DEFAULT 'NFC')
+RETURNS text
+LANGUAGE internal
+STRICT IMMUTABLE PARALLEL SAFE
+AS 'unicode_normalize_func';
+
+CREATE OR REPLACE FUNCTION
+  is_normalized(text, text DEFAULT 'NFC')
+RETURNS boolean
+LANGUAGE internal
+STRICT IMMUTABLE PARALLEL SAFE
+AS 'unicode_is_normalized';
+
 --
 -- The default permissions for functions mean that anyone can execute them.
 -- A number of functions shouldn't be executable by just anyone, but rather
diff --git a/src/backend/parser/gram.y b/src/backend/parser/gram.y
index ba5916b4d2..dfc785295e 100644
--- a/src/backend/parser/gram.y
+++ b/src/backend/parser/gram.y
@@ -444,6 +444,7 @@ static Node *makeRecursiveViewSelect(char *relname, List *aliases, Node *query);
 %type <list>	substr_list trim_list
 %type <list>	opt_interval interval_second
 %type <node>	overlay_placing substr_from substr_for
+%type <str>		unicode_normal_form
 
 %type <boolean> opt_instead
 %type <boolean> opt_unique opt_concurrently opt_verbose opt_full
@@ -664,7 +665,8 @@ static Node *makeRecursiveViewSelect(char *relname, List *aliases, Node *query);
 
 	MAPPING MATCH MATERIALIZED MAXVALUE METHOD MINUTE_P MINVALUE MODE MONTH_P MOVE
 
-	NAME_P NAMES NATIONAL NATURAL NCHAR NEW NEXT NO NONE
+	NAME_P NAMES NATIONAL NATURAL NCHAR NEW NEXT NFC NFD NFKC NFKD NO NONE
+	NORMALIZE NORMALIZED
 	NOT NOTHING NOTIFY NOTNULL NOWAIT NULL_P NULLIF
 	NULLS_P NUMERIC
 
@@ -13456,6 +13458,22 @@ a_expr:		c_expr									{ $$ = $1; }
 												 list_make1($1), @2),
 									 @2);
 				}
+			| a_expr IS NORMALIZED								%prec IS
+				{
+					$$ = (Node *) makeFuncCall(SystemFuncName("is_normalized"), list_make1($1), @2);
+				}
+			| a_expr IS unicode_normal_form NORMALIZED			%prec IS
+				{
+					$$ = (Node *) makeFuncCall(SystemFuncName("is_normalized"), list_make2($1, makeStringConst($3, @3)), @2);
+				}
+			| a_expr IS NOT NORMALIZED							%prec IS
+				{
+					$$ = makeNotExpr((Node *) makeFuncCall(SystemFuncName("is_normalized"), list_make1($1), @2), @2);
+				}
+			| a_expr IS NOT unicode_normal_form NORMALIZED		%prec IS
+				{
+					$$ = makeNotExpr((Node *) makeFuncCall(SystemFuncName("is_normalized"), list_make2($1, makeStringConst($4, @4)), @2), @2);
+				}
 			| DEFAULT
 				{
 					/*
@@ -13899,6 +13917,14 @@ func_expr_common_subexpr:
 				{
 					$$ = (Node *) makeFuncCall(SystemFuncName("date_part"), $3, @1);
 				}
+			| NORMALIZE '(' a_expr ')'
+				{
+					$$ = (Node *) makeFuncCall(SystemFuncName("normalize"), list_make1($3), @1);
+				}
+			| NORMALIZE '(' a_expr ',' unicode_normal_form ')'
+				{
+					$$ = (Node *) makeFuncCall(SystemFuncName("normalize"), list_make2($3, makeStringConst($5, @5)), @1);
+				}
 			| OVERLAY '(' overlay_list ')'
 				{
 					/* overlay(A PLACING B FROM C FOR D) is converted to
@@ -14534,6 +14560,13 @@ extract_arg:
 			| Sconst								{ $$ = $1; }
 		;
 
+unicode_normal_form:
+			NFC										{ $$ = "nfc"; }
+			| NFD									{ $$ = "nfd"; }
+			| NFKC									{ $$ = "nfkc"; }
+			| NFKD									{ $$ = "nfkd"; }
+		;
+
 /* OVERLAY() arguments
  * SQL99 defines the OVERLAY() function:
  * o overlay(text placing text from int for int)
@@ -15280,7 +15313,12 @@ unreserved_keyword:
 			| NAMES
 			| NEW
 			| NEXT
+			| NFC
+			| NFD
+			| NFKC
+			| NFKD
 			| NO
+			| NORMALIZED
 			| NOTHING
 			| NOTIFY
 			| NOWAIT
@@ -15459,6 +15497,7 @@ col_name_keyword:
 			| NATIONAL
 			| NCHAR
 			| NONE
+			| NORMALIZE
 			| NULLIF
 			| NUMERIC
 			| OUT_P
diff --git a/src/backend/utils/adt/varlena.c b/src/backend/utils/adt/varlena.c
index 1b351cbc68..3f4d81e014 100644
--- a/src/backend/utils/adt/varlena.c
+++ b/src/backend/utils/adt/varlena.c
@@ -21,6 +21,7 @@
 #include "catalog/pg_collation.h"
 #include "catalog/pg_type.h"
 #include "common/int.h"
+#include "common/unicode_norm.h"
 #include "lib/hyperloglog.h"
 #include "libpq/pqformat.h"
 #include "miscadmin.h"
@@ -5956,3 +5957,152 @@ rest_of_char_same(const char *s1, const char *s2, int len)
 #include "levenshtein.c"
 #define LEVENSHTEIN_LESS_EQUAL
 #include "levenshtein.c"
+
+
+/*
+ * Unicode support
+ */
+
+static UnicodeNormalizationForm
+unicode_norm_form_from_string(const char *formstr)
+{
+	UnicodeNormalizationForm form = -1;
+
+	/*
+	 * Might as well check this while we're here.
+	 */
+	if (GetDatabaseEncoding() != PG_UTF8)
+		ereport(ERROR,
+				(errcode(ERRCODE_SYNTAX_ERROR),
+				 errmsg("Unicode normalization can only be performed if server encoding is UTF8")));
+
+	if (pg_strcasecmp(formstr, "NFC") == 0)
+		form = UNICODE_NFC;
+	else if (pg_strcasecmp(formstr, "NFD") == 0)
+		form = UNICODE_NFD;
+	else if (pg_strcasecmp(formstr, "NFKC") == 0)
+		form = UNICODE_NFKC;
+	else if (pg_strcasecmp(formstr, "NFKD") == 0)
+		form = UNICODE_NFKD;
+	else
+		ereport(ERROR,
+				(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
+				 errmsg("invalid normalization form: %s", formstr)));
+
+	return form;
+}
+
+Datum
+unicode_normalize_func(PG_FUNCTION_ARGS)
+{
+	text	   *input = PG_GETARG_TEXT_PP(0);
+	char	   *formstr = text_to_cstring(PG_GETARG_TEXT_PP(1));
+	UnicodeNormalizationForm form;
+	int			size;
+	pg_wchar   *input_chars;
+	pg_wchar   *output_chars;
+	unsigned char *p;
+	text	   *result;
+	int			i;
+
+	form = unicode_norm_form_from_string(formstr);
+
+	/* convert to pg_wchar */
+	size = pg_mbstrlen_with_len(VARDATA_ANY(input), VARSIZE_ANY_EXHDR(input));
+	input_chars = palloc((size + 1) * sizeof(pg_wchar));
+	p = (unsigned char *) VARDATA_ANY(input);
+	for (i = 0; i < size; i++)
+	{
+		input_chars[i] = utf8_to_unicode(p);
+		p += pg_utf_mblen(p);
+	}
+	input_chars[i] = (pg_wchar) '\0';
+	Assert((char *) p == VARDATA_ANY(input) + VARSIZE_ANY_EXHDR(input));
+
+	/* action */
+	output_chars = unicode_normalize(form, input_chars);
+
+	/* convert back to UTF-8 string */
+	size = 0;
+	for (pg_wchar *wp = output_chars; *wp; wp++)
+	{
+		unsigned char buf[4];
+
+		unicode_to_utf8(*wp, buf);
+		size += pg_utf_mblen(buf);
+	}
+
+	result = palloc(size + VARHDRSZ);
+	SET_VARSIZE(result, size + VARHDRSZ);
+
+	p = (unsigned char *) VARDATA_ANY(result);
+	for (pg_wchar *wp = output_chars; *wp; wp++)
+	{
+		unicode_to_utf8(*wp, p);
+		p += pg_utf_mblen(p);
+	}
+	Assert((char *) p == (char *) result + size + VARHDRSZ);
+
+	PG_RETURN_TEXT_P(result);
+}
+
+/*
+ * Check whether the string is in the specified Unicode normalization form.
+ *
+ * This is done by convering the string to the specified normal form and then
+ * comparing that to the original string.  To speed that up, we also apply the
+ * "quick check" algorithm specified in UAX #15, which can give a yes or no
+ * answer for many strings by just scanning the string once.
+ *
+ * This function should generally be optimized for the case where the string
+ * is in fact normalized.  In that case, we'll end up looking at the entire
+ * string, so it's probably not worth doing any incremental conversion etc.
+ */
+Datum
+unicode_is_normalized(PG_FUNCTION_ARGS)
+{
+	text	   *input = PG_GETARG_TEXT_PP(0);
+	char	   *formstr = text_to_cstring(PG_GETARG_TEXT_PP(1));
+	UnicodeNormalizationForm form;
+	int			size;
+	pg_wchar   *input_chars;
+	pg_wchar   *output_chars;
+	unsigned char *p;
+	int			i;
+	UnicodeNormalizationQC quickcheck;
+	int			output_size;
+	bool		result;
+
+	form = unicode_norm_form_from_string(formstr);
+
+	/* convert to pg_wchar */
+	size = pg_mbstrlen_with_len(VARDATA_ANY(input), VARSIZE_ANY_EXHDR(input));
+	input_chars = palloc((size + 1) * sizeof(pg_wchar));
+	p = (unsigned char *) VARDATA_ANY(input);
+	for (i = 0; i < size; i++)
+	{
+		input_chars[i] = utf8_to_unicode(p);
+		p += pg_utf_mblen(p);
+	}
+	input_chars[i] = (pg_wchar) '\0';
+	Assert((char *) p == VARDATA_ANY(input) + VARSIZE_ANY_EXHDR(input));
+
+	/* quick check (see UAX #15) */
+	quickcheck = unicode_is_normalized_quickcheck(form, input_chars);
+	if (quickcheck == UNICODE_NORM_QC_YES)
+		PG_RETURN_BOOL(true);
+	else if (quickcheck == UNICODE_NORM_QC_NO)
+		PG_RETURN_BOOL(false);
+
+	/* normalize and compare with original */
+	output_chars = unicode_normalize(form, input_chars);
+
+	output_size = 0;
+	for (pg_wchar *wp = output_chars; *wp; wp++)
+		output_size++;
+
+	result = (size == output_size) &&
+		(memcmp(input_chars, output_chars, size * sizeof(pg_wchar)) == 0);
+
+	PG_RETURN_BOOL(result);
+}
diff --git a/src/common/unicode/.gitignore b/src/common/unicode/.gitignore
index b5a4d84274..512862e538 100644
--- a/src/common/unicode/.gitignore
+++ b/src/common/unicode/.gitignore
@@ -3,5 +3,6 @@
 
 # Downloaded files
 /CompositionExclusions.txt
+/DerivedNormalizationProps.txt
 /NormalizationTest.txt
 /UnicodeData.txt
diff --git a/src/common/unicode/Makefile b/src/common/unicode/Makefile
index ec78aeec2a..7a37ec7b55 100644
--- a/src/common/unicode/Makefile
+++ b/src/common/unicode/Makefile
@@ -18,14 +18,14 @@ LIBS += $(PTHREAD_LIBS)
 # By default, do nothing.
 all:
 
-update-unicode: unicode_norm_table.h unicode_combining_table.h
+update-unicode: unicode_norm_table.h unicode_combining_table.h unicode_normprops_table.h
 	$(MAKE) normalization-check
-	mv unicode_norm_table.h unicode_combining_table.h ../../../src/include/common/
+	mv $^ ../../../src/include/common/
 
 # These files are part of the Unicode Character Database. Download
 # them on demand.  The dependency on Makefile.global is for
 # UNICODE_VERSION.
-UnicodeData.txt CompositionExclusions.txt NormalizationTest.txt: $(top_builddir)/src/Makefile.global
+UnicodeData.txt DerivedNormalizationProps.txt CompositionExclusions.txt NormalizationTest.txt: $(top_builddir)/src/Makefile.global
 	$(DOWNLOAD) https://www.unicode.org/Public/$(UNICODE_VERSION)/ucd/$(@F)
 
 # Generation of conversion tables used for string normalization with
@@ -36,6 +36,9 @@ unicode_norm_table.h: generate-unicode_norm_table.pl UnicodeData.txt Composition
 unicode_combining_table.h: generate-unicode_combining_table.pl UnicodeData.txt
 	$(PERL) $^ >$@
 
+unicode_normprops_table.h: generate-unicode_normprops_table.pl DerivedNormalizationProps.txt
+	$(PERL) $^ >$@
+
 # Test suite
 normalization-check: norm_test
 	./norm_test
diff --git a/src/common/unicode/generate-unicode_normprops_table.pl b/src/common/unicode/generate-unicode_normprops_table.pl
new file mode 100644
index 0000000000..fb1461635d
--- /dev/null
+++ b/src/common/unicode/generate-unicode_normprops_table.pl
@@ -0,0 +1,79 @@
+#!/usr/bin/perl
+#
+# Generate table of Unicode normalization "quick check" properties
+# (see UAX #15).  Pass DerivedNormalizationProps.txt as argument.  The
+# output is on stdout.
+#
+# Copyright (c) 2020, PostgreSQL Global Development Group
+
+use strict;
+use warnings;
+
+my %data;
+
+print "/* generated by src/common/unicode/generate-unicode_normprops_table.pl, do not edit */\n\n";
+
+print <<EOS;
+#include "common/unicode_norm.h"
+
+typedef struct
+{
+	uint32		codepoint;
+	UnicodeNormalizationQC quickcheck;
+} pg_unicode_normprops;
+EOS
+
+foreach my $line (<ARGV>)
+{
+	chomp $line;
+	$line =~ s/\s*#.*$//;
+	next if $line eq '';
+	my ($codepoint, $prop, $value) = split/\s*;\s*/, $line;
+	next if $prop !~ /_QC/;
+
+	my ($first, $last);
+	if ($codepoint =~ /\.\./)
+	{
+		($first, $last) = split /\.\./, $codepoint;
+	}
+	else
+	{
+		$first = $last = $codepoint;
+	}
+
+	foreach my $i (hex($first)..hex($last))
+	{
+		$data{$prop}{$i} = $value;
+	}
+}
+
+# We create a separate array for each normalization form rather than,
+# say, a two-dimensional array, because that array would be very
+# sparse and would create unnecessary overhead especially for the NFC
+# lookup.
+foreach my $key (sort keys %data)
+{
+	print "\n";
+	print "static const pg_unicode_normprops UnicodeNormProps_${key}[] = {\n";
+
+	my %subdata = %{$data{$key}};
+	foreach my $cp (sort { $a <=> $b } keys %subdata)
+	{
+		my $qc;
+		if ($subdata{$cp} eq 'N')
+		{
+			$qc = 'UNICODE_NORM_QC_NO';
+		}
+		elsif ($subdata{$cp} eq 'M')
+		{
+			$qc = 'UNICODE_NORM_QC_MAYBE';
+		}
+		else
+		{
+			die;
+		}
+		printf "\t{0x%04X, %s},\n", $cp, $qc;
+	}
+
+	print "};\n";
+}
diff --git a/src/common/unicode_norm.c b/src/common/unicode_norm.c
index a88959f0fc..91a56d4005 100644
--- a/src/common/unicode_norm.c
+++ b/src/common/unicode_norm.c
@@ -20,6 +20,7 @@
 
 #include "common/unicode_norm.h"
 #include "common/unicode_norm_table.h"
+#include "common/unicode_normprops_table.h"
 
 #ifndef FRONTEND
 #define ALLOC(size) palloc(size)
@@ -442,3 +443,103 @@ unicode_normalize(UnicodeNormalizationForm form, const pg_wchar *input)
 
 	return recomp_chars;
 }
+
+/*
+ * Normalization "quick check" algorithm; see
+ * <http://www.unicode.org/reports/tr15/#Detecting_Normalization_Forms>
+ */
+
+static uint8
+get_canonical_class(pg_wchar ch)
+{
+	pg_unicode_decomposition *entry = get_code_entry(ch);
+
+	if (!entry)
+		return 0;
+	else
+		return entry->comb_class;
+}
+
+static int
+qc_compare(const void *p1, const void *p2)
+{
+	uint32		v1,
+				v2;
+
+	v1 = ((const pg_unicode_normprops *) p1)->codepoint;
+	v2 = ((const pg_unicode_normprops *) p2)->codepoint;
+	return (v1 - v2);
+}
+
+/*
+ * Look up the normalization quick check character property
+ */
+static UnicodeNormalizationQC
+qc_is_allowed(UnicodeNormalizationForm form, pg_wchar ch)
+{
+	pg_unicode_normprops *entry = NULL;
+
+	switch (form)
+	{
+		case UNICODE_NFC:
+			entry = bsearch(&ch,
+							UnicodeNormProps_NFC_QC,
+							lengthof(UnicodeNormProps_NFC_QC),
+							sizeof(pg_unicode_normprops),
+							qc_compare);
+			break;
+		case UNICODE_NFD:
+			entry = bsearch(&ch,
+							UnicodeNormProps_NFD_QC,
+							lengthof(UnicodeNormProps_NFD_QC),
+							sizeof(pg_unicode_normprops),
+							qc_compare);
+			break;
+		case UNICODE_NFKC:
+			entry = bsearch(&ch,
+							UnicodeNormProps_NFKC_QC,
+							lengthof(UnicodeNormProps_NFKC_QC),
+							sizeof(pg_unicode_normprops),
+							qc_compare);
+			break;
+		case UNICODE_NFKD:
+			entry = bsearch(&ch,
+							UnicodeNormProps_NFKD_QC,
+							lengthof(UnicodeNormProps_NFKD_QC),
+							sizeof(pg_unicode_normprops),
+							qc_compare);
+			break;
+	}
+
+	if (entry)
+		return entry->quickcheck;
+	else
+		return UNICODE_NORM_QC_YES;
+}
+
+UnicodeNormalizationQC
+unicode_is_normalized_quickcheck(UnicodeNormalizationForm form, const pg_wchar *input)
+{
+	uint8		lastCanonicalClass = 0;
+	UnicodeNormalizationQC result = UNICODE_NORM_QC_YES;
+
+	for (const pg_wchar *p = input; *p; p++)
+	{
+		pg_wchar	ch = *p;
+		uint8		canonicalClass;
+		UnicodeNormalizationQC check;
+
+		canonicalClass = get_canonical_class(ch);
+		if (lastCanonicalClass > canonicalClass && canonicalClass != 0)
+			return UNICODE_NORM_QC_NO;
+
+		check = qc_is_allowed(form, ch);
+		if (check == UNICODE_NORM_QC_NO)
+			return UNICODE_NORM_QC_NO;
+		if (check == UNICODE_NORM_QC_MAYBE)
+			result = UNICODE_NORM_QC_MAYBE;
+
+		lastCanonicalClass = canonicalClass;
+	}
+	return result;
+}
diff --git a/src/include/catalog/pg_proc.dat b/src/include/catalog/pg_proc.dat
index bef50c76d9..83b54922bb 100644
--- a/src/include/catalog/pg_proc.dat
+++ b/src/include/catalog/pg_proc.dat
@@ -10768,4 +10768,12 @@
   proname => 'pg_partition_root', prorettype => 'regclass',
   proargtypes => 'regclass', prosrc => 'pg_partition_root' },
 
+{ oid => '4350', descr => 'Unicode normalization',
+  proname => 'normalize', prorettype => 'text',
+  proargtypes => 'text text', prosrc => 'unicode_normalize_func' },
+
+{ oid => '4351', descr => 'check Unicode normalization',
+  proname => 'is_normalized', prorettype => 'bool',
+  proargtypes => 'text text', prosrc => 'unicode_is_normalized' },
+
 ]
diff --git a/src/include/common/unicode_norm.h b/src/include/common/unicode_norm.h
index 9a5e250bcf..731e05bf7d 100644
--- a/src/include/common/unicode_norm.h
+++ b/src/include/common/unicode_norm.h
@@ -24,6 +24,16 @@ typedef enum
 	UNICODE_NFKD = 3,
 } UnicodeNormalizationForm;
 
+/* see UAX #15 */
+typedef enum
+{
+	UNICODE_NORM_QC_NO = 0,
+	UNICODE_NORM_QC_YES = 1,
+	UNICODE_NORM_QC_MAYBE = -1,
+} UnicodeNormalizationQC;
+
 extern pg_wchar *unicode_normalize(UnicodeNormalizationForm form, const pg_wchar *input);
 
+extern UnicodeNormalizationQC unicode_is_normalized_quickcheck(UnicodeNormalizationForm form, const pg_wchar *input);
+
 #endif							/* UNICODE_NORM_H */
diff --git a/src/include/common/unicode_normprops_table.h b/src/include/common/unicode_normprops_table.h
new file mode 100644
index 0000000000..4515142dd3
--- /dev/null
+++ b/src/include/common/unicode_normprops_table.h
@@ -0,0 +1,36285 @@
+/* generated by src/common/unicode/generate-unicode_normprops_table.pl, do not edit */
+
+#include "common/unicode_norm.h"
+
+typedef struct
+{
+	uint32		codepoint;
+	UnicodeNormalizationQC quickcheck;
+} pg_unicode_normprops;
+
+static const pg_unicode_normprops UnicodeNormProps_NFC_QC[] = {
+	{0x0300, UNICODE_NORM_QC_MAYBE},
+	{0x0301, UNICODE_NORM_QC_MAYBE},
+	{0x0302, UNICODE_NORM_QC_MAYBE},
+	{0x0303, UNICODE_NORM_QC_MAYBE},
+	{0x0304, UNICODE_NORM_QC_MAYBE},
+	{0x0306, UNICODE_NORM_QC_MAYBE},
+	{0x0307, UNICODE_NORM_QC_MAYBE},
+	{0x0308, UNICODE_NORM_QC_MAYBE},
+	{0x0309, UNICODE_NORM_QC_MAYBE},
+	{0x030A, UNICODE_NORM_QC_MAYBE},
+	{0x030B, UNICODE_NORM_QC_MAYBE},
+	{0x030C, UNICODE_NORM_QC_MAYBE},
+	{0x030F, UNICODE_NORM_QC_MAYBE},
+	{0x0311, UNICODE_NORM_QC_MAYBE},
+	{0x0313, UNICODE_NORM_QC_MAYBE},
+	{0x0314, UNICODE_NORM_QC_MAYBE},
+	{0x031B, UNICODE_NORM_QC_MAYBE},
+	{0x0323, UNICODE_NORM_QC_MAYBE},
+	{0x0324, UNICODE_NORM_QC_MAYBE},
+	{0x0325, UNICODE_NORM_QC_MAYBE},
+	{0x0326, UNICODE_NORM_QC_MAYBE},
+	{0x0327, UNICODE_NORM_QC_MAYBE},
+	{0x0328, UNICODE_NORM_QC_MAYBE},
+	{0x032D, UNICODE_NORM_QC_MAYBE},
+	{0x032E, UNICODE_NORM_QC_MAYBE},
+	{0x0330, UNICODE_NORM_QC_MAYBE},
+	{0x0331, UNICODE_NORM_QC_MAYBE},
+	{0x0338, UNICODE_NORM_QC_MAYBE},
+	{0x0340, UNICODE_NORM_QC_NO},
+	{0x0341, UNICODE_NORM_QC_NO},
+	{0x0342, UNICODE_NORM_QC_MAYBE},
+	{0x0343, UNICODE_NORM_QC_NO},
+	{0x0344, UNICODE_NORM_QC_NO},
+	{0x0345, UNICODE_NORM_QC_MAYBE},
+	{0x0374, UNICODE_NORM_QC_NO},
+	{0x037E, UNICODE_NORM_QC_NO},
+	{0x0387, UNICODE_NORM_QC_NO},
+	{0x0653, UNICODE_NORM_QC_MAYBE},
+	{0x0654, UNICODE_NORM_QC_MAYBE},
+	{0x0655, UNICODE_NORM_QC_MAYBE},
+	{0x093C, UNICODE_NORM_QC_MAYBE},
+	{0x0958, UNICODE_NORM_QC_NO},
+	{0x0959, UNICODE_NORM_QC_NO},
+	{0x095A, UNICODE_NORM_QC_NO},
+	{0x095B, UNICODE_NORM_QC_NO},
+	{0x095C, UNICODE_NORM_QC_NO},
+	{0x095D, UNICODE_NORM_QC_NO},
+	{0x095E, UNICODE_NORM_QC_NO},
+	{0x095F, UNICODE_NORM_QC_NO},
+	{0x09BE, UNICODE_NORM_QC_MAYBE},
+	{0x09D7, UNICODE_NORM_QC_MAYBE},
+	{0x09DC, UNICODE_NORM_QC_NO},
+	{0x09DD, UNICODE_NORM_QC_NO},
+	{0x09DF, UNICODE_NORM_QC_NO},
+	{0x0A33, UNICODE_NORM_QC_NO},
+	{0x0A36, UNICODE_NORM_QC_NO},
+	{0x0A59, UNICODE_NORM_QC_NO},
+	{0x0A5A, UNICODE_NORM_QC_NO},
+	{0x0A5B, UNICODE_NORM_QC_NO},
+	{0x0A5E, UNICODE_NORM_QC_NO},
+	{0x0B3E, UNICODE_NORM_QC_MAYBE},
+	{0x0B56, UNICODE_NORM_QC_MAYBE},
+	{0x0B57, UNICODE_NORM_QC_MAYBE},
+	{0x0B5C, UNICODE_NORM_QC_NO},
+	{0x0B5D, UNICODE_NORM_QC_NO},
+	{0x0BBE, UNICODE_NORM_QC_MAYBE},
+	{0x0BD7, UNICODE_NORM_QC_MAYBE},
+	{0x0C56, UNICODE_NORM_QC_MAYBE},
+	{0x0CC2, UNICODE_NORM_QC_MAYBE},
+	{0x0CD5, UNICODE_NORM_QC_MAYBE},
+	{0x0CD6, UNICODE_NORM_QC_MAYBE},
+	{0x0D3E, UNICODE_NORM_QC_MAYBE},
+	{0x0D57, UNICODE_NORM_QC_MAYBE},
+	{0x0DCA, UNICODE_NORM_QC_MAYBE},
+	{0x0DCF, UNICODE_NORM_QC_MAYBE},
+	{0x0DDF, UNICODE_NORM_QC_MAYBE},
+	{0x0F43, UNICODE_NORM_QC_NO},
+	{0x0F4D, UNICODE_NORM_QC_NO},
+	{0x0F52, UNICODE_NORM_QC_NO},
+	{0x0F57, UNICODE_NORM_QC_NO},
+	{0x0F5C, UNICODE_NORM_QC_NO},
+	{0x0F69, UNICODE_NORM_QC_NO},
+	{0x0F73, UNICODE_NORM_QC_NO},
+	{0x0F75, UNICODE_NORM_QC_NO},
+	{0x0F76, UNICODE_NORM_QC_NO},
+	{0x0F78, UNICODE_NORM_QC_NO},
+	{0x0F81, UNICODE_NORM_QC_NO},
+	{0x0F93, UNICODE_NORM_QC_NO},
+	{0x0F9D, UNICODE_NORM_QC_NO},
+	{0x0FA2, UNICODE_NORM_QC_NO},
+	{0x0FA7, UNICODE_NORM_QC_NO},
+	{0x0FAC, UNICODE_NORM_QC_NO},
+	{0x0FB9, UNICODE_NORM_QC_NO},
+	{0x102E, UNICODE_NORM_QC_MAYBE},
+	{0x1161, UNICODE_NORM_QC_MAYBE},
+	{0x1162, UNICODE_NORM_QC_MAYBE},
+	{0x1163, UNICODE_NORM_QC_MAYBE},
+	{0x1164, UNICODE_NORM_QC_MAYBE},
+	{0x1165, UNICODE_NORM_QC_MAYBE},
+	{0x1166, UNICODE_NORM_QC_MAYBE},
+	{0x1167, UNICODE_NORM_QC_MAYBE},
+	{0x1168, UNICODE_NORM_QC_MAYBE},
+	{0x1169, UNICODE_NORM_QC_MAYBE},
+	{0x116A, UNICODE_NORM_QC_MAYBE},
+	{0x116B, UNICODE_NORM_QC_MAYBE},
+	{0x116C, UNICODE_NORM_QC_MAYBE},
+	{0x116D, UNICODE_NORM_QC_MAYBE},
+	{0x116E, UNICODE_NORM_QC_MAYBE},
+	{0x116F, UNICODE_NORM_QC_MAYBE},
+	{0x1170, UNICODE_NORM_QC_MAYBE},
+	{0x1171, UNICODE_NORM_QC_MAYBE},
+	{0x1172, UNICODE_NORM_QC_MAYBE},
+	{0x1173, UNICODE_NORM_QC_MAYBE},
+	{0x1174, UNICODE_NORM_QC_MAYBE},
+	{0x1175, UNICODE_NORM_QC_MAYBE},
+	{0x11A8, UNICODE_NORM_QC_MAYBE},
+	{0x11A9, UNICODE_NORM_QC_MAYBE},
+	{0x11AA, UNICODE_NORM_QC_MAYBE},
+	{0x11AB, UNICODE_NORM_QC_MAYBE},
+	{0x11AC, UNICODE_NORM_QC_MAYBE},
+	{0x11AD, UNICODE_NORM_QC_MAYBE},
+	{0x11AE, UNICODE_NORM_QC_MAYBE},
+	{0x11AF, UNICODE_NORM_QC_MAYBE},
+	{0x11B0, UNICODE_NORM_QC_MAYBE},
+	{0x11B1, UNICODE_NORM_QC_MAYBE},
+	{0x11B2, UNICODE_NORM_QC_MAYBE},
+	{0x11B3, UNICODE_NORM_QC_MAYBE},
+	{0x11B4, UNICODE_NORM_QC_MAYBE},
+	{0x11B5, UNICODE_NORM_QC_MAYBE},
+	{0x11B6, UNICODE_NORM_QC_MAYBE},
+	{0x11B7, UNICODE_NORM_QC_MAYBE},
+	{0x11B8, UNICODE_NORM_QC_MAYBE},
+	{0x11B9, UNICODE_NORM_QC_MAYBE},
+	{0x11BA, UNICODE_NORM_QC_MAYBE},
+	{0x11BB, UNICODE_NORM_QC_MAYBE},
+	{0x11BC, UNICODE_NORM_QC_MAYBE},
+	{0x11BD, UNICODE_NORM_QC_MAYBE},
+	{0x11BE, UNICODE_NORM_QC_MAYBE},
+	{0x11BF, UNICODE_NORM_QC_MAYBE},
+	{0x11C0, UNICODE_NORM_QC_MAYBE},
+	{0x11C1, UNICODE_NORM_QC_MAYBE},
+	{0x11C2, UNICODE_NORM_QC_MAYBE},
+	{0x1B35, UNICODE_NORM_QC_MAYBE},
+	{0x1F71, UNICODE_NORM_QC_NO},
+	{0x1F73, UNICODE_NORM_QC_NO},
+	{0x1F75, UNICODE_NORM_QC_NO},
+	{0x1F77, UNICODE_NORM_QC_NO},
+	{0x1F79, UNICODE_NORM_QC_NO},
+	{0x1F7B, UNICODE_NORM_QC_NO},
+	{0x1F7D, UNICODE_NORM_QC_NO},
+	{0x1FBB, UNICODE_NORM_QC_NO},
+	{0x1FBE, UNICODE_NORM_QC_NO},
+	{0x1FC9, UNICODE_NORM_QC_NO},
+	{0x1FCB, UNICODE_NORM_QC_NO},
+	{0x1FD3, UNICODE_NORM_QC_NO},
+	{0x1FDB, UNICODE_NORM_QC_NO},
+	{0x1FE3, UNICODE_NORM_QC_NO},
+	{0x1FEB, UNICODE_NORM_QC_NO},
+	{0x1FEE, UNICODE_NORM_QC_NO},
+	{0x1FEF, UNICODE_NORM_QC_NO},
+	{0x1FF9, UNICODE_NORM_QC_NO},
+	{0x1FFB, UNICODE_NORM_QC_NO},
+	{0x1FFD, UNICODE_NORM_QC_NO},
+	{0x2000, UNICODE_NORM_QC_NO},
+	{0x2001, UNICODE_NORM_QC_NO},
+	{0x2126, UNICODE_NORM_QC_NO},
+	{0x212A, UNICODE_NORM_QC_NO},
+	{0x212B, UNICODE_NORM_QC_NO},
+	{0x2329, UNICODE_NORM_QC_NO},
+	{0x232A, UNICODE_NORM_QC_NO},
+	{0x2ADC, UNICODE_NORM_QC_NO},
+	{0x3099, UNICODE_NORM_QC_MAYBE},
+	{0x309A, UNICODE_NORM_QC_MAYBE},
+	{0xF900, UNICODE_NORM_QC_NO},
+	{0xF901, UNICODE_NORM_QC_NO},
+	{0xF902, UNICODE_NORM_QC_NO},
+	{0xF903, UNICODE_NORM_QC_NO},
+	{0xF904, UNICODE_NORM_QC_NO},
+	{0xF905, UNICODE_NORM_QC_NO},
+	{0xF906, UNICODE_NORM_QC_NO},
+	{0xF907, UNICODE_NORM_QC_NO},
+	{0xF908, UNICODE_NORM_QC_NO},
+	{0xF909, UNICODE_NORM_QC_NO},
+	{0xF90A, UNICODE_NORM_QC_NO},
+	{0xF90B, UNICODE_NORM_QC_NO},
+	{0xF90C, UNICODE_NORM_QC_NO},
+	{0xF90D, UNICODE_NORM_QC_NO},
+	{0xF90E, UNICODE_NORM_QC_NO},
+	{0xF90F, UNICODE_NORM_QC_NO},
+	{0xF910, UNICODE_NORM_QC_NO},
+	{0xF911, UNICODE_NORM_QC_NO},
+	{0xF912, UNICODE_NORM_QC_NO},
+	{0xF913, UNICODE_NORM_QC_NO},
+	{0xF914, UNICODE_NORM_QC_NO},
+	{0xF915, UNICODE_NORM_QC_NO},
+	{0xF916, UNICODE_NORM_QC_NO},
+	{0xF917, UNICODE_NORM_QC_NO},
+	{0xF918, UNICODE_NORM_QC_NO},
+	{0xF919, UNICODE_NORM_QC_NO},
+	{0xF91A, UNICODE_NORM_QC_NO},
+	{0xF91B, UNICODE_NORM_QC_NO},
+	{0xF91C, UNICODE_NORM_QC_NO},
+	{0xF91D, UNICODE_NORM_QC_NO},
+	{0xF91E, UNICODE_NORM_QC_NO},
+	{0xF91F, UNICODE_NORM_QC_NO},
+	{0xF920, UNICODE_NORM_QC_NO},
+	{0xF921, UNICODE_NORM_QC_NO},
+	{0xF922, UNICODE_NORM_QC_NO},
+	{0xF923, UNICODE_NORM_QC_NO},
+	{0xF924, UNICODE_NORM_QC_NO},
+	{0xF925, UNICODE_NORM_QC_NO},
+	{0xF926, UNICODE_NORM_QC_NO},
+	{0xF927, UNICODE_NORM_QC_NO},
+	{0xF928, UNICODE_NORM_QC_NO},
+	{0xF929, UNICODE_NORM_QC_NO},
+	{0xF92A, UNICODE_NORM_QC_NO},
+	{0xF92B, UNICODE_NORM_QC_NO},
+	{0xF92C, UNICODE_NORM_QC_NO},
+	{0xF92D, UNICODE_NORM_QC_NO},
+	{0xF92E, UNICODE_NORM_QC_NO},
+	{0xF92F, UNICODE_NORM_QC_NO},
+	{0xF930, UNICODE_NORM_QC_NO},
+	{0xF931, UNICODE_NORM_QC_NO},
+	{0xF932, UNICODE_NORM_QC_NO},
+	{0xF933, UNICODE_NORM_QC_NO},
+	{0xF934, UNICODE_NORM_QC_NO},
+	{0xF935, UNICODE_NORM_QC_NO},
+	{0xF936, UNICODE_NORM_QC_NO},
+	{0xF937, UNICODE_NORM_QC_NO},
+	{0xF938, UNICODE_NORM_QC_NO},
+	{0xF939, UNICODE_NORM_QC_NO},
+	{0xF93A, UNICODE_NORM_QC_NO},
+	{0xF93B, UNICODE_NORM_QC_NO},
+	{0xF93C, UNICODE_NORM_QC_NO},
+	{0xF93D, UNICODE_NORM_QC_NO},
+	{0xF93E, UNICODE_NORM_QC_NO},
+	{0xF93F, UNICODE_NORM_QC_NO},
+	{0xF940, UNICODE_NORM_QC_NO},
+	{0xF941, UNICODE_NORM_QC_NO},
+	{0xF942, UNICODE_NORM_QC_NO},
+	{0xF943, UNICODE_NORM_QC_NO},
+	{0xF944, UNICODE_NORM_QC_NO},
+	{0xF945, UNICODE_NORM_QC_NO},
+	{0xF946, UNICODE_NORM_QC_NO},
+	{0xF947, UNICODE_NORM_QC_NO},
+	{0xF948, UNICODE_NORM_QC_NO},
+	{0xF949, UNICODE_NORM_QC_NO},
+	{0xF94A, UNICODE_NORM_QC_NO},
+	{0xF94B, UNICODE_NORM_QC_NO},
+	{0xF94C, UNICODE_NORM_QC_NO},
+	{0xF94D, UNICODE_NORM_QC_NO},
+	{0xF94E, UNICODE_NORM_QC_NO},
+	{0xF94F, UNICODE_NORM_QC_NO},
+	{0xF950, UNICODE_NORM_QC_NO},
+	{0xF951, UNICODE_NORM_QC_NO},
+	{0xF952, UNICODE_NORM_QC_NO},
+	{0xF953, UNICODE_NORM_QC_NO},
+	{0xF954, UNICODE_NORM_QC_NO},
+	{0xF955, UNICODE_NORM_QC_NO},
+	{0xF956, UNICODE_NORM_QC_NO},
+	{0xF957, UNICODE_NORM_QC_NO},
+	{0xF958, UNICODE_NORM_QC_NO},
+	{0xF959, UNICODE_NORM_QC_NO},
+	{0xF95A, UNICODE_NORM_QC_NO},
+	{0xF95B, UNICODE_NORM_QC_NO},
+	{0xF95C, UNICODE_NORM_QC_NO},
+	{0xF95D, UNICODE_NORM_QC_NO},
+	{0xF95E, UNICODE_NORM_QC_NO},
+	{0xF95F, UNICODE_NORM_QC_NO},
+	{0xF960, UNICODE_NORM_QC_NO},
+	{0xF961, UNICODE_NORM_QC_NO},
+	{0xF962, UNICODE_NORM_QC_NO},
+	{0xF963, UNICODE_NORM_QC_NO},
+	{0xF964, UNICODE_NORM_QC_NO},
+	{0xF965, UNICODE_NORM_QC_NO},
+	{0xF966, UNICODE_NORM_QC_NO},
+	{0xF967, UNICODE_NORM_QC_NO},
+	{0xF968, UNICODE_NORM_QC_NO},
+	{0xF969, UNICODE_NORM_QC_NO},
+	{0xF96A, UNICODE_NORM_QC_NO},
+	{0xF96B, UNICODE_NORM_QC_NO},
+	{0xF96C, UNICODE_NORM_QC_NO},
+	{0xF96D, UNICODE_NORM_QC_NO},
+	{0xF96E, UNICODE_NORM_QC_NO},
+	{0xF96F, UNICODE_NORM_QC_NO},
+	{0xF970, UNICODE_NORM_QC_NO},
+	{0xF971, UNICODE_NORM_QC_NO},
+	{0xF972, UNICODE_NORM_QC_NO},
+	{0xF973, UNICODE_NORM_QC_NO},
+	{0xF974, UNICODE_NORM_QC_NO},
+	{0xF975, UNICODE_NORM_QC_NO},
+	{0xF976, UNICODE_NORM_QC_NO},
+	{0xF977, UNICODE_NORM_QC_NO},
+	{0xF978, UNICODE_NORM_QC_NO},
+	{0xF979, UNICODE_NORM_QC_NO},
+	{0xF97A, UNICODE_NORM_QC_NO},
+	{0xF97B, UNICODE_NORM_QC_NO},
+	{0xF97C, UNICODE_NORM_QC_NO},
+	{0xF97D, UNICODE_NORM_QC_NO},
+	{0xF97E, UNICODE_NORM_QC_NO},
+	{0xF97F, UNICODE_NORM_QC_NO},
+	{0xF980, UNICODE_NORM_QC_NO},
+	{0xF981, UNICODE_NORM_QC_NO},
+	{0xF982, UNICODE_NORM_QC_NO},
+	{0xF983, UNICODE_NORM_QC_NO},
+	{0xF984, UNICODE_NORM_QC_NO},
+	{0xF985, UNICODE_NORM_QC_NO},
+	{0xF986, UNICODE_NORM_QC_NO},
+	{0xF987, UNICODE_NORM_QC_NO},
+	{0xF988, UNICODE_NORM_QC_NO},
+	{0xF989, UNICODE_NORM_QC_NO},
+	{0xF98A, UNICODE_NORM_QC_NO},
+	{0xF98B, UNICODE_NORM_QC_NO},
+	{0xF98C, UNICODE_NORM_QC_NO},
+	{0xF98D, UNICODE_NORM_QC_NO},
+	{0xF98E, UNICODE_NORM_QC_NO},
+	{0xF98F, UNICODE_NORM_QC_NO},
+	{0xF990, UNICODE_NORM_QC_NO},
+	{0xF991, UNICODE_NORM_QC_NO},
+	{0xF992, UNICODE_NORM_QC_NO},
+	{0xF993, UNICODE_NORM_QC_NO},
+	{0xF994, UNICODE_NORM_QC_NO},
+	{0xF995, UNICODE_NORM_QC_NO},
+	{0xF996, UNICODE_NORM_QC_NO},
+	{0xF997, UNICODE_NORM_QC_NO},
+	{0xF998, UNICODE_NORM_QC_NO},
+	{0xF999, UNICODE_NORM_QC_NO},
+	{0xF99A, UNICODE_NORM_QC_NO},
+	{0xF99B, UNICODE_NORM_QC_NO},
+	{0xF99C, UNICODE_NORM_QC_NO},
+	{0xF99D, UNICODE_NORM_QC_NO},
+	{0xF99E, UNICODE_NORM_QC_NO},
+	{0xF99F, UNICODE_NORM_QC_NO},
+	{0xF9A0, UNICODE_NORM_QC_NO},
+	{0xF9A1, UNICODE_NORM_QC_NO},
+	{0xF9A2, UNICODE_NORM_QC_NO},
+	{0xF9A3, UNICODE_NORM_QC_NO},
+	{0xF9A4, UNICODE_NORM_QC_NO},
+	{0xF9A5, UNICODE_NORM_QC_NO},
+	{0xF9A6, UNICODE_NORM_QC_NO},
+	{0xF9A7, UNICODE_NORM_QC_NO},
+	{0xF9A8, UNICODE_NORM_QC_NO},
+	{0xF9A9, UNICODE_NORM_QC_NO},
+	{0xF9AA, UNICODE_NORM_QC_NO},
+	{0xF9AB, UNICODE_NORM_QC_NO},
+	{0xF9AC, UNICODE_NORM_QC_NO},
+	{0xF9AD, UNICODE_NORM_QC_NO},
+	{0xF9AE, UNICODE_NORM_QC_NO},
+	{0xF9AF, UNICODE_NORM_QC_NO},
+	{0xF9B0, UNICODE_NORM_QC_NO},
+	{0xF9B1, UNICODE_NORM_QC_NO},
+	{0xF9B2, UNICODE_NORM_QC_NO},
+	{0xF9B3, UNICODE_NORM_QC_NO},
+	{0xF9B4, UNICODE_NORM_QC_NO},
+	{0xF9B5, UNICODE_NORM_QC_NO},
+	{0xF9B6, UNICODE_NORM_QC_NO},
+	{0xF9B7, UNICODE_NORM_QC_NO},
+	{0xF9B8, UNICODE_NORM_QC_NO},
+	{0xF9B9, UNICODE_NORM_QC_NO},
+	{0xF9BA, UNICODE_NORM_QC_NO},
+	{0xF9BB, UNICODE_NORM_QC_NO},
+	{0xF9BC, UNICODE_NORM_QC_NO},
+	{0xF9BD, UNICODE_NORM_QC_NO},
+	{0xF9BE, UNICODE_NORM_QC_NO},
+	{0xF9BF, UNICODE_NORM_QC_NO},
+	{0xF9C0, UNICODE_NORM_QC_NO},
+	{0xF9C1, UNICODE_NORM_QC_NO},
+	{0xF9C2, UNICODE_NORM_QC_NO},
+	{0xF9C3, UNICODE_NORM_QC_NO},
+	{0xF9C4, UNICODE_NORM_QC_NO},
+	{0xF9C5, UNICODE_NORM_QC_NO},
+	{0xF9C6, UNICODE_NORM_QC_NO},
+	{0xF9C7, UNICODE_NORM_QC_NO},
+	{0xF9C8, UNICODE_NORM_QC_NO},
+	{0xF9C9, UNICODE_NORM_QC_NO},
+	{0xF9CA, UNICODE_NORM_QC_NO},
+	{0xF9CB, UNICODE_NORM_QC_NO},
+	{0xF9CC, UNICODE_NORM_QC_NO},
+	{0xF9CD, UNICODE_NORM_QC_NO},
+	{0xF9CE, UNICODE_NORM_QC_NO},
+	{0xF9CF, UNICODE_NORM_QC_NO},
+	{0xF9D0, UNICODE_NORM_QC_NO},
+	{0xF9D1, UNICODE_NORM_QC_NO},
+	{0xF9D2, UNICODE_NORM_QC_NO},
+	{0xF9D3, UNICODE_NORM_QC_NO},
+	{0xF9D4, UNICODE_NORM_QC_NO},
+	{0xF9D5, UNICODE_NORM_QC_NO},
+	{0xF9D6, UNICODE_NORM_QC_NO},
+	{0xF9D7, UNICODE_NORM_QC_NO},
+	{0xF9D8, UNICODE_NORM_QC_NO},
+	{0xF9D9, UNICODE_NORM_QC_NO},
+	{0xF9DA, UNICODE_NORM_QC_NO},
+	{0xF9DB, UNICODE_NORM_QC_NO},
+	{0xF9DC, UNICODE_NORM_QC_NO},
+	{0xF9DD, UNICODE_NORM_QC_NO},
+	{0xF9DE, UNICODE_NORM_QC_NO},
+	{0xF9DF, UNICODE_NORM_QC_NO},
+	{0xF9E0, UNICODE_NORM_QC_NO},
+	{0xF9E1, UNICODE_NORM_QC_NO},
+	{0xF9E2, UNICODE_NORM_QC_NO},
+	{0xF9E3, UNICODE_NORM_QC_NO},
+	{0xF9E4, UNICODE_NORM_QC_NO},
+	{0xF9E5, UNICODE_NORM_QC_NO},
+	{0xF9E6, UNICODE_NORM_QC_NO},
+	{0xF9E7, UNICODE_NORM_QC_NO},
+	{0xF9E8, UNICODE_NORM_QC_NO},
+	{0xF9E9, UNICODE_NORM_QC_NO},
+	{0xF9EA, UNICODE_NORM_QC_NO},
+	{0xF9EB, UNICODE_NORM_QC_NO},
+	{0xF9EC, UNICODE_NORM_QC_NO},
+	{0xF9ED, UNICODE_NORM_QC_NO},
+	{0xF9EE, UNICODE_NORM_QC_NO},
+	{0xF9EF, UNICODE_NORM_QC_NO},
+	{0xF9F0, UNICODE_NORM_QC_NO},
+	{0xF9F1, UNICODE_NORM_QC_NO},
+	{0xF9F2, UNICODE_NORM_QC_NO},
+	{0xF9F3, UNICODE_NORM_QC_NO},
+	{0xF9F4, UNICODE_NORM_QC_NO},
+	{0xF9F5, UNICODE_NORM_QC_NO},
+	{0xF9F6, UNICODE_NORM_QC_NO},
+	{0xF9F7, UNICODE_NORM_QC_NO},
+	{0xF9F8, UNICODE_NORM_QC_NO},
+	{0xF9F9, UNICODE_NORM_QC_NO},
+	{0xF9FA, UNICODE_NORM_QC_NO},
+	{0xF9FB, UNICODE_NORM_QC_NO},
+	{0xF9FC, UNICODE_NORM_QC_NO},
+	{0xF9FD, UNICODE_NORM_QC_NO},
+	{0xF9FE, UNICODE_NORM_QC_NO},
+	{0xF9FF, UNICODE_NORM_QC_NO},
+	{0xFA00, UNICODE_NORM_QC_NO},
+	{0xFA01, UNICODE_NORM_QC_NO},
+	{0xFA02, UNICODE_NORM_QC_NO},
+	{0xFA03, UNICODE_NORM_QC_NO},
+	{0xFA04, UNICODE_NORM_QC_NO},
+	{0xFA05, UNICODE_NORM_QC_NO},
+	{0xFA06, UNICODE_NORM_QC_NO},
+	{0xFA07, UNICODE_NORM_QC_NO},
+	{0xFA08, UNICODE_NORM_QC_NO},
+	{0xFA09, UNICODE_NORM_QC_NO},
+	{0xFA0A, UNICODE_NORM_QC_NO},
+	{0xFA0B, UNICODE_NORM_QC_NO},
+	{0xFA0C, UNICODE_NORM_QC_NO},
+	{0xFA0D, UNICODE_NORM_QC_NO},
+	{0xFA10, UNICODE_NORM_QC_NO},
+	{0xFA12, UNICODE_NORM_QC_NO},
+	{0xFA15, UNICODE_NORM_QC_NO},
+	{0xFA16, UNICODE_NORM_QC_NO},
+	{0xFA17, UNICODE_NORM_QC_NO},
+	{0xFA18, UNICODE_NORM_QC_NO},
+	{0xFA19, UNICODE_NORM_QC_NO},
+	{0xFA1A, UNICODE_NORM_QC_NO},
+	{0xFA1B, UNICODE_NORM_QC_NO},
+	{0xFA1C, UNICODE_NORM_QC_NO},
+	{0xFA1D, UNICODE_NORM_QC_NO},
+	{0xFA1E, UNICODE_NORM_QC_NO},
+	{0xFA20, UNICODE_NORM_QC_NO},
+	{0xFA22, UNICODE_NORM_QC_NO},
+	{0xFA25, UNICODE_NORM_QC_NO},
+	{0xFA26, UNICODE_NORM_QC_NO},
+	{0xFA2A, UNICODE_NORM_QC_NO},
+	{0xFA2B, UNICODE_NORM_QC_NO},
+	{0xFA2C, UNICODE_NORM_QC_NO},
+	{0xFA2D, UNICODE_NORM_QC_NO},
+	{0xFA2E, UNICODE_NORM_QC_NO},
+	{0xFA2F, UNICODE_NORM_QC_NO},
+	{0xFA30, UNICODE_NORM_QC_NO},
+	{0xFA31, UNICODE_NORM_QC_NO},
+	{0xFA32, UNICODE_NORM_QC_NO},
+	{0xFA33, UNICODE_NORM_QC_NO},
+	{0xFA34, UNICODE_NORM_QC_NO},
+	{0xFA35, UNICODE_NORM_QC_NO},
+	{0xFA36, UNICODE_NORM_QC_NO},
+	{0xFA37, UNICODE_NORM_QC_NO},
+	{0xFA38, UNICODE_NORM_QC_NO},
+	{0xFA39, UNICODE_NORM_QC_NO},
+	{0xFA3A, UNICODE_NORM_QC_NO},
+	{0xFA3B, UNICODE_NORM_QC_NO},
+	{0xFA3C, UNICODE_NORM_QC_NO},
+	{0xFA3D, UNICODE_NORM_QC_NO},
+	{0xFA3E, UNICODE_NORM_QC_NO},
+	{0xFA3F, UNICODE_NORM_QC_NO},
+	{0xFA40, UNICODE_NORM_QC_NO},
+	{0xFA41, UNICODE_NORM_QC_NO},
+	{0xFA42, UNICODE_NORM_QC_NO},
+	{0xFA43, UNICODE_NORM_QC_NO},
+	{0xFA44, UNICODE_NORM_QC_NO},
+	{0xFA45, UNICODE_NORM_QC_NO},
+	{0xFA46, UNICODE_NORM_QC_NO},
+	{0xFA47, UNICODE_NORM_QC_NO},
+	{0xFA48, UNICODE_NORM_QC_NO},
+	{0xFA49, UNICODE_NORM_QC_NO},
+	{0xFA4A, UNICODE_NORM_QC_NO},
+	{0xFA4B, UNICODE_NORM_QC_NO},
+	{0xFA4C, UNICODE_NORM_QC_NO},
+	{0xFA4D, UNICODE_NORM_QC_NO},
+	{0xFA4E, UNICODE_NORM_QC_NO},
+	{0xFA4F, UNICODE_NORM_QC_NO},
+	{0xFA50, UNICODE_NORM_QC_NO},
+	{0xFA51, UNICODE_NORM_QC_NO},
+	{0xFA52, UNICODE_NORM_QC_NO},
+	{0xFA53, UNICODE_NORM_QC_NO},
+	{0xFA54, UNICODE_NORM_QC_NO},
+	{0xFA55, UNICODE_NORM_QC_NO},
+	{0xFA56, UNICODE_NORM_QC_NO},
+	{0xFA57, UNICODE_NORM_QC_NO},
+	{0xFA58, UNICODE_NORM_QC_NO},
+	{0xFA59, UNICODE_NORM_QC_NO},
+	{0xFA5A, UNICODE_NORM_QC_NO},
+	{0xFA5B, UNICODE_NORM_QC_NO},
+	{0xFA5C, UNICODE_NORM_QC_NO},
+	{0xFA5D, UNICODE_NORM_QC_NO},
+	{0xFA5E, UNICODE_NORM_QC_NO},
+	{0xFA5F, UNICODE_NORM_QC_NO},
+	{0xFA60, UNICODE_NORM_QC_NO},
+	{0xFA61, UNICODE_NORM_QC_NO},
+	{0xFA62, UNICODE_NORM_QC_NO},
+	{0xFA63, UNICODE_NORM_QC_NO},
+	{0xFA64, UNICODE_NORM_QC_NO},
+	{0xFA65, UNICODE_NORM_QC_NO},
+	{0xFA66, UNICODE_NORM_QC_NO},
+	{0xFA67, UNICODE_NORM_QC_NO},
+	{0xFA68, UNICODE_NORM_QC_NO},
+	{0xFA69, UNICODE_NORM_QC_NO},
+	{0xFA6A, UNICODE_NORM_QC_NO},
+	{0xFA6B, UNICODE_NORM_QC_NO},
+	{0xFA6C, UNICODE_NORM_QC_NO},
+	{0xFA6D, UNICODE_NORM_QC_NO},
+	{0xFA70, UNICODE_NORM_QC_NO},
+	{0xFA71, UNICODE_NORM_QC_NO},
+	{0xFA72, UNICODE_NORM_QC_NO},
+	{0xFA73, UNICODE_NORM_QC_NO},
+	{0xFA74, UNICODE_NORM_QC_NO},
+	{0xFA75, UNICODE_NORM_QC_NO},
+	{0xFA76, UNICODE_NORM_QC_NO},
+	{0xFA77, UNICODE_NORM_QC_NO},
+	{0xFA78, UNICODE_NORM_QC_NO},
+	{0xFA79, UNICODE_NORM_QC_NO},
+	{0xFA7A, UNICODE_NORM_QC_NO},
+	{0xFA7B, UNICODE_NORM_QC_NO},
+	{0xFA7C, UNICODE_NORM_QC_NO},
+	{0xFA7D, UNICODE_NORM_QC_NO},
+	{0xFA7E, UNICODE_NORM_QC_NO},
+	{0xFA7F, UNICODE_NORM_QC_NO},
+	{0xFA80, UNICODE_NORM_QC_NO},
+	{0xFA81, UNICODE_NORM_QC_NO},
+	{0xFA82, UNICODE_NORM_QC_NO},
+	{0xFA83, UNICODE_NORM_QC_NO},
+	{0xFA84, UNICODE_NORM_QC_NO},
+	{0xFA85, UNICODE_NORM_QC_NO},
+	{0xFA86, UNICODE_NORM_QC_NO},
+	{0xFA87, UNICODE_NORM_QC_NO},
+	{0xFA88, UNICODE_NORM_QC_NO},
+	{0xFA89, UNICODE_NORM_QC_NO},
+	{0xFA8A, UNICODE_NORM_QC_NO},
+	{0xFA8B, UNICODE_NORM_QC_NO},
+	{0xFA8C, UNICODE_NORM_QC_NO},
+	{0xFA8D, UNICODE_NORM_QC_NO},
+	{0xFA8E, UNICODE_NORM_QC_NO},
+	{0xFA8F, UNICODE_NORM_QC_NO},
+	{0xFA90, UNICODE_NORM_QC_NO},
+	{0xFA91, UNICODE_NORM_QC_NO},
+	{0xFA92, UNICODE_NORM_QC_NO},
+	{0xFA93, UNICODE_NORM_QC_NO},
+	{0xFA94, UNICODE_NORM_QC_NO},
+	{0xFA95, UNICODE_NORM_QC_NO},
+	{0xFA96, UNICODE_NORM_QC_NO},
+	{0xFA97, UNICODE_NORM_QC_NO},
+	{0xFA98, UNICODE_NORM_QC_NO},
+	{0xFA99, UNICODE_NORM_QC_NO},
+	{0xFA9A, UNICODE_NORM_QC_NO},
+	{0xFA9B, UNICODE_NORM_QC_NO},
+	{0xFA9C, UNICODE_NORM_QC_NO},
+	{0xFA9D, UNICODE_NORM_QC_NO},
+	{0xFA9E, UNICODE_NORM_QC_NO},
+	{0xFA9F, UNICODE_NORM_QC_NO},
+	{0xFAA0, UNICODE_NORM_QC_NO},
+	{0xFAA1, UNICODE_NORM_QC_NO},
+	{0xFAA2, UNICODE_NORM_QC_NO},
+	{0xFAA3, UNICODE_NORM_QC_NO},
+	{0xFAA4, UNICODE_NORM_QC_NO},
+	{0xFAA5, UNICODE_NORM_QC_NO},
+	{0xFAA6, UNICODE_NORM_QC_NO},
+	{0xFAA7, UNICODE_NORM_QC_NO},
+	{0xFAA8, UNICODE_NORM_QC_NO},
+	{0xFAA9, UNICODE_NORM_QC_NO},
+	{0xFAAA, UNICODE_NORM_QC_NO},
+	{0xFAAB, UNICODE_NORM_QC_NO},
+	{0xFAAC, UNICODE_NORM_QC_NO},
+	{0xFAAD, UNICODE_NORM_QC_NO},
+	{0xFAAE, UNICODE_NORM_QC_NO},
+	{0xFAAF, UNICODE_NORM_QC_NO},
+	{0xFAB0, UNICODE_NORM_QC_NO},
+	{0xFAB1, UNICODE_NORM_QC_NO},
+	{0xFAB2, UNICODE_NORM_QC_NO},
+	{0xFAB3, UNICODE_NORM_QC_NO},
+	{0xFAB4, UNICODE_NORM_QC_NO},
+	{0xFAB5, UNICODE_NORM_QC_NO},
+	{0xFAB6, UNICODE_NORM_QC_NO},
+	{0xFAB7, UNICODE_NORM_QC_NO},
+	{0xFAB8, UNICODE_NORM_QC_NO},
+	{0xFAB9, UNICODE_NORM_QC_NO},
+	{0xFABA, UNICODE_NORM_QC_NO},
+	{0xFABB, UNICODE_NORM_QC_NO},
+	{0xFABC, UNICODE_NORM_QC_NO},
+	{0xFABD, UNICODE_NORM_QC_NO},
+	{0xFABE, UNICODE_NORM_QC_NO},
+	{0xFABF, UNICODE_NORM_QC_NO},
+	{0xFAC0, UNICODE_NORM_QC_NO},
+	{0xFAC1, UNICODE_NORM_QC_NO},
+	{0xFAC2, UNICODE_NORM_QC_NO},
+	{0xFAC3, UNICODE_NORM_QC_NO},
+	{0xFAC4, UNICODE_NORM_QC_NO},
+	{0xFAC5, UNICODE_NORM_QC_NO},
+	{0xFAC6, UNICODE_NORM_QC_NO},
+	{0xFAC7, UNICODE_NORM_QC_NO},
+	{0xFAC8, UNICODE_NORM_QC_NO},
+	{0xFAC9, UNICODE_NORM_QC_NO},
+	{0xFACA, UNICODE_NORM_QC_NO},
+	{0xFACB, UNICODE_NORM_QC_NO},
+	{0xFACC, UNICODE_NORM_QC_NO},
+	{0xFACD, UNICODE_NORM_QC_NO},
+	{0xFACE, UNICODE_NORM_QC_NO},
+	{0xFACF, UNICODE_NORM_QC_NO},
+	{0xFAD0, UNICODE_NORM_QC_NO},
+	{0xFAD1, UNICODE_NORM_QC_NO},
+	{0xFAD2, UNICODE_NORM_QC_NO},
+	{0xFAD3, UNICODE_NORM_QC_NO},
+	{0xFAD4, UNICODE_NORM_QC_NO},
+	{0xFAD5, UNICODE_NORM_QC_NO},
+	{0xFAD6, UNICODE_NORM_QC_NO},
+	{0xFAD7, UNICODE_NORM_QC_NO},
+	{0xFAD8, UNICODE_NORM_QC_NO},
+	{0xFAD9, UNICODE_NORM_QC_NO},
+	{0xFB1D, UNICODE_NORM_QC_NO},
+	{0xFB1F, UNICODE_NORM_QC_NO},
+	{0xFB2A, UNICODE_NORM_QC_NO},
+	{0xFB2B, UNICODE_NORM_QC_NO},
+	{0xFB2C, UNICODE_NORM_QC_NO},
+	{0xFB2D, UNICODE_NORM_QC_NO},
+	{0xFB2E, UNICODE_NORM_QC_NO},
+	{0xFB2F, UNICODE_NORM_QC_NO},
+	{0xFB30, UNICODE_NORM_QC_NO},
+	{0xFB31, UNICODE_NORM_QC_NO},
+	{0xFB32, UNICODE_NORM_QC_NO},
+	{0xFB33, UNICODE_NORM_QC_NO},
+	{0xFB34, UNICODE_NORM_QC_NO},
+	{0xFB35, UNICODE_NORM_QC_NO},
+	{0xFB36, UNICODE_NORM_QC_NO},
+	{0xFB38, UNICODE_NORM_QC_NO},
+	{0xFB39, UNICODE_NORM_QC_NO},
+	{0xFB3A, UNICODE_NORM_QC_NO},
+	{0xFB3B, UNICODE_NORM_QC_NO},
+	{0xFB3C, UNICODE_NORM_QC_NO},
+	{0xFB3E, UNICODE_NORM_QC_NO},
+	{0xFB40, UNICODE_NORM_QC_NO},
+	{0xFB41, UNICODE_NORM_QC_NO},
+	{0xFB43, UNICODE_NORM_QC_NO},
+	{0xFB44, UNICODE_NORM_QC_NO},
+	{0xFB46, UNICODE_NORM_QC_NO},
+	{0xFB47, UNICODE_NORM_QC_NO},
+	{0xFB48, UNICODE_NORM_QC_NO},
+	{0xFB49, UNICODE_NORM_QC_NO},
+	{0xFB4A, UNICODE_NORM_QC_NO},
+	{0xFB4B, UNICODE_NORM_QC_NO},
+	{0xFB4C, UNICODE_NORM_QC_NO},
+	{0xFB4D, UNICODE_NORM_QC_NO},
+	{0xFB4E, UNICODE_NORM_QC_NO},
+	{0x110BA, UNICODE_NORM_QC_MAYBE},
+	{0x11127, UNICODE_NORM_QC_MAYBE},
+	{0x1133E, UNICODE_NORM_QC_MAYBE},
+	{0x11357, UNICODE_NORM_QC_MAYBE},
+	{0x114B0, UNICODE_NORM_QC_MAYBE},
+	{0x114BA, UNICODE_NORM_QC_MAYBE},
+	{0x114BD, UNICODE_NORM_QC_MAYBE},
+	{0x115AF, UNICODE_NORM_QC_MAYBE},
+	{0x1D15E, UNICODE_NORM_QC_NO},
+	{0x1D15F, UNICODE_NORM_QC_NO},
+	{0x1D160, UNICODE_NORM_QC_NO},
+	{0x1D161, UNICODE_NORM_QC_NO},
+	{0x1D162, UNICODE_NORM_QC_NO},
+	{0x1D163, UNICODE_NORM_QC_NO},
+	{0x1D164, UNICODE_NORM_QC_NO},
+	{0x1D1BB, UNICODE_NORM_QC_NO},
+	{0x1D1BC, UNICODE_NORM_QC_NO},
+	{0x1D1BD, UNICODE_NORM_QC_NO},
+	{0x1D1BE, UNICODE_NORM_QC_NO},
+	{0x1D1BF, UNICODE_NORM_QC_NO},
+	{0x1D1C0, UNICODE_NORM_QC_NO},
+	{0x2F800, UNICODE_NORM_QC_NO},
+	{0x2F801, UNICODE_NORM_QC_NO},
+	{0x2F802, UNICODE_NORM_QC_NO},
+	{0x2F803, UNICODE_NORM_QC_NO},
+	{0x2F804, UNICODE_NORM_QC_NO},
+	{0x2F805, UNICODE_NORM_QC_NO},
+	{0x2F806, UNICODE_NORM_QC_NO},
+	{0x2F807, UNICODE_NORM_QC_NO},
+	{0x2F808, UNICODE_NORM_QC_NO},
+	{0x2F809, UNICODE_NORM_QC_NO},
+	{0x2F80A, UNICODE_NORM_QC_NO},
+	{0x2F80B, UNICODE_NORM_QC_NO},
+	{0x2F80C, UNICODE_NORM_QC_NO},
+	{0x2F80D, UNICODE_NORM_QC_NO},
+	{0x2F80E, UNICODE_NORM_QC_NO},
+	{0x2F80F, UNICODE_NORM_QC_NO},
+	{0x2F810, UNICODE_NORM_QC_NO},
+	{0x2F811, UNICODE_NORM_QC_NO},
+	{0x2F812, UNICODE_NORM_QC_NO},
+	{0x2F813, UNICODE_NORM_QC_NO},
+	{0x2F814, UNICODE_NORM_QC_NO},
+	{0x2F815, UNICODE_NORM_QC_NO},
+	{0x2F816, UNICODE_NORM_QC_NO},
+	{0x2F817, UNICODE_NORM_QC_NO},
+	{0x2F818, UNICODE_NORM_QC_NO},
+	{0x2F819, UNICODE_NORM_QC_NO},
+	{0x2F81A, UNICODE_NORM_QC_NO},
+	{0x2F81B, UNICODE_NORM_QC_NO},
+	{0x2F81C, UNICODE_NORM_QC_NO},
+	{0x2F81D, UNICODE_NORM_QC_NO},
+	{0x2F81E, UNICODE_NORM_QC_NO},
+	{0x2F81F, UNICODE_NORM_QC_NO},
+	{0x2F820, UNICODE_NORM_QC_NO},
+	{0x2F821, UNICODE_NORM_QC_NO},
+	{0x2F822, UNICODE_NORM_QC_NO},
+	{0x2F823, UNICODE_NORM_QC_NO},
+	{0x2F824, UNICODE_NORM_QC_NO},
+	{0x2F825, UNICODE_NORM_QC_NO},
+	{0x2F826, UNICODE_NORM_QC_NO},
+	{0x2F827, UNICODE_NORM_QC_NO},
+	{0x2F828, UNICODE_NORM_QC_NO},
+	{0x2F829, UNICODE_NORM_QC_NO},
+	{0x2F82A, UNICODE_NORM_QC_NO},
+	{0x2F82B, UNICODE_NORM_QC_NO},
+	{0x2F82C, UNICODE_NORM_QC_NO},
+	{0x2F82D, UNICODE_NORM_QC_NO},
+	{0x2F82E, UNICODE_NORM_QC_NO},
+	{0x2F82F, UNICODE_NORM_QC_NO},
+	{0x2F830, UNICODE_NORM_QC_NO},
+	{0x2F831, UNICODE_NORM_QC_NO},
+	{0x2F832, UNICODE_NORM_QC_NO},
+	{0x2F833, UNICODE_NORM_QC_NO},
+	{0x2F834, UNICODE_NORM_QC_NO},
+	{0x2F835, UNICODE_NORM_QC_NO},
+	{0x2F836, UNICODE_NORM_QC_NO},
+	{0x2F837, UNICODE_NORM_QC_NO},
+	{0x2F838, UNICODE_NORM_QC_NO},
+	{0x2F839, UNICODE_NORM_QC_NO},
+	{0x2F83A, UNICODE_NORM_QC_NO},
+	{0x2F83B, UNICODE_NORM_QC_NO},
+	{0x2F83C, UNICODE_NORM_QC_NO},
+	{0x2F83D, UNICODE_NORM_QC_NO},
+	{0x2F83E, UNICODE_NORM_QC_NO},
+	{0x2F83F, UNICODE_NORM_QC_NO},
+	{0x2F840, UNICODE_NORM_QC_NO},
+	{0x2F841, UNICODE_NORM_QC_NO},
+	{0x2F842, UNICODE_NORM_QC_NO},
+	{0x2F843, UNICODE_NORM_QC_NO},
+	{0x2F844, UNICODE_NORM_QC_NO},
+	{0x2F845, UNICODE_NORM_QC_NO},
+	{0x2F846, UNICODE_NORM_QC_NO},
+	{0x2F847, UNICODE_NORM_QC_NO},
+	{0x2F848, UNICODE_NORM_QC_NO},
+	{0x2F849, UNICODE_NORM_QC_NO},
+	{0x2F84A, UNICODE_NORM_QC_NO},
+	{0x2F84B, UNICODE_NORM_QC_NO},
+	{0x2F84C, UNICODE_NORM_QC_NO},
+	{0x2F84D, UNICODE_NORM_QC_NO},
+	{0x2F84E, UNICODE_NORM_QC_NO},
+	{0x2F84F, UNICODE_NORM_QC_NO},
+	{0x2F850, UNICODE_NORM_QC_NO},
+	{0x2F851, UNICODE_NORM_QC_NO},
+	{0x2F852, UNICODE_NORM_QC_NO},
+	{0x2F853, UNICODE_NORM_QC_NO},
+	{0x2F854, UNICODE_NORM_QC_NO},
+	{0x2F855, UNICODE_NORM_QC_NO},
+	{0x2F856, UNICODE_NORM_QC_NO},
+	{0x2F857, UNICODE_NORM_QC_NO},
+	{0x2F858, UNICODE_NORM_QC_NO},
+	{0x2F859, UNICODE_NORM_QC_NO},
+	{0x2F85A, UNICODE_NORM_QC_NO},
+	{0x2F85B, UNICODE_NORM_QC_NO},
+	{0x2F85C, UNICODE_NORM_QC_NO},
+	{0x2F85D, UNICODE_NORM_QC_NO},
+	{0x2F85E, UNICODE_NORM_QC_NO},
+	{0x2F85F, UNICODE_NORM_QC_NO},
+	{0x2F860, UNICODE_NORM_QC_NO},
+	{0x2F861, UNICODE_NORM_QC_NO},
+	{0x2F862, UNICODE_NORM_QC_NO},
+	{0x2F863, UNICODE_NORM_QC_NO},
+	{0x2F864, UNICODE_NORM_QC_NO},
+	{0x2F865, UNICODE_NORM_QC_NO},
+	{0x2F866, UNICODE_NORM_QC_NO},
+	{0x2F867, UNICODE_NORM_QC_NO},
+	{0x2F868, UNICODE_NORM_QC_NO},
+	{0x2F869, UNICODE_NORM_QC_NO},
+	{0x2F86A, UNICODE_NORM_QC_NO},
+	{0x2F86B, UNICODE_NORM_QC_NO},
+	{0x2F86C, UNICODE_NORM_QC_NO},
+	{0x2F86D, UNICODE_NORM_QC_NO},
+	{0x2F86E, UNICODE_NORM_QC_NO},
+	{0x2F86F, UNICODE_NORM_QC_NO},
+	{0x2F870, UNICODE_NORM_QC_NO},
+	{0x2F871, UNICODE_NORM_QC_NO},
+	{0x2F872, UNICODE_NORM_QC_NO},
+	{0x2F873, UNICODE_NORM_QC_NO},
+	{0x2F874, UNICODE_NORM_QC_NO},
+	{0x2F875, UNICODE_NORM_QC_NO},
+	{0x2F876, UNICODE_NORM_QC_NO},
+	{0x2F877, UNICODE_NORM_QC_NO},
+	{0x2F878, UNICODE_NORM_QC_NO},
+	{0x2F879, UNICODE_NORM_QC_NO},
+	{0x2F87A, UNICODE_NORM_QC_NO},
+	{0x2F87B, UNICODE_NORM_QC_NO},
+	{0x2F87C, UNICODE_NORM_QC_NO},
+	{0x2F87D, UNICODE_NORM_QC_NO},
+	{0x2F87E, UNICODE_NORM_QC_NO},
+	{0x2F87F, UNICODE_NORM_QC_NO},
+	{0x2F880, UNICODE_NORM_QC_NO},
+	{0x2F881, UNICODE_NORM_QC_NO},
+	{0x2F882, UNICODE_NORM_QC_NO},
+	{0x2F883, UNICODE_NORM_QC_NO},
+	{0x2F884, UNICODE_NORM_QC_NO},
+	{0x2F885, UNICODE_NORM_QC_NO},
+	{0x2F886, UNICODE_NORM_QC_NO},
+	{0x2F887, UNICODE_NORM_QC_NO},
+	{0x2F888, UNICODE_NORM_QC_NO},
+	{0x2F889, UNICODE_NORM_QC_NO},
+	{0x2F88A, UNICODE_NORM_QC_NO},
+	{0x2F88B, UNICODE_NORM_QC_NO},
+	{0x2F88C, UNICODE_NORM_QC_NO},
+	{0x2F88D, UNICODE_NORM_QC_NO},
+	{0x2F88E, UNICODE_NORM_QC_NO},
+	{0x2F88F, UNICODE_NORM_QC_NO},
+	{0x2F890, UNICODE_NORM_QC_NO},
+	{0x2F891, UNICODE_NORM_QC_NO},
+	{0x2F892, UNICODE_NORM_QC_NO},
+	{0x2F893, UNICODE_NORM_QC_NO},
+	{0x2F894, UNICODE_NORM_QC_NO},
+	{0x2F895, UNICODE_NORM_QC_NO},
+	{0x2F896, UNICODE_NORM_QC_NO},
+	{0x2F897, UNICODE_NORM_QC_NO},
+	{0x2F898, UNICODE_NORM_QC_NO},
+	{0x2F899, UNICODE_NORM_QC_NO},
+	{0x2F89A, UNICODE_NORM_QC_NO},
+	{0x2F89B, UNICODE_NORM_QC_NO},
+	{0x2F89C, UNICODE_NORM_QC_NO},
+	{0x2F89D, UNICODE_NORM_QC_NO},
+	{0x2F89E, UNICODE_NORM_QC_NO},
+	{0x2F89F, UNICODE_NORM_QC_NO},
+	{0x2F8A0, UNICODE_NORM_QC_NO},
+	{0x2F8A1, UNICODE_NORM_QC_NO},
+	{0x2F8A2, UNICODE_NORM_QC_NO},
+	{0x2F8A3, UNICODE_NORM_QC_NO},
+	{0x2F8A4, UNICODE_NORM_QC_NO},
+	{0x2F8A5, UNICODE_NORM_QC_NO},
+	{0x2F8A6, UNICODE_NORM_QC_NO},
+	{0x2F8A7, UNICODE_NORM_QC_NO},
+	{0x2F8A8, UNICODE_NORM_QC_NO},
+	{0x2F8A9, UNICODE_NORM_QC_NO},
+	{0x2F8AA, UNICODE_NORM_QC_NO},
+	{0x2F8AB, UNICODE_NORM_QC_NO},
+	{0x2F8AC, UNICODE_NORM_QC_NO},
+	{0x2F8AD, UNICODE_NORM_QC_NO},
+	{0x2F8AE, UNICODE_NORM_QC_NO},
+	{0x2F8AF, UNICODE_NORM_QC_NO},
+	{0x2F8B0, UNICODE_NORM_QC_NO},
+	{0x2F8B1, UNICODE_NORM_QC_NO},
+	{0x2F8B2, UNICODE_NORM_QC_NO},
+	{0x2F8B3, UNICODE_NORM_QC_NO},
+	{0x2F8B4, UNICODE_NORM_QC_NO},
+	{0x2F8B5, UNICODE_NORM_QC_NO},
+	{0x2F8B6, UNICODE_NORM_QC_NO},
+	{0x2F8B7, UNICODE_NORM_QC_NO},
+	{0x2F8B8, UNICODE_NORM_QC_NO},
+	{0x2F8B9, UNICODE_NORM_QC_NO},
+	{0x2F8BA, UNICODE_NORM_QC_NO},
+	{0x2F8BB, UNICODE_NORM_QC_NO},
+	{0x2F8BC, UNICODE_NORM_QC_NO},
+	{0x2F8BD, UNICODE_NORM_QC_NO},
+	{0x2F8BE, UNICODE_NORM_QC_NO},
+	{0x2F8BF, UNICODE_NORM_QC_NO},
+	{0x2F8C0, UNICODE_NORM_QC_NO},
+	{0x2F8C1, UNICODE_NORM_QC_NO},
+	{0x2F8C2, UNICODE_NORM_QC_NO},
+	{0x2F8C3, UNICODE_NORM_QC_NO},
+	{0x2F8C4, UNICODE_NORM_QC_NO},
+	{0x2F8C5, UNICODE_NORM_QC_NO},
+	{0x2F8C6, UNICODE_NORM_QC_NO},
+	{0x2F8C7, UNICODE_NORM_QC_NO},
+	{0x2F8C8, UNICODE_NORM_QC_NO},
+	{0x2F8C9, UNICODE_NORM_QC_NO},
+	{0x2F8CA, UNICODE_NORM_QC_NO},
+	{0x2F8CB, UNICODE_NORM_QC_NO},
+	{0x2F8CC, UNICODE_NORM_QC_NO},
+	{0x2F8CD, UNICODE_NORM_QC_NO},
+	{0x2F8CE, UNICODE_NORM_QC_NO},
+	{0x2F8CF, UNICODE_NORM_QC_NO},
+	{0x2F8D0, UNICODE_NORM_QC_NO},
+	{0x2F8D1, UNICODE_NORM_QC_NO},
+	{0x2F8D2, UNICODE_NORM_QC_NO},
+	{0x2F8D3, UNICODE_NORM_QC_NO},
+	{0x2F8D4, UNICODE_NORM_QC_NO},
+	{0x2F8D5, UNICODE_NORM_QC_NO},
+	{0x2F8D6, UNICODE_NORM_QC_NO},
+	{0x2F8D7, UNICODE_NORM_QC_NO},
+	{0x2F8D8, UNICODE_NORM_QC_NO},
+	{0x2F8D9, UNICODE_NORM_QC_NO},
+	{0x2F8DA, UNICODE_NORM_QC_NO},
+	{0x2F8DB, UNICODE_NORM_QC_NO},
+	{0x2F8DC, UNICODE_NORM_QC_NO},
+	{0x2F8DD, UNICODE_NORM_QC_NO},
+	{0x2F8DE, UNICODE_NORM_QC_NO},
+	{0x2F8DF, UNICODE_NORM_QC_NO},
+	{0x2F8E0, UNICODE_NORM_QC_NO},
+	{0x2F8E1, UNICODE_NORM_QC_NO},
+	{0x2F8E2, UNICODE_NORM_QC_NO},
+	{0x2F8E3, UNICODE_NORM_QC_NO},
+	{0x2F8E4, UNICODE_NORM_QC_NO},
+	{0x2F8E5, UNICODE_NORM_QC_NO},
+	{0x2F8E6, UNICODE_NORM_QC_NO},
+	{0x2F8E7, UNICODE_NORM_QC_NO},
+	{0x2F8E8, UNICODE_NORM_QC_NO},
+	{0x2F8E9, UNICODE_NORM_QC_NO},
+	{0x2F8EA, UNICODE_NORM_QC_NO},
+	{0x2F8EB, UNICODE_NORM_QC_NO},
+	{0x2F8EC, UNICODE_NORM_QC_NO},
+	{0x2F8ED, UNICODE_NORM_QC_NO},
+	{0x2F8EE, UNICODE_NORM_QC_NO},
+	{0x2F8EF, UNICODE_NORM_QC_NO},
+	{0x2F8F0, UNICODE_NORM_QC_NO},
+	{0x2F8F1, UNICODE_NORM_QC_NO},
+	{0x2F8F2, UNICODE_NORM_QC_NO},
+	{0x2F8F3, UNICODE_NORM_QC_NO},
+	{0x2F8F4, UNICODE_NORM_QC_NO},
+	{0x2F8F5, UNICODE_NORM_QC_NO},
+	{0x2F8F6, UNICODE_NORM_QC_NO},
+	{0x2F8F7, UNICODE_NORM_QC_NO},
+	{0x2F8F8, UNICODE_NORM_QC_NO},
+	{0x2F8F9, UNICODE_NORM_QC_NO},
+	{0x2F8FA, UNICODE_NORM_QC_NO},
+	{0x2F8FB, UNICODE_NORM_QC_NO},
+	{0x2F8FC, UNICODE_NORM_QC_NO},
+	{0x2F8FD, UNICODE_NORM_QC_NO},
+	{0x2F8FE, UNICODE_NORM_QC_NO},
+	{0x2F8FF, UNICODE_NORM_QC_NO},
+	{0x2F900, UNICODE_NORM_QC_NO},
+	{0x2F901, UNICODE_NORM_QC_NO},
+	{0x2F902, UNICODE_NORM_QC_NO},
+	{0x2F903, UNICODE_NORM_QC_NO},
+	{0x2F904, UNICODE_NORM_QC_NO},
+	{0x2F905, UNICODE_NORM_QC_NO},
+	{0x2F906, UNICODE_NORM_QC_NO},
+	{0x2F907, UNICODE_NORM_QC_NO},
+	{0x2F908, UNICODE_NORM_QC_NO},
+	{0x2F909, UNICODE_NORM_QC_NO},
+	{0x2F90A, UNICODE_NORM_QC_NO},
+	{0x2F90B, UNICODE_NORM_QC_NO},
+	{0x2F90C, UNICODE_NORM_QC_NO},
+	{0x2F90D, UNICODE_NORM_QC_NO},
+	{0x2F90E, UNICODE_NORM_QC_NO},
+	{0x2F90F, UNICODE_NORM_QC_NO},
+	{0x2F910, UNICODE_NORM_QC_NO},
+	{0x2F911, UNICODE_NORM_QC_NO},
+	{0x2F912, UNICODE_NORM_QC_NO},
+	{0x2F913, UNICODE_NORM_QC_NO},
+	{0x2F914, UNICODE_NORM_QC_NO},
+	{0x2F915, UNICODE_NORM_QC_NO},
+	{0x2F916, UNICODE_NORM_QC_NO},
+	{0x2F917, UNICODE_NORM_QC_NO},
+	{0x2F918, UNICODE_NORM_QC_NO},
+	{0x2F919, UNICODE_NORM_QC_NO},
+	{0x2F91A, UNICODE_NORM_QC_NO},
+	{0x2F91B, UNICODE_NORM_QC_NO},
+	{0x2F91C, UNICODE_NORM_QC_NO},
+	{0x2F91D, UNICODE_NORM_QC_NO},
+	{0x2F91E, UNICODE_NORM_QC_NO},
+	{0x2F91F, UNICODE_NORM_QC_NO},
+	{0x2F920, UNICODE_NORM_QC_NO},
+	{0x2F921, UNICODE_NORM_QC_NO},
+	{0x2F922, UNICODE_NORM_QC_NO},
+	{0x2F923, UNICODE_NORM_QC_NO},
+	{0x2F924, UNICODE_NORM_QC_NO},
+	{0x2F925, UNICODE_NORM_QC_NO},
+	{0x2F926, UNICODE_NORM_QC_NO},
+	{0x2F927, UNICODE_NORM_QC_NO},
+	{0x2F928, UNICODE_NORM_QC_NO},
+	{0x2F929, UNICODE_NORM_QC_NO},
+	{0x2F92A, UNICODE_NORM_QC_NO},
+	{0x2F92B, UNICODE_NORM_QC_NO},
+	{0x2F92C, UNICODE_NORM_QC_NO},
+	{0x2F92D, UNICODE_NORM_QC_NO},
+	{0x2F92E, UNICODE_NORM_QC_NO},
+	{0x2F92F, UNICODE_NORM_QC_NO},
+	{0x2F930, UNICODE_NORM_QC_NO},
+	{0x2F931, UNICODE_NORM_QC_NO},
+	{0x2F932, UNICODE_NORM_QC_NO},
+	{0x2F933, UNICODE_NORM_QC_NO},
+	{0x2F934, UNICODE_NORM_QC_NO},
+	{0x2F935, UNICODE_NORM_QC_NO},
+	{0x2F936, UNICODE_NORM_QC_NO},
+	{0x2F937, UNICODE_NORM_QC_NO},
+	{0x2F938, UNICODE_NORM_QC_NO},
+	{0x2F939, UNICODE_NORM_QC_NO},
+	{0x2F93A, UNICODE_NORM_QC_NO},
+	{0x2F93B, UNICODE_NORM_QC_NO},
+	{0x2F93C, UNICODE_NORM_QC_NO},
+	{0x2F93D, UNICODE_NORM_QC_NO},
+	{0x2F93E, UNICODE_NORM_QC_NO},
+	{0x2F93F, UNICODE_NORM_QC_NO},
+	{0x2F940, UNICODE_NORM_QC_NO},
+	{0x2F941, UNICODE_NORM_QC_NO},
+	{0x2F942, UNICODE_NORM_QC_NO},
+	{0x2F943, UNICODE_NORM_QC_NO},
+	{0x2F944, UNICODE_NORM_QC_NO},
+	{0x2F945, UNICODE_NORM_QC_NO},
+	{0x2F946, UNICODE_NORM_QC_NO},
+	{0x2F947, UNICODE_NORM_QC_NO},
+	{0x2F948, UNICODE_NORM_QC_NO},
+	{0x2F949, UNICODE_NORM_QC_NO},
+	{0x2F94A, UNICODE_NORM_QC_NO},
+	{0x2F94B, UNICODE_NORM_QC_NO},
+	{0x2F94C, UNICODE_NORM_QC_NO},
+	{0x2F94D, UNICODE_NORM_QC_NO},
+	{0x2F94E, UNICODE_NORM_QC_NO},
+	{0x2F94F, UNICODE_NORM_QC_NO},
+	{0x2F950, UNICODE_NORM_QC_NO},
+	{0x2F951, UNICODE_NORM_QC_NO},
+	{0x2F952, UNICODE_NORM_QC_NO},
+	{0x2F953, UNICODE_NORM_QC_NO},
+	{0x2F954, UNICODE_NORM_QC_NO},
+	{0x2F955, UNICODE_NORM_QC_NO},
+	{0x2F956, UNICODE_NORM_QC_NO},
+	{0x2F957, UNICODE_NORM_QC_NO},
+	{0x2F958, UNICODE_NORM_QC_NO},
+	{0x2F959, UNICODE_NORM_QC_NO},
+	{0x2F95A, UNICODE_NORM_QC_NO},
+	{0x2F95B, UNICODE_NORM_QC_NO},
+	{0x2F95C, UNICODE_NORM_QC_NO},
+	{0x2F95D, UNICODE_NORM_QC_NO},
+	{0x2F95E, UNICODE_NORM_QC_NO},
+	{0x2F95F, UNICODE_NORM_QC_NO},
+	{0x2F960, UNICODE_NORM_QC_NO},
+	{0x2F961, UNICODE_NORM_QC_NO},
+	{0x2F962, UNICODE_NORM_QC_NO},
+	{0x2F963, UNICODE_NORM_QC_NO},
+	{0x2F964, UNICODE_NORM_QC_NO},
+	{0x2F965, UNICODE_NORM_QC_NO},
+	{0x2F966, UNICODE_NORM_QC_NO},
+	{0x2F967, UNICODE_NORM_QC_NO},
+	{0x2F968, UNICODE_NORM_QC_NO},
+	{0x2F969, UNICODE_NORM_QC_NO},
+	{0x2F96A, UNICODE_NORM_QC_NO},
+	{0x2F96B, UNICODE_NORM_QC_NO},
+	{0x2F96C, UNICODE_NORM_QC_NO},
+	{0x2F96D, UNICODE_NORM_QC_NO},
+	{0x2F96E, UNICODE_NORM_QC_NO},
+	{0x2F96F, UNICODE_NORM_QC_NO},
+	{0x2F970, UNICODE_NORM_QC_NO},
+	{0x2F971, UNICODE_NORM_QC_NO},
+	{0x2F972, UNICODE_NORM_QC_NO},
+	{0x2F973, UNICODE_NORM_QC_NO},
+	{0x2F974, UNICODE_NORM_QC_NO},
+	{0x2F975, UNICODE_NORM_QC_NO},
+	{0x2F976, UNICODE_NORM_QC_NO},
+	{0x2F977, UNICODE_NORM_QC_NO},
+	{0x2F978, UNICODE_NORM_QC_NO},
+	{0x2F979, UNICODE_NORM_QC_NO},
+	{0x2F97A, UNICODE_NORM_QC_NO},
+	{0x2F97B, UNICODE_NORM_QC_NO},
+	{0x2F97C, UNICODE_NORM_QC_NO},
+	{0x2F97D, UNICODE_NORM_QC_NO},
+	{0x2F97E, UNICODE_NORM_QC_NO},
+	{0x2F97F, UNICODE_NORM_QC_NO},
+	{0x2F980, UNICODE_NORM_QC_NO},
+	{0x2F981, UNICODE_NORM_QC_NO},
+	{0x2F982, UNICODE_NORM_QC_NO},
+	{0x2F983, UNICODE_NORM_QC_NO},
+	{0x2F984, UNICODE_NORM_QC_NO},
+	{0x2F985, UNICODE_NORM_QC_NO},
+	{0x2F986, UNICODE_NORM_QC_NO},
+	{0x2F987, UNICODE_NORM_QC_NO},
+	{0x2F988, UNICODE_NORM_QC_NO},
+	{0x2F989, UNICODE_NORM_QC_NO},
+	{0x2F98A, UNICODE_NORM_QC_NO},
+	{0x2F98B, UNICODE_NORM_QC_NO},
+	{0x2F98C, UNICODE_NORM_QC_NO},
+	{0x2F98D, UNICODE_NORM_QC_NO},
+	{0x2F98E, UNICODE_NORM_QC_NO},
+	{0x2F98F, UNICODE_NORM_QC_NO},
+	{0x2F990, UNICODE_NORM_QC_NO},
+	{0x2F991, UNICODE_NORM_QC_NO},
+	{0x2F992, UNICODE_NORM_QC_NO},
+	{0x2F993, UNICODE_NORM_QC_NO},
+	{0x2F994, UNICODE_NORM_QC_NO},
+	{0x2F995, UNICODE_NORM_QC_NO},
+	{0x2F996, UNICODE_NORM_QC_NO},
+	{0x2F997, UNICODE_NORM_QC_NO},
+	{0x2F998, UNICODE_NORM_QC_NO},
+	{0x2F999, UNICODE_NORM_QC_NO},
+	{0x2F99A, UNICODE_NORM_QC_NO},
+	{0x2F99B, UNICODE_NORM_QC_NO},
+	{0x2F99C, UNICODE_NORM_QC_NO},
+	{0x2F99D, UNICODE_NORM_QC_NO},
+	{0x2F99E, UNICODE_NORM_QC_NO},
+	{0x2F99F, UNICODE_NORM_QC_NO},
+	{0x2F9A0, UNICODE_NORM_QC_NO},
+	{0x2F9A1, UNICODE_NORM_QC_NO},
+	{0x2F9A2, UNICODE_NORM_QC_NO},
+	{0x2F9A3, UNICODE_NORM_QC_NO},
+	{0x2F9A4, UNICODE_NORM_QC_NO},
+	{0x2F9A5, UNICODE_NORM_QC_NO},
+	{0x2F9A6, UNICODE_NORM_QC_NO},
+	{0x2F9A7, UNICODE_NORM_QC_NO},
+	{0x2F9A8, UNICODE_NORM_QC_NO},
+	{0x2F9A9, UNICODE_NORM_QC_NO},
+	{0x2F9AA, UNICODE_NORM_QC_NO},
+	{0x2F9AB, UNICODE_NORM_QC_NO},
+	{0x2F9AC, UNICODE_NORM_QC_NO},
+	{0x2F9AD, UNICODE_NORM_QC_NO},
+	{0x2F9AE, UNICODE_NORM_QC_NO},
+	{0x2F9AF, UNICODE_NORM_QC_NO},
+	{0x2F9B0, UNICODE_NORM_QC_NO},
+	{0x2F9B1, UNICODE_NORM_QC_NO},
+	{0x2F9B2, UNICODE_NORM_QC_NO},
+	{0x2F9B3, UNICODE_NORM_QC_NO},
+	{0x2F9B4, UNICODE_NORM_QC_NO},
+	{0x2F9B5, UNICODE_NORM_QC_NO},
+	{0x2F9B6, UNICODE_NORM_QC_NO},
+	{0x2F9B7, UNICODE_NORM_QC_NO},
+	{0x2F9B8, UNICODE_NORM_QC_NO},
+	{0x2F9B9, UNICODE_NORM_QC_NO},
+	{0x2F9BA, UNICODE_NORM_QC_NO},
+	{0x2F9BB, UNICODE_NORM_QC_NO},
+	{0x2F9BC, UNICODE_NORM_QC_NO},
+	{0x2F9BD, UNICODE_NORM_QC_NO},
+	{0x2F9BE, UNICODE_NORM_QC_NO},
+	{0x2F9BF, UNICODE_NORM_QC_NO},
+	{0x2F9C0, UNICODE_NORM_QC_NO},
+	{0x2F9C1, UNICODE_NORM_QC_NO},
+	{0x2F9C2, UNICODE_NORM_QC_NO},
+	{0x2F9C3, UNICODE_NORM_QC_NO},
+	{0x2F9C4, UNICODE_NORM_QC_NO},
+	{0x2F9C5, UNICODE_NORM_QC_NO},
+	{0x2F9C6, UNICODE_NORM_QC_NO},
+	{0x2F9C7, UNICODE_NORM_QC_NO},
+	{0x2F9C8, UNICODE_NORM_QC_NO},
+	{0x2F9C9, UNICODE_NORM_QC_NO},
+	{0x2F9CA, UNICODE_NORM_QC_NO},
+	{0x2F9CB, UNICODE_NORM_QC_NO},
+	{0x2F9CC, UNICODE_NORM_QC_NO},
+	{0x2F9CD, UNICODE_NORM_QC_NO},
+	{0x2F9CE, UNICODE_NORM_QC_NO},
+	{0x2F9CF, UNICODE_NORM_QC_NO},
+	{0x2F9D0, UNICODE_NORM_QC_NO},
+	{0x2F9D1, UNICODE_NORM_QC_NO},
+	{0x2F9D2, UNICODE_NORM_QC_NO},
+	{0x2F9D3, UNICODE_NORM_QC_NO},
+	{0x2F9D4, UNICODE_NORM_QC_NO},
+	{0x2F9D5, UNICODE_NORM_QC_NO},
+	{0x2F9D6, UNICODE_NORM_QC_NO},
+	{0x2F9D7, UNICODE_NORM_QC_NO},
+	{0x2F9D8, UNICODE_NORM_QC_NO},
+	{0x2F9D9, UNICODE_NORM_QC_NO},
+	{0x2F9DA, UNICODE_NORM_QC_NO},
+	{0x2F9DB, UNICODE_NORM_QC_NO},
+	{0x2F9DC, UNICODE_NORM_QC_NO},
+	{0x2F9DD, UNICODE_NORM_QC_NO},
+	{0x2F9DE, UNICODE_NORM_QC_NO},
+	{0x2F9DF, UNICODE_NORM_QC_NO},
+	{0x2F9E0, UNICODE_NORM_QC_NO},
+	{0x2F9E1, UNICODE_NORM_QC_NO},
+	{0x2F9E2, UNICODE_NORM_QC_NO},
+	{0x2F9E3, UNICODE_NORM_QC_NO},
+	{0x2F9E4, UNICODE_NORM_QC_NO},
+	{0x2F9E5, UNICODE_NORM_QC_NO},
+	{0x2F9E6, UNICODE_NORM_QC_NO},
+	{0x2F9E7, UNICODE_NORM_QC_NO},
+	{0x2F9E8, UNICODE_NORM_QC_NO},
+	{0x2F9E9, UNICODE_NORM_QC_NO},
+	{0x2F9EA, UNICODE_NORM_QC_NO},
+	{0x2F9EB, UNICODE_NORM_QC_NO},
+	{0x2F9EC, UNICODE_NORM_QC_NO},
+	{0x2F9ED, UNICODE_NORM_QC_NO},
+	{0x2F9EE, UNICODE_NORM_QC_NO},
+	{0x2F9EF, UNICODE_NORM_QC_NO},
+	{0x2F9F0, UNICODE_NORM_QC_NO},
+	{0x2F9F1, UNICODE_NORM_QC_NO},
+	{0x2F9F2, UNICODE_NORM_QC_NO},
+	{0x2F9F3, UNICODE_NORM_QC_NO},
+	{0x2F9F4, UNICODE_NORM_QC_NO},
+	{0x2F9F5, UNICODE_NORM_QC_NO},
+	{0x2F9F6, UNICODE_NORM_QC_NO},
+	{0x2F9F7, UNICODE_NORM_QC_NO},
+	{0x2F9F8, UNICODE_NORM_QC_NO},
+	{0x2F9F9, UNICODE_NORM_QC_NO},
+	{0x2F9FA, UNICODE_NORM_QC_NO},
+	{0x2F9FB, UNICODE_NORM_QC_NO},
+	{0x2F9FC, UNICODE_NORM_QC_NO},
+	{0x2F9FD, UNICODE_NORM_QC_NO},
+	{0x2F9FE, UNICODE_NORM_QC_NO},
+	{0x2F9FF, UNICODE_NORM_QC_NO},
+	{0x2FA00, UNICODE_NORM_QC_NO},
+	{0x2FA01, UNICODE_NORM_QC_NO},
+	{0x2FA02, UNICODE_NORM_QC_NO},
+	{0x2FA03, UNICODE_NORM_QC_NO},
+	{0x2FA04, UNICODE_NORM_QC_NO},
+	{0x2FA05, UNICODE_NORM_QC_NO},
+	{0x2FA06, UNICODE_NORM_QC_NO},
+	{0x2FA07, UNICODE_NORM_QC_NO},
+	{0x2FA08, UNICODE_NORM_QC_NO},
+	{0x2FA09, UNICODE_NORM_QC_NO},
+	{0x2FA0A, UNICODE_NORM_QC_NO},
+	{0x2FA0B, UNICODE_NORM_QC_NO},
+	{0x2FA0C, UNICODE_NORM_QC_NO},
+	{0x2FA0D, UNICODE_NORM_QC_NO},
+	{0x2FA0E, UNICODE_NORM_QC_NO},
+	{0x2FA0F, UNICODE_NORM_QC_NO},
+	{0x2FA10, UNICODE_NORM_QC_NO},
+	{0x2FA11, UNICODE_NORM_QC_NO},
+	{0x2FA12, UNICODE_NORM_QC_NO},
+	{0x2FA13, UNICODE_NORM_QC_NO},
+	{0x2FA14, UNICODE_NORM_QC_NO},
+	{0x2FA15, UNICODE_NORM_QC_NO},
+	{0x2FA16, UNICODE_NORM_QC_NO},
+	{0x2FA17, UNICODE_NORM_QC_NO},
+	{0x2FA18, UNICODE_NORM_QC_NO},
+	{0x2FA19, UNICODE_NORM_QC_NO},
+	{0x2FA1A, UNICODE_NORM_QC_NO},
+	{0x2FA1B, UNICODE_NORM_QC_NO},
+	{0x2FA1C, UNICODE_NORM_QC_NO},
+	{0x2FA1D, UNICODE_NORM_QC_NO},
+};
+
+static const pg_unicode_normprops UnicodeNormProps_NFD_QC[] = {
+	{0x00C0, UNICODE_NORM_QC_NO},
+	{0x00C1, UNICODE_NORM_QC_NO},
+	{0x00C2, UNICODE_NORM_QC_NO},
+	{0x00C3, UNICODE_NORM_QC_NO},
+	{0x00C4, UNICODE_NORM_QC_NO},
+	{0x00C5, UNICODE_NORM_QC_NO},
+	{0x00C7, UNICODE_NORM_QC_NO},
+	{0x00C8, UNICODE_NORM_QC_NO},
+	{0x00C9, UNICODE_NORM_QC_NO},
+	{0x00CA, UNICODE_NORM_QC_NO},
+	{0x00CB, UNICODE_NORM_QC_NO},
+	{0x00CC, UNICODE_NORM_QC_NO},
+	{0x00CD, UNICODE_NORM_QC_NO},
+	{0x00CE, UNICODE_NORM_QC_NO},
+	{0x00CF, UNICODE_NORM_QC_NO},
+	{0x00D1, UNICODE_NORM_QC_NO},
+	{0x00D2, UNICODE_NORM_QC_NO},
+	{0x00D3, UNICODE_NORM_QC_NO},
+	{0x00D4, UNICODE_NORM_QC_NO},
+	{0x00D5, UNICODE_NORM_QC_NO},
+	{0x00D6, UNICODE_NORM_QC_NO},
+	{0x00D9, UNICODE_NORM_QC_NO},
+	{0x00DA, UNICODE_NORM_QC_NO},
+	{0x00DB, UNICODE_NORM_QC_NO},
+	{0x00DC, UNICODE_NORM_QC_NO},
+	{0x00DD, UNICODE_NORM_QC_NO},
+	{0x00E0, UNICODE_NORM_QC_NO},
+	{0x00E1, UNICODE_NORM_QC_NO},
+	{0x00E2, UNICODE_NORM_QC_NO},
+	{0x00E3, UNICODE_NORM_QC_NO},
+	{0x00E4, UNICODE_NORM_QC_NO},
+	{0x00E5, UNICODE_NORM_QC_NO},
+	{0x00E7, UNICODE_NORM_QC_NO},
+	{0x00E8, UNICODE_NORM_QC_NO},
+	{0x00E9, UNICODE_NORM_QC_NO},
+	{0x00EA, UNICODE_NORM_QC_NO},
+	{0x00EB, UNICODE_NORM_QC_NO},
+	{0x00EC, UNICODE_NORM_QC_NO},
+	{0x00ED, UNICODE_NORM_QC_NO},
+	{0x00EE, UNICODE_NORM_QC_NO},
+	{0x00EF, UNICODE_NORM_QC_NO},
+	{0x00F1, UNICODE_NORM_QC_NO},
+	{0x00F2, UNICODE_NORM_QC_NO},
+	{0x00F3, UNICODE_NORM_QC_NO},
+	{0x00F4, UNICODE_NORM_QC_NO},
+	{0x00F5, UNICODE_NORM_QC_NO},
+	{0x00F6, UNICODE_NORM_QC_NO},
+	{0x00F9, UNICODE_NORM_QC_NO},
+	{0x00FA, UNICODE_NORM_QC_NO},
+	{0x00FB, UNICODE_NORM_QC_NO},
+	{0x00FC, UNICODE_NORM_QC_NO},
+	{0x00FD, UNICODE_NORM_QC_NO},
+	{0x00FF, UNICODE_NORM_QC_NO},
+	{0x0100, UNICODE_NORM_QC_NO},
+	{0x0101, UNICODE_NORM_QC_NO},
+	{0x0102, UNICODE_NORM_QC_NO},
+	{0x0103, UNICODE_NORM_QC_NO},
+	{0x0104, UNICODE_NORM_QC_NO},
+	{0x0105, UNICODE_NORM_QC_NO},
+	{0x0106, UNICODE_NORM_QC_NO},
+	{0x0107, UNICODE_NORM_QC_NO},
+	{0x0108, UNICODE_NORM_QC_NO},
+	{0x0109, UNICODE_NORM_QC_NO},
+	{0x010A, UNICODE_NORM_QC_NO},
+	{0x010B, UNICODE_NORM_QC_NO},
+	{0x010C, UNICODE_NORM_QC_NO},
+	{0x010D, UNICODE_NORM_QC_NO},
+	{0x010E, UNICODE_NORM_QC_NO},
+	{0x010F, UNICODE_NORM_QC_NO},
+	{0x0112, UNICODE_NORM_QC_NO},
+	{0x0113, UNICODE_NORM_QC_NO},
+	{0x0114, UNICODE_NORM_QC_NO},
+	{0x0115, UNICODE_NORM_QC_NO},
+	{0x0116, UNICODE_NORM_QC_NO},
+	{0x0117, UNICODE_NORM_QC_NO},
+	{0x0118, UNICODE_NORM_QC_NO},
+	{0x0119, UNICODE_NORM_QC_NO},
+	{0x011A, UNICODE_NORM_QC_NO},
+	{0x011B, UNICODE_NORM_QC_NO},
+	{0x011C, UNICODE_NORM_QC_NO},
+	{0x011D, UNICODE_NORM_QC_NO},
+	{0x011E, UNICODE_NORM_QC_NO},
+	{0x011F, UNICODE_NORM_QC_NO},
+	{0x0120, UNICODE_NORM_QC_NO},
+	{0x0121, UNICODE_NORM_QC_NO},
+	{0x0122, UNICODE_NORM_QC_NO},
+	{0x0123, UNICODE_NORM_QC_NO},
+	{0x0124, UNICODE_NORM_QC_NO},
+	{0x0125, UNICODE_NORM_QC_NO},
+	{0x0128, UNICODE_NORM_QC_NO},
+	{0x0129, UNICODE_NORM_QC_NO},
+	{0x012A, UNICODE_NORM_QC_NO},
+	{0x012B, UNICODE_NORM_QC_NO},
+	{0x012C, UNICODE_NORM_QC_NO},
+	{0x012D, UNICODE_NORM_QC_NO},
+	{0x012E, UNICODE_NORM_QC_NO},
+	{0x012F, UNICODE_NORM_QC_NO},
+	{0x0130, UNICODE_NORM_QC_NO},
+	{0x0134, UNICODE_NORM_QC_NO},
+	{0x0135, UNICODE_NORM_QC_NO},
+	{0x0136, UNICODE_NORM_QC_NO},
+	{0x0137, UNICODE_NORM_QC_NO},
+	{0x0139, UNICODE_NORM_QC_NO},
+	{0x013A, UNICODE_NORM_QC_NO},
+	{0x013B, UNICODE_NORM_QC_NO},
+	{0x013C, UNICODE_NORM_QC_NO},
+	{0x013D, UNICODE_NORM_QC_NO},
+	{0x013E, UNICODE_NORM_QC_NO},
+	{0x0143, UNICODE_NORM_QC_NO},
+	{0x0144, UNICODE_NORM_QC_NO},
+	{0x0145, UNICODE_NORM_QC_NO},
+	{0x0146, UNICODE_NORM_QC_NO},
+	{0x0147, UNICODE_NORM_QC_NO},
+	{0x0148, UNICODE_NORM_QC_NO},
+	{0x014C, UNICODE_NORM_QC_NO},
+	{0x014D, UNICODE_NORM_QC_NO},
+	{0x014E, UNICODE_NORM_QC_NO},
+	{0x014F, UNICODE_NORM_QC_NO},
+	{0x0150, UNICODE_NORM_QC_NO},
+	{0x0151, UNICODE_NORM_QC_NO},
+	{0x0154, UNICODE_NORM_QC_NO},
+	{0x0155, UNICODE_NORM_QC_NO},
+	{0x0156, UNICODE_NORM_QC_NO},
+	{0x0157, UNICODE_NORM_QC_NO},
+	{0x0158, UNICODE_NORM_QC_NO},
+	{0x0159, UNICODE_NORM_QC_NO},
+	{0x015A, UNICODE_NORM_QC_NO},
+	{0x015B, UNICODE_NORM_QC_NO},
+	{0x015C, UNICODE_NORM_QC_NO},
+	{0x015D, UNICODE_NORM_QC_NO},
+	{0x015E, UNICODE_NORM_QC_NO},
+	{0x015F, UNICODE_NORM_QC_NO},
+	{0x0160, UNICODE_NORM_QC_NO},
+	{0x0161, UNICODE_NORM_QC_NO},
+	{0x0162, UNICODE_NORM_QC_NO},
+	{0x0163, UNICODE_NORM_QC_NO},
+	{0x0164, UNICODE_NORM_QC_NO},
+	{0x0165, UNICODE_NORM_QC_NO},
+	{0x0168, UNICODE_NORM_QC_NO},
+	{0x0169, UNICODE_NORM_QC_NO},
+	{0x016A, UNICODE_NORM_QC_NO},
+	{0x016B, UNICODE_NORM_QC_NO},
+	{0x016C, UNICODE_NORM_QC_NO},
+	{0x016D, UNICODE_NORM_QC_NO},
+	{0x016E, UNICODE_NORM_QC_NO},
+	{0x016F, UNICODE_NORM_QC_NO},
+	{0x0170, UNICODE_NORM_QC_NO},
+	{0x0171, UNICODE_NORM_QC_NO},
+	{0x0172, UNICODE_NORM_QC_NO},
+	{0x0173, UNICODE_NORM_QC_NO},
+	{0x0174, UNICODE_NORM_QC_NO},
+	{0x0175, UNICODE_NORM_QC_NO},
+	{0x0176, UNICODE_NORM_QC_NO},
+	{0x0177, UNICODE_NORM_QC_NO},
+	{0x0178, UNICODE_NORM_QC_NO},
+	{0x0179, UNICODE_NORM_QC_NO},
+	{0x017A, UNICODE_NORM_QC_NO},
+	{0x017B, UNICODE_NORM_QC_NO},
+	{0x017C, UNICODE_NORM_QC_NO},
+	{0x017D, UNICODE_NORM_QC_NO},
+	{0x017E, UNICODE_NORM_QC_NO},
+	{0x01A0, UNICODE_NORM_QC_NO},
+	{0x01A1, UNICODE_NORM_QC_NO},
+	{0x01AF, UNICODE_NORM_QC_NO},
+	{0x01B0, UNICODE_NORM_QC_NO},
+	{0x01CD, UNICODE_NORM_QC_NO},
+	{0x01CE, UNICODE_NORM_QC_NO},
+	{0x01CF, UNICODE_NORM_QC_NO},
+	{0x01D0, UNICODE_NORM_QC_NO},
+	{0x01D1, UNICODE_NORM_QC_NO},
+	{0x01D2, UNICODE_NORM_QC_NO},
+	{0x01D3, UNICODE_NORM_QC_NO},
+	{0x01D4, UNICODE_NORM_QC_NO},
+	{0x01D5, UNICODE_NORM_QC_NO},
+	{0x01D6, UNICODE_NORM_QC_NO},
+	{0x01D7, UNICODE_NORM_QC_NO},
+	{0x01D8, UNICODE_NORM_QC_NO},
+	{0x01D9, UNICODE_NORM_QC_NO},
+	{0x01DA, UNICODE_NORM_QC_NO},
+	{0x01DB, UNICODE_NORM_QC_NO},
+	{0x01DC, UNICODE_NORM_QC_NO},
+	{0x01DE, UNICODE_NORM_QC_NO},
+	{0x01DF, UNICODE_NORM_QC_NO},
+	{0x01E0, UNICODE_NORM_QC_NO},
+	{0x01E1, UNICODE_NORM_QC_NO},
+	{0x01E2, UNICODE_NORM_QC_NO},
+	{0x01E3, UNICODE_NORM_QC_NO},
+	{0x01E6, UNICODE_NORM_QC_NO},
+	{0x01E7, UNICODE_NORM_QC_NO},
+	{0x01E8, UNICODE_NORM_QC_NO},
+	{0x01E9, UNICODE_NORM_QC_NO},
+	{0x01EA, UNICODE_NORM_QC_NO},
+	{0x01EB, UNICODE_NORM_QC_NO},
+	{0x01EC, UNICODE_NORM_QC_NO},
+	{0x01ED, UNICODE_NORM_QC_NO},
+	{0x01EE, UNICODE_NORM_QC_NO},
+	{0x01EF, UNICODE_NORM_QC_NO},
+	{0x01F0, UNICODE_NORM_QC_NO},
+	{0x01F4, UNICODE_NORM_QC_NO},
+	{0x01F5, UNICODE_NORM_QC_NO},
+	{0x01F8, UNICODE_NORM_QC_NO},
+	{0x01F9, UNICODE_NORM_QC_NO},
+	{0x01FA, UNICODE_NORM_QC_NO},
+	{0x01FB, UNICODE_NORM_QC_NO},
+	{0x01FC, UNICODE_NORM_QC_NO},
+	{0x01FD, UNICODE_NORM_QC_NO},
+	{0x01FE, UNICODE_NORM_QC_NO},
+	{0x01FF, UNICODE_NORM_QC_NO},
+	{0x0200, UNICODE_NORM_QC_NO},
+	{0x0201, UNICODE_NORM_QC_NO},
+	{0x0202, UNICODE_NORM_QC_NO},
+	{0x0203, UNICODE_NORM_QC_NO},
+	{0x0204, UNICODE_NORM_QC_NO},
+	{0x0205, UNICODE_NORM_QC_NO},
+	{0x0206, UNICODE_NORM_QC_NO},
+	{0x0207, UNICODE_NORM_QC_NO},
+	{0x0208, UNICODE_NORM_QC_NO},
+	{0x0209, UNICODE_NORM_QC_NO},
+	{0x020A, UNICODE_NORM_QC_NO},
+	{0x020B, UNICODE_NORM_QC_NO},
+	{0x020C, UNICODE_NORM_QC_NO},
+	{0x020D, UNICODE_NORM_QC_NO},
+	{0x020E, UNICODE_NORM_QC_NO},
+	{0x020F, UNICODE_NORM_QC_NO},
+	{0x0210, UNICODE_NORM_QC_NO},
+	{0x0211, UNICODE_NORM_QC_NO},
+	{0x0212, UNICODE_NORM_QC_NO},
+	{0x0213, UNICODE_NORM_QC_NO},
+	{0x0214, UNICODE_NORM_QC_NO},
+	{0x0215, UNICODE_NORM_QC_NO},
+	{0x0216, UNICODE_NORM_QC_NO},
+	{0x0217, UNICODE_NORM_QC_NO},
+	{0x0218, UNICODE_NORM_QC_NO},
+	{0x0219, UNICODE_NORM_QC_NO},
+	{0x021A, UNICODE_NORM_QC_NO},
+	{0x021B, UNICODE_NORM_QC_NO},
+	{0x021E, UNICODE_NORM_QC_NO},
+	{0x021F, UNICODE_NORM_QC_NO},
+	{0x0226, UNICODE_NORM_QC_NO},
+	{0x0227, UNICODE_NORM_QC_NO},
+	{0x0228, UNICODE_NORM_QC_NO},
+	{0x0229, UNICODE_NORM_QC_NO},
+	{0x022A, UNICODE_NORM_QC_NO},
+	{0x022B, UNICODE_NORM_QC_NO},
+	{0x022C, UNICODE_NORM_QC_NO},
+	{0x022D, UNICODE_NORM_QC_NO},
+	{0x022E, UNICODE_NORM_QC_NO},
+	{0x022F, UNICODE_NORM_QC_NO},
+	{0x0230, UNICODE_NORM_QC_NO},
+	{0x0231, UNICODE_NORM_QC_NO},
+	{0x0232, UNICODE_NORM_QC_NO},
+	{0x0233, UNICODE_NORM_QC_NO},
+	{0x0340, UNICODE_NORM_QC_NO},
+	{0x0341, UNICODE_NORM_QC_NO},
+	{0x0343, UNICODE_NORM_QC_NO},
+	{0x0344, UNICODE_NORM_QC_NO},
+	{0x0374, UNICODE_NORM_QC_NO},
+	{0x037E, UNICODE_NORM_QC_NO},
+	{0x0385, UNICODE_NORM_QC_NO},
+	{0x0386, UNICODE_NORM_QC_NO},
+	{0x0387, UNICODE_NORM_QC_NO},
+	{0x0388, UNICODE_NORM_QC_NO},
+	{0x0389, UNICODE_NORM_QC_NO},
+	{0x038A, UNICODE_NORM_QC_NO},
+	{0x038C, UNICODE_NORM_QC_NO},
+	{0x038E, UNICODE_NORM_QC_NO},
+	{0x038F, UNICODE_NORM_QC_NO},
+	{0x0390, UNICODE_NORM_QC_NO},
+	{0x03AA, UNICODE_NORM_QC_NO},
+	{0x03AB, UNICODE_NORM_QC_NO},
+	{0x03AC, UNICODE_NORM_QC_NO},
+	{0x03AD, UNICODE_NORM_QC_NO},
+	{0x03AE, UNICODE_NORM_QC_NO},
+	{0x03AF, UNICODE_NORM_QC_NO},
+	{0x03B0, UNICODE_NORM_QC_NO},
+	{0x03CA, UNICODE_NORM_QC_NO},
+	{0x03CB, UNICODE_NORM_QC_NO},
+	{0x03CC, UNICODE_NORM_QC_NO},
+	{0x03CD, UNICODE_NORM_QC_NO},
+	{0x03CE, UNICODE_NORM_QC_NO},
+	{0x03D3, UNICODE_NORM_QC_NO},
+	{0x03D4, UNICODE_NORM_QC_NO},
+	{0x0400, UNICODE_NORM_QC_NO},
+	{0x0401, UNICODE_NORM_QC_NO},
+	{0x0403, UNICODE_NORM_QC_NO},
+	{0x0407, UNICODE_NORM_QC_NO},
+	{0x040C, UNICODE_NORM_QC_NO},
+	{0x040D, UNICODE_NORM_QC_NO},
+	{0x040E, UNICODE_NORM_QC_NO},
+	{0x0419, UNICODE_NORM_QC_NO},
+	{0x0439, UNICODE_NORM_QC_NO},
+	{0x0450, UNICODE_NORM_QC_NO},
+	{0x0451, UNICODE_NORM_QC_NO},
+	{0x0453, UNICODE_NORM_QC_NO},
+	{0x0457, UNICODE_NORM_QC_NO},
+	{0x045C, UNICODE_NORM_QC_NO},
+	{0x045D, UNICODE_NORM_QC_NO},
+	{0x045E, UNICODE_NORM_QC_NO},
+	{0x0476, UNICODE_NORM_QC_NO},
+	{0x0477, UNICODE_NORM_QC_NO},
+	{0x04C1, UNICODE_NORM_QC_NO},
+	{0x04C2, UNICODE_NORM_QC_NO},
+	{0x04D0, UNICODE_NORM_QC_NO},
+	{0x04D1, UNICODE_NORM_QC_NO},
+	{0x04D2, UNICODE_NORM_QC_NO},
+	{0x04D3, UNICODE_NORM_QC_NO},
+	{0x04D6, UNICODE_NORM_QC_NO},
+	{0x04D7, UNICODE_NORM_QC_NO},
+	{0x04DA, UNICODE_NORM_QC_NO},
+	{0x04DB, UNICODE_NORM_QC_NO},
+	{0x04DC, UNICODE_NORM_QC_NO},
+	{0x04DD, UNICODE_NORM_QC_NO},
+	{0x04DE, UNICODE_NORM_QC_NO},
+	{0x04DF, UNICODE_NORM_QC_NO},
+	{0x04E2, UNICODE_NORM_QC_NO},
+	{0x04E3, UNICODE_NORM_QC_NO},
+	{0x04E4, UNICODE_NORM_QC_NO},
+	{0x04E5, UNICODE_NORM_QC_NO},
+	{0x04E6, UNICODE_NORM_QC_NO},
+	{0x04E7, UNICODE_NORM_QC_NO},
+	{0x04EA, UNICODE_NORM_QC_NO},
+	{0x04EB, UNICODE_NORM_QC_NO},
+	{0x04EC, UNICODE_NORM_QC_NO},
+	{0x04ED, UNICODE_NORM_QC_NO},
+	{0x04EE, UNICODE_NORM_QC_NO},
+	{0x04EF, UNICODE_NORM_QC_NO},
+	{0x04F0, UNICODE_NORM_QC_NO},
+	{0x04F1, UNICODE_NORM_QC_NO},
+	{0x04F2, UNICODE_NORM_QC_NO},
+	{0x04F3, UNICODE_NORM_QC_NO},
+	{0x04F4, UNICODE_NORM_QC_NO},
+	{0x04F5, UNICODE_NORM_QC_NO},
+	{0x04F8, UNICODE_NORM_QC_NO},
+	{0x04F9, UNICODE_NORM_QC_NO},
+	{0x0622, UNICODE_NORM_QC_NO},
+	{0x0623, UNICODE_NORM_QC_NO},
+	{0x0624, UNICODE_NORM_QC_NO},
+	{0x0625, UNICODE_NORM_QC_NO},
+	{0x0626, UNICODE_NORM_QC_NO},
+	{0x06C0, UNICODE_NORM_QC_NO},
+	{0x06C2, UNICODE_NORM_QC_NO},
+	{0x06D3, UNICODE_NORM_QC_NO},
+	{0x0929, UNICODE_NORM_QC_NO},
+	{0x0931, UNICODE_NORM_QC_NO},
+	{0x0934, UNICODE_NORM_QC_NO},
+	{0x0958, UNICODE_NORM_QC_NO},
+	{0x0959, UNICODE_NORM_QC_NO},
+	{0x095A, UNICODE_NORM_QC_NO},
+	{0x095B, UNICODE_NORM_QC_NO},
+	{0x095C, UNICODE_NORM_QC_NO},
+	{0x095D, UNICODE_NORM_QC_NO},
+	{0x095E, UNICODE_NORM_QC_NO},
+	{0x095F, UNICODE_NORM_QC_NO},
+	{0x09CB, UNICODE_NORM_QC_NO},
+	{0x09CC, UNICODE_NORM_QC_NO},
+	{0x09DC, UNICODE_NORM_QC_NO},
+	{0x09DD, UNICODE_NORM_QC_NO},
+	{0x09DF, UNICODE_NORM_QC_NO},
+	{0x0A33, UNICODE_NORM_QC_NO},
+	{0x0A36, UNICODE_NORM_QC_NO},
+	{0x0A59, UNICODE_NORM_QC_NO},
+	{0x0A5A, UNICODE_NORM_QC_NO},
+	{0x0A5B, UNICODE_NORM_QC_NO},
+	{0x0A5E, UNICODE_NORM_QC_NO},
+	{0x0B48, UNICODE_NORM_QC_NO},
+	{0x0B4B, UNICODE_NORM_QC_NO},
+	{0x0B4C, UNICODE_NORM_QC_NO},
+	{0x0B5C, UNICODE_NORM_QC_NO},
+	{0x0B5D, UNICODE_NORM_QC_NO},
+	{0x0B94, UNICODE_NORM_QC_NO},
+	{0x0BCA, UNICODE_NORM_QC_NO},
+	{0x0BCB, UNICODE_NORM_QC_NO},
+	{0x0BCC, UNICODE_NORM_QC_NO},
+	{0x0C48, UNICODE_NORM_QC_NO},
+	{0x0CC0, UNICODE_NORM_QC_NO},
+	{0x0CC7, UNICODE_NORM_QC_NO},
+	{0x0CC8, UNICODE_NORM_QC_NO},
+	{0x0CCA, UNICODE_NORM_QC_NO},
+	{0x0CCB, UNICODE_NORM_QC_NO},
+	{0x0D4A, UNICODE_NORM_QC_NO},
+	{0x0D4B, UNICODE_NORM_QC_NO},
+	{0x0D4C, UNICODE_NORM_QC_NO},
+	{0x0DDA, UNICODE_NORM_QC_NO},
+	{0x0DDC, UNICODE_NORM_QC_NO},
+	{0x0DDD, UNICODE_NORM_QC_NO},
+	{0x0DDE, UNICODE_NORM_QC_NO},
+	{0x0F43, UNICODE_NORM_QC_NO},
+	{0x0F4D, UNICODE_NORM_QC_NO},
+	{0x0F52, UNICODE_NORM_QC_NO},
+	{0x0F57, UNICODE_NORM_QC_NO},
+	{0x0F5C, UNICODE_NORM_QC_NO},
+	{0x0F69, UNICODE_NORM_QC_NO},
+	{0x0F73, UNICODE_NORM_QC_NO},
+	{0x0F75, UNICODE_NORM_QC_NO},
+	{0x0F76, UNICODE_NORM_QC_NO},
+	{0x0F78, UNICODE_NORM_QC_NO},
+	{0x0F81, UNICODE_NORM_QC_NO},
+	{0x0F93, UNICODE_NORM_QC_NO},
+	{0x0F9D, UNICODE_NORM_QC_NO},
+	{0x0FA2, UNICODE_NORM_QC_NO},
+	{0x0FA7, UNICODE_NORM_QC_NO},
+	{0x0FAC, UNICODE_NORM_QC_NO},
+	{0x0FB9, UNICODE_NORM_QC_NO},
+	{0x1026, UNICODE_NORM_QC_NO},
+	{0x1B06, UNICODE_NORM_QC_NO},
+	{0x1B08, UNICODE_NORM_QC_NO},
+	{0x1B0A, UNICODE_NORM_QC_NO},
+	{0x1B0C, UNICODE_NORM_QC_NO},
+	{0x1B0E, UNICODE_NORM_QC_NO},
+	{0x1B12, UNICODE_NORM_QC_NO},
+	{0x1B3B, UNICODE_NORM_QC_NO},
+	{0x1B3D, UNICODE_NORM_QC_NO},
+	{0x1B40, UNICODE_NORM_QC_NO},
+	{0x1B41, UNICODE_NORM_QC_NO},
+	{0x1B43, UNICODE_NORM_QC_NO},
+	{0x1E00, UNICODE_NORM_QC_NO},
+	{0x1E01, UNICODE_NORM_QC_NO},
+	{0x1E02, UNICODE_NORM_QC_NO},
+	{0x1E03, UNICODE_NORM_QC_NO},
+	{0x1E04, UNICODE_NORM_QC_NO},
+	{0x1E05, UNICODE_NORM_QC_NO},
+	{0x1E06, UNICODE_NORM_QC_NO},
+	{0x1E07, UNICODE_NORM_QC_NO},
+	{0x1E08, UNICODE_NORM_QC_NO},
+	{0x1E09, UNICODE_NORM_QC_NO},
+	{0x1E0A, UNICODE_NORM_QC_NO},
+	{0x1E0B, UNICODE_NORM_QC_NO},
+	{0x1E0C, UNICODE_NORM_QC_NO},
+	{0x1E0D, UNICODE_NORM_QC_NO},
+	{0x1E0E, UNICODE_NORM_QC_NO},
+	{0x1E0F, UNICODE_NORM_QC_NO},
+	{0x1E10, UNICODE_NORM_QC_NO},
+	{0x1E11, UNICODE_NORM_QC_NO},
+	{0x1E12, UNICODE_NORM_QC_NO},
+	{0x1E13, UNICODE_NORM_QC_NO},
+	{0x1E14, UNICODE_NORM_QC_NO},
+	{0x1E15, UNICODE_NORM_QC_NO},
+	{0x1E16, UNICODE_NORM_QC_NO},
+	{0x1E17, UNICODE_NORM_QC_NO},
+	{0x1E18, UNICODE_NORM_QC_NO},
+	{0x1E19, UNICODE_NORM_QC_NO},
+	{0x1E1A, UNICODE_NORM_QC_NO},
+	{0x1E1B, UNICODE_NORM_QC_NO},
+	{0x1E1C, UNICODE_NORM_QC_NO},
+	{0x1E1D, UNICODE_NORM_QC_NO},
+	{0x1E1E, UNICODE_NORM_QC_NO},
+	{0x1E1F, UNICODE_NORM_QC_NO},
+	{0x1E20, UNICODE_NORM_QC_NO},
+	{0x1E21, UNICODE_NORM_QC_NO},
+	{0x1E22, UNICODE_NORM_QC_NO},
+	{0x1E23, UNICODE_NORM_QC_NO},
+	{0x1E24, UNICODE_NORM_QC_NO},
+	{0x1E25, UNICODE_NORM_QC_NO},
+	{0x1E26, UNICODE_NORM_QC_NO},
+	{0x1E27, UNICODE_NORM_QC_NO},
+	{0x1E28, UNICODE_NORM_QC_NO},
+	{0x1E29, UNICODE_NORM_QC_NO},
+	{0x1E2A, UNICODE_NORM_QC_NO},
+	{0x1E2B, UNICODE_NORM_QC_NO},
+	{0x1E2C, UNICODE_NORM_QC_NO},
+	{0x1E2D, UNICODE_NORM_QC_NO},
+	{0x1E2E, UNICODE_NORM_QC_NO},
+	{0x1E2F, UNICODE_NORM_QC_NO},
+	{0x1E30, UNICODE_NORM_QC_NO},
+	{0x1E31, UNICODE_NORM_QC_NO},
+	{0x1E32, UNICODE_NORM_QC_NO},
+	{0x1E33, UNICODE_NORM_QC_NO},
+	{0x1E34, UNICODE_NORM_QC_NO},
+	{0x1E35, UNICODE_NORM_QC_NO},
+	{0x1E36, UNICODE_NORM_QC_NO},
+	{0x1E37, UNICODE_NORM_QC_NO},
+	{0x1E38, UNICODE_NORM_QC_NO},
+	{0x1E39, UNICODE_NORM_QC_NO},
+	{0x1E3A, UNICODE_NORM_QC_NO},
+	{0x1E3B, UNICODE_NORM_QC_NO},
+	{0x1E3C, UNICODE_NORM_QC_NO},
+	{0x1E3D, UNICODE_NORM_QC_NO},
+	{0x1E3E, UNICODE_NORM_QC_NO},
+	{0x1E3F, UNICODE_NORM_QC_NO},
+	{0x1E40, UNICODE_NORM_QC_NO},
+	{0x1E41, UNICODE_NORM_QC_NO},
+	{0x1E42, UNICODE_NORM_QC_NO},
+	{0x1E43, UNICODE_NORM_QC_NO},
+	{0x1E44, UNICODE_NORM_QC_NO},
+	{0x1E45, UNICODE_NORM_QC_NO},
+	{0x1E46, UNICODE_NORM_QC_NO},
+	{0x1E47, UNICODE_NORM_QC_NO},
+	{0x1E48, UNICODE_NORM_QC_NO},
+	{0x1E49, UNICODE_NORM_QC_NO},
+	{0x1E4A, UNICODE_NORM_QC_NO},
+	{0x1E4B, UNICODE_NORM_QC_NO},
+	{0x1E4C, UNICODE_NORM_QC_NO},
+	{0x1E4D, UNICODE_NORM_QC_NO},
+	{0x1E4E, UNICODE_NORM_QC_NO},
+	{0x1E4F, UNICODE_NORM_QC_NO},
+	{0x1E50, UNICODE_NORM_QC_NO},
+	{0x1E51, UNICODE_NORM_QC_NO},
+	{0x1E52, UNICODE_NORM_QC_NO},
+	{0x1E53, UNICODE_NORM_QC_NO},
+	{0x1E54, UNICODE_NORM_QC_NO},
+	{0x1E55, UNICODE_NORM_QC_NO},
+	{0x1E56, UNICODE_NORM_QC_NO},
+	{0x1E57, UNICODE_NORM_QC_NO},
+	{0x1E58, UNICODE_NORM_QC_NO},
+	{0x1E59, UNICODE_NORM_QC_NO},
+	{0x1E5A, UNICODE_NORM_QC_NO},
+	{0x1E5B, UNICODE_NORM_QC_NO},
+	{0x1E5C, UNICODE_NORM_QC_NO},
+	{0x1E5D, UNICODE_NORM_QC_NO},
+	{0x1E5E, UNICODE_NORM_QC_NO},
+	{0x1E5F, UNICODE_NORM_QC_NO},
+	{0x1E60, UNICODE_NORM_QC_NO},
+	{0x1E61, UNICODE_NORM_QC_NO},
+	{0x1E62, UNICODE_NORM_QC_NO},
+	{0x1E63, UNICODE_NORM_QC_NO},
+	{0x1E64, UNICODE_NORM_QC_NO},
+	{0x1E65, UNICODE_NORM_QC_NO},
+	{0x1E66, UNICODE_NORM_QC_NO},
+	{0x1E67, UNICODE_NORM_QC_NO},
+	{0x1E68, UNICODE_NORM_QC_NO},
+	{0x1E69, UNICODE_NORM_QC_NO},
+	{0x1E6A, UNICODE_NORM_QC_NO},
+	{0x1E6B, UNICODE_NORM_QC_NO},
+	{0x1E6C, UNICODE_NORM_QC_NO},
+	{0x1E6D, UNICODE_NORM_QC_NO},
+	{0x1E6E, UNICODE_NORM_QC_NO},
+	{0x1E6F, UNICODE_NORM_QC_NO},
+	{0x1E70, UNICODE_NORM_QC_NO},
+	{0x1E71, UNICODE_NORM_QC_NO},
+	{0x1E72, UNICODE_NORM_QC_NO},
+	{0x1E73, UNICODE_NORM_QC_NO},
+	{0x1E74, UNICODE_NORM_QC_NO},
+	{0x1E75, UNICODE_NORM_QC_NO},
+	{0x1E76, UNICODE_NORM_QC_NO},
+	{0x1E77, UNICODE_NORM_QC_NO},
+	{0x1E78, UNICODE_NORM_QC_NO},
+	{0x1E79, UNICODE_NORM_QC_NO},
+	{0x1E7A, UNICODE_NORM_QC_NO},
+	{0x1E7B, UNICODE_NORM_QC_NO},
+	{0x1E7C, UNICODE_NORM_QC_NO},
+	{0x1E7D, UNICODE_NORM_QC_NO},
+	{0x1E7E, UNICODE_NORM_QC_NO},
+	{0x1E7F, UNICODE_NORM_QC_NO},
+	{0x1E80, UNICODE_NORM_QC_NO},
+	{0x1E81, UNICODE_NORM_QC_NO},
+	{0x1E82, UNICODE_NORM_QC_NO},
+	{0x1E83, UNICODE_NORM_QC_NO},
+	{0x1E84, UNICODE_NORM_QC_NO},
+	{0x1E85, UNICODE_NORM_QC_NO},
+	{0x1E86, UNICODE_NORM_QC_NO},
+	{0x1E87, UNICODE_NORM_QC_NO},
+	{0x1E88, UNICODE_NORM_QC_NO},
+	{0x1E89, UNICODE_NORM_QC_NO},
+	{0x1E8A, UNICODE_NORM_QC_NO},
+	{0x1E8B, UNICODE_NORM_QC_NO},
+	{0x1E8C, UNICODE_NORM_QC_NO},
+	{0x1E8D, UNICODE_NORM_QC_NO},
+	{0x1E8E, UNICODE_NORM_QC_NO},
+	{0x1E8F, UNICODE_NORM_QC_NO},
+	{0x1E90, UNICODE_NORM_QC_NO},
+	{0x1E91, UNICODE_NORM_QC_NO},
+	{0x1E92, UNICODE_NORM_QC_NO},
+	{0x1E93, UNICODE_NORM_QC_NO},
+	{0x1E94, UNICODE_NORM_QC_NO},
+	{0x1E95, UNICODE_NORM_QC_NO},
+	{0x1E96, UNICODE_NORM_QC_NO},
+	{0x1E97, UNICODE_NORM_QC_NO},
+	{0x1E98, UNICODE_NORM_QC_NO},
+	{0x1E99, UNICODE_NORM_QC_NO},
+	{0x1E9B, UNICODE_NORM_QC_NO},
+	{0x1EA0, UNICODE_NORM_QC_NO},
+	{0x1EA1, UNICODE_NORM_QC_NO},
+	{0x1EA2, UNICODE_NORM_QC_NO},
+	{0x1EA3, UNICODE_NORM_QC_NO},
+	{0x1EA4, UNICODE_NORM_QC_NO},
+	{0x1EA5, UNICODE_NORM_QC_NO},
+	{0x1EA6, UNICODE_NORM_QC_NO},
+	{0x1EA7, UNICODE_NORM_QC_NO},
+	{0x1EA8, UNICODE_NORM_QC_NO},
+	{0x1EA9, UNICODE_NORM_QC_NO},
+	{0x1EAA, UNICODE_NORM_QC_NO},
+	{0x1EAB, UNICODE_NORM_QC_NO},
+	{0x1EAC, UNICODE_NORM_QC_NO},
+	{0x1EAD, UNICODE_NORM_QC_NO},
+	{0x1EAE, UNICODE_NORM_QC_NO},
+	{0x1EAF, UNICODE_NORM_QC_NO},
+	{0x1EB0, UNICODE_NORM_QC_NO},
+	{0x1EB1, UNICODE_NORM_QC_NO},
+	{0x1EB2, UNICODE_NORM_QC_NO},
+	{0x1EB3, UNICODE_NORM_QC_NO},
+	{0x1EB4, UNICODE_NORM_QC_NO},
+	{0x1EB5, UNICODE_NORM_QC_NO},
+	{0x1EB6, UNICODE_NORM_QC_NO},
+	{0x1EB7, UNICODE_NORM_QC_NO},
+	{0x1EB8, UNICODE_NORM_QC_NO},
+	{0x1EB9, UNICODE_NORM_QC_NO},
+	{0x1EBA, UNICODE_NORM_QC_NO},
+	{0x1EBB, UNICODE_NORM_QC_NO},
+	{0x1EBC, UNICODE_NORM_QC_NO},
+	{0x1EBD, UNICODE_NORM_QC_NO},
+	{0x1EBE, UNICODE_NORM_QC_NO},
+	{0x1EBF, UNICODE_NORM_QC_NO},
+	{0x1EC0, UNICODE_NORM_QC_NO},
+	{0x1EC1, UNICODE_NORM_QC_NO},
+	{0x1EC2, UNICODE_NORM_QC_NO},
+	{0x1EC3, UNICODE_NORM_QC_NO},
+	{0x1EC4, UNICODE_NORM_QC_NO},
+	{0x1EC5, UNICODE_NORM_QC_NO},
+	{0x1EC6, UNICODE_NORM_QC_NO},
+	{0x1EC7, UNICODE_NORM_QC_NO},
+	{0x1EC8, UNICODE_NORM_QC_NO},
+	{0x1EC9, UNICODE_NORM_QC_NO},
+	{0x1ECA, UNICODE_NORM_QC_NO},
+	{0x1ECB, UNICODE_NORM_QC_NO},
+	{0x1ECC, UNICODE_NORM_QC_NO},
+	{0x1ECD, UNICODE_NORM_QC_NO},
+	{0x1ECE, UNICODE_NORM_QC_NO},
+	{0x1ECF, UNICODE_NORM_QC_NO},
+	{0x1ED0, UNICODE_NORM_QC_NO},
+	{0x1ED1, UNICODE_NORM_QC_NO},
+	{0x1ED2, UNICODE_NORM_QC_NO},
+	{0x1ED3, UNICODE_NORM_QC_NO},
+	{0x1ED4, UNICODE_NORM_QC_NO},
+	{0x1ED5, UNICODE_NORM_QC_NO},
+	{0x1ED6, UNICODE_NORM_QC_NO},
+	{0x1ED7, UNICODE_NORM_QC_NO},
+	{0x1ED8, UNICODE_NORM_QC_NO},
+	{0x1ED9, UNICODE_NORM_QC_NO},
+	{0x1EDA, UNICODE_NORM_QC_NO},
+	{0x1EDB, UNICODE_NORM_QC_NO},
+	{0x1EDC, UNICODE_NORM_QC_NO},
+	{0x1EDD, UNICODE_NORM_QC_NO},
+	{0x1EDE, UNICODE_NORM_QC_NO},
+	{0x1EDF, UNICODE_NORM_QC_NO},
+	{0x1EE0, UNICODE_NORM_QC_NO},
+	{0x1EE1, UNICODE_NORM_QC_NO},
+	{0x1EE2, UNICODE_NORM_QC_NO},
+	{0x1EE3, UNICODE_NORM_QC_NO},
+	{0x1EE4, UNICODE_NORM_QC_NO},
+	{0x1EE5, UNICODE_NORM_QC_NO},
+	{0x1EE6, UNICODE_NORM_QC_NO},
+	{0x1EE7, UNICODE_NORM_QC_NO},
+	{0x1EE8, UNICODE_NORM_QC_NO},
+	{0x1EE9, UNICODE_NORM_QC_NO},
+	{0x1EEA, UNICODE_NORM_QC_NO},
+	{0x1EEB, UNICODE_NORM_QC_NO},
+	{0x1EEC, UNICODE_NORM_QC_NO},
+	{0x1EED, UNICODE_NORM_QC_NO},
+	{0x1EEE, UNICODE_NORM_QC_NO},
+	{0x1EEF, UNICODE_NORM_QC_NO},
+	{0x1EF0, UNICODE_NORM_QC_NO},
+	{0x1EF1, UNICODE_NORM_QC_NO},
+	{0x1EF2, UNICODE_NORM_QC_NO},
+	{0x1EF3, UNICODE_NORM_QC_NO},
+	{0x1EF4, UNICODE_NORM_QC_NO},
+	{0x1EF5, UNICODE_NORM_QC_NO},
+	{0x1EF6, UNICODE_NORM_QC_NO},
+	{0x1EF7, UNICODE_NORM_QC_NO},
+	{0x1EF8, UNICODE_NORM_QC_NO},
+	{0x1EF9, UNICODE_NORM_QC_NO},
+	{0x1F00, UNICODE_NORM_QC_NO},
+	{0x1F01, UNICODE_NORM_QC_NO},
+	{0x1F02, UNICODE_NORM_QC_NO},
+	{0x1F03, UNICODE_NORM_QC_NO},
+	{0x1F04, UNICODE_NORM_QC_NO},
+	{0x1F05, UNICODE_NORM_QC_NO},
+	{0x1F06, UNICODE_NORM_QC_NO},
+	{0x1F07, UNICODE_NORM_QC_NO},
+	{0x1F08, UNICODE_NORM_QC_NO},
+	{0x1F09, UNICODE_NORM_QC_NO},
+	{0x1F0A, UNICODE_NORM_QC_NO},
+	{0x1F0B, UNICODE_NORM_QC_NO},
+	{0x1F0C, UNICODE_NORM_QC_NO},
+	{0x1F0D, UNICODE_NORM_QC_NO},
+	{0x1F0E, UNICODE_NORM_QC_NO},
+	{0x1F0F, UNICODE_NORM_QC_NO},
+	{0x1F10, UNICODE_NORM_QC_NO},
+	{0x1F11, UNICODE_NORM_QC_NO},
+	{0x1F12, UNICODE_NORM_QC_NO},
+	{0x1F13, UNICODE_NORM_QC_NO},
+	{0x1F14, UNICODE_NORM_QC_NO},
+	{0x1F15, UNICODE_NORM_QC_NO},
+	{0x1F18, UNICODE_NORM_QC_NO},
+	{0x1F19, UNICODE_NORM_QC_NO},
+	{0x1F1A, UNICODE_NORM_QC_NO},
+	{0x1F1B, UNICODE_NORM_QC_NO},
+	{0x1F1C, UNICODE_NORM_QC_NO},
+	{0x1F1D, UNICODE_NORM_QC_NO},
+	{0x1F20, UNICODE_NORM_QC_NO},
+	{0x1F21, UNICODE_NORM_QC_NO},
+	{0x1F22, UNICODE_NORM_QC_NO},
+	{0x1F23, UNICODE_NORM_QC_NO},
+	{0x1F24, UNICODE_NORM_QC_NO},
+	{0x1F25, UNICODE_NORM_QC_NO},
+	{0x1F26, UNICODE_NORM_QC_NO},
+	{0x1F27, UNICODE_NORM_QC_NO},
+	{0x1F28, UNICODE_NORM_QC_NO},
+	{0x1F29, UNICODE_NORM_QC_NO},
+	{0x1F2A, UNICODE_NORM_QC_NO},
+	{0x1F2B, UNICODE_NORM_QC_NO},
+	{0x1F2C, UNICODE_NORM_QC_NO},
+	{0x1F2D, UNICODE_NORM_QC_NO},
+	{0x1F2E, UNICODE_NORM_QC_NO},
+	{0x1F2F, UNICODE_NORM_QC_NO},
+	{0x1F30, UNICODE_NORM_QC_NO},
+	{0x1F31, UNICODE_NORM_QC_NO},
+	{0x1F32, UNICODE_NORM_QC_NO},
+	{0x1F33, UNICODE_NORM_QC_NO},
+	{0x1F34, UNICODE_NORM_QC_NO},
+	{0x1F35, UNICODE_NORM_QC_NO},
+	{0x1F36, UNICODE_NORM_QC_NO},
+	{0x1F37, UNICODE_NORM_QC_NO},
+	{0x1F38, UNICODE_NORM_QC_NO},
+	{0x1F39, UNICODE_NORM_QC_NO},
+	{0x1F3A, UNICODE_NORM_QC_NO},
+	{0x1F3B, UNICODE_NORM_QC_NO},
+	{0x1F3C, UNICODE_NORM_QC_NO},
+	{0x1F3D, UNICODE_NORM_QC_NO},
+	{0x1F3E, UNICODE_NORM_QC_NO},
+	{0x1F3F, UNICODE_NORM_QC_NO},
+	{0x1F40, UNICODE_NORM_QC_NO},
+	{0x1F41, UNICODE_NORM_QC_NO},
+	{0x1F42, UNICODE_NORM_QC_NO},
+	{0x1F43, UNICODE_NORM_QC_NO},
+	{0x1F44, UNICODE_NORM_QC_NO},
+	{0x1F45, UNICODE_NORM_QC_NO},
+	{0x1F48, UNICODE_NORM_QC_NO},
+	{0x1F49, UNICODE_NORM_QC_NO},
+	{0x1F4A, UNICODE_NORM_QC_NO},
+	{0x1F4B, UNICODE_NORM_QC_NO},
+	{0x1F4C, UNICODE_NORM_QC_NO},
+	{0x1F4D, UNICODE_NORM_QC_NO},
+	{0x1F50, UNICODE_NORM_QC_NO},
+	{0x1F51, UNICODE_NORM_QC_NO},
+	{0x1F52, UNICODE_NORM_QC_NO},
+	{0x1F53, UNICODE_NORM_QC_NO},
+	{0x1F54, UNICODE_NORM_QC_NO},
+	{0x1F55, UNICODE_NORM_QC_NO},
+	{0x1F56, UNICODE_NORM_QC_NO},
+	{0x1F57, UNICODE_NORM_QC_NO},
+	{0x1F59, UNICODE_NORM_QC_NO},
+	{0x1F5B, UNICODE_NORM_QC_NO},
+	{0x1F5D, UNICODE_NORM_QC_NO},
+	{0x1F5F, UNICODE_NORM_QC_NO},
+	{0x1F60, UNICODE_NORM_QC_NO},
+	{0x1F61, UNICODE_NORM_QC_NO},
+	{0x1F62, UNICODE_NORM_QC_NO},
+	{0x1F63, UNICODE_NORM_QC_NO},
+	{0x1F64, UNICODE_NORM_QC_NO},
+	{0x1F65, UNICODE_NORM_QC_NO},
+	{0x1F66, UNICODE_NORM_QC_NO},
+	{0x1F67, UNICODE_NORM_QC_NO},
+	{0x1F68, UNICODE_NORM_QC_NO},
+	{0x1F69, UNICODE_NORM_QC_NO},
+	{0x1F6A, UNICODE_NORM_QC_NO},
+	{0x1F6B, UNICODE_NORM_QC_NO},
+	{0x1F6C, UNICODE_NORM_QC_NO},
+	{0x1F6D, UNICODE_NORM_QC_NO},
+	{0x1F6E, UNICODE_NORM_QC_NO},
+	{0x1F6F, UNICODE_NORM_QC_NO},
+	{0x1F70, UNICODE_NORM_QC_NO},
+	{0x1F71, UNICODE_NORM_QC_NO},
+	{0x1F72, UNICODE_NORM_QC_NO},
+	{0x1F73, UNICODE_NORM_QC_NO},
+	{0x1F74, UNICODE_NORM_QC_NO},
+	{0x1F75, UNICODE_NORM_QC_NO},
+	{0x1F76, UNICODE_NORM_QC_NO},
+	{0x1F77, UNICODE_NORM_QC_NO},
+	{0x1F78, UNICODE_NORM_QC_NO},
+	{0x1F79, UNICODE_NORM_QC_NO},
+	{0x1F7A, UNICODE_NORM_QC_NO},
+	{0x1F7B, UNICODE_NORM_QC_NO},
+	{0x1F7C, UNICODE_NORM_QC_NO},
+	{0x1F7D, UNICODE_NORM_QC_NO},
+	{0x1F80, UNICODE_NORM_QC_NO},
+	{0x1F81, UNICODE_NORM_QC_NO},
+	{0x1F82, UNICODE_NORM_QC_NO},
+	{0x1F83, UNICODE_NORM_QC_NO},
+	{0x1F84, UNICODE_NORM_QC_NO},
+	{0x1F85, UNICODE_NORM_QC_NO},
+	{0x1F86, UNICODE_NORM_QC_NO},
+	{0x1F87, UNICODE_NORM_QC_NO},
+	{0x1F88, UNICODE_NORM_QC_NO},
+	{0x1F89, UNICODE_NORM_QC_NO},
+	{0x1F8A, UNICODE_NORM_QC_NO},
+	{0x1F8B, UNICODE_NORM_QC_NO},
+	{0x1F8C, UNICODE_NORM_QC_NO},
+	{0x1F8D, UNICODE_NORM_QC_NO},
+	{0x1F8E, UNICODE_NORM_QC_NO},
+	{0x1F8F, UNICODE_NORM_QC_NO},
+	{0x1F90, UNICODE_NORM_QC_NO},
+	{0x1F91, UNICODE_NORM_QC_NO},
+	{0x1F92, UNICODE_NORM_QC_NO},
+	{0x1F93, UNICODE_NORM_QC_NO},
+	{0x1F94, UNICODE_NORM_QC_NO},
+	{0x1F95, UNICODE_NORM_QC_NO},
+	{0x1F96, UNICODE_NORM_QC_NO},
+	{0x1F97, UNICODE_NORM_QC_NO},
+	{0x1F98, UNICODE_NORM_QC_NO},
+	{0x1F99, UNICODE_NORM_QC_NO},
+	{0x1F9A, UNICODE_NORM_QC_NO},
+	{0x1F9B, UNICODE_NORM_QC_NO},
+	{0x1F9C, UNICODE_NORM_QC_NO},
+	{0x1F9D, UNICODE_NORM_QC_NO},
+	{0x1F9E, UNICODE_NORM_QC_NO},
+	{0x1F9F, UNICODE_NORM_QC_NO},
+	{0x1FA0, UNICODE_NORM_QC_NO},
+	{0x1FA1, UNICODE_NORM_QC_NO},
+	{0x1FA2, UNICODE_NORM_QC_NO},
+	{0x1FA3, UNICODE_NORM_QC_NO},
+	{0x1FA4, UNICODE_NORM_QC_NO},
+	{0x1FA5, UNICODE_NORM_QC_NO},
+	{0x1FA6, UNICODE_NORM_QC_NO},
+	{0x1FA7, UNICODE_NORM_QC_NO},
+	{0x1FA8, UNICODE_NORM_QC_NO},
+	{0x1FA9, UNICODE_NORM_QC_NO},
+	{0x1FAA, UNICODE_NORM_QC_NO},
+	{0x1FAB, UNICODE_NORM_QC_NO},
+	{0x1FAC, UNICODE_NORM_QC_NO},
+	{0x1FAD, UNICODE_NORM_QC_NO},
+	{0x1FAE, UNICODE_NORM_QC_NO},
+	{0x1FAF, UNICODE_NORM_QC_NO},
+	{0x1FB0, UNICODE_NORM_QC_NO},
+	{0x1FB1, UNICODE_NORM_QC_NO},
+	{0x1FB2, UNICODE_NORM_QC_NO},
+	{0x1FB3, UNICODE_NORM_QC_NO},
+	{0x1FB4, UNICODE_NORM_QC_NO},
+	{0x1FB6, UNICODE_NORM_QC_NO},
+	{0x1FB7, UNICODE_NORM_QC_NO},
+	{0x1FB8, UNICODE_NORM_QC_NO},
+	{0x1FB9, UNICODE_NORM_QC_NO},
+	{0x1FBA, UNICODE_NORM_QC_NO},
+	{0x1FBB, UNICODE_NORM_QC_NO},
+	{0x1FBC, UNICODE_NORM_QC_NO},
+	{0x1FBE, UNICODE_NORM_QC_NO},
+	{0x1FC1, UNICODE_NORM_QC_NO},
+	{0x1FC2, UNICODE_NORM_QC_NO},
+	{0x1FC3, UNICODE_NORM_QC_NO},
+	{0x1FC4, UNICODE_NORM_QC_NO},
+	{0x1FC6, UNICODE_NORM_QC_NO},
+	{0x1FC7, UNICODE_NORM_QC_NO},
+	{0x1FC8, UNICODE_NORM_QC_NO},
+	{0x1FC9, UNICODE_NORM_QC_NO},
+	{0x1FCA, UNICODE_NORM_QC_NO},
+	{0x1FCB, UNICODE_NORM_QC_NO},
+	{0x1FCC, UNICODE_NORM_QC_NO},
+	{0x1FCD, UNICODE_NORM_QC_NO},
+	{0x1FCE, UNICODE_NORM_QC_NO},
+	{0x1FCF, UNICODE_NORM_QC_NO},
+	{0x1FD0, UNICODE_NORM_QC_NO},
+	{0x1FD1, UNICODE_NORM_QC_NO},
+	{0x1FD2, UNICODE_NORM_QC_NO},
+	{0x1FD3, UNICODE_NORM_QC_NO},
+	{0x1FD6, UNICODE_NORM_QC_NO},
+	{0x1FD7, UNICODE_NORM_QC_NO},
+	{0x1FD8, UNICODE_NORM_QC_NO},
+	{0x1FD9, UNICODE_NORM_QC_NO},
+	{0x1FDA, UNICODE_NORM_QC_NO},
+	{0x1FDB, UNICODE_NORM_QC_NO},
+	{0x1FDD, UNICODE_NORM_QC_NO},
+	{0x1FDE, UNICODE_NORM_QC_NO},
+	{0x1FDF, UNICODE_NORM_QC_NO},
+	{0x1FE0, UNICODE_NORM_QC_NO},
+	{0x1FE1, UNICODE_NORM_QC_NO},
+	{0x1FE2, UNICODE_NORM_QC_NO},
+	{0x1FE3, UNICODE_NORM_QC_NO},
+	{0x1FE4, UNICODE_NORM_QC_NO},
+	{0x1FE5, UNICODE_NORM_QC_NO},
+	{0x1FE6, UNICODE_NORM_QC_NO},
+	{0x1FE7, UNICODE_NORM_QC_NO},
+	{0x1FE8, UNICODE_NORM_QC_NO},
+	{0x1FE9, UNICODE_NORM_QC_NO},
+	{0x1FEA, UNICODE_NORM_QC_NO},
+	{0x1FEB, UNICODE_NORM_QC_NO},
+	{0x1FEC, UNICODE_NORM_QC_NO},
+	{0x1FED, UNICODE_NORM_QC_NO},
+	{0x1FEE, UNICODE_NORM_QC_NO},
+	{0x1FEF, UNICODE_NORM_QC_NO},
+	{0x1FF2, UNICODE_NORM_QC_NO},
+	{0x1FF3, UNICODE_NORM_QC_NO},
+	{0x1FF4, UNICODE_NORM_QC_NO},
+	{0x1FF6, UNICODE_NORM_QC_NO},
+	{0x1FF7, UNICODE_NORM_QC_NO},
+	{0x1FF8, UNICODE_NORM_QC_NO},
+	{0x1FF9, UNICODE_NORM_QC_NO},
+	{0x1FFA, UNICODE_NORM_QC_NO},
+	{0x1FFB, UNICODE_NORM_QC_NO},
+	{0x1FFC, UNICODE_NORM_QC_NO},
+	{0x1FFD, UNICODE_NORM_QC_NO},
+	{0x2000, UNICODE_NORM_QC_NO},
+	{0x2001, UNICODE_NORM_QC_NO},
+	{0x2126, UNICODE_NORM_QC_NO},
+	{0x212A, UNICODE_NORM_QC_NO},
+	{0x212B, UNICODE_NORM_QC_NO},
+	{0x219A, UNICODE_NORM_QC_NO},
+	{0x219B, UNICODE_NORM_QC_NO},
+	{0x21AE, UNICODE_NORM_QC_NO},
+	{0x21CD, UNICODE_NORM_QC_NO},
+	{0x21CE, UNICODE_NORM_QC_NO},
+	{0x21CF, UNICODE_NORM_QC_NO},
+	{0x2204, UNICODE_NORM_QC_NO},
+	{0x2209, UNICODE_NORM_QC_NO},
+	{0x220C, UNICODE_NORM_QC_NO},
+	{0x2224, UNICODE_NORM_QC_NO},
+	{0x2226, UNICODE_NORM_QC_NO},
+	{0x2241, UNICODE_NORM_QC_NO},
+	{0x2244, UNICODE_NORM_QC_NO},
+	{0x2247, UNICODE_NORM_QC_NO},
+	{0x2249, UNICODE_NORM_QC_NO},
+	{0x2260, UNICODE_NORM_QC_NO},
+	{0x2262, UNICODE_NORM_QC_NO},
+	{0x226D, UNICODE_NORM_QC_NO},
+	{0x226E, UNICODE_NORM_QC_NO},
+	{0x226F, UNICODE_NORM_QC_NO},
+	{0x2270, UNICODE_NORM_QC_NO},
+	{0x2271, UNICODE_NORM_QC_NO},
+	{0x2274, UNICODE_NORM_QC_NO},
+	{0x2275, UNICODE_NORM_QC_NO},
+	{0x2278, UNICODE_NORM_QC_NO},
+	{0x2279, UNICODE_NORM_QC_NO},
+	{0x2280, UNICODE_NORM_QC_NO},
+	{0x2281, UNICODE_NORM_QC_NO},
+	{0x2284, UNICODE_NORM_QC_NO},
+	{0x2285, UNICODE_NORM_QC_NO},
+	{0x2288, UNICODE_NORM_QC_NO},
+	{0x2289, UNICODE_NORM_QC_NO},
+	{0x22AC, UNICODE_NORM_QC_NO},
+	{0x22AD, UNICODE_NORM_QC_NO},
+	{0x22AE, UNICODE_NORM_QC_NO},
+	{0x22AF, UNICODE_NORM_QC_NO},
+	{0x22E0, UNICODE_NORM_QC_NO},
+	{0x22E1, UNICODE_NORM_QC_NO},
+	{0x22E2, UNICODE_NORM_QC_NO},
+	{0x22E3, UNICODE_NORM_QC_NO},
+	{0x22EA, UNICODE_NORM_QC_NO},
+	{0x22EB, UNICODE_NORM_QC_NO},
+	{0x22EC, UNICODE_NORM_QC_NO},
+	{0x22ED, UNICODE_NORM_QC_NO},
+	{0x2329, UNICODE_NORM_QC_NO},
+	{0x232A, UNICODE_NORM_QC_NO},
+	{0x2ADC, UNICODE_NORM_QC_NO},
+	{0x304C, UNICODE_NORM_QC_NO},
+	{0x304E, UNICODE_NORM_QC_NO},
+	{0x3050, UNICODE_NORM_QC_NO},
+	{0x3052, UNICODE_NORM_QC_NO},
+	{0x3054, UNICODE_NORM_QC_NO},
+	{0x3056, UNICODE_NORM_QC_NO},
+	{0x3058, UNICODE_NORM_QC_NO},
+	{0x305A, UNICODE_NORM_QC_NO},
+	{0x305C, UNICODE_NORM_QC_NO},
+	{0x305E, UNICODE_NORM_QC_NO},
+	{0x3060, UNICODE_NORM_QC_NO},
+	{0x3062, UNICODE_NORM_QC_NO},
+	{0x3065, UNICODE_NORM_QC_NO},
+	{0x3067, UNICODE_NORM_QC_NO},
+	{0x3069, UNICODE_NORM_QC_NO},
+	{0x3070, UNICODE_NORM_QC_NO},
+	{0x3071, UNICODE_NORM_QC_NO},
+	{0x3073, UNICODE_NORM_QC_NO},
+	{0x3074, UNICODE_NORM_QC_NO},
+	{0x3076, UNICODE_NORM_QC_NO},
+	{0x3077, UNICODE_NORM_QC_NO},
+	{0x3079, UNICODE_NORM_QC_NO},
+	{0x307A, UNICODE_NORM_QC_NO},
+	{0x307C, UNICODE_NORM_QC_NO},
+	{0x307D, UNICODE_NORM_QC_NO},
+	{0x3094, UNICODE_NORM_QC_NO},
+	{0x309E, UNICODE_NORM_QC_NO},
+	{0x30AC, UNICODE_NORM_QC_NO},
+	{0x30AE, UNICODE_NORM_QC_NO},
+	{0x30B0, UNICODE_NORM_QC_NO},
+	{0x30B2, UNICODE_NORM_QC_NO},
+	{0x30B4, UNICODE_NORM_QC_NO},
+	{0x30B6, UNICODE_NORM_QC_NO},
+	{0x30B8, UNICODE_NORM_QC_NO},
+	{0x30BA, UNICODE_NORM_QC_NO},
+	{0x30BC, UNICODE_NORM_QC_NO},
+	{0x30BE, UNICODE_NORM_QC_NO},
+	{0x30C0, UNICODE_NORM_QC_NO},
+	{0x30C2, UNICODE_NORM_QC_NO},
+	{0x30C5, UNICODE_NORM_QC_NO},
+	{0x30C7, UNICODE_NORM_QC_NO},
+	{0x30C9, UNICODE_NORM_QC_NO},
+	{0x30D0, UNICODE_NORM_QC_NO},
+	{0x30D1, UNICODE_NORM_QC_NO},
+	{0x30D3, UNICODE_NORM_QC_NO},
+	{0x30D4, UNICODE_NORM_QC_NO},
+	{0x30D6, UNICODE_NORM_QC_NO},
+	{0x30D7, UNICODE_NORM_QC_NO},
+	{0x30D9, UNICODE_NORM_QC_NO},
+	{0x30DA, UNICODE_NORM_QC_NO},
+	{0x30DC, UNICODE_NORM_QC_NO},
+	{0x30DD, UNICODE_NORM_QC_NO},
+	{0x30F4, UNICODE_NORM_QC_NO},
+	{0x30F7, UNICODE_NORM_QC_NO},
+	{0x30F8, UNICODE_NORM_QC_NO},
+	{0x30F9, UNICODE_NORM_QC_NO},
+	{0x30FA, UNICODE_NORM_QC_NO},
+	{0x30FE, UNICODE_NORM_QC_NO},
+	{0xAC00, UNICODE_NORM_QC_NO},
+	{0xAC01, UNICODE_NORM_QC_NO},
+	{0xAC02, UNICODE_NORM_QC_NO},
+	{0xAC03, UNICODE_NORM_QC_NO},
+	{0xAC04, UNICODE_NORM_QC_NO},
+	{0xAC05, UNICODE_NORM_QC_NO},
+	{0xAC06, UNICODE_NORM_QC_NO},
+	{0xAC07, UNICODE_NORM_QC_NO},
+	{0xAC08, UNICODE_NORM_QC_NO},
+	{0xAC09, UNICODE_NORM_QC_NO},
+	{0xAC0A, UNICODE_NORM_QC_NO},
+	{0xAC0B, UNICODE_NORM_QC_NO},
+	{0xAC0C, UNICODE_NORM_QC_NO},
+	{0xAC0D, UNICODE_NORM_QC_NO},
+	{0xAC0E, UNICODE_NORM_QC_NO},
+	{0xAC0F, UNICODE_NORM_QC_NO},
+	{0xAC10, UNICODE_NORM_QC_NO},
+	{0xAC11, UNICODE_NORM_QC_NO},
+	{0xAC12, UNICODE_NORM_QC_NO},
+	{0xAC13, UNICODE_NORM_QC_NO},
+	{0xAC14, UNICODE_NORM_QC_NO},
+	{0xAC15, UNICODE_NORM_QC_NO},
+	{0xAC16, UNICODE_NORM_QC_NO},
+	{0xAC17, UNICODE_NORM_QC_NO},
+	{0xAC18, UNICODE_NORM_QC_NO},
+	{0xAC19, UNICODE_NORM_QC_NO},
+	{0xAC1A, UNICODE_NORM_QC_NO},
+	{0xAC1B, UNICODE_NORM_QC_NO},
+	{0xAC1C, UNICODE_NORM_QC_NO},
+	{0xAC1D, UNICODE_NORM_QC_NO},
+	{0xAC1E, UNICODE_NORM_QC_NO},
+	{0xAC1F, UNICODE_NORM_QC_NO},
+	{0xAC20, UNICODE_NORM_QC_NO},
+	{0xAC21, UNICODE_NORM_QC_NO},
+	{0xAC22, UNICODE_NORM_QC_NO},
+	{0xAC23, UNICODE_NORM_QC_NO},
+	{0xAC24, UNICODE_NORM_QC_NO},
+	{0xAC25, UNICODE_NORM_QC_NO},
+	{0xAC26, UNICODE_NORM_QC_NO},
+	{0xAC27, UNICODE_NORM_QC_NO},
+	{0xAC28, UNICODE_NORM_QC_NO},
+	{0xAC29, UNICODE_NORM_QC_NO},
+	{0xAC2A, UNICODE_NORM_QC_NO},
+	{0xAC2B, UNICODE_NORM_QC_NO},
+	{0xAC2C, UNICODE_NORM_QC_NO},
+	{0xAC2D, UNICODE_NORM_QC_NO},
+	{0xAC2E, UNICODE_NORM_QC_NO},
+	{0xAC2F, UNICODE_NORM_QC_NO},
+	{0xAC30, UNICODE_NORM_QC_NO},
+	{0xAC31, UNICODE_NORM_QC_NO},
+	{0xAC32, UNICODE_NORM_QC_NO},
+	{0xAC33, UNICODE_NORM_QC_NO},
+	{0xAC34, UNICODE_NORM_QC_NO},
+	{0xAC35, UNICODE_NORM_QC_NO},
+	{0xAC36, UNICODE_NORM_QC_NO},
+	{0xAC37, UNICODE_NORM_QC_NO},
+	{0xAC38, UNICODE_NORM_QC_NO},
+	{0xAC39, UNICODE_NORM_QC_NO},
+	{0xAC3A, UNICODE_NORM_QC_NO},
+	{0xAC3B, UNICODE_NORM_QC_NO},
+	{0xAC3C, UNICODE_NORM_QC_NO},
+	{0xAC3D, UNICODE_NORM_QC_NO},
+	{0xAC3E, UNICODE_NORM_QC_NO},
+	{0xAC3F, UNICODE_NORM_QC_NO},
+	{0xAC40, UNICODE_NORM_QC_NO},
+	{0xAC41, UNICODE_NORM_QC_NO},
+	{0xAC42, UNICODE_NORM_QC_NO},
+	{0xAC43, UNICODE_NORM_QC_NO},
+	{0xAC44, UNICODE_NORM_QC_NO},
+	{0xAC45, UNICODE_NORM_QC_NO},
+	{0xAC46, UNICODE_NORM_QC_NO},
+	{0xAC47, UNICODE_NORM_QC_NO},
+	{0xAC48, UNICODE_NORM_QC_NO},
+	{0xAC49, UNICODE_NORM_QC_NO},
+	{0xAC4A, UNICODE_NORM_QC_NO},
+	{0xAC4B, UNICODE_NORM_QC_NO},
+	{0xAC4C, UNICODE_NORM_QC_NO},
+	{0xAC4D, UNICODE_NORM_QC_NO},
+	{0xAC4E, UNICODE_NORM_QC_NO},
+	{0xAC4F, UNICODE_NORM_QC_NO},
+	{0xAC50, UNICODE_NORM_QC_NO},
+	{0xAC51, UNICODE_NORM_QC_NO},
+	{0xAC52, UNICODE_NORM_QC_NO},
+	{0xAC53, UNICODE_NORM_QC_NO},
+	{0xAC54, UNICODE_NORM_QC_NO},
+	{0xAC55, UNICODE_NORM_QC_NO},
+	{0xAC56, UNICODE_NORM_QC_NO},
+	{0xAC57, UNICODE_NORM_QC_NO},
+	{0xAC58, UNICODE_NORM_QC_NO},
+	{0xAC59, UNICODE_NORM_QC_NO},
+	{0xAC5A, UNICODE_NORM_QC_NO},
+	{0xAC5B, UNICODE_NORM_QC_NO},
+	{0xAC5C, UNICODE_NORM_QC_NO},
+	{0xAC5D, UNICODE_NORM_QC_NO},
+	{0xAC5E, UNICODE_NORM_QC_NO},
+	{0xAC5F, UNICODE_NORM_QC_NO},
+	{0xAC60, UNICODE_NORM_QC_NO},
+	{0xAC61, UNICODE_NORM_QC_NO},
+	{0xAC62, UNICODE_NORM_QC_NO},
+	{0xAC63, UNICODE_NORM_QC_NO},
+	{0xAC64, UNICODE_NORM_QC_NO},
+	{0xAC65, UNICODE_NORM_QC_NO},
+	{0xAC66, UNICODE_NORM_QC_NO},
+	{0xAC67, UNICODE_NORM_QC_NO},
+	{0xAC68, UNICODE_NORM_QC_NO},
+	{0xAC69, UNICODE_NORM_QC_NO},
+	{0xAC6A, UNICODE_NORM_QC_NO},
+	{0xAC6B, UNICODE_NORM_QC_NO},
+	{0xAC6C, UNICODE_NORM_QC_NO},
+	{0xAC6D, UNICODE_NORM_QC_NO},
+	{0xAC6E, UNICODE_NORM_QC_NO},
+	{0xAC6F, UNICODE_NORM_QC_NO},
+	{0xAC70, UNICODE_NORM_QC_NO},
+	{0xAC71, UNICODE_NORM_QC_NO},
+	{0xAC72, UNICODE_NORM_QC_NO},
+	{0xAC73, UNICODE_NORM_QC_NO},
+	{0xAC74, UNICODE_NORM_QC_NO},
+	{0xAC75, UNICODE_NORM_QC_NO},
+	{0xAC76, UNICODE_NORM_QC_NO},
+	{0xAC77, UNICODE_NORM_QC_NO},
+	{0xAC78, UNICODE_NORM_QC_NO},
+	{0xAC79, UNICODE_NORM_QC_NO},
+	{0xAC7A, UNICODE_NORM_QC_NO},
+	{0xAC7B, UNICODE_NORM_QC_NO},
+	{0xAC7C, UNICODE_NORM_QC_NO},
+	{0xAC7D, UNICODE_NORM_QC_NO},
+	{0xAC7E, UNICODE_NORM_QC_NO},
+	{0xAC7F, UNICODE_NORM_QC_NO},
+	{0xAC80, UNICODE_NORM_QC_NO},
+	{0xAC81, UNICODE_NORM_QC_NO},
+	{0xAC82, UNICODE_NORM_QC_NO},
+	{0xAC83, UNICODE_NORM_QC_NO},
+	{0xAC84, UNICODE_NORM_QC_NO},
+	{0xAC85, UNICODE_NORM_QC_NO},
+	{0xAC86, UNICODE_NORM_QC_NO},
+	{0xAC87, UNICODE_NORM_QC_NO},
+	{0xAC88, UNICODE_NORM_QC_NO},
+	{0xAC89, UNICODE_NORM_QC_NO},
+	{0xAC8A, UNICODE_NORM_QC_NO},
+	{0xAC8B, UNICODE_NORM_QC_NO},
+	{0xAC8C, UNICODE_NORM_QC_NO},
+	{0xAC8D, UNICODE_NORM_QC_NO},
+	{0xAC8E, UNICODE_NORM_QC_NO},
+	{0xAC8F, UNICODE_NORM_QC_NO},
+	{0xAC90, UNICODE_NORM_QC_NO},
+	{0xAC91, UNICODE_NORM_QC_NO},
+	{0xAC92, UNICODE_NORM_QC_NO},
+	{0xAC93, UNICODE_NORM_QC_NO},
+	{0xAC94, UNICODE_NORM_QC_NO},
+	{0xAC95, UNICODE_NORM_QC_NO},
+	{0xAC96, UNICODE_NORM_QC_NO},
+	{0xAC97, UNICODE_NORM_QC_NO},
+	{0xAC98, UNICODE_NORM_QC_NO},
+	{0xAC99, UNICODE_NORM_QC_NO},
+	{0xAC9A, UNICODE_NORM_QC_NO},
+	{0xAC9B, UNICODE_NORM_QC_NO},
+	{0xAC9C, UNICODE_NORM_QC_NO},
+	{0xAC9D, UNICODE_NORM_QC_NO},
+	{0xAC9E, UNICODE_NORM_QC_NO},
+	{0xAC9F, UNICODE_NORM_QC_NO},
+	{0xACA0, UNICODE_NORM_QC_NO},
+	{0xACA1, UNICODE_NORM_QC_NO},
+	{0xACA2, UNICODE_NORM_QC_NO},
+	{0xACA3, UNICODE_NORM_QC_NO},
+	{0xACA4, UNICODE_NORM_QC_NO},
+	{0xACA5, UNICODE_NORM_QC_NO},
+	{0xACA6, UNICODE_NORM_QC_NO},
+	{0xACA7, UNICODE_NORM_QC_NO},
+	{0xACA8, UNICODE_NORM_QC_NO},
+	{0xACA9, UNICODE_NORM_QC_NO},
+	{0xACAA, UNICODE_NORM_QC_NO},
+	{0xACAB, UNICODE_NORM_QC_NO},
+	{0xACAC, UNICODE_NORM_QC_NO},
+	{0xACAD, UNICODE_NORM_QC_NO},
+	{0xACAE, UNICODE_NORM_QC_NO},
+	{0xACAF, UNICODE_NORM_QC_NO},
+	{0xACB0, UNICODE_NORM_QC_NO},
+	{0xACB1, UNICODE_NORM_QC_NO},
+	{0xACB2, UNICODE_NORM_QC_NO},
+	{0xACB3, UNICODE_NORM_QC_NO},
+	{0xACB4, UNICODE_NORM_QC_NO},
+	{0xACB5, UNICODE_NORM_QC_NO},
+	{0xACB6, UNICODE_NORM_QC_NO},
+	{0xACB7, UNICODE_NORM_QC_NO},
+	{0xACB8, UNICODE_NORM_QC_NO},
+	{0xACB9, UNICODE_NORM_QC_NO},
+	{0xACBA, UNICODE_NORM_QC_NO},
+	{0xACBB, UNICODE_NORM_QC_NO},
+	{0xACBC, UNICODE_NORM_QC_NO},
+	{0xACBD, UNICODE_NORM_QC_NO},
+	{0xACBE, UNICODE_NORM_QC_NO},
+	{0xACBF, UNICODE_NORM_QC_NO},
+	{0xACC0, UNICODE_NORM_QC_NO},
+	{0xACC1, UNICODE_NORM_QC_NO},
+	{0xACC2, UNICODE_NORM_QC_NO},
+	{0xACC3, UNICODE_NORM_QC_NO},
+	{0xACC4, UNICODE_NORM_QC_NO},
+	{0xACC5, UNICODE_NORM_QC_NO},
+	{0xACC6, UNICODE_NORM_QC_NO},
+	{0xACC7, UNICODE_NORM_QC_NO},
+	{0xACC8, UNICODE_NORM_QC_NO},
+	{0xACC9, UNICODE_NORM_QC_NO},
+	{0xACCA, UNICODE_NORM_QC_NO},
+	{0xACCB, UNICODE_NORM_QC_NO},
+	{0xACCC, UNICODE_NORM_QC_NO},
+	{0xACCD, UNICODE_NORM_QC_NO},
+	{0xACCE, UNICODE_NORM_QC_NO},
+	{0xACCF, UNICODE_NORM_QC_NO},
+	{0xACD0, UNICODE_NORM_QC_NO},
+	{0xACD1, UNICODE_NORM_QC_NO},
+	{0xACD2, UNICODE_NORM_QC_NO},
+	{0xACD3, UNICODE_NORM_QC_NO},
+	{0xACD4, UNICODE_NORM_QC_NO},
+	{0xACD5, UNICODE_NORM_QC_NO},
+	{0xACD6, UNICODE_NORM_QC_NO},
+	{0xACD7, UNICODE_NORM_QC_NO},
+	{0xACD8, UNICODE_NORM_QC_NO},
+	{0xACD9, UNICODE_NORM_QC_NO},
+	{0xACDA, UNICODE_NORM_QC_NO},
+	{0xACDB, UNICODE_NORM_QC_NO},
+	{0xACDC, UNICODE_NORM_QC_NO},
+	{0xACDD, UNICODE_NORM_QC_NO},
+	{0xACDE, UNICODE_NORM_QC_NO},
+	{0xACDF, UNICODE_NORM_QC_NO},
+	{0xACE0, UNICODE_NORM_QC_NO},
+	{0xACE1, UNICODE_NORM_QC_NO},
+	{0xACE2, UNICODE_NORM_QC_NO},
+	{0xACE3, UNICODE_NORM_QC_NO},
+	{0xACE4, UNICODE_NORM_QC_NO},
+	{0xACE5, UNICODE_NORM_QC_NO},
+	{0xACE6, UNICODE_NORM_QC_NO},
+	{0xACE7, UNICODE_NORM_QC_NO},
+	{0xACE8, UNICODE_NORM_QC_NO},
+	{0xACE9, UNICODE_NORM_QC_NO},
+	{0xACEA, UNICODE_NORM_QC_NO},
+	{0xACEB, UNICODE_NORM_QC_NO},
+	{0xACEC, UNICODE_NORM_QC_NO},
+	{0xACED, UNICODE_NORM_QC_NO},
+	{0xACEE, UNICODE_NORM_QC_NO},
+	{0xACEF, UNICODE_NORM_QC_NO},
+	{0xACF0, UNICODE_NORM_QC_NO},
+	{0xACF1, UNICODE_NORM_QC_NO},
+	{0xACF2, UNICODE_NORM_QC_NO},
+	{0xACF3, UNICODE_NORM_QC_NO},
+	{0xACF4, UNICODE_NORM_QC_NO},
+	{0xACF5, UNICODE_NORM_QC_NO},
+	{0xACF6, UNICODE_NORM_QC_NO},
+	{0xACF7, UNICODE_NORM_QC_NO},
+	{0xACF8, UNICODE_NORM_QC_NO},
+	{0xACF9, UNICODE_NORM_QC_NO},
+	{0xACFA, UNICODE_NORM_QC_NO},
+	{0xACFB, UNICODE_NORM_QC_NO},
+	{0xACFC, UNICODE_NORM_QC_NO},
+	{0xACFD, UNICODE_NORM_QC_NO},
+	{0xACFE, UNICODE_NORM_QC_NO},
+	{0xACFF, UNICODE_NORM_QC_NO},
+	{0xAD00, UNICODE_NORM_QC_NO},
+	{0xAD01, UNICODE_NORM_QC_NO},
+	{0xAD02, UNICODE_NORM_QC_NO},
+	{0xAD03, UNICODE_NORM_QC_NO},
+	{0xAD04, UNICODE_NORM_QC_NO},
+	{0xAD05, UNICODE_NORM_QC_NO},
+	{0xAD06, UNICODE_NORM_QC_NO},
+	{0xAD07, UNICODE_NORM_QC_NO},
+	{0xAD08, UNICODE_NORM_QC_NO},
+	{0xAD09, UNICODE_NORM_QC_NO},
+	{0xAD0A, UNICODE_NORM_QC_NO},
+	{0xAD0B, UNICODE_NORM_QC_NO},
+	{0xAD0C, UNICODE_NORM_QC_NO},
+	{0xAD0D, UNICODE_NORM_QC_NO},
+	{0xAD0E, UNICODE_NORM_QC_NO},
+	{0xAD0F, UNICODE_NORM_QC_NO},
+	{0xAD10, UNICODE_NORM_QC_NO},
+	{0xAD11, UNICODE_NORM_QC_NO},
+	{0xAD12, UNICODE_NORM_QC_NO},
+	{0xAD13, UNICODE_NORM_QC_NO},
+	{0xAD14, UNICODE_NORM_QC_NO},
+	{0xAD15, UNICODE_NORM_QC_NO},
+	{0xAD16, UNICODE_NORM_QC_NO},
+	{0xAD17, UNICODE_NORM_QC_NO},
+	{0xAD18, UNICODE_NORM_QC_NO},
+	{0xAD19, UNICODE_NORM_QC_NO},
+	{0xAD1A, UNICODE_NORM_QC_NO},
+	{0xAD1B, UNICODE_NORM_QC_NO},
+	{0xAD1C, UNICODE_NORM_QC_NO},
+	{0xAD1D, UNICODE_NORM_QC_NO},
+	{0xAD1E, UNICODE_NORM_QC_NO},
+	{0xAD1F, UNICODE_NORM_QC_NO},
+	{0xAD20, UNICODE_NORM_QC_NO},
+	{0xAD21, UNICODE_NORM_QC_NO},
+	{0xAD22, UNICODE_NORM_QC_NO},
+	{0xAD23, UNICODE_NORM_QC_NO},
+	{0xAD24, UNICODE_NORM_QC_NO},
+	{0xAD25, UNICODE_NORM_QC_NO},
+	{0xAD26, UNICODE_NORM_QC_NO},
+	{0xAD27, UNICODE_NORM_QC_NO},
+	{0xAD28, UNICODE_NORM_QC_NO},
+	{0xAD29, UNICODE_NORM_QC_NO},
+	{0xAD2A, UNICODE_NORM_QC_NO},
+	{0xAD2B, UNICODE_NORM_QC_NO},
+	{0xAD2C, UNICODE_NORM_QC_NO},
+	{0xAD2D, UNICODE_NORM_QC_NO},
+	{0xAD2E, UNICODE_NORM_QC_NO},
+	{0xAD2F, UNICODE_NORM_QC_NO},
+	{0xAD30, UNICODE_NORM_QC_NO},
+	{0xAD31, UNICODE_NORM_QC_NO},
+	{0xAD32, UNICODE_NORM_QC_NO},
+	{0xAD33, UNICODE_NORM_QC_NO},
+	{0xAD34, UNICODE_NORM_QC_NO},
+	{0xAD35, UNICODE_NORM_QC_NO},
+	{0xAD36, UNICODE_NORM_QC_NO},
+	{0xAD37, UNICODE_NORM_QC_NO},
+	{0xAD38, UNICODE_NORM_QC_NO},
+	{0xAD39, UNICODE_NORM_QC_NO},
+	{0xAD3A, UNICODE_NORM_QC_NO},
+	{0xAD3B, UNICODE_NORM_QC_NO},
+	{0xAD3C, UNICODE_NORM_QC_NO},
+	{0xAD3D, UNICODE_NORM_QC_NO},
+	{0xAD3E, UNICODE_NORM_QC_NO},
+	{0xAD3F, UNICODE_NORM_QC_NO},
+	{0xAD40, UNICODE_NORM_QC_NO},
+	{0xAD41, UNICODE_NORM_QC_NO},
+	{0xAD42, UNICODE_NORM_QC_NO},
+	{0xAD43, UNICODE_NORM_QC_NO},
+	{0xAD44, UNICODE_NORM_QC_NO},
+	{0xAD45, UNICODE_NORM_QC_NO},
+	{0xAD46, UNICODE_NORM_QC_NO},
+	{0xAD47, UNICODE_NORM_QC_NO},
+	{0xAD48, UNICODE_NORM_QC_NO},
+	{0xAD49, UNICODE_NORM_QC_NO},
+	{0xAD4A, UNICODE_NORM_QC_NO},
+	{0xAD4B, UNICODE_NORM_QC_NO},
+	{0xAD4C, UNICODE_NORM_QC_NO},
+	{0xAD4D, UNICODE_NORM_QC_NO},
+	{0xAD4E, UNICODE_NORM_QC_NO},
+	{0xAD4F, UNICODE_NORM_QC_NO},
+	{0xAD50, UNICODE_NORM_QC_NO},
+	{0xAD51, UNICODE_NORM_QC_NO},
+	{0xAD52, UNICODE_NORM_QC_NO},
+	{0xAD53, UNICODE_NORM_QC_NO},
+	{0xAD54, UNICODE_NORM_QC_NO},
+	{0xAD55, UNICODE_NORM_QC_NO},
+	{0xAD56, UNICODE_NORM_QC_NO},
+	{0xAD57, UNICODE_NORM_QC_NO},
+	{0xAD58, UNICODE_NORM_QC_NO},
+	{0xAD59, UNICODE_NORM_QC_NO},
+	{0xAD5A, UNICODE_NORM_QC_NO},
+	{0xAD5B, UNICODE_NORM_QC_NO},
+	{0xAD5C, UNICODE_NORM_QC_NO},
+	{0xAD5D, UNICODE_NORM_QC_NO},
+	{0xAD5E, UNICODE_NORM_QC_NO},
+	{0xAD5F, UNICODE_NORM_QC_NO},
+	{0xAD60, UNICODE_NORM_QC_NO},
+	{0xAD61, UNICODE_NORM_QC_NO},
+	{0xAD62, UNICODE_NORM_QC_NO},
+	{0xAD63, UNICODE_NORM_QC_NO},
+	{0xAD64, UNICODE_NORM_QC_NO},
+	{0xAD65, UNICODE_NORM_QC_NO},
+	{0xAD66, UNICODE_NORM_QC_NO},
+	{0xAD67, UNICODE_NORM_QC_NO},
+	{0xAD68, UNICODE_NORM_QC_NO},
+	{0xAD69, UNICODE_NORM_QC_NO},
+	{0xAD6A, UNICODE_NORM_QC_NO},
+	{0xAD6B, UNICODE_NORM_QC_NO},
+	{0xAD6C, UNICODE_NORM_QC_NO},
+	{0xAD6D, UNICODE_NORM_QC_NO},
+	{0xAD6E, UNICODE_NORM_QC_NO},
+	{0xAD6F, UNICODE_NORM_QC_NO},
+	{0xAD70, UNICODE_NORM_QC_NO},
+	{0xAD71, UNICODE_NORM_QC_NO},
+	{0xAD72, UNICODE_NORM_QC_NO},
+	{0xAD73, UNICODE_NORM_QC_NO},
+	{0xAD74, UNICODE_NORM_QC_NO},
+	{0xAD75, UNICODE_NORM_QC_NO},
+	{0xAD76, UNICODE_NORM_QC_NO},
+	{0xAD77, UNICODE_NORM_QC_NO},
+	{0xAD78, UNICODE_NORM_QC_NO},
+	{0xAD79, UNICODE_NORM_QC_NO},
+	{0xAD7A, UNICODE_NORM_QC_NO},
+	{0xAD7B, UNICODE_NORM_QC_NO},
+	{0xAD7C, UNICODE_NORM_QC_NO},
+	{0xAD7D, UNICODE_NORM_QC_NO},
+	{0xAD7E, UNICODE_NORM_QC_NO},
+	{0xAD7F, UNICODE_NORM_QC_NO},
+	{0xAD80, UNICODE_NORM_QC_NO},
+	{0xAD81, UNICODE_NORM_QC_NO},
+	{0xAD82, UNICODE_NORM_QC_NO},
+	{0xAD83, UNICODE_NORM_QC_NO},
+	{0xAD84, UNICODE_NORM_QC_NO},
+	{0xAD85, UNICODE_NORM_QC_NO},
+	{0xAD86, UNICODE_NORM_QC_NO},
+	{0xAD87, UNICODE_NORM_QC_NO},
+	{0xAD88, UNICODE_NORM_QC_NO},
+	{0xAD89, UNICODE_NORM_QC_NO},
+	{0xAD8A, UNICODE_NORM_QC_NO},
+	{0xAD8B, UNICODE_NORM_QC_NO},
+	{0xAD8C, UNICODE_NORM_QC_NO},
+	{0xAD8D, UNICODE_NORM_QC_NO},
+	{0xAD8E, UNICODE_NORM_QC_NO},
+	{0xAD8F, UNICODE_NORM_QC_NO},
+	{0xAD90, UNICODE_NORM_QC_NO},
+	{0xAD91, UNICODE_NORM_QC_NO},
+	{0xAD92, UNICODE_NORM_QC_NO},
+	{0xAD93, UNICODE_NORM_QC_NO},
+	{0xAD94, UNICODE_NORM_QC_NO},
+	{0xAD95, UNICODE_NORM_QC_NO},
+	{0xAD96, UNICODE_NORM_QC_NO},
+	{0xAD97, UNICODE_NORM_QC_NO},
+	{0xAD98, UNICODE_NORM_QC_NO},
+	{0xAD99, UNICODE_NORM_QC_NO},
+	{0xAD9A, UNICODE_NORM_QC_NO},
+	{0xAD9B, UNICODE_NORM_QC_NO},
+	{0xAD9C, UNICODE_NORM_QC_NO},
+	{0xAD9D, UNICODE_NORM_QC_NO},
+	{0xAD9E, UNICODE_NORM_QC_NO},
+	{0xAD9F, UNICODE_NORM_QC_NO},
+	{0xADA0, UNICODE_NORM_QC_NO},
+	{0xADA1, UNICODE_NORM_QC_NO},
+	{0xADA2, UNICODE_NORM_QC_NO},
+	{0xADA3, UNICODE_NORM_QC_NO},
+	{0xADA4, UNICODE_NORM_QC_NO},
+	{0xADA5, UNICODE_NORM_QC_NO},
+	{0xADA6, UNICODE_NORM_QC_NO},
+	{0xADA7, UNICODE_NORM_QC_NO},
+	{0xADA8, UNICODE_NORM_QC_NO},
+	{0xADA9, UNICODE_NORM_QC_NO},
+	{0xADAA, UNICODE_NORM_QC_NO},
+	{0xADAB, UNICODE_NORM_QC_NO},
+	{0xADAC, UNICODE_NORM_QC_NO},
+	{0xADAD, UNICODE_NORM_QC_NO},
+	{0xADAE, UNICODE_NORM_QC_NO},
+	{0xADAF, UNICODE_NORM_QC_NO},
+	{0xADB0, UNICODE_NORM_QC_NO},
+	{0xADB1, UNICODE_NORM_QC_NO},
+	{0xADB2, UNICODE_NORM_QC_NO},
+	{0xADB3, UNICODE_NORM_QC_NO},
+	{0xADB4, UNICODE_NORM_QC_NO},
+	{0xADB5, UNICODE_NORM_QC_NO},
+	{0xADB6, UNICODE_NORM_QC_NO},
+	{0xADB7, UNICODE_NORM_QC_NO},
+	{0xADB8, UNICODE_NORM_QC_NO},
+	{0xADB9, UNICODE_NORM_QC_NO},
+	{0xADBA, UNICODE_NORM_QC_NO},
+	{0xADBB, UNICODE_NORM_QC_NO},
+	{0xADBC, UNICODE_NORM_QC_NO},
+	{0xADBD, UNICODE_NORM_QC_NO},
+	{0xADBE, UNICODE_NORM_QC_NO},
+	{0xADBF, UNICODE_NORM_QC_NO},
+	{0xADC0, UNICODE_NORM_QC_NO},
+	{0xADC1, UNICODE_NORM_QC_NO},
+	{0xADC2, UNICODE_NORM_QC_NO},
+	{0xADC3, UNICODE_NORM_QC_NO},
+	{0xADC4, UNICODE_NORM_QC_NO},
+	{0xADC5, UNICODE_NORM_QC_NO},
+	{0xADC6, UNICODE_NORM_QC_NO},
+	{0xADC7, UNICODE_NORM_QC_NO},
+	{0xADC8, UNICODE_NORM_QC_NO},
+	{0xADC9, UNICODE_NORM_QC_NO},
+	{0xADCA, UNICODE_NORM_QC_NO},
+	{0xADCB, UNICODE_NORM_QC_NO},
+	{0xADCC, UNICODE_NORM_QC_NO},
+	{0xADCD, UNICODE_NORM_QC_NO},
+	{0xADCE, UNICODE_NORM_QC_NO},
+	{0xADCF, UNICODE_NORM_QC_NO},
+	{0xADD0, UNICODE_NORM_QC_NO},
+	{0xADD1, UNICODE_NORM_QC_NO},
+	{0xADD2, UNICODE_NORM_QC_NO},
+	{0xADD3, UNICODE_NORM_QC_NO},
+	{0xADD4, UNICODE_NORM_QC_NO},
+	{0xADD5, UNICODE_NORM_QC_NO},
+	{0xADD6, UNICODE_NORM_QC_NO},
+	{0xADD7, UNICODE_NORM_QC_NO},
+	{0xADD8, UNICODE_NORM_QC_NO},
+	{0xADD9, UNICODE_NORM_QC_NO},
+	{0xADDA, UNICODE_NORM_QC_NO},
+	{0xADDB, UNICODE_NORM_QC_NO},
+	{0xADDC, UNICODE_NORM_QC_NO},
+	{0xADDD, UNICODE_NORM_QC_NO},
+	{0xADDE, UNICODE_NORM_QC_NO},
+	{0xADDF, UNICODE_NORM_QC_NO},
+	{0xADE0, UNICODE_NORM_QC_NO},
+	{0xADE1, UNICODE_NORM_QC_NO},
+	{0xADE2, UNICODE_NORM_QC_NO},
+	{0xADE3, UNICODE_NORM_QC_NO},
+	{0xADE4, UNICODE_NORM_QC_NO},
+	{0xADE5, UNICODE_NORM_QC_NO},
+	{0xADE6, UNICODE_NORM_QC_NO},
+	{0xADE7, UNICODE_NORM_QC_NO},
+	{0xADE8, UNICODE_NORM_QC_NO},
+	{0xADE9, UNICODE_NORM_QC_NO},
+	{0xADEA, UNICODE_NORM_QC_NO},
+	{0xADEB, UNICODE_NORM_QC_NO},
+	{0xADEC, UNICODE_NORM_QC_NO},
+	{0xADED, UNICODE_NORM_QC_NO},
+	{0xADEE, UNICODE_NORM_QC_NO},
+	{0xADEF, UNICODE_NORM_QC_NO},
+	{0xADF0, UNICODE_NORM_QC_NO},
+	{0xADF1, UNICODE_NORM_QC_NO},
+	{0xADF2, UNICODE_NORM_QC_NO},
+	{0xADF3, UNICODE_NORM_QC_NO},
+	{0xADF4, UNICODE_NORM_QC_NO},
+	{0xADF5, UNICODE_NORM_QC_NO},
+	{0xADF6, UNICODE_NORM_QC_NO},
+	{0xADF7, UNICODE_NORM_QC_NO},
+	{0xADF8, UNICODE_NORM_QC_NO},
+	{0xADF9, UNICODE_NORM_QC_NO},
+	{0xADFA, UNICODE_NORM_QC_NO},
+	{0xADFB, UNICODE_NORM_QC_NO},
+	{0xADFC, UNICODE_NORM_QC_NO},
+	{0xADFD, UNICODE_NORM_QC_NO},
+	{0xADFE, UNICODE_NORM_QC_NO},
+	{0xADFF, UNICODE_NORM_QC_NO},
+	{0xAE00, UNICODE_NORM_QC_NO},
+	{0xAE01, UNICODE_NORM_QC_NO},
+	{0xAE02, UNICODE_NORM_QC_NO},
+	{0xAE03, UNICODE_NORM_QC_NO},
+	{0xAE04, UNICODE_NORM_QC_NO},
+	{0xAE05, UNICODE_NORM_QC_NO},
+	{0xAE06, UNICODE_NORM_QC_NO},
+	{0xAE07, UNICODE_NORM_QC_NO},
+	{0xAE08, UNICODE_NORM_QC_NO},
+	{0xAE09, UNICODE_NORM_QC_NO},
+	{0xAE0A, UNICODE_NORM_QC_NO},
+	{0xAE0B, UNICODE_NORM_QC_NO},
+	{0xAE0C, UNICODE_NORM_QC_NO},
+	{0xAE0D, UNICODE_NORM_QC_NO},
+	{0xAE0E, UNICODE_NORM_QC_NO},
+	{0xAE0F, UNICODE_NORM_QC_NO},
+	{0xAE10, UNICODE_NORM_QC_NO},
+	{0xAE11, UNICODE_NORM_QC_NO},
+	{0xAE12, UNICODE_NORM_QC_NO},
+	{0xAE13, UNICODE_NORM_QC_NO},
+	{0xAE14, UNICODE_NORM_QC_NO},
+	{0xAE15, UNICODE_NORM_QC_NO},
+	{0xAE16, UNICODE_NORM_QC_NO},
+	{0xAE17, UNICODE_NORM_QC_NO},
+	{0xAE18, UNICODE_NORM_QC_NO},
+	{0xAE19, UNICODE_NORM_QC_NO},
+	{0xAE1A, UNICODE_NORM_QC_NO},
+	{0xAE1B, UNICODE_NORM_QC_NO},
+	{0xAE1C, UNICODE_NORM_QC_NO},
+	{0xAE1D, UNICODE_NORM_QC_NO},
+	{0xAE1E, UNICODE_NORM_QC_NO},
+	{0xAE1F, UNICODE_NORM_QC_NO},
+	{0xAE20, UNICODE_NORM_QC_NO},
+	{0xAE21, UNICODE_NORM_QC_NO},
+	{0xAE22, UNICODE_NORM_QC_NO},
+	{0xAE23, UNICODE_NORM_QC_NO},
+	{0xAE24, UNICODE_NORM_QC_NO},
+	{0xAE25, UNICODE_NORM_QC_NO},
+	{0xAE26, UNICODE_NORM_QC_NO},
+	{0xAE27, UNICODE_NORM_QC_NO},
+	{0xAE28, UNICODE_NORM_QC_NO},
+	{0xAE29, UNICODE_NORM_QC_NO},
+	{0xAE2A, UNICODE_NORM_QC_NO},
+	{0xAE2B, UNICODE_NORM_QC_NO},
+	{0xAE2C, UNICODE_NORM_QC_NO},
+	{0xAE2D, UNICODE_NORM_QC_NO},
+	{0xAE2E, UNICODE_NORM_QC_NO},
+	{0xAE2F, UNICODE_NORM_QC_NO},
+	{0xAE30, UNICODE_NORM_QC_NO},
+	{0xAE31, UNICODE_NORM_QC_NO},
+	{0xAE32, UNICODE_NORM_QC_NO},
+	{0xAE33, UNICODE_NORM_QC_NO},
+	{0xAE34, UNICODE_NORM_QC_NO},
+	{0xAE35, UNICODE_NORM_QC_NO},
+	{0xAE36, UNICODE_NORM_QC_NO},
+	{0xAE37, UNICODE_NORM_QC_NO},
+	{0xAE38, UNICODE_NORM_QC_NO},
+	{0xAE39, UNICODE_NORM_QC_NO},
+	{0xAE3A, UNICODE_NORM_QC_NO},
+	{0xAE3B, UNICODE_NORM_QC_NO},
+	{0xAE3C, UNICODE_NORM_QC_NO},
+	{0xAE3D, UNICODE_NORM_QC_NO},
+	{0xAE3E, UNICODE_NORM_QC_NO},
+	{0xAE3F, UNICODE_NORM_QC_NO},
+	{0xAE40, UNICODE_NORM_QC_NO},
+	{0xAE41, UNICODE_NORM_QC_NO},
+	{0xAE42, UNICODE_NORM_QC_NO},
+	{0xAE43, UNICODE_NORM_QC_NO},
+	{0xAE44, UNICODE_NORM_QC_NO},
+	{0xAE45, UNICODE_NORM_QC_NO},
+	{0xAE46, UNICODE_NORM_QC_NO},
+	{0xAE47, UNICODE_NORM_QC_NO},
+	{0xAE48, UNICODE_NORM_QC_NO},
+	{0xAE49, UNICODE_NORM_QC_NO},
+	{0xAE4A, UNICODE_NORM_QC_NO},
+	{0xAE4B, UNICODE_NORM_QC_NO},
+	{0xAE4C, UNICODE_NORM_QC_NO},
+	{0xAE4D, UNICODE_NORM_QC_NO},
+	{0xAE4E, UNICODE_NORM_QC_NO},
+	{0xAE4F, UNICODE_NORM_QC_NO},
+	{0xAE50, UNICODE_NORM_QC_NO},
+	{0xAE51, UNICODE_NORM_QC_NO},
+	{0xAE52, UNICODE_NORM_QC_NO},
+	{0xAE53, UNICODE_NORM_QC_NO},
+	{0xAE54, UNICODE_NORM_QC_NO},
+	{0xAE55, UNICODE_NORM_QC_NO},
+	{0xAE56, UNICODE_NORM_QC_NO},
+	{0xAE57, UNICODE_NORM_QC_NO},
+	{0xAE58, UNICODE_NORM_QC_NO},
+	{0xAE59, UNICODE_NORM_QC_NO},
+	{0xAE5A, UNICODE_NORM_QC_NO},
+	{0xAE5B, UNICODE_NORM_QC_NO},
+	{0xAE5C, UNICODE_NORM_QC_NO},
+	{0xAE5D, UNICODE_NORM_QC_NO},
+	{0xAE5E, UNICODE_NORM_QC_NO},
+	{0xAE5F, UNICODE_NORM_QC_NO},
+	{0xAE60, UNICODE_NORM_QC_NO},
+	{0xAE61, UNICODE_NORM_QC_NO},
+	{0xAE62, UNICODE_NORM_QC_NO},
+	{0xAE63, UNICODE_NORM_QC_NO},
+	{0xAE64, UNICODE_NORM_QC_NO},
+	{0xAE65, UNICODE_NORM_QC_NO},
+	{0xAE66, UNICODE_NORM_QC_NO},
+	{0xAE67, UNICODE_NORM_QC_NO},
+	{0xAE68, UNICODE_NORM_QC_NO},
+	{0xAE69, UNICODE_NORM_QC_NO},
+	{0xAE6A, UNICODE_NORM_QC_NO},
+	{0xAE6B, UNICODE_NORM_QC_NO},
+	{0xAE6C, UNICODE_NORM_QC_NO},
+	{0xAE6D, UNICODE_NORM_QC_NO},
+	{0xAE6E, UNICODE_NORM_QC_NO},
+	{0xAE6F, UNICODE_NORM_QC_NO},
+	{0xAE70, UNICODE_NORM_QC_NO},
+	{0xAE71, UNICODE_NORM_QC_NO},
+	{0xAE72, UNICODE_NORM_QC_NO},
+	{0xAE73, UNICODE_NORM_QC_NO},
+	{0xAE74, UNICODE_NORM_QC_NO},
+	{0xAE75, UNICODE_NORM_QC_NO},
+	{0xAE76, UNICODE_NORM_QC_NO},
+	{0xAE77, UNICODE_NORM_QC_NO},
+	{0xAE78, UNICODE_NORM_QC_NO},
+	{0xAE79, UNICODE_NORM_QC_NO},
+	{0xAE7A, UNICODE_NORM_QC_NO},
+	{0xAE7B, UNICODE_NORM_QC_NO},
+	{0xAE7C, UNICODE_NORM_QC_NO},
+	{0xAE7D, UNICODE_NORM_QC_NO},
+	{0xAE7E, UNICODE_NORM_QC_NO},
+	{0xAE7F, UNICODE_NORM_QC_NO},
+	{0xAE80, UNICODE_NORM_QC_NO},
+	{0xAE81, UNICODE_NORM_QC_NO},
+	{0xAE82, UNICODE_NORM_QC_NO},
+	{0xAE83, UNICODE_NORM_QC_NO},
+	{0xAE84, UNICODE_NORM_QC_NO},
+	{0xAE85, UNICODE_NORM_QC_NO},
+	{0xAE86, UNICODE_NORM_QC_NO},
+	{0xAE87, UNICODE_NORM_QC_NO},
+	{0xAE88, UNICODE_NORM_QC_NO},
+	{0xAE89, UNICODE_NORM_QC_NO},
+	{0xAE8A, UNICODE_NORM_QC_NO},
+	{0xAE8B, UNICODE_NORM_QC_NO},
+	{0xAE8C, UNICODE_NORM_QC_NO},
+	{0xAE8D, UNICODE_NORM_QC_NO},
+	{0xAE8E, UNICODE_NORM_QC_NO},
+	{0xAE8F, UNICODE_NORM_QC_NO},
+	{0xAE90, UNICODE_NORM_QC_NO},
+	{0xAE91, UNICODE_NORM_QC_NO},
+	{0xAE92, UNICODE_NORM_QC_NO},
+	{0xAE93, UNICODE_NORM_QC_NO},
+	{0xAE94, UNICODE_NORM_QC_NO},
+	{0xAE95, UNICODE_NORM_QC_NO},
+	{0xAE96, UNICODE_NORM_QC_NO},
+	{0xAE97, UNICODE_NORM_QC_NO},
+	{0xAE98, UNICODE_NORM_QC_NO},
+	{0xAE99, UNICODE_NORM_QC_NO},
+	{0xAE9A, UNICODE_NORM_QC_NO},
+	{0xAE9B, UNICODE_NORM_QC_NO},
+	{0xAE9C, UNICODE_NORM_QC_NO},
+	{0xAE9D, UNICODE_NORM_QC_NO},
+	{0xAE9E, UNICODE_NORM_QC_NO},
+	{0xAE9F, UNICODE_NORM_QC_NO},
+	{0xAEA0, UNICODE_NORM_QC_NO},
+	{0xAEA1, UNICODE_NORM_QC_NO},
+	{0xAEA2, UNICODE_NORM_QC_NO},
+	{0xAEA3, UNICODE_NORM_QC_NO},
+	{0xAEA4, UNICODE_NORM_QC_NO},
+	{0xAEA5, UNICODE_NORM_QC_NO},
+	{0xAEA6, UNICODE_NORM_QC_NO},
+	{0xAEA7, UNICODE_NORM_QC_NO},
+	{0xAEA8, UNICODE_NORM_QC_NO},
+	{0xAEA9, UNICODE_NORM_QC_NO},
+	{0xAEAA, UNICODE_NORM_QC_NO},
+	{0xAEAB, UNICODE_NORM_QC_NO},
+	{0xAEAC, UNICODE_NORM_QC_NO},
+	{0xAEAD, UNICODE_NORM_QC_NO},
+	{0xAEAE, UNICODE_NORM_QC_NO},
+	{0xAEAF, UNICODE_NORM_QC_NO},
+	{0xAEB0, UNICODE_NORM_QC_NO},
+	{0xAEB1, UNICODE_NORM_QC_NO},
+	{0xAEB2, UNICODE_NORM_QC_NO},
+	{0xAEB3, UNICODE_NORM_QC_NO},
+	{0xAEB4, UNICODE_NORM_QC_NO},
+	{0xAEB5, UNICODE_NORM_QC_NO},
+	{0xAEB6, UNICODE_NORM_QC_NO},
+	{0xAEB7, UNICODE_NORM_QC_NO},
+	{0xAEB8, UNICODE_NORM_QC_NO},
+	{0xAEB9, UNICODE_NORM_QC_NO},
+	{0xAEBA, UNICODE_NORM_QC_NO},
+	{0xAEBB, UNICODE_NORM_QC_NO},
+	{0xAEBC, UNICODE_NORM_QC_NO},
+	{0xAEBD, UNICODE_NORM_QC_NO},
+	{0xAEBE, UNICODE_NORM_QC_NO},
+	{0xAEBF, UNICODE_NORM_QC_NO},
+	{0xAEC0, UNICODE_NORM_QC_NO},
+	{0xAEC1, UNICODE_NORM_QC_NO},
+	{0xAEC2, UNICODE_NORM_QC_NO},
+	{0xAEC3, UNICODE_NORM_QC_NO},
+	{0xAEC4, UNICODE_NORM_QC_NO},
+	{0xAEC5, UNICODE_NORM_QC_NO},
+	{0xAEC6, UNICODE_NORM_QC_NO},
+	{0xAEC7, UNICODE_NORM_QC_NO},
+	{0xAEC8, UNICODE_NORM_QC_NO},
+	{0xAEC9, UNICODE_NORM_QC_NO},
+	{0xAECA, UNICODE_NORM_QC_NO},
+	{0xAECB, UNICODE_NORM_QC_NO},
+	{0xAECC, UNICODE_NORM_QC_NO},
+	{0xAECD, UNICODE_NORM_QC_NO},
+	{0xAECE, UNICODE_NORM_QC_NO},
+	{0xAECF, UNICODE_NORM_QC_NO},
+	{0xAED0, UNICODE_NORM_QC_NO},
+	{0xAED1, UNICODE_NORM_QC_NO},
+	{0xAED2, UNICODE_NORM_QC_NO},
+	{0xAED3, UNICODE_NORM_QC_NO},
+	{0xAED4, UNICODE_NORM_QC_NO},
+	{0xAED5, UNICODE_NORM_QC_NO},
+	{0xAED6, UNICODE_NORM_QC_NO},
+	{0xAED7, UNICODE_NORM_QC_NO},
+	{0xAED8, UNICODE_NORM_QC_NO},
+	{0xAED9, UNICODE_NORM_QC_NO},
+	{0xAEDA, UNICODE_NORM_QC_NO},
+	{0xAEDB, UNICODE_NORM_QC_NO},
+	{0xAEDC, UNICODE_NORM_QC_NO},
+	{0xAEDD, UNICODE_NORM_QC_NO},
+	{0xAEDE, UNICODE_NORM_QC_NO},
+	{0xAEDF, UNICODE_NORM_QC_NO},
+	{0xAEE0, UNICODE_NORM_QC_NO},
+	{0xAEE1, UNICODE_NORM_QC_NO},
+	{0xAEE2, UNICODE_NORM_QC_NO},
+	{0xAEE3, UNICODE_NORM_QC_NO},
+	{0xAEE4, UNICODE_NORM_QC_NO},
+	{0xAEE5, UNICODE_NORM_QC_NO},
+	{0xAEE6, UNICODE_NORM_QC_NO},
+	{0xAEE7, UNICODE_NORM_QC_NO},
+	{0xAEE8, UNICODE_NORM_QC_NO},
+	{0xAEE9, UNICODE_NORM_QC_NO},
+	{0xAEEA, UNICODE_NORM_QC_NO},
+	{0xAEEB, UNICODE_NORM_QC_NO},
+	{0xAEEC, UNICODE_NORM_QC_NO},
+	{0xAEED, UNICODE_NORM_QC_NO},
+	{0xAEEE, UNICODE_NORM_QC_NO},
+	{0xAEEF, UNICODE_NORM_QC_NO},
+	{0xAEF0, UNICODE_NORM_QC_NO},
+	{0xAEF1, UNICODE_NORM_QC_NO},
+	{0xAEF2, UNICODE_NORM_QC_NO},
+	{0xAEF3, UNICODE_NORM_QC_NO},
+	{0xAEF4, UNICODE_NORM_QC_NO},
+	{0xAEF5, UNICODE_NORM_QC_NO},
+	{0xAEF6, UNICODE_NORM_QC_NO},
+	{0xAEF7, UNICODE_NORM_QC_NO},
+	{0xAEF8, UNICODE_NORM_QC_NO},
+	{0xAEF9, UNICODE_NORM_QC_NO},
+	{0xAEFA, UNICODE_NORM_QC_NO},
+	{0xAEFB, UNICODE_NORM_QC_NO},
+	{0xAEFC, UNICODE_NORM_QC_NO},
+	{0xAEFD, UNICODE_NORM_QC_NO},
+	{0xAEFE, UNICODE_NORM_QC_NO},
+	{0xAEFF, UNICODE_NORM_QC_NO},
+	{0xAF00, UNICODE_NORM_QC_NO},
+	{0xAF01, UNICODE_NORM_QC_NO},
+	{0xAF02, UNICODE_NORM_QC_NO},
+	{0xAF03, UNICODE_NORM_QC_NO},
+	{0xAF04, UNICODE_NORM_QC_NO},
+	{0xAF05, UNICODE_NORM_QC_NO},
+	{0xAF06, UNICODE_NORM_QC_NO},
+	{0xAF07, UNICODE_NORM_QC_NO},
+	{0xAF08, UNICODE_NORM_QC_NO},
+	{0xAF09, UNICODE_NORM_QC_NO},
+	{0xAF0A, UNICODE_NORM_QC_NO},
+	{0xAF0B, UNICODE_NORM_QC_NO},
+	{0xAF0C, UNICODE_NORM_QC_NO},
+	{0xAF0D, UNICODE_NORM_QC_NO},
+	{0xAF0E, UNICODE_NORM_QC_NO},
+	{0xAF0F, UNICODE_NORM_QC_NO},
+	{0xAF10, UNICODE_NORM_QC_NO},
+	{0xAF11, UNICODE_NORM_QC_NO},
+	{0xAF12, UNICODE_NORM_QC_NO},
+	{0xAF13, UNICODE_NORM_QC_NO},
+	{0xAF14, UNICODE_NORM_QC_NO},
+	{0xAF15, UNICODE_NORM_QC_NO},
+	{0xAF16, UNICODE_NORM_QC_NO},
+	{0xAF17, UNICODE_NORM_QC_NO},
+	{0xAF18, UNICODE_NORM_QC_NO},
+	{0xAF19, UNICODE_NORM_QC_NO},
+	{0xAF1A, UNICODE_NORM_QC_NO},
+	{0xAF1B, UNICODE_NORM_QC_NO},
+	{0xAF1C, UNICODE_NORM_QC_NO},
+	{0xAF1D, UNICODE_NORM_QC_NO},
+	{0xAF1E, UNICODE_NORM_QC_NO},
+	{0xAF1F, UNICODE_NORM_QC_NO},
+	{0xAF20, UNICODE_NORM_QC_NO},
+	{0xAF21, UNICODE_NORM_QC_NO},
+	{0xAF22, UNICODE_NORM_QC_NO},
+	{0xAF23, UNICODE_NORM_QC_NO},
+	{0xAF24, UNICODE_NORM_QC_NO},
+	{0xAF25, UNICODE_NORM_QC_NO},
+	{0xAF26, UNICODE_NORM_QC_NO},
+	{0xAF27, UNICODE_NORM_QC_NO},
+	{0xAF28, UNICODE_NORM_QC_NO},
+	{0xAF29, UNICODE_NORM_QC_NO},
+	{0xAF2A, UNICODE_NORM_QC_NO},
+	{0xAF2B, UNICODE_NORM_QC_NO},
+	{0xAF2C, UNICODE_NORM_QC_NO},
+	{0xAF2D, UNICODE_NORM_QC_NO},
+	{0xAF2E, UNICODE_NORM_QC_NO},
+	{0xAF2F, UNICODE_NORM_QC_NO},
+	{0xAF30, UNICODE_NORM_QC_NO},
+	{0xAF31, UNICODE_NORM_QC_NO},
+	{0xAF32, UNICODE_NORM_QC_NO},
+	{0xAF33, UNICODE_NORM_QC_NO},
+	{0xAF34, UNICODE_NORM_QC_NO},
+	{0xAF35, UNICODE_NORM_QC_NO},
+	{0xAF36, UNICODE_NORM_QC_NO},
+	{0xAF37, UNICODE_NORM_QC_NO},
+	{0xAF38, UNICODE_NORM_QC_NO},
+	{0xAF39, UNICODE_NORM_QC_NO},
+	{0xAF3A, UNICODE_NORM_QC_NO},
+	{0xAF3B, UNICODE_NORM_QC_NO},
+	{0xAF3C, UNICODE_NORM_QC_NO},
+	{0xAF3D, UNICODE_NORM_QC_NO},
+	{0xAF3E, UNICODE_NORM_QC_NO},
+	{0xAF3F, UNICODE_NORM_QC_NO},
+	{0xAF40, UNICODE_NORM_QC_NO},
+	{0xAF41, UNICODE_NORM_QC_NO},
+	{0xAF42, UNICODE_NORM_QC_NO},
+	{0xAF43, UNICODE_NORM_QC_NO},
+	{0xAF44, UNICODE_NORM_QC_NO},
+	{0xAF45, UNICODE_NORM_QC_NO},
+	{0xAF46, UNICODE_NORM_QC_NO},
+	{0xAF47, UNICODE_NORM_QC_NO},
+	{0xAF48, UNICODE_NORM_QC_NO},
+	{0xAF49, UNICODE_NORM_QC_NO},
+	{0xAF4A, UNICODE_NORM_QC_NO},
+	{0xAF4B, UNICODE_NORM_QC_NO},
+	{0xAF4C, UNICODE_NORM_QC_NO},
+	{0xAF4D, UNICODE_NORM_QC_NO},
+	{0xAF4E, UNICODE_NORM_QC_NO},
+	{0xAF4F, UNICODE_NORM_QC_NO},
+	{0xAF50, UNICODE_NORM_QC_NO},
+	{0xAF51, UNICODE_NORM_QC_NO},
+	{0xAF52, UNICODE_NORM_QC_NO},
+	{0xAF53, UNICODE_NORM_QC_NO},
+	{0xAF54, UNICODE_NORM_QC_NO},
+	{0xAF55, UNICODE_NORM_QC_NO},
+	{0xAF56, UNICODE_NORM_QC_NO},
+	{0xAF57, UNICODE_NORM_QC_NO},
+	{0xAF58, UNICODE_NORM_QC_NO},
+	{0xAF59, UNICODE_NORM_QC_NO},
+	{0xAF5A, UNICODE_NORM_QC_NO},
+	{0xAF5B, UNICODE_NORM_QC_NO},
+	{0xAF5C, UNICODE_NORM_QC_NO},
+	{0xAF5D, UNICODE_NORM_QC_NO},
+	{0xAF5E, UNICODE_NORM_QC_NO},
+	{0xAF5F, UNICODE_NORM_QC_NO},
+	{0xAF60, UNICODE_NORM_QC_NO},
+	{0xAF61, UNICODE_NORM_QC_NO},
+	{0xAF62, UNICODE_NORM_QC_NO},
+	{0xAF63, UNICODE_NORM_QC_NO},
+	{0xAF64, UNICODE_NORM_QC_NO},
+	{0xAF65, UNICODE_NORM_QC_NO},
+	{0xAF66, UNICODE_NORM_QC_NO},
+	{0xAF67, UNICODE_NORM_QC_NO},
+	{0xAF68, UNICODE_NORM_QC_NO},
+	{0xAF69, UNICODE_NORM_QC_NO},
+	{0xAF6A, UNICODE_NORM_QC_NO},
+	{0xAF6B, UNICODE_NORM_QC_NO},
+	{0xAF6C, UNICODE_NORM_QC_NO},
+	{0xAF6D, UNICODE_NORM_QC_NO},
+	{0xAF6E, UNICODE_NORM_QC_NO},
+	{0xAF6F, UNICODE_NORM_QC_NO},
+	{0xAF70, UNICODE_NORM_QC_NO},
+	{0xAF71, UNICODE_NORM_QC_NO},
+	{0xAF72, UNICODE_NORM_QC_NO},
+	{0xAF73, UNICODE_NORM_QC_NO},
+	{0xAF74, UNICODE_NORM_QC_NO},
+	{0xAF75, UNICODE_NORM_QC_NO},
+	{0xAF76, UNICODE_NORM_QC_NO},
+	{0xAF77, UNICODE_NORM_QC_NO},
+	{0xAF78, UNICODE_NORM_QC_NO},
+	{0xAF79, UNICODE_NORM_QC_NO},
+	{0xAF7A, UNICODE_NORM_QC_NO},
+	{0xAF7B, UNICODE_NORM_QC_NO},
+	{0xAF7C, UNICODE_NORM_QC_NO},
+	{0xAF7D, UNICODE_NORM_QC_NO},
+	{0xAF7E, UNICODE_NORM_QC_NO},
+	{0xAF7F, UNICODE_NORM_QC_NO},
+	{0xAF80, UNICODE_NORM_QC_NO},
+	{0xAF81, UNICODE_NORM_QC_NO},
+	{0xAF82, UNICODE_NORM_QC_NO},
+	{0xAF83, UNICODE_NORM_QC_NO},
+	{0xAF84, UNICODE_NORM_QC_NO},
+	{0xAF85, UNICODE_NORM_QC_NO},
+	{0xAF86, UNICODE_NORM_QC_NO},
+	{0xAF87, UNICODE_NORM_QC_NO},
+	{0xAF88, UNICODE_NORM_QC_NO},
+	{0xAF89, UNICODE_NORM_QC_NO},
+	{0xAF8A, UNICODE_NORM_QC_NO},
+	{0xAF8B, UNICODE_NORM_QC_NO},
+	{0xAF8C, UNICODE_NORM_QC_NO},
+	{0xAF8D, UNICODE_NORM_QC_NO},
+	{0xAF8E, UNICODE_NORM_QC_NO},
+	{0xAF8F, UNICODE_NORM_QC_NO},
+	{0xAF90, UNICODE_NORM_QC_NO},
+	{0xAF91, UNICODE_NORM_QC_NO},
+	{0xAF92, UNICODE_NORM_QC_NO},
+	{0xAF93, UNICODE_NORM_QC_NO},
+	{0xAF94, UNICODE_NORM_QC_NO},
+	{0xAF95, UNICODE_NORM_QC_NO},
+	{0xAF96, UNICODE_NORM_QC_NO},
+	{0xAF97, UNICODE_NORM_QC_NO},
+	{0xAF98, UNICODE_NORM_QC_NO},
+	{0xAF99, UNICODE_NORM_QC_NO},
+	{0xAF9A, UNICODE_NORM_QC_NO},
+	{0xAF9B, UNICODE_NORM_QC_NO},
+	{0xAF9C, UNICODE_NORM_QC_NO},
+	{0xAF9D, UNICODE_NORM_QC_NO},
+	{0xAF9E, UNICODE_NORM_QC_NO},
+	{0xAF9F, UNICODE_NORM_QC_NO},
+	{0xAFA0, UNICODE_NORM_QC_NO},
+	{0xAFA1, UNICODE_NORM_QC_NO},
+	{0xAFA2, UNICODE_NORM_QC_NO},
+	{0xAFA3, UNICODE_NORM_QC_NO},
+	{0xAFA4, UNICODE_NORM_QC_NO},
+	{0xAFA5, UNICODE_NORM_QC_NO},
+	{0xAFA6, UNICODE_NORM_QC_NO},
+	{0xAFA7, UNICODE_NORM_QC_NO},
+	{0xAFA8, UNICODE_NORM_QC_NO},
+	{0xAFA9, UNICODE_NORM_QC_NO},
+	{0xAFAA, UNICODE_NORM_QC_NO},
+	{0xAFAB, UNICODE_NORM_QC_NO},
+	{0xAFAC, UNICODE_NORM_QC_NO},
+	{0xAFAD, UNICODE_NORM_QC_NO},
+	{0xAFAE, UNICODE_NORM_QC_NO},
+	{0xAFAF, UNICODE_NORM_QC_NO},
+	{0xAFB0, UNICODE_NORM_QC_NO},
+	{0xAFB1, UNICODE_NORM_QC_NO},
+	{0xAFB2, UNICODE_NORM_QC_NO},
+	{0xAFB3, UNICODE_NORM_QC_NO},
+	{0xAFB4, UNICODE_NORM_QC_NO},
+	{0xAFB5, UNICODE_NORM_QC_NO},
+	{0xAFB6, UNICODE_NORM_QC_NO},
+	{0xAFB7, UNICODE_NORM_QC_NO},
+	{0xAFB8, UNICODE_NORM_QC_NO},
+	{0xAFB9, UNICODE_NORM_QC_NO},
+	{0xAFBA, UNICODE_NORM_QC_NO},
+	{0xAFBB, UNICODE_NORM_QC_NO},
+	{0xAFBC, UNICODE_NORM_QC_NO},
+	{0xAFBD, UNICODE_NORM_QC_NO},
+	{0xAFBE, UNICODE_NORM_QC_NO},
+	{0xAFBF, UNICODE_NORM_QC_NO},
+	{0xAFC0, UNICODE_NORM_QC_NO},
+	{0xAFC1, UNICODE_NORM_QC_NO},
+	{0xAFC2, UNICODE_NORM_QC_NO},
+	{0xAFC3, UNICODE_NORM_QC_NO},
+	{0xAFC4, UNICODE_NORM_QC_NO},
+	{0xAFC5, UNICODE_NORM_QC_NO},
+	{0xAFC6, UNICODE_NORM_QC_NO},
+	{0xAFC7, UNICODE_NORM_QC_NO},
+	{0xAFC8, UNICODE_NORM_QC_NO},
+	{0xAFC9, UNICODE_NORM_QC_NO},
+	{0xAFCA, UNICODE_NORM_QC_NO},
+	{0xAFCB, UNICODE_NORM_QC_NO},
+	{0xAFCC, UNICODE_NORM_QC_NO},
+	{0xAFCD, UNICODE_NORM_QC_NO},
+	{0xAFCE, UNICODE_NORM_QC_NO},
+	{0xAFCF, UNICODE_NORM_QC_NO},
+	{0xAFD0, UNICODE_NORM_QC_NO},
+	{0xAFD1, UNICODE_NORM_QC_NO},
+	{0xAFD2, UNICODE_NORM_QC_NO},
+	{0xAFD3, UNICODE_NORM_QC_NO},
+	{0xAFD4, UNICODE_NORM_QC_NO},
+	{0xAFD5, UNICODE_NORM_QC_NO},
+	{0xAFD6, UNICODE_NORM_QC_NO},
+	{0xAFD7, UNICODE_NORM_QC_NO},
+	{0xAFD8, UNICODE_NORM_QC_NO},
+	{0xAFD9, UNICODE_NORM_QC_NO},
+	{0xAFDA, UNICODE_NORM_QC_NO},
+	{0xAFDB, UNICODE_NORM_QC_NO},
+	{0xAFDC, UNICODE_NORM_QC_NO},
+	{0xAFDD, UNICODE_NORM_QC_NO},
+	{0xAFDE, UNICODE_NORM_QC_NO},
+	{0xAFDF, UNICODE_NORM_QC_NO},
+	{0xAFE0, UNICODE_NORM_QC_NO},
+	{0xAFE1, UNICODE_NORM_QC_NO},
+	{0xAFE2, UNICODE_NORM_QC_NO},
+	{0xAFE3, UNICODE_NORM_QC_NO},
+	{0xAFE4, UNICODE_NORM_QC_NO},
+	{0xAFE5, UNICODE_NORM_QC_NO},
+	{0xAFE6, UNICODE_NORM_QC_NO},
+	{0xAFE7, UNICODE_NORM_QC_NO},
+	{0xAFE8, UNICODE_NORM_QC_NO},
+	{0xAFE9, UNICODE_NORM_QC_NO},
+	{0xAFEA, UNICODE_NORM_QC_NO},
+	{0xAFEB, UNICODE_NORM_QC_NO},
+	{0xAFEC, UNICODE_NORM_QC_NO},
+	{0xAFED, UNICODE_NORM_QC_NO},
+	{0xAFEE, UNICODE_NORM_QC_NO},
+	{0xAFEF, UNICODE_NORM_QC_NO},
+	{0xAFF0, UNICODE_NORM_QC_NO},
+	{0xAFF1, UNICODE_NORM_QC_NO},
+	{0xAFF2, UNICODE_NORM_QC_NO},
+	{0xAFF3, UNICODE_NORM_QC_NO},
+	{0xAFF4, UNICODE_NORM_QC_NO},
+	{0xAFF5, UNICODE_NORM_QC_NO},
+	{0xAFF6, UNICODE_NORM_QC_NO},
+	{0xAFF7, UNICODE_NORM_QC_NO},
+	{0xAFF8, UNICODE_NORM_QC_NO},
+	{0xAFF9, UNICODE_NORM_QC_NO},
+	{0xAFFA, UNICODE_NORM_QC_NO},
+	{0xAFFB, UNICODE_NORM_QC_NO},
+	{0xAFFC, UNICODE_NORM_QC_NO},
+	{0xAFFD, UNICODE_NORM_QC_NO},
+	{0xAFFE, UNICODE_NORM_QC_NO},
+	{0xAFFF, UNICODE_NORM_QC_NO},
+	{0xB000, UNICODE_NORM_QC_NO},
+	{0xB001, UNICODE_NORM_QC_NO},
+	{0xB002, UNICODE_NORM_QC_NO},
+	{0xB003, UNICODE_NORM_QC_NO},
+	{0xB004, UNICODE_NORM_QC_NO},
+	{0xB005, UNICODE_NORM_QC_NO},
+	{0xB006, UNICODE_NORM_QC_NO},
+	{0xB007, UNICODE_NORM_QC_NO},
+	{0xB008, UNICODE_NORM_QC_NO},
+	{0xB009, UNICODE_NORM_QC_NO},
+	{0xB00A, UNICODE_NORM_QC_NO},
+	{0xB00B, UNICODE_NORM_QC_NO},
+	{0xB00C, UNICODE_NORM_QC_NO},
+	{0xB00D, UNICODE_NORM_QC_NO},
+	{0xB00E, UNICODE_NORM_QC_NO},
+	{0xB00F, UNICODE_NORM_QC_NO},
+	{0xB010, UNICODE_NORM_QC_NO},
+	{0xB011, UNICODE_NORM_QC_NO},
+	{0xB012, UNICODE_NORM_QC_NO},
+	{0xB013, UNICODE_NORM_QC_NO},
+	{0xB014, UNICODE_NORM_QC_NO},
+	{0xB015, UNICODE_NORM_QC_NO},
+	{0xB016, UNICODE_NORM_QC_NO},
+	{0xB017, UNICODE_NORM_QC_NO},
+	{0xB018, UNICODE_NORM_QC_NO},
+	{0xB019, UNICODE_NORM_QC_NO},
+	{0xB01A, UNICODE_NORM_QC_NO},
+	{0xB01B, UNICODE_NORM_QC_NO},
+	{0xB01C, UNICODE_NORM_QC_NO},
+	{0xB01D, UNICODE_NORM_QC_NO},
+	{0xB01E, UNICODE_NORM_QC_NO},
+	{0xB01F, UNICODE_NORM_QC_NO},
+	{0xB020, UNICODE_NORM_QC_NO},
+	{0xB021, UNICODE_NORM_QC_NO},
+	{0xB022, UNICODE_NORM_QC_NO},
+	{0xB023, UNICODE_NORM_QC_NO},
+	{0xB024, UNICODE_NORM_QC_NO},
+	{0xB025, UNICODE_NORM_QC_NO},
+	{0xB026, UNICODE_NORM_QC_NO},
+	{0xB027, UNICODE_NORM_QC_NO},
+	{0xB028, UNICODE_NORM_QC_NO},
+	{0xB029, UNICODE_NORM_QC_NO},
+	{0xB02A, UNICODE_NORM_QC_NO},
+	{0xB02B, UNICODE_NORM_QC_NO},
+	{0xB02C, UNICODE_NORM_QC_NO},
+	{0xB02D, UNICODE_NORM_QC_NO},
+	{0xB02E, UNICODE_NORM_QC_NO},
+	{0xB02F, UNICODE_NORM_QC_NO},
+	{0xB030, UNICODE_NORM_QC_NO},
+	{0xB031, UNICODE_NORM_QC_NO},
+	{0xB032, UNICODE_NORM_QC_NO},
+	{0xB033, UNICODE_NORM_QC_NO},
+	{0xB034, UNICODE_NORM_QC_NO},
+	{0xB035, UNICODE_NORM_QC_NO},
+	{0xB036, UNICODE_NORM_QC_NO},
+	{0xB037, UNICODE_NORM_QC_NO},
+	{0xB038, UNICODE_NORM_QC_NO},
+	{0xB039, UNICODE_NORM_QC_NO},
+	{0xB03A, UNICODE_NORM_QC_NO},
+	{0xB03B, UNICODE_NORM_QC_NO},
+	{0xB03C, UNICODE_NORM_QC_NO},
+	{0xB03D, UNICODE_NORM_QC_NO},
+	{0xB03E, UNICODE_NORM_QC_NO},
+	{0xB03F, UNICODE_NORM_QC_NO},
+	{0xB040, UNICODE_NORM_QC_NO},
+	{0xB041, UNICODE_NORM_QC_NO},
+	{0xB042, UNICODE_NORM_QC_NO},
+	{0xB043, UNICODE_NORM_QC_NO},
+	{0xB044, UNICODE_NORM_QC_NO},
+	{0xB045, UNICODE_NORM_QC_NO},
+	{0xB046, UNICODE_NORM_QC_NO},
+	{0xB047, UNICODE_NORM_QC_NO},
+	{0xB048, UNICODE_NORM_QC_NO},
+	{0xB049, UNICODE_NORM_QC_NO},
+	{0xB04A, UNICODE_NORM_QC_NO},
+	{0xB04B, UNICODE_NORM_QC_NO},
+	{0xB04C, UNICODE_NORM_QC_NO},
+	{0xB04D, UNICODE_NORM_QC_NO},
+	{0xB04E, UNICODE_NORM_QC_NO},
+	{0xB04F, UNICODE_NORM_QC_NO},
+	{0xB050, UNICODE_NORM_QC_NO},
+	{0xB051, UNICODE_NORM_QC_NO},
+	{0xB052, UNICODE_NORM_QC_NO},
+	{0xB053, UNICODE_NORM_QC_NO},
+	{0xB054, UNICODE_NORM_QC_NO},
+	{0xB055, UNICODE_NORM_QC_NO},
+	{0xB056, UNICODE_NORM_QC_NO},
+	{0xB057, UNICODE_NORM_QC_NO},
+	{0xB058, UNICODE_NORM_QC_NO},
+	{0xB059, UNICODE_NORM_QC_NO},
+	{0xB05A, UNICODE_NORM_QC_NO},
+	{0xB05B, UNICODE_NORM_QC_NO},
+	{0xB05C, UNICODE_NORM_QC_NO},
+	{0xB05D, UNICODE_NORM_QC_NO},
+	{0xB05E, UNICODE_NORM_QC_NO},
+	{0xB05F, UNICODE_NORM_QC_NO},
+	{0xB060, UNICODE_NORM_QC_NO},
+	{0xB061, UNICODE_NORM_QC_NO},
+	{0xB062, UNICODE_NORM_QC_NO},
+	{0xB063, UNICODE_NORM_QC_NO},
+	{0xB064, UNICODE_NORM_QC_NO},
+	{0xB065, UNICODE_NORM_QC_NO},
+	{0xB066, UNICODE_NORM_QC_NO},
+	{0xB067, UNICODE_NORM_QC_NO},
+	{0xB068, UNICODE_NORM_QC_NO},
+	{0xB069, UNICODE_NORM_QC_NO},
+	{0xB06A, UNICODE_NORM_QC_NO},
+	{0xB06B, UNICODE_NORM_QC_NO},
+	{0xB06C, UNICODE_NORM_QC_NO},
+	{0xB06D, UNICODE_NORM_QC_NO},
+	{0xB06E, UNICODE_NORM_QC_NO},
+	{0xB06F, UNICODE_NORM_QC_NO},
+	{0xB070, UNICODE_NORM_QC_NO},
+	{0xB071, UNICODE_NORM_QC_NO},
+	{0xB072, UNICODE_NORM_QC_NO},
+	{0xB073, UNICODE_NORM_QC_NO},
+	{0xB074, UNICODE_NORM_QC_NO},
+	{0xB075, UNICODE_NORM_QC_NO},
+	{0xB076, UNICODE_NORM_QC_NO},
+	{0xB077, UNICODE_NORM_QC_NO},
+	{0xB078, UNICODE_NORM_QC_NO},
+	{0xB079, UNICODE_NORM_QC_NO},
+	{0xB07A, UNICODE_NORM_QC_NO},
+	{0xB07B, UNICODE_NORM_QC_NO},
+	{0xB07C, UNICODE_NORM_QC_NO},
+	{0xB07D, UNICODE_NORM_QC_NO},
+	{0xB07E, UNICODE_NORM_QC_NO},
+	{0xB07F, UNICODE_NORM_QC_NO},
+	{0xB080, UNICODE_NORM_QC_NO},
+	{0xB081, UNICODE_NORM_QC_NO},
+	{0xB082, UNICODE_NORM_QC_NO},
+	{0xB083, UNICODE_NORM_QC_NO},
+	{0xB084, UNICODE_NORM_QC_NO},
+	{0xB085, UNICODE_NORM_QC_NO},
+	{0xB086, UNICODE_NORM_QC_NO},
+	{0xB087, UNICODE_NORM_QC_NO},
+	{0xB088, UNICODE_NORM_QC_NO},
+	{0xB089, UNICODE_NORM_QC_NO},
+	{0xB08A, UNICODE_NORM_QC_NO},
+	{0xB08B, UNICODE_NORM_QC_NO},
+	{0xB08C, UNICODE_NORM_QC_NO},
+	{0xB08D, UNICODE_NORM_QC_NO},
+	{0xB08E, UNICODE_NORM_QC_NO},
+	{0xB08F, UNICODE_NORM_QC_NO},
+	{0xB090, UNICODE_NORM_QC_NO},
+	{0xB091, UNICODE_NORM_QC_NO},
+	{0xB092, UNICODE_NORM_QC_NO},
+	{0xB093, UNICODE_NORM_QC_NO},
+	{0xB094, UNICODE_NORM_QC_NO},
+	{0xB095, UNICODE_NORM_QC_NO},
+	{0xB096, UNICODE_NORM_QC_NO},
+	{0xB097, UNICODE_NORM_QC_NO},
+	{0xB098, UNICODE_NORM_QC_NO},
+	{0xB099, UNICODE_NORM_QC_NO},
+	{0xB09A, UNICODE_NORM_QC_NO},
+	{0xB09B, UNICODE_NORM_QC_NO},
+	{0xB09C, UNICODE_NORM_QC_NO},
+	{0xB09D, UNICODE_NORM_QC_NO},
+	{0xB09E, UNICODE_NORM_QC_NO},
+	{0xB09F, UNICODE_NORM_QC_NO},
+	{0xB0A0, UNICODE_NORM_QC_NO},
+	{0xB0A1, UNICODE_NORM_QC_NO},
+	{0xB0A2, UNICODE_NORM_QC_NO},
+	{0xB0A3, UNICODE_NORM_QC_NO},
+	{0xB0A4, UNICODE_NORM_QC_NO},
+	{0xB0A5, UNICODE_NORM_QC_NO},
+	{0xB0A6, UNICODE_NORM_QC_NO},
+	{0xB0A7, UNICODE_NORM_QC_NO},
+	{0xB0A8, UNICODE_NORM_QC_NO},
+	{0xB0A9, UNICODE_NORM_QC_NO},
+	{0xB0AA, UNICODE_NORM_QC_NO},
+	{0xB0AB, UNICODE_NORM_QC_NO},
+	{0xB0AC, UNICODE_NORM_QC_NO},
+	{0xB0AD, UNICODE_NORM_QC_NO},
+	{0xB0AE, UNICODE_NORM_QC_NO},
+	{0xB0AF, UNICODE_NORM_QC_NO},
+	{0xB0B0, UNICODE_NORM_QC_NO},
+	{0xB0B1, UNICODE_NORM_QC_NO},
+	{0xB0B2, UNICODE_NORM_QC_NO},
+	{0xB0B3, UNICODE_NORM_QC_NO},
+	{0xB0B4, UNICODE_NORM_QC_NO},
+	{0xB0B5, UNICODE_NORM_QC_NO},
+	{0xB0B6, UNICODE_NORM_QC_NO},
+	{0xB0B7, UNICODE_NORM_QC_NO},
+	{0xB0B8, UNICODE_NORM_QC_NO},
+	{0xB0B9, UNICODE_NORM_QC_NO},
+	{0xB0BA, UNICODE_NORM_QC_NO},
+	{0xB0BB, UNICODE_NORM_QC_NO},
+	{0xB0BC, UNICODE_NORM_QC_NO},
+	{0xB0BD, UNICODE_NORM_QC_NO},
+	{0xB0BE, UNICODE_NORM_QC_NO},
+	{0xB0BF, UNICODE_NORM_QC_NO},
+	{0xB0C0, UNICODE_NORM_QC_NO},
+	{0xB0C1, UNICODE_NORM_QC_NO},
+	{0xB0C2, UNICODE_NORM_QC_NO},
+	{0xB0C3, UNICODE_NORM_QC_NO},
+	{0xB0C4, UNICODE_NORM_QC_NO},
+	{0xB0C5, UNICODE_NORM_QC_NO},
+	{0xB0C6, UNICODE_NORM_QC_NO},
+	{0xB0C7, UNICODE_NORM_QC_NO},
+	{0xB0C8, UNICODE_NORM_QC_NO},
+	{0xB0C9, UNICODE_NORM_QC_NO},
+	{0xB0CA, UNICODE_NORM_QC_NO},
+	{0xB0CB, UNICODE_NORM_QC_NO},
+	{0xB0CC, UNICODE_NORM_QC_NO},
+	{0xB0CD, UNICODE_NORM_QC_NO},
+	{0xB0CE, UNICODE_NORM_QC_NO},
+	{0xB0CF, UNICODE_NORM_QC_NO},
+	{0xB0D0, UNICODE_NORM_QC_NO},
+	{0xB0D1, UNICODE_NORM_QC_NO},
+	{0xB0D2, UNICODE_NORM_QC_NO},
+	{0xB0D3, UNICODE_NORM_QC_NO},
+	{0xB0D4, UNICODE_NORM_QC_NO},
+	{0xB0D5, UNICODE_NORM_QC_NO},
+	{0xB0D6, UNICODE_NORM_QC_NO},
+	{0xB0D7, UNICODE_NORM_QC_NO},
+	{0xB0D8, UNICODE_NORM_QC_NO},
+	{0xB0D9, UNICODE_NORM_QC_NO},
+	{0xB0DA, UNICODE_NORM_QC_NO},
+	{0xB0DB, UNICODE_NORM_QC_NO},
+	{0xB0DC, UNICODE_NORM_QC_NO},
+	{0xB0DD, UNICODE_NORM_QC_NO},
+	{0xB0DE, UNICODE_NORM_QC_NO},
+	{0xB0DF, UNICODE_NORM_QC_NO},
+	{0xB0E0, UNICODE_NORM_QC_NO},
+	{0xB0E1, UNICODE_NORM_QC_NO},
+	{0xB0E2, UNICODE_NORM_QC_NO},
+	{0xB0E3, UNICODE_NORM_QC_NO},
+	{0xB0E4, UNICODE_NORM_QC_NO},
+	{0xB0E5, UNICODE_NORM_QC_NO},
+	{0xB0E6, UNICODE_NORM_QC_NO},
+	{0xB0E7, UNICODE_NORM_QC_NO},
+	{0xB0E8, UNICODE_NORM_QC_NO},
+	{0xB0E9, UNICODE_NORM_QC_NO},
+	{0xB0EA, UNICODE_NORM_QC_NO},
+	{0xB0EB, UNICODE_NORM_QC_NO},
+	{0xB0EC, UNICODE_NORM_QC_NO},
+	{0xB0ED, UNICODE_NORM_QC_NO},
+	{0xB0EE, UNICODE_NORM_QC_NO},
+	{0xB0EF, UNICODE_NORM_QC_NO},
+	{0xB0F0, UNICODE_NORM_QC_NO},
+	{0xB0F1, UNICODE_NORM_QC_NO},
+	{0xB0F2, UNICODE_NORM_QC_NO},
+	{0xB0F3, UNICODE_NORM_QC_NO},
+	{0xB0F4, UNICODE_NORM_QC_NO},
+	{0xB0F5, UNICODE_NORM_QC_NO},
+	{0xB0F6, UNICODE_NORM_QC_NO},
+	{0xB0F7, UNICODE_NORM_QC_NO},
+	{0xB0F8, UNICODE_NORM_QC_NO},
+	{0xB0F9, UNICODE_NORM_QC_NO},
+	{0xB0FA, UNICODE_NORM_QC_NO},
+	{0xB0FB, UNICODE_NORM_QC_NO},
+	{0xB0FC, UNICODE_NORM_QC_NO},
+	{0xB0FD, UNICODE_NORM_QC_NO},
+	{0xB0FE, UNICODE_NORM_QC_NO},
+	{0xB0FF, UNICODE_NORM_QC_NO},
+	{0xB100, UNICODE_NORM_QC_NO},
+	{0xB101, UNICODE_NORM_QC_NO},
+	{0xB102, UNICODE_NORM_QC_NO},
+	{0xB103, UNICODE_NORM_QC_NO},
+	{0xB104, UNICODE_NORM_QC_NO},
+	{0xB105, UNICODE_NORM_QC_NO},
+	{0xB106, UNICODE_NORM_QC_NO},
+	{0xB107, UNICODE_NORM_QC_NO},
+	{0xB108, UNICODE_NORM_QC_NO},
+	{0xB109, UNICODE_NORM_QC_NO},
+	{0xB10A, UNICODE_NORM_QC_NO},
+	{0xB10B, UNICODE_NORM_QC_NO},
+	{0xB10C, UNICODE_NORM_QC_NO},
+	{0xB10D, UNICODE_NORM_QC_NO},
+	{0xB10E, UNICODE_NORM_QC_NO},
+	{0xB10F, UNICODE_NORM_QC_NO},
+	{0xB110, UNICODE_NORM_QC_NO},
+	{0xB111, UNICODE_NORM_QC_NO},
+	{0xB112, UNICODE_NORM_QC_NO},
+	{0xB113, UNICODE_NORM_QC_NO},
+	{0xB114, UNICODE_NORM_QC_NO},
+	{0xB115, UNICODE_NORM_QC_NO},
+	{0xB116, UNICODE_NORM_QC_NO},
+	{0xB117, UNICODE_NORM_QC_NO},
+	{0xB118, UNICODE_NORM_QC_NO},
+	{0xB119, UNICODE_NORM_QC_NO},
+	{0xB11A, UNICODE_NORM_QC_NO},
+	{0xB11B, UNICODE_NORM_QC_NO},
+	{0xB11C, UNICODE_NORM_QC_NO},
+	{0xB11D, UNICODE_NORM_QC_NO},
+	{0xB11E, UNICODE_NORM_QC_NO},
+	{0xB11F, UNICODE_NORM_QC_NO},
+	{0xB120, UNICODE_NORM_QC_NO},
+	{0xB121, UNICODE_NORM_QC_NO},
+	{0xB122, UNICODE_NORM_QC_NO},
+	{0xB123, UNICODE_NORM_QC_NO},
+	{0xB124, UNICODE_NORM_QC_NO},
+	{0xB125, UNICODE_NORM_QC_NO},
+	{0xB126, UNICODE_NORM_QC_NO},
+	{0xB127, UNICODE_NORM_QC_NO},
+	{0xB128, UNICODE_NORM_QC_NO},
+	{0xB129, UNICODE_NORM_QC_NO},
+	{0xB12A, UNICODE_NORM_QC_NO},
+	{0xB12B, UNICODE_NORM_QC_NO},
+	{0xB12C, UNICODE_NORM_QC_NO},
+	{0xB12D, UNICODE_NORM_QC_NO},
+	{0xB12E, UNICODE_NORM_QC_NO},
+	{0xB12F, UNICODE_NORM_QC_NO},
+	{0xB130, UNICODE_NORM_QC_NO},
+	{0xB131, UNICODE_NORM_QC_NO},
+	{0xB132, UNICODE_NORM_QC_NO},
+	{0xB133, UNICODE_NORM_QC_NO},
+	{0xB134, UNICODE_NORM_QC_NO},
+	{0xB135, UNICODE_NORM_QC_NO},
+	{0xB136, UNICODE_NORM_QC_NO},
+	{0xB137, UNICODE_NORM_QC_NO},
+	{0xB138, UNICODE_NORM_QC_NO},
+	{0xB139, UNICODE_NORM_QC_NO},
+	{0xB13A, UNICODE_NORM_QC_NO},
+	{0xB13B, UNICODE_NORM_QC_NO},
+	{0xB13C, UNICODE_NORM_QC_NO},
+	{0xB13D, UNICODE_NORM_QC_NO},
+	{0xB13E, UNICODE_NORM_QC_NO},
+	{0xB13F, UNICODE_NORM_QC_NO},
+	{0xB140, UNICODE_NORM_QC_NO},
+	{0xB141, UNICODE_NORM_QC_NO},
+	{0xB142, UNICODE_NORM_QC_NO},
+	{0xB143, UNICODE_NORM_QC_NO},
+	{0xB144, UNICODE_NORM_QC_NO},
+	{0xB145, UNICODE_NORM_QC_NO},
+	{0xB146, UNICODE_NORM_QC_NO},
+	{0xB147, UNICODE_NORM_QC_NO},
+	{0xB148, UNICODE_NORM_QC_NO},
+	{0xB149, UNICODE_NORM_QC_NO},
+	{0xB14A, UNICODE_NORM_QC_NO},
+	{0xB14B, UNICODE_NORM_QC_NO},
+	{0xB14C, UNICODE_NORM_QC_NO},
+	{0xB14D, UNICODE_NORM_QC_NO},
+	{0xB14E, UNICODE_NORM_QC_NO},
+	{0xB14F, UNICODE_NORM_QC_NO},
+	{0xB150, UNICODE_NORM_QC_NO},
+	{0xB151, UNICODE_NORM_QC_NO},
+	{0xB152, UNICODE_NORM_QC_NO},
+	{0xB153, UNICODE_NORM_QC_NO},
+	{0xB154, UNICODE_NORM_QC_NO},
+	{0xB155, UNICODE_NORM_QC_NO},
+	{0xB156, UNICODE_NORM_QC_NO},
+	{0xB157, UNICODE_NORM_QC_NO},
+	{0xB158, UNICODE_NORM_QC_NO},
+	{0xB159, UNICODE_NORM_QC_NO},
+	{0xB15A, UNICODE_NORM_QC_NO},
+	{0xB15B, UNICODE_NORM_QC_NO},
+	{0xB15C, UNICODE_NORM_QC_NO},
+	{0xB15D, UNICODE_NORM_QC_NO},
+	{0xB15E, UNICODE_NORM_QC_NO},
+	{0xB15F, UNICODE_NORM_QC_NO},
+	{0xB160, UNICODE_NORM_QC_NO},
+	{0xB161, UNICODE_NORM_QC_NO},
+	{0xB162, UNICODE_NORM_QC_NO},
+	{0xB163, UNICODE_NORM_QC_NO},
+	{0xB164, UNICODE_NORM_QC_NO},
+	{0xB165, UNICODE_NORM_QC_NO},
+	{0xB166, UNICODE_NORM_QC_NO},
+	{0xB167, UNICODE_NORM_QC_NO},
+	{0xB168, UNICODE_NORM_QC_NO},
+	{0xB169, UNICODE_NORM_QC_NO},
+	{0xB16A, UNICODE_NORM_QC_NO},
+	{0xB16B, UNICODE_NORM_QC_NO},
+	{0xB16C, UNICODE_NORM_QC_NO},
+	{0xB16D, UNICODE_NORM_QC_NO},
+	{0xB16E, UNICODE_NORM_QC_NO},
+	{0xB16F, UNICODE_NORM_QC_NO},
+	{0xB170, UNICODE_NORM_QC_NO},
+	{0xB171, UNICODE_NORM_QC_NO},
+	{0xB172, UNICODE_NORM_QC_NO},
+	{0xB173, UNICODE_NORM_QC_NO},
+	{0xB174, UNICODE_NORM_QC_NO},
+	{0xB175, UNICODE_NORM_QC_NO},
+	{0xB176, UNICODE_NORM_QC_NO},
+	{0xB177, UNICODE_NORM_QC_NO},
+	{0xB178, UNICODE_NORM_QC_NO},
+	{0xB179, UNICODE_NORM_QC_NO},
+	{0xB17A, UNICODE_NORM_QC_NO},
+	{0xB17B, UNICODE_NORM_QC_NO},
+	{0xB17C, UNICODE_NORM_QC_NO},
+	{0xB17D, UNICODE_NORM_QC_NO},
+	{0xB17E, UNICODE_NORM_QC_NO},
+	{0xB17F, UNICODE_NORM_QC_NO},
+	{0xB180, UNICODE_NORM_QC_NO},
+	{0xB181, UNICODE_NORM_QC_NO},
+	{0xB182, UNICODE_NORM_QC_NO},
+	{0xB183, UNICODE_NORM_QC_NO},
+	{0xB184, UNICODE_NORM_QC_NO},
+	{0xB185, UNICODE_NORM_QC_NO},
+	{0xB186, UNICODE_NORM_QC_NO},
+	{0xB187, UNICODE_NORM_QC_NO},
+	{0xB188, UNICODE_NORM_QC_NO},
+	{0xB189, UNICODE_NORM_QC_NO},
+	{0xB18A, UNICODE_NORM_QC_NO},
+	{0xB18B, UNICODE_NORM_QC_NO},
+	{0xB18C, UNICODE_NORM_QC_NO},
+	{0xB18D, UNICODE_NORM_QC_NO},
+	{0xB18E, UNICODE_NORM_QC_NO},
+	{0xB18F, UNICODE_NORM_QC_NO},
+	{0xB190, UNICODE_NORM_QC_NO},
+	{0xB191, UNICODE_NORM_QC_NO},
+	{0xB192, UNICODE_NORM_QC_NO},
+	{0xB193, UNICODE_NORM_QC_NO},
+	{0xB194, UNICODE_NORM_QC_NO},
+	{0xB195, UNICODE_NORM_QC_NO},
+	{0xB196, UNICODE_NORM_QC_NO},
+	{0xB197, UNICODE_NORM_QC_NO},
+	{0xB198, UNICODE_NORM_QC_NO},
+	{0xB199, UNICODE_NORM_QC_NO},
+	{0xB19A, UNICODE_NORM_QC_NO},
+	{0xB19B, UNICODE_NORM_QC_NO},
+	{0xB19C, UNICODE_NORM_QC_NO},
+	{0xB19D, UNICODE_NORM_QC_NO},
+	{0xB19E, UNICODE_NORM_QC_NO},
+	{0xB19F, UNICODE_NORM_QC_NO},
+	{0xB1A0, UNICODE_NORM_QC_NO},
+	{0xB1A1, UNICODE_NORM_QC_NO},
+	{0xB1A2, UNICODE_NORM_QC_NO},
+	{0xB1A3, UNICODE_NORM_QC_NO},
+	{0xB1A4, UNICODE_NORM_QC_NO},
+	{0xB1A5, UNICODE_NORM_QC_NO},
+	{0xB1A6, UNICODE_NORM_QC_NO},
+	{0xB1A7, UNICODE_NORM_QC_NO},
+	{0xB1A8, UNICODE_NORM_QC_NO},
+	{0xB1A9, UNICODE_NORM_QC_NO},
+	{0xB1AA, UNICODE_NORM_QC_NO},
+	{0xB1AB, UNICODE_NORM_QC_NO},
+	{0xB1AC, UNICODE_NORM_QC_NO},
+	{0xB1AD, UNICODE_NORM_QC_NO},
+	{0xB1AE, UNICODE_NORM_QC_NO},
+	{0xB1AF, UNICODE_NORM_QC_NO},
+	{0xB1B0, UNICODE_NORM_QC_NO},
+	{0xB1B1, UNICODE_NORM_QC_NO},
+	{0xB1B2, UNICODE_NORM_QC_NO},
+	{0xB1B3, UNICODE_NORM_QC_NO},
+	{0xB1B4, UNICODE_NORM_QC_NO},
+	{0xB1B5, UNICODE_NORM_QC_NO},
+	{0xB1B6, UNICODE_NORM_QC_NO},
+	{0xB1B7, UNICODE_NORM_QC_NO},
+	{0xB1B8, UNICODE_NORM_QC_NO},
+	{0xB1B9, UNICODE_NORM_QC_NO},
+	{0xB1BA, UNICODE_NORM_QC_NO},
+	{0xB1BB, UNICODE_NORM_QC_NO},
+	{0xB1BC, UNICODE_NORM_QC_NO},
+	{0xB1BD, UNICODE_NORM_QC_NO},
+	{0xB1BE, UNICODE_NORM_QC_NO},
+	{0xB1BF, UNICODE_NORM_QC_NO},
+	{0xB1C0, UNICODE_NORM_QC_NO},
+	{0xB1C1, UNICODE_NORM_QC_NO},
+	{0xB1C2, UNICODE_NORM_QC_NO},
+	{0xB1C3, UNICODE_NORM_QC_NO},
+	{0xB1C4, UNICODE_NORM_QC_NO},
+	{0xB1C5, UNICODE_NORM_QC_NO},
+	{0xB1C6, UNICODE_NORM_QC_NO},
+	{0xB1C7, UNICODE_NORM_QC_NO},
+	{0xB1C8, UNICODE_NORM_QC_NO},
+	{0xB1C9, UNICODE_NORM_QC_NO},
+	{0xB1CA, UNICODE_NORM_QC_NO},
+	{0xB1CB, UNICODE_NORM_QC_NO},
+	{0xB1CC, UNICODE_NORM_QC_NO},
+	{0xB1CD, UNICODE_NORM_QC_NO},
+	{0xB1CE, UNICODE_NORM_QC_NO},
+	{0xB1CF, UNICODE_NORM_QC_NO},
+	{0xB1D0, UNICODE_NORM_QC_NO},
+	{0xB1D1, UNICODE_NORM_QC_NO},
+	{0xB1D2, UNICODE_NORM_QC_NO},
+	{0xB1D3, UNICODE_NORM_QC_NO},
+	{0xB1D4, UNICODE_NORM_QC_NO},
+	{0xB1D5, UNICODE_NORM_QC_NO},
+	{0xB1D6, UNICODE_NORM_QC_NO},
+	{0xB1D7, UNICODE_NORM_QC_NO},
+	{0xB1D8, UNICODE_NORM_QC_NO},
+	{0xB1D9, UNICODE_NORM_QC_NO},
+	{0xB1DA, UNICODE_NORM_QC_NO},
+	{0xB1DB, UNICODE_NORM_QC_NO},
+	{0xB1DC, UNICODE_NORM_QC_NO},
+	{0xB1DD, UNICODE_NORM_QC_NO},
+	{0xB1DE, UNICODE_NORM_QC_NO},
+	{0xB1DF, UNICODE_NORM_QC_NO},
+	{0xB1E0, UNICODE_NORM_QC_NO},
+	{0xB1E1, UNICODE_NORM_QC_NO},
+	{0xB1E2, UNICODE_NORM_QC_NO},
+	{0xB1E3, UNICODE_NORM_QC_NO},
+	{0xB1E4, UNICODE_NORM_QC_NO},
+	{0xB1E5, UNICODE_NORM_QC_NO},
+	{0xB1E6, UNICODE_NORM_QC_NO},
+	{0xB1E7, UNICODE_NORM_QC_NO},
+	{0xB1E8, UNICODE_NORM_QC_NO},
+	{0xB1E9, UNICODE_NORM_QC_NO},
+	{0xB1EA, UNICODE_NORM_QC_NO},
+	{0xB1EB, UNICODE_NORM_QC_NO},
+	{0xB1EC, UNICODE_NORM_QC_NO},
+	{0xB1ED, UNICODE_NORM_QC_NO},
+	{0xB1EE, UNICODE_NORM_QC_NO},
+	{0xB1EF, UNICODE_NORM_QC_NO},
+	{0xB1F0, UNICODE_NORM_QC_NO},
+	{0xB1F1, UNICODE_NORM_QC_NO},
+	{0xB1F2, UNICODE_NORM_QC_NO},
+	{0xB1F3, UNICODE_NORM_QC_NO},
+	{0xB1F4, UNICODE_NORM_QC_NO},
+	{0xB1F5, UNICODE_NORM_QC_NO},
+	{0xB1F6, UNICODE_NORM_QC_NO},
+	{0xB1F7, UNICODE_NORM_QC_NO},
+	{0xB1F8, UNICODE_NORM_QC_NO},
+	{0xB1F9, UNICODE_NORM_QC_NO},
+	{0xB1FA, UNICODE_NORM_QC_NO},
+	{0xB1FB, UNICODE_NORM_QC_NO},
+	{0xB1FC, UNICODE_NORM_QC_NO},
+	{0xB1FD, UNICODE_NORM_QC_NO},
+	{0xB1FE, UNICODE_NORM_QC_NO},
+	{0xB1FF, UNICODE_NORM_QC_NO},
+	{0xB200, UNICODE_NORM_QC_NO},
+	{0xB201, UNICODE_NORM_QC_NO},
+	{0xB202, UNICODE_NORM_QC_NO},
+	{0xB203, UNICODE_NORM_QC_NO},
+	{0xB204, UNICODE_NORM_QC_NO},
+	{0xB205, UNICODE_NORM_QC_NO},
+	{0xB206, UNICODE_NORM_QC_NO},
+	{0xB207, UNICODE_NORM_QC_NO},
+	{0xB208, UNICODE_NORM_QC_NO},
+	{0xB209, UNICODE_NORM_QC_NO},
+	{0xB20A, UNICODE_NORM_QC_NO},
+	{0xB20B, UNICODE_NORM_QC_NO},
+	{0xB20C, UNICODE_NORM_QC_NO},
+	{0xB20D, UNICODE_NORM_QC_NO},
+	{0xB20E, UNICODE_NORM_QC_NO},
+	{0xB20F, UNICODE_NORM_QC_NO},
+	{0xB210, UNICODE_NORM_QC_NO},
+	{0xB211, UNICODE_NORM_QC_NO},
+	{0xB212, UNICODE_NORM_QC_NO},
+	{0xB213, UNICODE_NORM_QC_NO},
+	{0xB214, UNICODE_NORM_QC_NO},
+	{0xB215, UNICODE_NORM_QC_NO},
+	{0xB216, UNICODE_NORM_QC_NO},
+	{0xB217, UNICODE_NORM_QC_NO},
+	{0xB218, UNICODE_NORM_QC_NO},
+	{0xB219, UNICODE_NORM_QC_NO},
+	{0xB21A, UNICODE_NORM_QC_NO},
+	{0xB21B, UNICODE_NORM_QC_NO},
+	{0xB21C, UNICODE_NORM_QC_NO},
+	{0xB21D, UNICODE_NORM_QC_NO},
+	{0xB21E, UNICODE_NORM_QC_NO},
+	{0xB21F, UNICODE_NORM_QC_NO},
+	{0xB220, UNICODE_NORM_QC_NO},
+	{0xB221, UNICODE_NORM_QC_NO},
+	{0xB222, UNICODE_NORM_QC_NO},
+	{0xB223, UNICODE_NORM_QC_NO},
+	{0xB224, UNICODE_NORM_QC_NO},
+	{0xB225, UNICODE_NORM_QC_NO},
+	{0xB226, UNICODE_NORM_QC_NO},
+	{0xB227, UNICODE_NORM_QC_NO},
+	{0xB228, UNICODE_NORM_QC_NO},
+	{0xB229, UNICODE_NORM_QC_NO},
+	{0xB22A, UNICODE_NORM_QC_NO},
+	{0xB22B, UNICODE_NORM_QC_NO},
+	{0xB22C, UNICODE_NORM_QC_NO},
+	{0xB22D, UNICODE_NORM_QC_NO},
+	{0xB22E, UNICODE_NORM_QC_NO},
+	{0xB22F, UNICODE_NORM_QC_NO},
+	{0xB230, UNICODE_NORM_QC_NO},
+	{0xB231, UNICODE_NORM_QC_NO},
+	{0xB232, UNICODE_NORM_QC_NO},
+	{0xB233, UNICODE_NORM_QC_NO},
+	{0xB234, UNICODE_NORM_QC_NO},
+	{0xB235, UNICODE_NORM_QC_NO},
+	{0xB236, UNICODE_NORM_QC_NO},
+	{0xB237, UNICODE_NORM_QC_NO},
+	{0xB238, UNICODE_NORM_QC_NO},
+	{0xB239, UNICODE_NORM_QC_NO},
+	{0xB23A, UNICODE_NORM_QC_NO},
+	{0xB23B, UNICODE_NORM_QC_NO},
+	{0xB23C, UNICODE_NORM_QC_NO},
+	{0xB23D, UNICODE_NORM_QC_NO},
+	{0xB23E, UNICODE_NORM_QC_NO},
+	{0xB23F, UNICODE_NORM_QC_NO},
+	{0xB240, UNICODE_NORM_QC_NO},
+	{0xB241, UNICODE_NORM_QC_NO},
+	{0xB242, UNICODE_NORM_QC_NO},
+	{0xB243, UNICODE_NORM_QC_NO},
+	{0xB244, UNICODE_NORM_QC_NO},
+	{0xB245, UNICODE_NORM_QC_NO},
+	{0xB246, UNICODE_NORM_QC_NO},
+	{0xB247, UNICODE_NORM_QC_NO},
+	{0xB248, UNICODE_NORM_QC_NO},
+	{0xB249, UNICODE_NORM_QC_NO},
+	{0xB24A, UNICODE_NORM_QC_NO},
+	{0xB24B, UNICODE_NORM_QC_NO},
+	{0xB24C, UNICODE_NORM_QC_NO},
+	{0xB24D, UNICODE_NORM_QC_NO},
+	{0xB24E, UNICODE_NORM_QC_NO},
+	{0xB24F, UNICODE_NORM_QC_NO},
+	{0xB250, UNICODE_NORM_QC_NO},
+	{0xB251, UNICODE_NORM_QC_NO},
+	{0xB252, UNICODE_NORM_QC_NO},
+	{0xB253, UNICODE_NORM_QC_NO},
+	{0xB254, UNICODE_NORM_QC_NO},
+	{0xB255, UNICODE_NORM_QC_NO},
+	{0xB256, UNICODE_NORM_QC_NO},
+	{0xB257, UNICODE_NORM_QC_NO},
+	{0xB258, UNICODE_NORM_QC_NO},
+	{0xB259, UNICODE_NORM_QC_NO},
+	{0xB25A, UNICODE_NORM_QC_NO},
+	{0xB25B, UNICODE_NORM_QC_NO},
+	{0xB25C, UNICODE_NORM_QC_NO},
+	{0xB25D, UNICODE_NORM_QC_NO},
+	{0xB25E, UNICODE_NORM_QC_NO},
+	{0xB25F, UNICODE_NORM_QC_NO},
+	{0xB260, UNICODE_NORM_QC_NO},
+	{0xB261, UNICODE_NORM_QC_NO},
+	{0xB262, UNICODE_NORM_QC_NO},
+	{0xB263, UNICODE_NORM_QC_NO},
+	{0xB264, UNICODE_NORM_QC_NO},
+	{0xB265, UNICODE_NORM_QC_NO},
+	{0xB266, UNICODE_NORM_QC_NO},
+	{0xB267, UNICODE_NORM_QC_NO},
+	{0xB268, UNICODE_NORM_QC_NO},
+	{0xB269, UNICODE_NORM_QC_NO},
+	{0xB26A, UNICODE_NORM_QC_NO},
+	{0xB26B, UNICODE_NORM_QC_NO},
+	{0xB26C, UNICODE_NORM_QC_NO},
+	{0xB26D, UNICODE_NORM_QC_NO},
+	{0xB26E, UNICODE_NORM_QC_NO},
+	{0xB26F, UNICODE_NORM_QC_NO},
+	{0xB270, UNICODE_NORM_QC_NO},
+	{0xB271, UNICODE_NORM_QC_NO},
+	{0xB272, UNICODE_NORM_QC_NO},
+	{0xB273, UNICODE_NORM_QC_NO},
+	{0xB274, UNICODE_NORM_QC_NO},
+	{0xB275, UNICODE_NORM_QC_NO},
+	{0xB276, UNICODE_NORM_QC_NO},
+	{0xB277, UNICODE_NORM_QC_NO},
+	{0xB278, UNICODE_NORM_QC_NO},
+	{0xB279, UNICODE_NORM_QC_NO},
+	{0xB27A, UNICODE_NORM_QC_NO},
+	{0xB27B, UNICODE_NORM_QC_NO},
+	{0xB27C, UNICODE_NORM_QC_NO},
+	{0xB27D, UNICODE_NORM_QC_NO},
+	{0xB27E, UNICODE_NORM_QC_NO},
+	{0xB27F, UNICODE_NORM_QC_NO},
+	{0xB280, UNICODE_NORM_QC_NO},
+	{0xB281, UNICODE_NORM_QC_NO},
+	{0xB282, UNICODE_NORM_QC_NO},
+	{0xB283, UNICODE_NORM_QC_NO},
+	{0xB284, UNICODE_NORM_QC_NO},
+	{0xB285, UNICODE_NORM_QC_NO},
+	{0xB286, UNICODE_NORM_QC_NO},
+	{0xB287, UNICODE_NORM_QC_NO},
+	{0xB288, UNICODE_NORM_QC_NO},
+	{0xB289, UNICODE_NORM_QC_NO},
+	{0xB28A, UNICODE_NORM_QC_NO},
+	{0xB28B, UNICODE_NORM_QC_NO},
+	{0xB28C, UNICODE_NORM_QC_NO},
+	{0xB28D, UNICODE_NORM_QC_NO},
+	{0xB28E, UNICODE_NORM_QC_NO},
+	{0xB28F, UNICODE_NORM_QC_NO},
+	{0xB290, UNICODE_NORM_QC_NO},
+	{0xB291, UNICODE_NORM_QC_NO},
+	{0xB292, UNICODE_NORM_QC_NO},
+	{0xB293, UNICODE_NORM_QC_NO},
+	{0xB294, UNICODE_NORM_QC_NO},
+	{0xB295, UNICODE_NORM_QC_NO},
+	{0xB296, UNICODE_NORM_QC_NO},
+	{0xB297, UNICODE_NORM_QC_NO},
+	{0xB298, UNICODE_NORM_QC_NO},
+	{0xB299, UNICODE_NORM_QC_NO},
+	{0xB29A, UNICODE_NORM_QC_NO},
+	{0xB29B, UNICODE_NORM_QC_NO},
+	{0xB29C, UNICODE_NORM_QC_NO},
+	{0xB29D, UNICODE_NORM_QC_NO},
+	{0xB29E, UNICODE_NORM_QC_NO},
+	{0xB29F, UNICODE_NORM_QC_NO},
+	{0xB2A0, UNICODE_NORM_QC_NO},
+	{0xB2A1, UNICODE_NORM_QC_NO},
+	{0xB2A2, UNICODE_NORM_QC_NO},
+	{0xB2A3, UNICODE_NORM_QC_NO},
+	{0xB2A4, UNICODE_NORM_QC_NO},
+	{0xB2A5, UNICODE_NORM_QC_NO},
+	{0xB2A6, UNICODE_NORM_QC_NO},
+	{0xB2A7, UNICODE_NORM_QC_NO},
+	{0xB2A8, UNICODE_NORM_QC_NO},
+	{0xB2A9, UNICODE_NORM_QC_NO},
+	{0xB2AA, UNICODE_NORM_QC_NO},
+	{0xB2AB, UNICODE_NORM_QC_NO},
+	{0xB2AC, UNICODE_NORM_QC_NO},
+	{0xB2AD, UNICODE_NORM_QC_NO},
+	{0xB2AE, UNICODE_NORM_QC_NO},
+	{0xB2AF, UNICODE_NORM_QC_NO},
+	{0xB2B0, UNICODE_NORM_QC_NO},
+	{0xB2B1, UNICODE_NORM_QC_NO},
+	{0xB2B2, UNICODE_NORM_QC_NO},
+	{0xB2B3, UNICODE_NORM_QC_NO},
+	{0xB2B4, UNICODE_NORM_QC_NO},
+	{0xB2B5, UNICODE_NORM_QC_NO},
+	{0xB2B6, UNICODE_NORM_QC_NO},
+	{0xB2B7, UNICODE_NORM_QC_NO},
+	{0xB2B8, UNICODE_NORM_QC_NO},
+	{0xB2B9, UNICODE_NORM_QC_NO},
+	{0xB2BA, UNICODE_NORM_QC_NO},
+	{0xB2BB, UNICODE_NORM_QC_NO},
+	{0xB2BC, UNICODE_NORM_QC_NO},
+	{0xB2BD, UNICODE_NORM_QC_NO},
+	{0xB2BE, UNICODE_NORM_QC_NO},
+	{0xB2BF, UNICODE_NORM_QC_NO},
+	{0xB2C0, UNICODE_NORM_QC_NO},
+	{0xB2C1, UNICODE_NORM_QC_NO},
+	{0xB2C2, UNICODE_NORM_QC_NO},
+	{0xB2C3, UNICODE_NORM_QC_NO},
+	{0xB2C4, UNICODE_NORM_QC_NO},
+	{0xB2C5, UNICODE_NORM_QC_NO},
+	{0xB2C6, UNICODE_NORM_QC_NO},
+	{0xB2C7, UNICODE_NORM_QC_NO},
+	{0xB2C8, UNICODE_NORM_QC_NO},
+	{0xB2C9, UNICODE_NORM_QC_NO},
+	{0xB2CA, UNICODE_NORM_QC_NO},
+	{0xB2CB, UNICODE_NORM_QC_NO},
+	{0xB2CC, UNICODE_NORM_QC_NO},
+	{0xB2CD, UNICODE_NORM_QC_NO},
+	{0xB2CE, UNICODE_NORM_QC_NO},
+	{0xB2CF, UNICODE_NORM_QC_NO},
+	{0xB2D0, UNICODE_NORM_QC_NO},
+	{0xB2D1, UNICODE_NORM_QC_NO},
+	{0xB2D2, UNICODE_NORM_QC_NO},
+	{0xB2D3, UNICODE_NORM_QC_NO},
+	{0xB2D4, UNICODE_NORM_QC_NO},
+	{0xB2D5, UNICODE_NORM_QC_NO},
+	{0xB2D6, UNICODE_NORM_QC_NO},
+	{0xB2D7, UNICODE_NORM_QC_NO},
+	{0xB2D8, UNICODE_NORM_QC_NO},
+	{0xB2D9, UNICODE_NORM_QC_NO},
+	{0xB2DA, UNICODE_NORM_QC_NO},
+	{0xB2DB, UNICODE_NORM_QC_NO},
+	{0xB2DC, UNICODE_NORM_QC_NO},
+	{0xB2DD, UNICODE_NORM_QC_NO},
+	{0xB2DE, UNICODE_NORM_QC_NO},
+	{0xB2DF, UNICODE_NORM_QC_NO},
+	{0xB2E0, UNICODE_NORM_QC_NO},
+	{0xB2E1, UNICODE_NORM_QC_NO},
+	{0xB2E2, UNICODE_NORM_QC_NO},
+	{0xB2E3, UNICODE_NORM_QC_NO},
+	{0xB2E4, UNICODE_NORM_QC_NO},
+	{0xB2E5, UNICODE_NORM_QC_NO},
+	{0xB2E6, UNICODE_NORM_QC_NO},
+	{0xB2E7, UNICODE_NORM_QC_NO},
+	{0xB2E8, UNICODE_NORM_QC_NO},
+	{0xB2E9, UNICODE_NORM_QC_NO},
+	{0xB2EA, UNICODE_NORM_QC_NO},
+	{0xB2EB, UNICODE_NORM_QC_NO},
+	{0xB2EC, UNICODE_NORM_QC_NO},
+	{0xB2ED, UNICODE_NORM_QC_NO},
+	{0xB2EE, UNICODE_NORM_QC_NO},
+	{0xB2EF, UNICODE_NORM_QC_NO},
+	{0xB2F0, UNICODE_NORM_QC_NO},
+	{0xB2F1, UNICODE_NORM_QC_NO},
+	{0xB2F2, UNICODE_NORM_QC_NO},
+	{0xB2F3, UNICODE_NORM_QC_NO},
+	{0xB2F4, UNICODE_NORM_QC_NO},
+	{0xB2F5, UNICODE_NORM_QC_NO},
+	{0xB2F6, UNICODE_NORM_QC_NO},
+	{0xB2F7, UNICODE_NORM_QC_NO},
+	{0xB2F8, UNICODE_NORM_QC_NO},
+	{0xB2F9, UNICODE_NORM_QC_NO},
+	{0xB2FA, UNICODE_NORM_QC_NO},
+	{0xB2FB, UNICODE_NORM_QC_NO},
+	{0xB2FC, UNICODE_NORM_QC_NO},
+	{0xB2FD, UNICODE_NORM_QC_NO},
+	{0xB2FE, UNICODE_NORM_QC_NO},
+	{0xB2FF, UNICODE_NORM_QC_NO},
+	{0xB300, UNICODE_NORM_QC_NO},
+	{0xB301, UNICODE_NORM_QC_NO},
+	{0xB302, UNICODE_NORM_QC_NO},
+	{0xB303, UNICODE_NORM_QC_NO},
+	{0xB304, UNICODE_NORM_QC_NO},
+	{0xB305, UNICODE_NORM_QC_NO},
+	{0xB306, UNICODE_NORM_QC_NO},
+	{0xB307, UNICODE_NORM_QC_NO},
+	{0xB308, UNICODE_NORM_QC_NO},
+	{0xB309, UNICODE_NORM_QC_NO},
+	{0xB30A, UNICODE_NORM_QC_NO},
+	{0xB30B, UNICODE_NORM_QC_NO},
+	{0xB30C, UNICODE_NORM_QC_NO},
+	{0xB30D, UNICODE_NORM_QC_NO},
+	{0xB30E, UNICODE_NORM_QC_NO},
+	{0xB30F, UNICODE_NORM_QC_NO},
+	{0xB310, UNICODE_NORM_QC_NO},
+	{0xB311, UNICODE_NORM_QC_NO},
+	{0xB312, UNICODE_NORM_QC_NO},
+	{0xB313, UNICODE_NORM_QC_NO},
+	{0xB314, UNICODE_NORM_QC_NO},
+	{0xB315, UNICODE_NORM_QC_NO},
+	{0xB316, UNICODE_NORM_QC_NO},
+	{0xB317, UNICODE_NORM_QC_NO},
+	{0xB318, UNICODE_NORM_QC_NO},
+	{0xB319, UNICODE_NORM_QC_NO},
+	{0xB31A, UNICODE_NORM_QC_NO},
+	{0xB31B, UNICODE_NORM_QC_NO},
+	{0xB31C, UNICODE_NORM_QC_NO},
+	{0xB31D, UNICODE_NORM_QC_NO},
+	{0xB31E, UNICODE_NORM_QC_NO},
+	{0xB31F, UNICODE_NORM_QC_NO},
+	{0xB320, UNICODE_NORM_QC_NO},
+	{0xB321, UNICODE_NORM_QC_NO},
+	{0xB322, UNICODE_NORM_QC_NO},
+	{0xB323, UNICODE_NORM_QC_NO},
+	{0xB324, UNICODE_NORM_QC_NO},
+	{0xB325, UNICODE_NORM_QC_NO},
+	{0xB326, UNICODE_NORM_QC_NO},
+	{0xB327, UNICODE_NORM_QC_NO},
+	{0xB328, UNICODE_NORM_QC_NO},
+	{0xB329, UNICODE_NORM_QC_NO},
+	{0xB32A, UNICODE_NORM_QC_NO},
+	{0xB32B, UNICODE_NORM_QC_NO},
+	{0xB32C, UNICODE_NORM_QC_NO},
+	{0xB32D, UNICODE_NORM_QC_NO},
+	{0xB32E, UNICODE_NORM_QC_NO},
+	{0xB32F, UNICODE_NORM_QC_NO},
+	{0xB330, UNICODE_NORM_QC_NO},
+	{0xB331, UNICODE_NORM_QC_NO},
+	{0xB332, UNICODE_NORM_QC_NO},
+	{0xB333, UNICODE_NORM_QC_NO},
+	{0xB334, UNICODE_NORM_QC_NO},
+	{0xB335, UNICODE_NORM_QC_NO},
+	{0xB336, UNICODE_NORM_QC_NO},
+	{0xB337, UNICODE_NORM_QC_NO},
+	{0xB338, UNICODE_NORM_QC_NO},
+	{0xB339, UNICODE_NORM_QC_NO},
+	{0xB33A, UNICODE_NORM_QC_NO},
+	{0xB33B, UNICODE_NORM_QC_NO},
+	{0xB33C, UNICODE_NORM_QC_NO},
+	{0xB33D, UNICODE_NORM_QC_NO},
+	{0xB33E, UNICODE_NORM_QC_NO},
+	{0xB33F, UNICODE_NORM_QC_NO},
+	{0xB340, UNICODE_NORM_QC_NO},
+	{0xB341, UNICODE_NORM_QC_NO},
+	{0xB342, UNICODE_NORM_QC_NO},
+	{0xB343, UNICODE_NORM_QC_NO},
+	{0xB344, UNICODE_NORM_QC_NO},
+	{0xB345, UNICODE_NORM_QC_NO},
+	{0xB346, UNICODE_NORM_QC_NO},
+	{0xB347, UNICODE_NORM_QC_NO},
+	{0xB348, UNICODE_NORM_QC_NO},
+	{0xB349, UNICODE_NORM_QC_NO},
+	{0xB34A, UNICODE_NORM_QC_NO},
+	{0xB34B, UNICODE_NORM_QC_NO},
+	{0xB34C, UNICODE_NORM_QC_NO},
+	{0xB34D, UNICODE_NORM_QC_NO},
+	{0xB34E, UNICODE_NORM_QC_NO},
+	{0xB34F, UNICODE_NORM_QC_NO},
+	{0xB350, UNICODE_NORM_QC_NO},
+	{0xB351, UNICODE_NORM_QC_NO},
+	{0xB352, UNICODE_NORM_QC_NO},
+	{0xB353, UNICODE_NORM_QC_NO},
+	{0xB354, UNICODE_NORM_QC_NO},
+	{0xB355, UNICODE_NORM_QC_NO},
+	{0xB356, UNICODE_NORM_QC_NO},
+	{0xB357, UNICODE_NORM_QC_NO},
+	{0xB358, UNICODE_NORM_QC_NO},
+	{0xB359, UNICODE_NORM_QC_NO},
+	{0xB35A, UNICODE_NORM_QC_NO},
+	{0xB35B, UNICODE_NORM_QC_NO},
+	{0xB35C, UNICODE_NORM_QC_NO},
+	{0xB35D, UNICODE_NORM_QC_NO},
+	{0xB35E, UNICODE_NORM_QC_NO},
+	{0xB35F, UNICODE_NORM_QC_NO},
+	{0xB360, UNICODE_NORM_QC_NO},
+	{0xB361, UNICODE_NORM_QC_NO},
+	{0xB362, UNICODE_NORM_QC_NO},
+	{0xB363, UNICODE_NORM_QC_NO},
+	{0xB364, UNICODE_NORM_QC_NO},
+	{0xB365, UNICODE_NORM_QC_NO},
+	{0xB366, UNICODE_NORM_QC_NO},
+	{0xB367, UNICODE_NORM_QC_NO},
+	{0xB368, UNICODE_NORM_QC_NO},
+	{0xB369, UNICODE_NORM_QC_NO},
+	{0xB36A, UNICODE_NORM_QC_NO},
+	{0xB36B, UNICODE_NORM_QC_NO},
+	{0xB36C, UNICODE_NORM_QC_NO},
+	{0xB36D, UNICODE_NORM_QC_NO},
+	{0xB36E, UNICODE_NORM_QC_NO},
+	{0xB36F, UNICODE_NORM_QC_NO},
+	{0xB370, UNICODE_NORM_QC_NO},
+	{0xB371, UNICODE_NORM_QC_NO},
+	{0xB372, UNICODE_NORM_QC_NO},
+	{0xB373, UNICODE_NORM_QC_NO},
+	{0xB374, UNICODE_NORM_QC_NO},
+	{0xB375, UNICODE_NORM_QC_NO},
+	{0xB376, UNICODE_NORM_QC_NO},
+	{0xB377, UNICODE_NORM_QC_NO},
+	{0xB378, UNICODE_NORM_QC_NO},
+	{0xB379, UNICODE_NORM_QC_NO},
+	{0xB37A, UNICODE_NORM_QC_NO},
+	{0xB37B, UNICODE_NORM_QC_NO},
+	{0xB37C, UNICODE_NORM_QC_NO},
+	{0xB37D, UNICODE_NORM_QC_NO},
+	{0xB37E, UNICODE_NORM_QC_NO},
+	{0xB37F, UNICODE_NORM_QC_NO},
+	{0xB380, UNICODE_NORM_QC_NO},
+	{0xB381, UNICODE_NORM_QC_NO},
+	{0xB382, UNICODE_NORM_QC_NO},
+	{0xB383, UNICODE_NORM_QC_NO},
+	{0xB384, UNICODE_NORM_QC_NO},
+	{0xB385, UNICODE_NORM_QC_NO},
+	{0xB386, UNICODE_NORM_QC_NO},
+	{0xB387, UNICODE_NORM_QC_NO},
+	{0xB388, UNICODE_NORM_QC_NO},
+	{0xB389, UNICODE_NORM_QC_NO},
+	{0xB38A, UNICODE_NORM_QC_NO},
+	{0xB38B, UNICODE_NORM_QC_NO},
+	{0xB38C, UNICODE_NORM_QC_NO},
+	{0xB38D, UNICODE_NORM_QC_NO},
+	{0xB38E, UNICODE_NORM_QC_NO},
+	{0xB38F, UNICODE_NORM_QC_NO},
+	{0xB390, UNICODE_NORM_QC_NO},
+	{0xB391, UNICODE_NORM_QC_NO},
+	{0xB392, UNICODE_NORM_QC_NO},
+	{0xB393, UNICODE_NORM_QC_NO},
+	{0xB394, UNICODE_NORM_QC_NO},
+	{0xB395, UNICODE_NORM_QC_NO},
+	{0xB396, UNICODE_NORM_QC_NO},
+	{0xB397, UNICODE_NORM_QC_NO},
+	{0xB398, UNICODE_NORM_QC_NO},
+	{0xB399, UNICODE_NORM_QC_NO},
+	{0xB39A, UNICODE_NORM_QC_NO},
+	{0xB39B, UNICODE_NORM_QC_NO},
+	{0xB39C, UNICODE_NORM_QC_NO},
+	{0xB39D, UNICODE_NORM_QC_NO},
+	{0xB39E, UNICODE_NORM_QC_NO},
+	{0xB39F, UNICODE_NORM_QC_NO},
+	{0xB3A0, UNICODE_NORM_QC_NO},
+	{0xB3A1, UNICODE_NORM_QC_NO},
+	{0xB3A2, UNICODE_NORM_QC_NO},
+	{0xB3A3, UNICODE_NORM_QC_NO},
+	{0xB3A4, UNICODE_NORM_QC_NO},
+	{0xB3A5, UNICODE_NORM_QC_NO},
+	{0xB3A6, UNICODE_NORM_QC_NO},
+	{0xB3A7, UNICODE_NORM_QC_NO},
+	{0xB3A8, UNICODE_NORM_QC_NO},
+	{0xB3A9, UNICODE_NORM_QC_NO},
+	{0xB3AA, UNICODE_NORM_QC_NO},
+	{0xB3AB, UNICODE_NORM_QC_NO},
+	{0xB3AC, UNICODE_NORM_QC_NO},
+	{0xB3AD, UNICODE_NORM_QC_NO},
+	{0xB3AE, UNICODE_NORM_QC_NO},
+	{0xB3AF, UNICODE_NORM_QC_NO},
+	{0xB3B0, UNICODE_NORM_QC_NO},
+	{0xB3B1, UNICODE_NORM_QC_NO},
+	{0xB3B2, UNICODE_NORM_QC_NO},
+	{0xB3B3, UNICODE_NORM_QC_NO},
+	{0xB3B4, UNICODE_NORM_QC_NO},
+	{0xB3B5, UNICODE_NORM_QC_NO},
+	{0xB3B6, UNICODE_NORM_QC_NO},
+	{0xB3B7, UNICODE_NORM_QC_NO},
+	{0xB3B8, UNICODE_NORM_QC_NO},
+	{0xB3B9, UNICODE_NORM_QC_NO},
+	{0xB3BA, UNICODE_NORM_QC_NO},
+	{0xB3BB, UNICODE_NORM_QC_NO},
+	{0xB3BC, UNICODE_NORM_QC_NO},
+	{0xB3BD, UNICODE_NORM_QC_NO},
+	{0xB3BE, UNICODE_NORM_QC_NO},
+	{0xB3BF, UNICODE_NORM_QC_NO},
+	{0xB3C0, UNICODE_NORM_QC_NO},
+	{0xB3C1, UNICODE_NORM_QC_NO},
+	{0xB3C2, UNICODE_NORM_QC_NO},
+	{0xB3C3, UNICODE_NORM_QC_NO},
+	{0xB3C4, UNICODE_NORM_QC_NO},
+	{0xB3C5, UNICODE_NORM_QC_NO},
+	{0xB3C6, UNICODE_NORM_QC_NO},
+	{0xB3C7, UNICODE_NORM_QC_NO},
+	{0xB3C8, UNICODE_NORM_QC_NO},
+	{0xB3C9, UNICODE_NORM_QC_NO},
+	{0xB3CA, UNICODE_NORM_QC_NO},
+	{0xB3CB, UNICODE_NORM_QC_NO},
+	{0xB3CC, UNICODE_NORM_QC_NO},
+	{0xB3CD, UNICODE_NORM_QC_NO},
+	{0xB3CE, UNICODE_NORM_QC_NO},
+	{0xB3CF, UNICODE_NORM_QC_NO},
+	{0xB3D0, UNICODE_NORM_QC_NO},
+	{0xB3D1, UNICODE_NORM_QC_NO},
+	{0xB3D2, UNICODE_NORM_QC_NO},
+	{0xB3D3, UNICODE_NORM_QC_NO},
+	{0xB3D4, UNICODE_NORM_QC_NO},
+	{0xB3D5, UNICODE_NORM_QC_NO},
+	{0xB3D6, UNICODE_NORM_QC_NO},
+	{0xB3D7, UNICODE_NORM_QC_NO},
+	{0xB3D8, UNICODE_NORM_QC_NO},
+	{0xB3D9, UNICODE_NORM_QC_NO},
+	{0xB3DA, UNICODE_NORM_QC_NO},
+	{0xB3DB, UNICODE_NORM_QC_NO},
+	{0xB3DC, UNICODE_NORM_QC_NO},
+	{0xB3DD, UNICODE_NORM_QC_NO},
+	{0xB3DE, UNICODE_NORM_QC_NO},
+	{0xB3DF, UNICODE_NORM_QC_NO},
+	{0xB3E0, UNICODE_NORM_QC_NO},
+	{0xB3E1, UNICODE_NORM_QC_NO},
+	{0xB3E2, UNICODE_NORM_QC_NO},
+	{0xB3E3, UNICODE_NORM_QC_NO},
+	{0xB3E4, UNICODE_NORM_QC_NO},
+	{0xB3E5, UNICODE_NORM_QC_NO},
+	{0xB3E6, UNICODE_NORM_QC_NO},
+	{0xB3E7, UNICODE_NORM_QC_NO},
+	{0xB3E8, UNICODE_NORM_QC_NO},
+	{0xB3E9, UNICODE_NORM_QC_NO},
+	{0xB3EA, UNICODE_NORM_QC_NO},
+	{0xB3EB, UNICODE_NORM_QC_NO},
+	{0xB3EC, UNICODE_NORM_QC_NO},
+	{0xB3ED, UNICODE_NORM_QC_NO},
+	{0xB3EE, UNICODE_NORM_QC_NO},
+	{0xB3EF, UNICODE_NORM_QC_NO},
+	{0xB3F0, UNICODE_NORM_QC_NO},
+	{0xB3F1, UNICODE_NORM_QC_NO},
+	{0xB3F2, UNICODE_NORM_QC_NO},
+	{0xB3F3, UNICODE_NORM_QC_NO},
+	{0xB3F4, UNICODE_NORM_QC_NO},
+	{0xB3F5, UNICODE_NORM_QC_NO},
+	{0xB3F6, UNICODE_NORM_QC_NO},
+	{0xB3F7, UNICODE_NORM_QC_NO},
+	{0xB3F8, UNICODE_NORM_QC_NO},
+	{0xB3F9, UNICODE_NORM_QC_NO},
+	{0xB3FA, UNICODE_NORM_QC_NO},
+	{0xB3FB, UNICODE_NORM_QC_NO},
+	{0xB3FC, UNICODE_NORM_QC_NO},
+	{0xB3FD, UNICODE_NORM_QC_NO},
+	{0xB3FE, UNICODE_NORM_QC_NO},
+	{0xB3FF, UNICODE_NORM_QC_NO},
+	{0xB400, UNICODE_NORM_QC_NO},
+	{0xB401, UNICODE_NORM_QC_NO},
+	{0xB402, UNICODE_NORM_QC_NO},
+	{0xB403, UNICODE_NORM_QC_NO},
+	{0xB404, UNICODE_NORM_QC_NO},
+	{0xB405, UNICODE_NORM_QC_NO},
+	{0xB406, UNICODE_NORM_QC_NO},
+	{0xB407, UNICODE_NORM_QC_NO},
+	{0xB408, UNICODE_NORM_QC_NO},
+	{0xB409, UNICODE_NORM_QC_NO},
+	{0xB40A, UNICODE_NORM_QC_NO},
+	{0xB40B, UNICODE_NORM_QC_NO},
+	{0xB40C, UNICODE_NORM_QC_NO},
+	{0xB40D, UNICODE_NORM_QC_NO},
+	{0xB40E, UNICODE_NORM_QC_NO},
+	{0xB40F, UNICODE_NORM_QC_NO},
+	{0xB410, UNICODE_NORM_QC_NO},
+	{0xB411, UNICODE_NORM_QC_NO},
+	{0xB412, UNICODE_NORM_QC_NO},
+	{0xB413, UNICODE_NORM_QC_NO},
+	{0xB414, UNICODE_NORM_QC_NO},
+	{0xB415, UNICODE_NORM_QC_NO},
+	{0xB416, UNICODE_NORM_QC_NO},
+	{0xB417, UNICODE_NORM_QC_NO},
+	{0xB418, UNICODE_NORM_QC_NO},
+	{0xB419, UNICODE_NORM_QC_NO},
+	{0xB41A, UNICODE_NORM_QC_NO},
+	{0xB41B, UNICODE_NORM_QC_NO},
+	{0xB41C, UNICODE_NORM_QC_NO},
+	{0xB41D, UNICODE_NORM_QC_NO},
+	{0xB41E, UNICODE_NORM_QC_NO},
+	{0xB41F, UNICODE_NORM_QC_NO},
+	{0xB420, UNICODE_NORM_QC_NO},
+	{0xB421, UNICODE_NORM_QC_NO},
+	{0xB422, UNICODE_NORM_QC_NO},
+	{0xB423, UNICODE_NORM_QC_NO},
+	{0xB424, UNICODE_NORM_QC_NO},
+	{0xB425, UNICODE_NORM_QC_NO},
+	{0xB426, UNICODE_NORM_QC_NO},
+	{0xB427, UNICODE_NORM_QC_NO},
+	{0xB428, UNICODE_NORM_QC_NO},
+	{0xB429, UNICODE_NORM_QC_NO},
+	{0xB42A, UNICODE_NORM_QC_NO},
+	{0xB42B, UNICODE_NORM_QC_NO},
+	{0xB42C, UNICODE_NORM_QC_NO},
+	{0xB42D, UNICODE_NORM_QC_NO},
+	{0xB42E, UNICODE_NORM_QC_NO},
+	{0xB42F, UNICODE_NORM_QC_NO},
+	{0xB430, UNICODE_NORM_QC_NO},
+	{0xB431, UNICODE_NORM_QC_NO},
+	{0xB432, UNICODE_NORM_QC_NO},
+	{0xB433, UNICODE_NORM_QC_NO},
+	{0xB434, UNICODE_NORM_QC_NO},
+	{0xB435, UNICODE_NORM_QC_NO},
+	{0xB436, UNICODE_NORM_QC_NO},
+	{0xB437, UNICODE_NORM_QC_NO},
+	{0xB438, UNICODE_NORM_QC_NO},
+	{0xB439, UNICODE_NORM_QC_NO},
+	{0xB43A, UNICODE_NORM_QC_NO},
+	{0xB43B, UNICODE_NORM_QC_NO},
+	{0xB43C, UNICODE_NORM_QC_NO},
+	{0xB43D, UNICODE_NORM_QC_NO},
+	{0xB43E, UNICODE_NORM_QC_NO},
+	{0xB43F, UNICODE_NORM_QC_NO},
+	{0xB440, UNICODE_NORM_QC_NO},
+	{0xB441, UNICODE_NORM_QC_NO},
+	{0xB442, UNICODE_NORM_QC_NO},
+	{0xB443, UNICODE_NORM_QC_NO},
+	{0xB444, UNICODE_NORM_QC_NO},
+	{0xB445, UNICODE_NORM_QC_NO},
+	{0xB446, UNICODE_NORM_QC_NO},
+	{0xB447, UNICODE_NORM_QC_NO},
+	{0xB448, UNICODE_NORM_QC_NO},
+	{0xB449, UNICODE_NORM_QC_NO},
+	{0xB44A, UNICODE_NORM_QC_NO},
+	{0xB44B, UNICODE_NORM_QC_NO},
+	{0xB44C, UNICODE_NORM_QC_NO},
+	{0xB44D, UNICODE_NORM_QC_NO},
+	{0xB44E, UNICODE_NORM_QC_NO},
+	{0xB44F, UNICODE_NORM_QC_NO},
+	{0xB450, UNICODE_NORM_QC_NO},
+	{0xB451, UNICODE_NORM_QC_NO},
+	{0xB452, UNICODE_NORM_QC_NO},
+	{0xB453, UNICODE_NORM_QC_NO},
+	{0xB454, UNICODE_NORM_QC_NO},
+	{0xB455, UNICODE_NORM_QC_NO},
+	{0xB456, UNICODE_NORM_QC_NO},
+	{0xB457, UNICODE_NORM_QC_NO},
+	{0xB458, UNICODE_NORM_QC_NO},
+	{0xB459, UNICODE_NORM_QC_NO},
+	{0xB45A, UNICODE_NORM_QC_NO},
+	{0xB45B, UNICODE_NORM_QC_NO},
+	{0xB45C, UNICODE_NORM_QC_NO},
+	{0xB45D, UNICODE_NORM_QC_NO},
+	{0xB45E, UNICODE_NORM_QC_NO},
+	{0xB45F, UNICODE_NORM_QC_NO},
+	{0xB460, UNICODE_NORM_QC_NO},
+	{0xB461, UNICODE_NORM_QC_NO},
+	{0xB462, UNICODE_NORM_QC_NO},
+	{0xB463, UNICODE_NORM_QC_NO},
+	{0xB464, UNICODE_NORM_QC_NO},
+	{0xB465, UNICODE_NORM_QC_NO},
+	{0xB466, UNICODE_NORM_QC_NO},
+	{0xB467, UNICODE_NORM_QC_NO},
+	{0xB468, UNICODE_NORM_QC_NO},
+	{0xB469, UNICODE_NORM_QC_NO},
+	{0xB46A, UNICODE_NORM_QC_NO},
+	{0xB46B, UNICODE_NORM_QC_NO},
+	{0xB46C, UNICODE_NORM_QC_NO},
+	{0xB46D, UNICODE_NORM_QC_NO},
+	{0xB46E, UNICODE_NORM_QC_NO},
+	{0xB46F, UNICODE_NORM_QC_NO},
+	{0xB470, UNICODE_NORM_QC_NO},
+	{0xB471, UNICODE_NORM_QC_NO},
+	{0xB472, UNICODE_NORM_QC_NO},
+	{0xB473, UNICODE_NORM_QC_NO},
+	{0xB474, UNICODE_NORM_QC_NO},
+	{0xB475, UNICODE_NORM_QC_NO},
+	{0xB476, UNICODE_NORM_QC_NO},
+	{0xB477, UNICODE_NORM_QC_NO},
+	{0xB478, UNICODE_NORM_QC_NO},
+	{0xB479, UNICODE_NORM_QC_NO},
+	{0xB47A, UNICODE_NORM_QC_NO},
+	{0xB47B, UNICODE_NORM_QC_NO},
+	{0xB47C, UNICODE_NORM_QC_NO},
+	{0xB47D, UNICODE_NORM_QC_NO},
+	{0xB47E, UNICODE_NORM_QC_NO},
+	{0xB47F, UNICODE_NORM_QC_NO},
+	{0xB480, UNICODE_NORM_QC_NO},
+	{0xB481, UNICODE_NORM_QC_NO},
+	{0xB482, UNICODE_NORM_QC_NO},
+	{0xB483, UNICODE_NORM_QC_NO},
+	{0xB484, UNICODE_NORM_QC_NO},
+	{0xB485, UNICODE_NORM_QC_NO},
+	{0xB486, UNICODE_NORM_QC_NO},
+	{0xB487, UNICODE_NORM_QC_NO},
+	{0xB488, UNICODE_NORM_QC_NO},
+	{0xB489, UNICODE_NORM_QC_NO},
+	{0xB48A, UNICODE_NORM_QC_NO},
+	{0xB48B, UNICODE_NORM_QC_NO},
+	{0xB48C, UNICODE_NORM_QC_NO},
+	{0xB48D, UNICODE_NORM_QC_NO},
+	{0xB48E, UNICODE_NORM_QC_NO},
+	{0xB48F, UNICODE_NORM_QC_NO},
+	{0xB490, UNICODE_NORM_QC_NO},
+	{0xB491, UNICODE_NORM_QC_NO},
+	{0xB492, UNICODE_NORM_QC_NO},
+	{0xB493, UNICODE_NORM_QC_NO},
+	{0xB494, UNICODE_NORM_QC_NO},
+	{0xB495, UNICODE_NORM_QC_NO},
+	{0xB496, UNICODE_NORM_QC_NO},
+	{0xB497, UNICODE_NORM_QC_NO},
+	{0xB498, UNICODE_NORM_QC_NO},
+	{0xB499, UNICODE_NORM_QC_NO},
+	{0xB49A, UNICODE_NORM_QC_NO},
+	{0xB49B, UNICODE_NORM_QC_NO},
+	{0xB49C, UNICODE_NORM_QC_NO},
+	{0xB49D, UNICODE_NORM_QC_NO},
+	{0xB49E, UNICODE_NORM_QC_NO},
+	{0xB49F, UNICODE_NORM_QC_NO},
+	{0xB4A0, UNICODE_NORM_QC_NO},
+	{0xB4A1, UNICODE_NORM_QC_NO},
+	{0xB4A2, UNICODE_NORM_QC_NO},
+	{0xB4A3, UNICODE_NORM_QC_NO},
+	{0xB4A4, UNICODE_NORM_QC_NO},
+	{0xB4A5, UNICODE_NORM_QC_NO},
+	{0xB4A6, UNICODE_NORM_QC_NO},
+	{0xB4A7, UNICODE_NORM_QC_NO},
+	{0xB4A8, UNICODE_NORM_QC_NO},
+	{0xB4A9, UNICODE_NORM_QC_NO},
+	{0xB4AA, UNICODE_NORM_QC_NO},
+	{0xB4AB, UNICODE_NORM_QC_NO},
+	{0xB4AC, UNICODE_NORM_QC_NO},
+	{0xB4AD, UNICODE_NORM_QC_NO},
+	{0xB4AE, UNICODE_NORM_QC_NO},
+	{0xB4AF, UNICODE_NORM_QC_NO},
+	{0xB4B0, UNICODE_NORM_QC_NO},
+	{0xB4B1, UNICODE_NORM_QC_NO},
+	{0xB4B2, UNICODE_NORM_QC_NO},
+	{0xB4B3, UNICODE_NORM_QC_NO},
+	{0xB4B4, UNICODE_NORM_QC_NO},
+	{0xB4B5, UNICODE_NORM_QC_NO},
+	{0xB4B6, UNICODE_NORM_QC_NO},
+	{0xB4B7, UNICODE_NORM_QC_NO},
+	{0xB4B8, UNICODE_NORM_QC_NO},
+	{0xB4B9, UNICODE_NORM_QC_NO},
+	{0xB4BA, UNICODE_NORM_QC_NO},
+	{0xB4BB, UNICODE_NORM_QC_NO},
+	{0xB4BC, UNICODE_NORM_QC_NO},
+	{0xB4BD, UNICODE_NORM_QC_NO},
+	{0xB4BE, UNICODE_NORM_QC_NO},
+	{0xB4BF, UNICODE_NORM_QC_NO},
+	{0xB4C0, UNICODE_NORM_QC_NO},
+	{0xB4C1, UNICODE_NORM_QC_NO},
+	{0xB4C2, UNICODE_NORM_QC_NO},
+	{0xB4C3, UNICODE_NORM_QC_NO},
+	{0xB4C4, UNICODE_NORM_QC_NO},
+	{0xB4C5, UNICODE_NORM_QC_NO},
+	{0xB4C6, UNICODE_NORM_QC_NO},
+	{0xB4C7, UNICODE_NORM_QC_NO},
+	{0xB4C8, UNICODE_NORM_QC_NO},
+	{0xB4C9, UNICODE_NORM_QC_NO},
+	{0xB4CA, UNICODE_NORM_QC_NO},
+	{0xB4CB, UNICODE_NORM_QC_NO},
+	{0xB4CC, UNICODE_NORM_QC_NO},
+	{0xB4CD, UNICODE_NORM_QC_NO},
+	{0xB4CE, UNICODE_NORM_QC_NO},
+	{0xB4CF, UNICODE_NORM_QC_NO},
+	{0xB4D0, UNICODE_NORM_QC_NO},
+	{0xB4D1, UNICODE_NORM_QC_NO},
+	{0xB4D2, UNICODE_NORM_QC_NO},
+	{0xB4D3, UNICODE_NORM_QC_NO},
+	{0xB4D4, UNICODE_NORM_QC_NO},
+	{0xB4D5, UNICODE_NORM_QC_NO},
+	{0xB4D6, UNICODE_NORM_QC_NO},
+	{0xB4D7, UNICODE_NORM_QC_NO},
+	{0xB4D8, UNICODE_NORM_QC_NO},
+	{0xB4D9, UNICODE_NORM_QC_NO},
+	{0xB4DA, UNICODE_NORM_QC_NO},
+	{0xB4DB, UNICODE_NORM_QC_NO},
+	{0xB4DC, UNICODE_NORM_QC_NO},
+	{0xB4DD, UNICODE_NORM_QC_NO},
+	{0xB4DE, UNICODE_NORM_QC_NO},
+	{0xB4DF, UNICODE_NORM_QC_NO},
+	{0xB4E0, UNICODE_NORM_QC_NO},
+	{0xB4E1, UNICODE_NORM_QC_NO},
+	{0xB4E2, UNICODE_NORM_QC_NO},
+	{0xB4E3, UNICODE_NORM_QC_NO},
+	{0xB4E4, UNICODE_NORM_QC_NO},
+	{0xB4E5, UNICODE_NORM_QC_NO},
+	{0xB4E6, UNICODE_NORM_QC_NO},
+	{0xB4E7, UNICODE_NORM_QC_NO},
+	{0xB4E8, UNICODE_NORM_QC_NO},
+	{0xB4E9, UNICODE_NORM_QC_NO},
+	{0xB4EA, UNICODE_NORM_QC_NO},
+	{0xB4EB, UNICODE_NORM_QC_NO},
+	{0xB4EC, UNICODE_NORM_QC_NO},
+	{0xB4ED, UNICODE_NORM_QC_NO},
+	{0xB4EE, UNICODE_NORM_QC_NO},
+	{0xB4EF, UNICODE_NORM_QC_NO},
+	{0xB4F0, UNICODE_NORM_QC_NO},
+	{0xB4F1, UNICODE_NORM_QC_NO},
+	{0xB4F2, UNICODE_NORM_QC_NO},
+	{0xB4F3, UNICODE_NORM_QC_NO},
+	{0xB4F4, UNICODE_NORM_QC_NO},
+	{0xB4F5, UNICODE_NORM_QC_NO},
+	{0xB4F6, UNICODE_NORM_QC_NO},
+	{0xB4F7, UNICODE_NORM_QC_NO},
+	{0xB4F8, UNICODE_NORM_QC_NO},
+	{0xB4F9, UNICODE_NORM_QC_NO},
+	{0xB4FA, UNICODE_NORM_QC_NO},
+	{0xB4FB, UNICODE_NORM_QC_NO},
+	{0xB4FC, UNICODE_NORM_QC_NO},
+	{0xB4FD, UNICODE_NORM_QC_NO},
+	{0xB4FE, UNICODE_NORM_QC_NO},
+	{0xB4FF, UNICODE_NORM_QC_NO},
+	{0xB500, UNICODE_NORM_QC_NO},
+	{0xB501, UNICODE_NORM_QC_NO},
+	{0xB502, UNICODE_NORM_QC_NO},
+	{0xB503, UNICODE_NORM_QC_NO},
+	{0xB504, UNICODE_NORM_QC_NO},
+	{0xB505, UNICODE_NORM_QC_NO},
+	{0xB506, UNICODE_NORM_QC_NO},
+	{0xB507, UNICODE_NORM_QC_NO},
+	{0xB508, UNICODE_NORM_QC_NO},
+	{0xB509, UNICODE_NORM_QC_NO},
+	{0xB50A, UNICODE_NORM_QC_NO},
+	{0xB50B, UNICODE_NORM_QC_NO},
+	{0xB50C, UNICODE_NORM_QC_NO},
+	{0xB50D, UNICODE_NORM_QC_NO},
+	{0xB50E, UNICODE_NORM_QC_NO},
+	{0xB50F, UNICODE_NORM_QC_NO},
+	{0xB510, UNICODE_NORM_QC_NO},
+	{0xB511, UNICODE_NORM_QC_NO},
+	{0xB512, UNICODE_NORM_QC_NO},
+	{0xB513, UNICODE_NORM_QC_NO},
+	{0xB514, UNICODE_NORM_QC_NO},
+	{0xB515, UNICODE_NORM_QC_NO},
+	{0xB516, UNICODE_NORM_QC_NO},
+	{0xB517, UNICODE_NORM_QC_NO},
+	{0xB518, UNICODE_NORM_QC_NO},
+	{0xB519, UNICODE_NORM_QC_NO},
+	{0xB51A, UNICODE_NORM_QC_NO},
+	{0xB51B, UNICODE_NORM_QC_NO},
+	{0xB51C, UNICODE_NORM_QC_NO},
+	{0xB51D, UNICODE_NORM_QC_NO},
+	{0xB51E, UNICODE_NORM_QC_NO},
+	{0xB51F, UNICODE_NORM_QC_NO},
+	{0xB520, UNICODE_NORM_QC_NO},
+	{0xB521, UNICODE_NORM_QC_NO},
+	{0xB522, UNICODE_NORM_QC_NO},
+	{0xB523, UNICODE_NORM_QC_NO},
+	{0xB524, UNICODE_NORM_QC_NO},
+	{0xB525, UNICODE_NORM_QC_NO},
+	{0xB526, UNICODE_NORM_QC_NO},
+	{0xB527, UNICODE_NORM_QC_NO},
+	{0xB528, UNICODE_NORM_QC_NO},
+	{0xB529, UNICODE_NORM_QC_NO},
+	{0xB52A, UNICODE_NORM_QC_NO},
+	{0xB52B, UNICODE_NORM_QC_NO},
+	{0xB52C, UNICODE_NORM_QC_NO},
+	{0xB52D, UNICODE_NORM_QC_NO},
+	{0xB52E, UNICODE_NORM_QC_NO},
+	{0xB52F, UNICODE_NORM_QC_NO},
+	{0xB530, UNICODE_NORM_QC_NO},
+	{0xB531, UNICODE_NORM_QC_NO},
+	{0xB532, UNICODE_NORM_QC_NO},
+	{0xB533, UNICODE_NORM_QC_NO},
+	{0xB534, UNICODE_NORM_QC_NO},
+	{0xB535, UNICODE_NORM_QC_NO},
+	{0xB536, UNICODE_NORM_QC_NO},
+	{0xB537, UNICODE_NORM_QC_NO},
+	{0xB538, UNICODE_NORM_QC_NO},
+	{0xB539, UNICODE_NORM_QC_NO},
+	{0xB53A, UNICODE_NORM_QC_NO},
+	{0xB53B, UNICODE_NORM_QC_NO},
+	{0xB53C, UNICODE_NORM_QC_NO},
+	{0xB53D, UNICODE_NORM_QC_NO},
+	{0xB53E, UNICODE_NORM_QC_NO},
+	{0xB53F, UNICODE_NORM_QC_NO},
+	{0xB540, UNICODE_NORM_QC_NO},
+	{0xB541, UNICODE_NORM_QC_NO},
+	{0xB542, UNICODE_NORM_QC_NO},
+	{0xB543, UNICODE_NORM_QC_NO},
+	{0xB544, UNICODE_NORM_QC_NO},
+	{0xB545, UNICODE_NORM_QC_NO},
+	{0xB546, UNICODE_NORM_QC_NO},
+	{0xB547, UNICODE_NORM_QC_NO},
+	{0xB548, UNICODE_NORM_QC_NO},
+	{0xB549, UNICODE_NORM_QC_NO},
+	{0xB54A, UNICODE_NORM_QC_NO},
+	{0xB54B, UNICODE_NORM_QC_NO},
+	{0xB54C, UNICODE_NORM_QC_NO},
+	{0xB54D, UNICODE_NORM_QC_NO},
+	{0xB54E, UNICODE_NORM_QC_NO},
+	{0xB54F, UNICODE_NORM_QC_NO},
+	{0xB550, UNICODE_NORM_QC_NO},
+	{0xB551, UNICODE_NORM_QC_NO},
+	{0xB552, UNICODE_NORM_QC_NO},
+	{0xB553, UNICODE_NORM_QC_NO},
+	{0xB554, UNICODE_NORM_QC_NO},
+	{0xB555, UNICODE_NORM_QC_NO},
+	{0xB556, UNICODE_NORM_QC_NO},
+	{0xB557, UNICODE_NORM_QC_NO},
+	{0xB558, UNICODE_NORM_QC_NO},
+	{0xB559, UNICODE_NORM_QC_NO},
+	{0xB55A, UNICODE_NORM_QC_NO},
+	{0xB55B, UNICODE_NORM_QC_NO},
+	{0xB55C, UNICODE_NORM_QC_NO},
+	{0xB55D, UNICODE_NORM_QC_NO},
+	{0xB55E, UNICODE_NORM_QC_NO},
+	{0xB55F, UNICODE_NORM_QC_NO},
+	{0xB560, UNICODE_NORM_QC_NO},
+	{0xB561, UNICODE_NORM_QC_NO},
+	{0xB562, UNICODE_NORM_QC_NO},
+	{0xB563, UNICODE_NORM_QC_NO},
+	{0xB564, UNICODE_NORM_QC_NO},
+	{0xB565, UNICODE_NORM_QC_NO},
+	{0xB566, UNICODE_NORM_QC_NO},
+	{0xB567, UNICODE_NORM_QC_NO},
+	{0xB568, UNICODE_NORM_QC_NO},
+	{0xB569, UNICODE_NORM_QC_NO},
+	{0xB56A, UNICODE_NORM_QC_NO},
+	{0xB56B, UNICODE_NORM_QC_NO},
+	{0xB56C, UNICODE_NORM_QC_NO},
+	{0xB56D, UNICODE_NORM_QC_NO},
+	{0xB56E, UNICODE_NORM_QC_NO},
+	{0xB56F, UNICODE_NORM_QC_NO},
+	{0xB570, UNICODE_NORM_QC_NO},
+	{0xB571, UNICODE_NORM_QC_NO},
+	{0xB572, UNICODE_NORM_QC_NO},
+	{0xB573, UNICODE_NORM_QC_NO},
+	{0xB574, UNICODE_NORM_QC_NO},
+	{0xB575, UNICODE_NORM_QC_NO},
+	{0xB576, UNICODE_NORM_QC_NO},
+	{0xB577, UNICODE_NORM_QC_NO},
+	{0xB578, UNICODE_NORM_QC_NO},
+	{0xB579, UNICODE_NORM_QC_NO},
+	{0xB57A, UNICODE_NORM_QC_NO},
+	{0xB57B, UNICODE_NORM_QC_NO},
+	{0xB57C, UNICODE_NORM_QC_NO},
+	{0xB57D, UNICODE_NORM_QC_NO},
+	{0xB57E, UNICODE_NORM_QC_NO},
+	{0xB57F, UNICODE_NORM_QC_NO},
+	{0xB580, UNICODE_NORM_QC_NO},
+	{0xB581, UNICODE_NORM_QC_NO},
+	{0xB582, UNICODE_NORM_QC_NO},
+	{0xB583, UNICODE_NORM_QC_NO},
+	{0xB584, UNICODE_NORM_QC_NO},
+	{0xB585, UNICODE_NORM_QC_NO},
+	{0xB586, UNICODE_NORM_QC_NO},
+	{0xB587, UNICODE_NORM_QC_NO},
+	{0xB588, UNICODE_NORM_QC_NO},
+	{0xB589, UNICODE_NORM_QC_NO},
+	{0xB58A, UNICODE_NORM_QC_NO},
+	{0xB58B, UNICODE_NORM_QC_NO},
+	{0xB58C, UNICODE_NORM_QC_NO},
+	{0xB58D, UNICODE_NORM_QC_NO},
+	{0xB58E, UNICODE_NORM_QC_NO},
+	{0xB58F, UNICODE_NORM_QC_NO},
+	{0xB590, UNICODE_NORM_QC_NO},
+	{0xB591, UNICODE_NORM_QC_NO},
+	{0xB592, UNICODE_NORM_QC_NO},
+	{0xB593, UNICODE_NORM_QC_NO},
+	{0xB594, UNICODE_NORM_QC_NO},
+	{0xB595, UNICODE_NORM_QC_NO},
+	{0xB596, UNICODE_NORM_QC_NO},
+	{0xB597, UNICODE_NORM_QC_NO},
+	{0xB598, UNICODE_NORM_QC_NO},
+	{0xB599, UNICODE_NORM_QC_NO},
+	{0xB59A, UNICODE_NORM_QC_NO},
+	{0xB59B, UNICODE_NORM_QC_NO},
+	{0xB59C, UNICODE_NORM_QC_NO},
+	{0xB59D, UNICODE_NORM_QC_NO},
+	{0xB59E, UNICODE_NORM_QC_NO},
+	{0xB59F, UNICODE_NORM_QC_NO},
+	{0xB5A0, UNICODE_NORM_QC_NO},
+	{0xB5A1, UNICODE_NORM_QC_NO},
+	{0xB5A2, UNICODE_NORM_QC_NO},
+	{0xB5A3, UNICODE_NORM_QC_NO},
+	{0xB5A4, UNICODE_NORM_QC_NO},
+	{0xB5A5, UNICODE_NORM_QC_NO},
+	{0xB5A6, UNICODE_NORM_QC_NO},
+	{0xB5A7, UNICODE_NORM_QC_NO},
+	{0xB5A8, UNICODE_NORM_QC_NO},
+	{0xB5A9, UNICODE_NORM_QC_NO},
+	{0xB5AA, UNICODE_NORM_QC_NO},
+	{0xB5AB, UNICODE_NORM_QC_NO},
+	{0xB5AC, UNICODE_NORM_QC_NO},
+	{0xB5AD, UNICODE_NORM_QC_NO},
+	{0xB5AE, UNICODE_NORM_QC_NO},
+	{0xB5AF, UNICODE_NORM_QC_NO},
+	{0xB5B0, UNICODE_NORM_QC_NO},
+	{0xB5B1, UNICODE_NORM_QC_NO},
+	{0xB5B2, UNICODE_NORM_QC_NO},
+	{0xB5B3, UNICODE_NORM_QC_NO},
+	{0xB5B4, UNICODE_NORM_QC_NO},
+	{0xB5B5, UNICODE_NORM_QC_NO},
+	{0xB5B6, UNICODE_NORM_QC_NO},
+	{0xB5B7, UNICODE_NORM_QC_NO},
+	{0xB5B8, UNICODE_NORM_QC_NO},
+	{0xB5B9, UNICODE_NORM_QC_NO},
+	{0xB5BA, UNICODE_NORM_QC_NO},
+	{0xB5BB, UNICODE_NORM_QC_NO},
+	{0xB5BC, UNICODE_NORM_QC_NO},
+	{0xB5BD, UNICODE_NORM_QC_NO},
+	{0xB5BE, UNICODE_NORM_QC_NO},
+	{0xB5BF, UNICODE_NORM_QC_NO},
+	{0xB5C0, UNICODE_NORM_QC_NO},
+	{0xB5C1, UNICODE_NORM_QC_NO},
+	{0xB5C2, UNICODE_NORM_QC_NO},
+	{0xB5C3, UNICODE_NORM_QC_NO},
+	{0xB5C4, UNICODE_NORM_QC_NO},
+	{0xB5C5, UNICODE_NORM_QC_NO},
+	{0xB5C6, UNICODE_NORM_QC_NO},
+	{0xB5C7, UNICODE_NORM_QC_NO},
+	{0xB5C8, UNICODE_NORM_QC_NO},
+	{0xB5C9, UNICODE_NORM_QC_NO},
+	{0xB5CA, UNICODE_NORM_QC_NO},
+	{0xB5CB, UNICODE_NORM_QC_NO},
+	{0xB5CC, UNICODE_NORM_QC_NO},
+	{0xB5CD, UNICODE_NORM_QC_NO},
+	{0xB5CE, UNICODE_NORM_QC_NO},
+	{0xB5CF, UNICODE_NORM_QC_NO},
+	{0xB5D0, UNICODE_NORM_QC_NO},
+	{0xB5D1, UNICODE_NORM_QC_NO},
+	{0xB5D2, UNICODE_NORM_QC_NO},
+	{0xB5D3, UNICODE_NORM_QC_NO},
+	{0xB5D4, UNICODE_NORM_QC_NO},
+	{0xB5D5, UNICODE_NORM_QC_NO},
+	{0xB5D6, UNICODE_NORM_QC_NO},
+	{0xB5D7, UNICODE_NORM_QC_NO},
+	{0xB5D8, UNICODE_NORM_QC_NO},
+	{0xB5D9, UNICODE_NORM_QC_NO},
+	{0xB5DA, UNICODE_NORM_QC_NO},
+	{0xB5DB, UNICODE_NORM_QC_NO},
+	{0xB5DC, UNICODE_NORM_QC_NO},
+	{0xB5DD, UNICODE_NORM_QC_NO},
+	{0xB5DE, UNICODE_NORM_QC_NO},
+	{0xB5DF, UNICODE_NORM_QC_NO},
+	{0xB5E0, UNICODE_NORM_QC_NO},
+	{0xB5E1, UNICODE_NORM_QC_NO},
+	{0xB5E2, UNICODE_NORM_QC_NO},
+	{0xB5E3, UNICODE_NORM_QC_NO},
+	{0xB5E4, UNICODE_NORM_QC_NO},
+	{0xB5E5, UNICODE_NORM_QC_NO},
+	{0xB5E6, UNICODE_NORM_QC_NO},
+	{0xB5E7, UNICODE_NORM_QC_NO},
+	{0xB5E8, UNICODE_NORM_QC_NO},
+	{0xB5E9, UNICODE_NORM_QC_NO},
+	{0xB5EA, UNICODE_NORM_QC_NO},
+	{0xB5EB, UNICODE_NORM_QC_NO},
+	{0xB5EC, UNICODE_NORM_QC_NO},
+	{0xB5ED, UNICODE_NORM_QC_NO},
+	{0xB5EE, UNICODE_NORM_QC_NO},
+	{0xB5EF, UNICODE_NORM_QC_NO},
+	{0xB5F0, UNICODE_NORM_QC_NO},
+	{0xB5F1, UNICODE_NORM_QC_NO},
+	{0xB5F2, UNICODE_NORM_QC_NO},
+	{0xB5F3, UNICODE_NORM_QC_NO},
+	{0xB5F4, UNICODE_NORM_QC_NO},
+	{0xB5F5, UNICODE_NORM_QC_NO},
+	{0xB5F6, UNICODE_NORM_QC_NO},
+	{0xB5F7, UNICODE_NORM_QC_NO},
+	{0xB5F8, UNICODE_NORM_QC_NO},
+	{0xB5F9, UNICODE_NORM_QC_NO},
+	{0xB5FA, UNICODE_NORM_QC_NO},
+	{0xB5FB, UNICODE_NORM_QC_NO},
+	{0xB5FC, UNICODE_NORM_QC_NO},
+	{0xB5FD, UNICODE_NORM_QC_NO},
+	{0xB5FE, UNICODE_NORM_QC_NO},
+	{0xB5FF, UNICODE_NORM_QC_NO},
+	{0xB600, UNICODE_NORM_QC_NO},
+	{0xB601, UNICODE_NORM_QC_NO},
+	{0xB602, UNICODE_NORM_QC_NO},
+	{0xB603, UNICODE_NORM_QC_NO},
+	{0xB604, UNICODE_NORM_QC_NO},
+	{0xB605, UNICODE_NORM_QC_NO},
+	{0xB606, UNICODE_NORM_QC_NO},
+	{0xB607, UNICODE_NORM_QC_NO},
+	{0xB608, UNICODE_NORM_QC_NO},
+	{0xB609, UNICODE_NORM_QC_NO},
+	{0xB60A, UNICODE_NORM_QC_NO},
+	{0xB60B, UNICODE_NORM_QC_NO},
+	{0xB60C, UNICODE_NORM_QC_NO},
+	{0xB60D, UNICODE_NORM_QC_NO},
+	{0xB60E, UNICODE_NORM_QC_NO},
+	{0xB60F, UNICODE_NORM_QC_NO},
+	{0xB610, UNICODE_NORM_QC_NO},
+	{0xB611, UNICODE_NORM_QC_NO},
+	{0xB612, UNICODE_NORM_QC_NO},
+	{0xB613, UNICODE_NORM_QC_NO},
+	{0xB614, UNICODE_NORM_QC_NO},
+	{0xB615, UNICODE_NORM_QC_NO},
+	{0xB616, UNICODE_NORM_QC_NO},
+	{0xB617, UNICODE_NORM_QC_NO},
+	{0xB618, UNICODE_NORM_QC_NO},
+	{0xB619, UNICODE_NORM_QC_NO},
+	{0xB61A, UNICODE_NORM_QC_NO},
+	{0xB61B, UNICODE_NORM_QC_NO},
+	{0xB61C, UNICODE_NORM_QC_NO},
+	{0xB61D, UNICODE_NORM_QC_NO},
+	{0xB61E, UNICODE_NORM_QC_NO},
+	{0xB61F, UNICODE_NORM_QC_NO},
+	{0xB620, UNICODE_NORM_QC_NO},
+	{0xB621, UNICODE_NORM_QC_NO},
+	{0xB622, UNICODE_NORM_QC_NO},
+	{0xB623, UNICODE_NORM_QC_NO},
+	{0xB624, UNICODE_NORM_QC_NO},
+	{0xB625, UNICODE_NORM_QC_NO},
+	{0xB626, UNICODE_NORM_QC_NO},
+	{0xB627, UNICODE_NORM_QC_NO},
+	{0xB628, UNICODE_NORM_QC_NO},
+	{0xB629, UNICODE_NORM_QC_NO},
+	{0xB62A, UNICODE_NORM_QC_NO},
+	{0xB62B, UNICODE_NORM_QC_NO},
+	{0xB62C, UNICODE_NORM_QC_NO},
+	{0xB62D, UNICODE_NORM_QC_NO},
+	{0xB62E, UNICODE_NORM_QC_NO},
+	{0xB62F, UNICODE_NORM_QC_NO},
+	{0xB630, UNICODE_NORM_QC_NO},
+	{0xB631, UNICODE_NORM_QC_NO},
+	{0xB632, UNICODE_NORM_QC_NO},
+	{0xB633, UNICODE_NORM_QC_NO},
+	{0xB634, UNICODE_NORM_QC_NO},
+	{0xB635, UNICODE_NORM_QC_NO},
+	{0xB636, UNICODE_NORM_QC_NO},
+	{0xB637, UNICODE_NORM_QC_NO},
+	{0xB638, UNICODE_NORM_QC_NO},
+	{0xB639, UNICODE_NORM_QC_NO},
+	{0xB63A, UNICODE_NORM_QC_NO},
+	{0xB63B, UNICODE_NORM_QC_NO},
+	{0xB63C, UNICODE_NORM_QC_NO},
+	{0xB63D, UNICODE_NORM_QC_NO},
+	{0xB63E, UNICODE_NORM_QC_NO},
+	{0xB63F, UNICODE_NORM_QC_NO},
+	{0xB640, UNICODE_NORM_QC_NO},
+	{0xB641, UNICODE_NORM_QC_NO},
+	{0xB642, UNICODE_NORM_QC_NO},
+	{0xB643, UNICODE_NORM_QC_NO},
+	{0xB644, UNICODE_NORM_QC_NO},
+	{0xB645, UNICODE_NORM_QC_NO},
+	{0xB646, UNICODE_NORM_QC_NO},
+	{0xB647, UNICODE_NORM_QC_NO},
+	{0xB648, UNICODE_NORM_QC_NO},
+	{0xB649, UNICODE_NORM_QC_NO},
+	{0xB64A, UNICODE_NORM_QC_NO},
+	{0xB64B, UNICODE_NORM_QC_NO},
+	{0xB64C, UNICODE_NORM_QC_NO},
+	{0xB64D, UNICODE_NORM_QC_NO},
+	{0xB64E, UNICODE_NORM_QC_NO},
+	{0xB64F, UNICODE_NORM_QC_NO},
+	{0xB650, UNICODE_NORM_QC_NO},
+	{0xB651, UNICODE_NORM_QC_NO},
+	{0xB652, UNICODE_NORM_QC_NO},
+	{0xB653, UNICODE_NORM_QC_NO},
+	{0xB654, UNICODE_NORM_QC_NO},
+	{0xB655, UNICODE_NORM_QC_NO},
+	{0xB656, UNICODE_NORM_QC_NO},
+	{0xB657, UNICODE_NORM_QC_NO},
+	{0xB658, UNICODE_NORM_QC_NO},
+	{0xB659, UNICODE_NORM_QC_NO},
+	{0xB65A, UNICODE_NORM_QC_NO},
+	{0xB65B, UNICODE_NORM_QC_NO},
+	{0xB65C, UNICODE_NORM_QC_NO},
+	{0xB65D, UNICODE_NORM_QC_NO},
+	{0xB65E, UNICODE_NORM_QC_NO},
+	{0xB65F, UNICODE_NORM_QC_NO},
+	{0xB660, UNICODE_NORM_QC_NO},
+	{0xB661, UNICODE_NORM_QC_NO},
+	{0xB662, UNICODE_NORM_QC_NO},
+	{0xB663, UNICODE_NORM_QC_NO},
+	{0xB664, UNICODE_NORM_QC_NO},
+	{0xB665, UNICODE_NORM_QC_NO},
+	{0xB666, UNICODE_NORM_QC_NO},
+	{0xB667, UNICODE_NORM_QC_NO},
+	{0xB668, UNICODE_NORM_QC_NO},
+	{0xB669, UNICODE_NORM_QC_NO},
+	{0xB66A, UNICODE_NORM_QC_NO},
+	{0xB66B, UNICODE_NORM_QC_NO},
+	{0xB66C, UNICODE_NORM_QC_NO},
+	{0xB66D, UNICODE_NORM_QC_NO},
+	{0xB66E, UNICODE_NORM_QC_NO},
+	{0xB66F, UNICODE_NORM_QC_NO},
+	{0xB670, UNICODE_NORM_QC_NO},
+	{0xB671, UNICODE_NORM_QC_NO},
+	{0xB672, UNICODE_NORM_QC_NO},
+	{0xB673, UNICODE_NORM_QC_NO},
+	{0xB674, UNICODE_NORM_QC_NO},
+	{0xB675, UNICODE_NORM_QC_NO},
+	{0xB676, UNICODE_NORM_QC_NO},
+	{0xB677, UNICODE_NORM_QC_NO},
+	{0xB678, UNICODE_NORM_QC_NO},
+	{0xB679, UNICODE_NORM_QC_NO},
+	{0xB67A, UNICODE_NORM_QC_NO},
+	{0xB67B, UNICODE_NORM_QC_NO},
+	{0xB67C, UNICODE_NORM_QC_NO},
+	{0xB67D, UNICODE_NORM_QC_NO},
+	{0xB67E, UNICODE_NORM_QC_NO},
+	{0xB67F, UNICODE_NORM_QC_NO},
+	{0xB680, UNICODE_NORM_QC_NO},
+	{0xB681, UNICODE_NORM_QC_NO},
+	{0xB682, UNICODE_NORM_QC_NO},
+	{0xB683, UNICODE_NORM_QC_NO},
+	{0xB684, UNICODE_NORM_QC_NO},
+	{0xB685, UNICODE_NORM_QC_NO},
+	{0xB686, UNICODE_NORM_QC_NO},
+	{0xB687, UNICODE_NORM_QC_NO},
+	{0xB688, UNICODE_NORM_QC_NO},
+	{0xB689, UNICODE_NORM_QC_NO},
+	{0xB68A, UNICODE_NORM_QC_NO},
+	{0xB68B, UNICODE_NORM_QC_NO},
+	{0xB68C, UNICODE_NORM_QC_NO},
+	{0xB68D, UNICODE_NORM_QC_NO},
+	{0xB68E, UNICODE_NORM_QC_NO},
+	{0xB68F, UNICODE_NORM_QC_NO},
+	{0xB690, UNICODE_NORM_QC_NO},
+	{0xB691, UNICODE_NORM_QC_NO},
+	{0xB692, UNICODE_NORM_QC_NO},
+	{0xB693, UNICODE_NORM_QC_NO},
+	{0xB694, UNICODE_NORM_QC_NO},
+	{0xB695, UNICODE_NORM_QC_NO},
+	{0xB696, UNICODE_NORM_QC_NO},
+	{0xB697, UNICODE_NORM_QC_NO},
+	{0xB698, UNICODE_NORM_QC_NO},
+	{0xB699, UNICODE_NORM_QC_NO},
+	{0xB69A, UNICODE_NORM_QC_NO},
+	{0xB69B, UNICODE_NORM_QC_NO},
+	{0xB69C, UNICODE_NORM_QC_NO},
+	{0xB69D, UNICODE_NORM_QC_NO},
+	{0xB69E, UNICODE_NORM_QC_NO},
+	{0xB69F, UNICODE_NORM_QC_NO},
+	{0xB6A0, UNICODE_NORM_QC_NO},
+	{0xB6A1, UNICODE_NORM_QC_NO},
+	{0xB6A2, UNICODE_NORM_QC_NO},
+	{0xB6A3, UNICODE_NORM_QC_NO},
+	{0xB6A4, UNICODE_NORM_QC_NO},
+	{0xB6A5, UNICODE_NORM_QC_NO},
+	{0xB6A6, UNICODE_NORM_QC_NO},
+	{0xB6A7, UNICODE_NORM_QC_NO},
+	{0xB6A8, UNICODE_NORM_QC_NO},
+	{0xB6A9, UNICODE_NORM_QC_NO},
+	{0xB6AA, UNICODE_NORM_QC_NO},
+	{0xB6AB, UNICODE_NORM_QC_NO},
+	{0xB6AC, UNICODE_NORM_QC_NO},
+	{0xB6AD, UNICODE_NORM_QC_NO},
+	{0xB6AE, UNICODE_NORM_QC_NO},
+	{0xB6AF, UNICODE_NORM_QC_NO},
+	{0xB6B0, UNICODE_NORM_QC_NO},
+	{0xB6B1, UNICODE_NORM_QC_NO},
+	{0xB6B2, UNICODE_NORM_QC_NO},
+	{0xB6B3, UNICODE_NORM_QC_NO},
+	{0xB6B4, UNICODE_NORM_QC_NO},
+	{0xB6B5, UNICODE_NORM_QC_NO},
+	{0xB6B6, UNICODE_NORM_QC_NO},
+	{0xB6B7, UNICODE_NORM_QC_NO},
+	{0xB6B8, UNICODE_NORM_QC_NO},
+	{0xB6B9, UNICODE_NORM_QC_NO},
+	{0xB6BA, UNICODE_NORM_QC_NO},
+	{0xB6BB, UNICODE_NORM_QC_NO},
+	{0xB6BC, UNICODE_NORM_QC_NO},
+	{0xB6BD, UNICODE_NORM_QC_NO},
+	{0xB6BE, UNICODE_NORM_QC_NO},
+	{0xB6BF, UNICODE_NORM_QC_NO},
+	{0xB6C0, UNICODE_NORM_QC_NO},
+	{0xB6C1, UNICODE_NORM_QC_NO},
+	{0xB6C2, UNICODE_NORM_QC_NO},
+	{0xB6C3, UNICODE_NORM_QC_NO},
+	{0xB6C4, UNICODE_NORM_QC_NO},
+	{0xB6C5, UNICODE_NORM_QC_NO},
+	{0xB6C6, UNICODE_NORM_QC_NO},
+	{0xB6C7, UNICODE_NORM_QC_NO},
+	{0xB6C8, UNICODE_NORM_QC_NO},
+	{0xB6C9, UNICODE_NORM_QC_NO},
+	{0xB6CA, UNICODE_NORM_QC_NO},
+	{0xB6CB, UNICODE_NORM_QC_NO},
+	{0xB6CC, UNICODE_NORM_QC_NO},
+	{0xB6CD, UNICODE_NORM_QC_NO},
+	{0xB6CE, UNICODE_NORM_QC_NO},
+	{0xB6CF, UNICODE_NORM_QC_NO},
+	{0xB6D0, UNICODE_NORM_QC_NO},
+	{0xB6D1, UNICODE_NORM_QC_NO},
+	{0xB6D2, UNICODE_NORM_QC_NO},
+	{0xB6D3, UNICODE_NORM_QC_NO},
+	{0xB6D4, UNICODE_NORM_QC_NO},
+	{0xB6D5, UNICODE_NORM_QC_NO},
+	{0xB6D6, UNICODE_NORM_QC_NO},
+	{0xB6D7, UNICODE_NORM_QC_NO},
+	{0xB6D8, UNICODE_NORM_QC_NO},
+	{0xB6D9, UNICODE_NORM_QC_NO},
+	{0xB6DA, UNICODE_NORM_QC_NO},
+	{0xB6DB, UNICODE_NORM_QC_NO},
+	{0xB6DC, UNICODE_NORM_QC_NO},
+	{0xB6DD, UNICODE_NORM_QC_NO},
+	{0xB6DE, UNICODE_NORM_QC_NO},
+	{0xB6DF, UNICODE_NORM_QC_NO},
+	{0xB6E0, UNICODE_NORM_QC_NO},
+	{0xB6E1, UNICODE_NORM_QC_NO},
+	{0xB6E2, UNICODE_NORM_QC_NO},
+	{0xB6E3, UNICODE_NORM_QC_NO},
+	{0xB6E4, UNICODE_NORM_QC_NO},
+	{0xB6E5, UNICODE_NORM_QC_NO},
+	{0xB6E6, UNICODE_NORM_QC_NO},
+	{0xB6E7, UNICODE_NORM_QC_NO},
+	{0xB6E8, UNICODE_NORM_QC_NO},
+	{0xB6E9, UNICODE_NORM_QC_NO},
+	{0xB6EA, UNICODE_NORM_QC_NO},
+	{0xB6EB, UNICODE_NORM_QC_NO},
+	{0xB6EC, UNICODE_NORM_QC_NO},
+	{0xB6ED, UNICODE_NORM_QC_NO},
+	{0xB6EE, UNICODE_NORM_QC_NO},
+	{0xB6EF, UNICODE_NORM_QC_NO},
+	{0xB6F0, UNICODE_NORM_QC_NO},
+	{0xB6F1, UNICODE_NORM_QC_NO},
+	{0xB6F2, UNICODE_NORM_QC_NO},
+	{0xB6F3, UNICODE_NORM_QC_NO},
+	{0xB6F4, UNICODE_NORM_QC_NO},
+	{0xB6F5, UNICODE_NORM_QC_NO},
+	{0xB6F6, UNICODE_NORM_QC_NO},
+	{0xB6F7, UNICODE_NORM_QC_NO},
+	{0xB6F8, UNICODE_NORM_QC_NO},
+	{0xB6F9, UNICODE_NORM_QC_NO},
+	{0xB6FA, UNICODE_NORM_QC_NO},
+	{0xB6FB, UNICODE_NORM_QC_NO},
+	{0xB6FC, UNICODE_NORM_QC_NO},
+	{0xB6FD, UNICODE_NORM_QC_NO},
+	{0xB6FE, UNICODE_NORM_QC_NO},
+	{0xB6FF, UNICODE_NORM_QC_NO},
+	{0xB700, UNICODE_NORM_QC_NO},
+	{0xB701, UNICODE_NORM_QC_NO},
+	{0xB702, UNICODE_NORM_QC_NO},
+	{0xB703, UNICODE_NORM_QC_NO},
+	{0xB704, UNICODE_NORM_QC_NO},
+	{0xB705, UNICODE_NORM_QC_NO},
+	{0xB706, UNICODE_NORM_QC_NO},
+	{0xB707, UNICODE_NORM_QC_NO},
+	{0xB708, UNICODE_NORM_QC_NO},
+	{0xB709, UNICODE_NORM_QC_NO},
+	{0xB70A, UNICODE_NORM_QC_NO},
+	{0xB70B, UNICODE_NORM_QC_NO},
+	{0xB70C, UNICODE_NORM_QC_NO},
+	{0xB70D, UNICODE_NORM_QC_NO},
+	{0xB70E, UNICODE_NORM_QC_NO},
+	{0xB70F, UNICODE_NORM_QC_NO},
+	{0xB710, UNICODE_NORM_QC_NO},
+	{0xB711, UNICODE_NORM_QC_NO},
+	{0xB712, UNICODE_NORM_QC_NO},
+	{0xB713, UNICODE_NORM_QC_NO},
+	{0xB714, UNICODE_NORM_QC_NO},
+	{0xB715, UNICODE_NORM_QC_NO},
+	{0xB716, UNICODE_NORM_QC_NO},
+	{0xB717, UNICODE_NORM_QC_NO},
+	{0xB718, UNICODE_NORM_QC_NO},
+	{0xB719, UNICODE_NORM_QC_NO},
+	{0xB71A, UNICODE_NORM_QC_NO},
+	{0xB71B, UNICODE_NORM_QC_NO},
+	{0xB71C, UNICODE_NORM_QC_NO},
+	{0xB71D, UNICODE_NORM_QC_NO},
+	{0xB71E, UNICODE_NORM_QC_NO},
+	{0xB71F, UNICODE_NORM_QC_NO},
+	{0xB720, UNICODE_NORM_QC_NO},
+	{0xB721, UNICODE_NORM_QC_NO},
+	{0xB722, UNICODE_NORM_QC_NO},
+	{0xB723, UNICODE_NORM_QC_NO},
+	{0xB724, UNICODE_NORM_QC_NO},
+	{0xB725, UNICODE_NORM_QC_NO},
+	{0xB726, UNICODE_NORM_QC_NO},
+	{0xB727, UNICODE_NORM_QC_NO},
+	{0xB728, UNICODE_NORM_QC_NO},
+	{0xB729, UNICODE_NORM_QC_NO},
+	{0xB72A, UNICODE_NORM_QC_NO},
+	{0xB72B, UNICODE_NORM_QC_NO},
+	{0xB72C, UNICODE_NORM_QC_NO},
+	{0xB72D, UNICODE_NORM_QC_NO},
+	{0xB72E, UNICODE_NORM_QC_NO},
+	{0xB72F, UNICODE_NORM_QC_NO},
+	{0xB730, UNICODE_NORM_QC_NO},
+	{0xB731, UNICODE_NORM_QC_NO},
+	{0xB732, UNICODE_NORM_QC_NO},
+	{0xB733, UNICODE_NORM_QC_NO},
+	{0xB734, UNICODE_NORM_QC_NO},
+	{0xB735, UNICODE_NORM_QC_NO},
+	{0xB736, UNICODE_NORM_QC_NO},
+	{0xB737, UNICODE_NORM_QC_NO},
+	{0xB738, UNICODE_NORM_QC_NO},
+	{0xB739, UNICODE_NORM_QC_NO},
+	{0xB73A, UNICODE_NORM_QC_NO},
+	{0xB73B, UNICODE_NORM_QC_NO},
+	{0xB73C, UNICODE_NORM_QC_NO},
+	{0xB73D, UNICODE_NORM_QC_NO},
+	{0xB73E, UNICODE_NORM_QC_NO},
+	{0xB73F, UNICODE_NORM_QC_NO},
+	{0xB740, UNICODE_NORM_QC_NO},
+	{0xB741, UNICODE_NORM_QC_NO},
+	{0xB742, UNICODE_NORM_QC_NO},
+	{0xB743, UNICODE_NORM_QC_NO},
+	{0xB744, UNICODE_NORM_QC_NO},
+	{0xB745, UNICODE_NORM_QC_NO},
+	{0xB746, UNICODE_NORM_QC_NO},
+	{0xB747, UNICODE_NORM_QC_NO},
+	{0xB748, UNICODE_NORM_QC_NO},
+	{0xB749, UNICODE_NORM_QC_NO},
+	{0xB74A, UNICODE_NORM_QC_NO},
+	{0xB74B, UNICODE_NORM_QC_NO},
+	{0xB74C, UNICODE_NORM_QC_NO},
+	{0xB74D, UNICODE_NORM_QC_NO},
+	{0xB74E, UNICODE_NORM_QC_NO},
+	{0xB74F, UNICODE_NORM_QC_NO},
+	{0xB750, UNICODE_NORM_QC_NO},
+	{0xB751, UNICODE_NORM_QC_NO},
+	{0xB752, UNICODE_NORM_QC_NO},
+	{0xB753, UNICODE_NORM_QC_NO},
+	{0xB754, UNICODE_NORM_QC_NO},
+	{0xB755, UNICODE_NORM_QC_NO},
+	{0xB756, UNICODE_NORM_QC_NO},
+	{0xB757, UNICODE_NORM_QC_NO},
+	{0xB758, UNICODE_NORM_QC_NO},
+	{0xB759, UNICODE_NORM_QC_NO},
+	{0xB75A, UNICODE_NORM_QC_NO},
+	{0xB75B, UNICODE_NORM_QC_NO},
+	{0xB75C, UNICODE_NORM_QC_NO},
+	{0xB75D, UNICODE_NORM_QC_NO},
+	{0xB75E, UNICODE_NORM_QC_NO},
+	{0xB75F, UNICODE_NORM_QC_NO},
+	{0xB760, UNICODE_NORM_QC_NO},
+	{0xB761, UNICODE_NORM_QC_NO},
+	{0xB762, UNICODE_NORM_QC_NO},
+	{0xB763, UNICODE_NORM_QC_NO},
+	{0xB764, UNICODE_NORM_QC_NO},
+	{0xB765, UNICODE_NORM_QC_NO},
+	{0xB766, UNICODE_NORM_QC_NO},
+	{0xB767, UNICODE_NORM_QC_NO},
+	{0xB768, UNICODE_NORM_QC_NO},
+	{0xB769, UNICODE_NORM_QC_NO},
+	{0xB76A, UNICODE_NORM_QC_NO},
+	{0xB76B, UNICODE_NORM_QC_NO},
+	{0xB76C, UNICODE_NORM_QC_NO},
+	{0xB76D, UNICODE_NORM_QC_NO},
+	{0xB76E, UNICODE_NORM_QC_NO},
+	{0xB76F, UNICODE_NORM_QC_NO},
+	{0xB770, UNICODE_NORM_QC_NO},
+	{0xB771, UNICODE_NORM_QC_NO},
+	{0xB772, UNICODE_NORM_QC_NO},
+	{0xB773, UNICODE_NORM_QC_NO},
+	{0xB774, UNICODE_NORM_QC_NO},
+	{0xB775, UNICODE_NORM_QC_NO},
+	{0xB776, UNICODE_NORM_QC_NO},
+	{0xB777, UNICODE_NORM_QC_NO},
+	{0xB778, UNICODE_NORM_QC_NO},
+	{0xB779, UNICODE_NORM_QC_NO},
+	{0xB77A, UNICODE_NORM_QC_NO},
+	{0xB77B, UNICODE_NORM_QC_NO},
+	{0xB77C, UNICODE_NORM_QC_NO},
+	{0xB77D, UNICODE_NORM_QC_NO},
+	{0xB77E, UNICODE_NORM_QC_NO},
+	{0xB77F, UNICODE_NORM_QC_NO},
+	{0xB780, UNICODE_NORM_QC_NO},
+	{0xB781, UNICODE_NORM_QC_NO},
+	{0xB782, UNICODE_NORM_QC_NO},
+	{0xB783, UNICODE_NORM_QC_NO},
+	{0xB784, UNICODE_NORM_QC_NO},
+	{0xB785, UNICODE_NORM_QC_NO},
+	{0xB786, UNICODE_NORM_QC_NO},
+	{0xB787, UNICODE_NORM_QC_NO},
+	{0xB788, UNICODE_NORM_QC_NO},
+	{0xB789, UNICODE_NORM_QC_NO},
+	{0xB78A, UNICODE_NORM_QC_NO},
+	{0xB78B, UNICODE_NORM_QC_NO},
+	{0xB78C, UNICODE_NORM_QC_NO},
+	{0xB78D, UNICODE_NORM_QC_NO},
+	{0xB78E, UNICODE_NORM_QC_NO},
+	{0xB78F, UNICODE_NORM_QC_NO},
+	{0xB790, UNICODE_NORM_QC_NO},
+	{0xB791, UNICODE_NORM_QC_NO},
+	{0xB792, UNICODE_NORM_QC_NO},
+	{0xB793, UNICODE_NORM_QC_NO},
+	{0xB794, UNICODE_NORM_QC_NO},
+	{0xB795, UNICODE_NORM_QC_NO},
+	{0xB796, UNICODE_NORM_QC_NO},
+	{0xB797, UNICODE_NORM_QC_NO},
+	{0xB798, UNICODE_NORM_QC_NO},
+	{0xB799, UNICODE_NORM_QC_NO},
+	{0xB79A, UNICODE_NORM_QC_NO},
+	{0xB79B, UNICODE_NORM_QC_NO},
+	{0xB79C, UNICODE_NORM_QC_NO},
+	{0xB79D, UNICODE_NORM_QC_NO},
+	{0xB79E, UNICODE_NORM_QC_NO},
+	{0xB79F, UNICODE_NORM_QC_NO},
+	{0xB7A0, UNICODE_NORM_QC_NO},
+	{0xB7A1, UNICODE_NORM_QC_NO},
+	{0xB7A2, UNICODE_NORM_QC_NO},
+	{0xB7A3, UNICODE_NORM_QC_NO},
+	{0xB7A4, UNICODE_NORM_QC_NO},
+	{0xB7A5, UNICODE_NORM_QC_NO},
+	{0xB7A6, UNICODE_NORM_QC_NO},
+	{0xB7A7, UNICODE_NORM_QC_NO},
+	{0xB7A8, UNICODE_NORM_QC_NO},
+	{0xB7A9, UNICODE_NORM_QC_NO},
+	{0xB7AA, UNICODE_NORM_QC_NO},
+	{0xB7AB, UNICODE_NORM_QC_NO},
+	{0xB7AC, UNICODE_NORM_QC_NO},
+	{0xB7AD, UNICODE_NORM_QC_NO},
+	{0xB7AE, UNICODE_NORM_QC_NO},
+	{0xB7AF, UNICODE_NORM_QC_NO},
+	{0xB7B0, UNICODE_NORM_QC_NO},
+	{0xB7B1, UNICODE_NORM_QC_NO},
+	{0xB7B2, UNICODE_NORM_QC_NO},
+	{0xB7B3, UNICODE_NORM_QC_NO},
+	{0xB7B4, UNICODE_NORM_QC_NO},
+	{0xB7B5, UNICODE_NORM_QC_NO},
+	{0xB7B6, UNICODE_NORM_QC_NO},
+	{0xB7B7, UNICODE_NORM_QC_NO},
+	{0xB7B8, UNICODE_NORM_QC_NO},
+	{0xB7B9, UNICODE_NORM_QC_NO},
+	{0xB7BA, UNICODE_NORM_QC_NO},
+	{0xB7BB, UNICODE_NORM_QC_NO},
+	{0xB7BC, UNICODE_NORM_QC_NO},
+	{0xB7BD, UNICODE_NORM_QC_NO},
+	{0xB7BE, UNICODE_NORM_QC_NO},
+	{0xB7BF, UNICODE_NORM_QC_NO},
+	{0xB7C0, UNICODE_NORM_QC_NO},
+	{0xB7C1, UNICODE_NORM_QC_NO},
+	{0xB7C2, UNICODE_NORM_QC_NO},
+	{0xB7C3, UNICODE_NORM_QC_NO},
+	{0xB7C4, UNICODE_NORM_QC_NO},
+	{0xB7C5, UNICODE_NORM_QC_NO},
+	{0xB7C6, UNICODE_NORM_QC_NO},
+	{0xB7C7, UNICODE_NORM_QC_NO},
+	{0xB7C8, UNICODE_NORM_QC_NO},
+	{0xB7C9, UNICODE_NORM_QC_NO},
+	{0xB7CA, UNICODE_NORM_QC_NO},
+	{0xB7CB, UNICODE_NORM_QC_NO},
+	{0xB7CC, UNICODE_NORM_QC_NO},
+	{0xB7CD, UNICODE_NORM_QC_NO},
+	{0xB7CE, UNICODE_NORM_QC_NO},
+	{0xB7CF, UNICODE_NORM_QC_NO},
+	{0xB7D0, UNICODE_NORM_QC_NO},
+	{0xB7D1, UNICODE_NORM_QC_NO},
+	{0xB7D2, UNICODE_NORM_QC_NO},
+	{0xB7D3, UNICODE_NORM_QC_NO},
+	{0xB7D4, UNICODE_NORM_QC_NO},
+	{0xB7D5, UNICODE_NORM_QC_NO},
+	{0xB7D6, UNICODE_NORM_QC_NO},
+	{0xB7D7, UNICODE_NORM_QC_NO},
+	{0xB7D8, UNICODE_NORM_QC_NO},
+	{0xB7D9, UNICODE_NORM_QC_NO},
+	{0xB7DA, UNICODE_NORM_QC_NO},
+	{0xB7DB, UNICODE_NORM_QC_NO},
+	{0xB7DC, UNICODE_NORM_QC_NO},
+	{0xB7DD, UNICODE_NORM_QC_NO},
+	{0xB7DE, UNICODE_NORM_QC_NO},
+	{0xB7DF, UNICODE_NORM_QC_NO},
+	{0xB7E0, UNICODE_NORM_QC_NO},
+	{0xB7E1, UNICODE_NORM_QC_NO},
+	{0xB7E2, UNICODE_NORM_QC_NO},
+	{0xB7E3, UNICODE_NORM_QC_NO},
+	{0xB7E4, UNICODE_NORM_QC_NO},
+	{0xB7E5, UNICODE_NORM_QC_NO},
+	{0xB7E6, UNICODE_NORM_QC_NO},
+	{0xB7E7, UNICODE_NORM_QC_NO},
+	{0xB7E8, UNICODE_NORM_QC_NO},
+	{0xB7E9, UNICODE_NORM_QC_NO},
+	{0xB7EA, UNICODE_NORM_QC_NO},
+	{0xB7EB, UNICODE_NORM_QC_NO},
+	{0xB7EC, UNICODE_NORM_QC_NO},
+	{0xB7ED, UNICODE_NORM_QC_NO},
+	{0xB7EE, UNICODE_NORM_QC_NO},
+	{0xB7EF, UNICODE_NORM_QC_NO},
+	{0xB7F0, UNICODE_NORM_QC_NO},
+	{0xB7F1, UNICODE_NORM_QC_NO},
+	{0xB7F2, UNICODE_NORM_QC_NO},
+	{0xB7F3, UNICODE_NORM_QC_NO},
+	{0xB7F4, UNICODE_NORM_QC_NO},
+	{0xB7F5, UNICODE_NORM_QC_NO},
+	{0xB7F6, UNICODE_NORM_QC_NO},
+	{0xB7F7, UNICODE_NORM_QC_NO},
+	{0xB7F8, UNICODE_NORM_QC_NO},
+	{0xB7F9, UNICODE_NORM_QC_NO},
+	{0xB7FA, UNICODE_NORM_QC_NO},
+	{0xB7FB, UNICODE_NORM_QC_NO},
+	{0xB7FC, UNICODE_NORM_QC_NO},
+	{0xB7FD, UNICODE_NORM_QC_NO},
+	{0xB7FE, UNICODE_NORM_QC_NO},
+	{0xB7FF, UNICODE_NORM_QC_NO},
+	{0xB800, UNICODE_NORM_QC_NO},
+	{0xB801, UNICODE_NORM_QC_NO},
+	{0xB802, UNICODE_NORM_QC_NO},
+	{0xB803, UNICODE_NORM_QC_NO},
+	{0xB804, UNICODE_NORM_QC_NO},
+	{0xB805, UNICODE_NORM_QC_NO},
+	{0xB806, UNICODE_NORM_QC_NO},
+	{0xB807, UNICODE_NORM_QC_NO},
+	{0xB808, UNICODE_NORM_QC_NO},
+	{0xB809, UNICODE_NORM_QC_NO},
+	{0xB80A, UNICODE_NORM_QC_NO},
+	{0xB80B, UNICODE_NORM_QC_NO},
+	{0xB80C, UNICODE_NORM_QC_NO},
+	{0xB80D, UNICODE_NORM_QC_NO},
+	{0xB80E, UNICODE_NORM_QC_NO},
+	{0xB80F, UNICODE_NORM_QC_NO},
+	{0xB810, UNICODE_NORM_QC_NO},
+	{0xB811, UNICODE_NORM_QC_NO},
+	{0xB812, UNICODE_NORM_QC_NO},
+	{0xB813, UNICODE_NORM_QC_NO},
+	{0xB814, UNICODE_NORM_QC_NO},
+	{0xB815, UNICODE_NORM_QC_NO},
+	{0xB816, UNICODE_NORM_QC_NO},
+	{0xB817, UNICODE_NORM_QC_NO},
+	{0xB818, UNICODE_NORM_QC_NO},
+	{0xB819, UNICODE_NORM_QC_NO},
+	{0xB81A, UNICODE_NORM_QC_NO},
+	{0xB81B, UNICODE_NORM_QC_NO},
+	{0xB81C, UNICODE_NORM_QC_NO},
+	{0xB81D, UNICODE_NORM_QC_NO},
+	{0xB81E, UNICODE_NORM_QC_NO},
+	{0xB81F, UNICODE_NORM_QC_NO},
+	{0xB820, UNICODE_NORM_QC_NO},
+	{0xB821, UNICODE_NORM_QC_NO},
+	{0xB822, UNICODE_NORM_QC_NO},
+	{0xB823, UNICODE_NORM_QC_NO},
+	{0xB824, UNICODE_NORM_QC_NO},
+	{0xB825, UNICODE_NORM_QC_NO},
+	{0xB826, UNICODE_NORM_QC_NO},
+	{0xB827, UNICODE_NORM_QC_NO},
+	{0xB828, UNICODE_NORM_QC_NO},
+	{0xB829, UNICODE_NORM_QC_NO},
+	{0xB82A, UNICODE_NORM_QC_NO},
+	{0xB82B, UNICODE_NORM_QC_NO},
+	{0xB82C, UNICODE_NORM_QC_NO},
+	{0xB82D, UNICODE_NORM_QC_NO},
+	{0xB82E, UNICODE_NORM_QC_NO},
+	{0xB82F, UNICODE_NORM_QC_NO},
+	{0xB830, UNICODE_NORM_QC_NO},
+	{0xB831, UNICODE_NORM_QC_NO},
+	{0xB832, UNICODE_NORM_QC_NO},
+	{0xB833, UNICODE_NORM_QC_NO},
+	{0xB834, UNICODE_NORM_QC_NO},
+	{0xB835, UNICODE_NORM_QC_NO},
+	{0xB836, UNICODE_NORM_QC_NO},
+	{0xB837, UNICODE_NORM_QC_NO},
+	{0xB838, UNICODE_NORM_QC_NO},
+	{0xB839, UNICODE_NORM_QC_NO},
+	{0xB83A, UNICODE_NORM_QC_NO},
+	{0xB83B, UNICODE_NORM_QC_NO},
+	{0xB83C, UNICODE_NORM_QC_NO},
+	{0xB83D, UNICODE_NORM_QC_NO},
+	{0xB83E, UNICODE_NORM_QC_NO},
+	{0xB83F, UNICODE_NORM_QC_NO},
+	{0xB840, UNICODE_NORM_QC_NO},
+	{0xB841, UNICODE_NORM_QC_NO},
+	{0xB842, UNICODE_NORM_QC_NO},
+	{0xB843, UNICODE_NORM_QC_NO},
+	{0xB844, UNICODE_NORM_QC_NO},
+	{0xB845, UNICODE_NORM_QC_NO},
+	{0xB846, UNICODE_NORM_QC_NO},
+	{0xB847, UNICODE_NORM_QC_NO},
+	{0xB848, UNICODE_NORM_QC_NO},
+	{0xB849, UNICODE_NORM_QC_NO},
+	{0xB84A, UNICODE_NORM_QC_NO},
+	{0xB84B, UNICODE_NORM_QC_NO},
+	{0xB84C, UNICODE_NORM_QC_NO},
+	{0xB84D, UNICODE_NORM_QC_NO},
+	{0xB84E, UNICODE_NORM_QC_NO},
+	{0xB84F, UNICODE_NORM_QC_NO},
+	{0xB850, UNICODE_NORM_QC_NO},
+	{0xB851, UNICODE_NORM_QC_NO},
+	{0xB852, UNICODE_NORM_QC_NO},
+	{0xB853, UNICODE_NORM_QC_NO},
+	{0xB854, UNICODE_NORM_QC_NO},
+	{0xB855, UNICODE_NORM_QC_NO},
+	{0xB856, UNICODE_NORM_QC_NO},
+	{0xB857, UNICODE_NORM_QC_NO},
+	{0xB858, UNICODE_NORM_QC_NO},
+	{0xB859, UNICODE_NORM_QC_NO},
+	{0xB85A, UNICODE_NORM_QC_NO},
+	{0xB85B, UNICODE_NORM_QC_NO},
+	{0xB85C, UNICODE_NORM_QC_NO},
+	{0xB85D, UNICODE_NORM_QC_NO},
+	{0xB85E, UNICODE_NORM_QC_NO},
+	{0xB85F, UNICODE_NORM_QC_NO},
+	{0xB860, UNICODE_NORM_QC_NO},
+	{0xB861, UNICODE_NORM_QC_NO},
+	{0xB862, UNICODE_NORM_QC_NO},
+	{0xB863, UNICODE_NORM_QC_NO},
+	{0xB864, UNICODE_NORM_QC_NO},
+	{0xB865, UNICODE_NORM_QC_NO},
+	{0xB866, UNICODE_NORM_QC_NO},
+	{0xB867, UNICODE_NORM_QC_NO},
+	{0xB868, UNICODE_NORM_QC_NO},
+	{0xB869, UNICODE_NORM_QC_NO},
+	{0xB86A, UNICODE_NORM_QC_NO},
+	{0xB86B, UNICODE_NORM_QC_NO},
+	{0xB86C, UNICODE_NORM_QC_NO},
+	{0xB86D, UNICODE_NORM_QC_NO},
+	{0xB86E, UNICODE_NORM_QC_NO},
+	{0xB86F, UNICODE_NORM_QC_NO},
+	{0xB870, UNICODE_NORM_QC_NO},
+	{0xB871, UNICODE_NORM_QC_NO},
+	{0xB872, UNICODE_NORM_QC_NO},
+	{0xB873, UNICODE_NORM_QC_NO},
+	{0xB874, UNICODE_NORM_QC_NO},
+	{0xB875, UNICODE_NORM_QC_NO},
+	{0xB876, UNICODE_NORM_QC_NO},
+	{0xB877, UNICODE_NORM_QC_NO},
+	{0xB878, UNICODE_NORM_QC_NO},
+	{0xB879, UNICODE_NORM_QC_NO},
+	{0xB87A, UNICODE_NORM_QC_NO},
+	{0xB87B, UNICODE_NORM_QC_NO},
+	{0xB87C, UNICODE_NORM_QC_NO},
+	{0xB87D, UNICODE_NORM_QC_NO},
+	{0xB87E, UNICODE_NORM_QC_NO},
+	{0xB87F, UNICODE_NORM_QC_NO},
+	{0xB880, UNICODE_NORM_QC_NO},
+	{0xB881, UNICODE_NORM_QC_NO},
+	{0xB882, UNICODE_NORM_QC_NO},
+	{0xB883, UNICODE_NORM_QC_NO},
+	{0xB884, UNICODE_NORM_QC_NO},
+	{0xB885, UNICODE_NORM_QC_NO},
+	{0xB886, UNICODE_NORM_QC_NO},
+	{0xB887, UNICODE_NORM_QC_NO},
+	{0xB888, UNICODE_NORM_QC_NO},
+	{0xB889, UNICODE_NORM_QC_NO},
+	{0xB88A, UNICODE_NORM_QC_NO},
+	{0xB88B, UNICODE_NORM_QC_NO},
+	{0xB88C, UNICODE_NORM_QC_NO},
+	{0xB88D, UNICODE_NORM_QC_NO},
+	{0xB88E, UNICODE_NORM_QC_NO},
+	{0xB88F, UNICODE_NORM_QC_NO},
+	{0xB890, UNICODE_NORM_QC_NO},
+	{0xB891, UNICODE_NORM_QC_NO},
+	{0xB892, UNICODE_NORM_QC_NO},
+	{0xB893, UNICODE_NORM_QC_NO},
+	{0xB894, UNICODE_NORM_QC_NO},
+	{0xB895, UNICODE_NORM_QC_NO},
+	{0xB896, UNICODE_NORM_QC_NO},
+	{0xB897, UNICODE_NORM_QC_NO},
+	{0xB898, UNICODE_NORM_QC_NO},
+	{0xB899, UNICODE_NORM_QC_NO},
+	{0xB89A, UNICODE_NORM_QC_NO},
+	{0xB89B, UNICODE_NORM_QC_NO},
+	{0xB89C, UNICODE_NORM_QC_NO},
+	{0xB89D, UNICODE_NORM_QC_NO},
+	{0xB89E, UNICODE_NORM_QC_NO},
+	{0xB89F, UNICODE_NORM_QC_NO},
+	{0xB8A0, UNICODE_NORM_QC_NO},
+	{0xB8A1, UNICODE_NORM_QC_NO},
+	{0xB8A2, UNICODE_NORM_QC_NO},
+	{0xB8A3, UNICODE_NORM_QC_NO},
+	{0xB8A4, UNICODE_NORM_QC_NO},
+	{0xB8A5, UNICODE_NORM_QC_NO},
+	{0xB8A6, UNICODE_NORM_QC_NO},
+	{0xB8A7, UNICODE_NORM_QC_NO},
+	{0xB8A8, UNICODE_NORM_QC_NO},
+	{0xB8A9, UNICODE_NORM_QC_NO},
+	{0xB8AA, UNICODE_NORM_QC_NO},
+	{0xB8AB, UNICODE_NORM_QC_NO},
+	{0xB8AC, UNICODE_NORM_QC_NO},
+	{0xB8AD, UNICODE_NORM_QC_NO},
+	{0xB8AE, UNICODE_NORM_QC_NO},
+	{0xB8AF, UNICODE_NORM_QC_NO},
+	{0xB8B0, UNICODE_NORM_QC_NO},
+	{0xB8B1, UNICODE_NORM_QC_NO},
+	{0xB8B2, UNICODE_NORM_QC_NO},
+	{0xB8B3, UNICODE_NORM_QC_NO},
+	{0xB8B4, UNICODE_NORM_QC_NO},
+	{0xB8B5, UNICODE_NORM_QC_NO},
+	{0xB8B6, UNICODE_NORM_QC_NO},
+	{0xB8B7, UNICODE_NORM_QC_NO},
+	{0xB8B8, UNICODE_NORM_QC_NO},
+	{0xB8B9, UNICODE_NORM_QC_NO},
+	{0xB8BA, UNICODE_NORM_QC_NO},
+	{0xB8BB, UNICODE_NORM_QC_NO},
+	{0xB8BC, UNICODE_NORM_QC_NO},
+	{0xB8BD, UNICODE_NORM_QC_NO},
+	{0xB8BE, UNICODE_NORM_QC_NO},
+	{0xB8BF, UNICODE_NORM_QC_NO},
+	{0xB8C0, UNICODE_NORM_QC_NO},
+	{0xB8C1, UNICODE_NORM_QC_NO},
+	{0xB8C2, UNICODE_NORM_QC_NO},
+	{0xB8C3, UNICODE_NORM_QC_NO},
+	{0xB8C4, UNICODE_NORM_QC_NO},
+	{0xB8C5, UNICODE_NORM_QC_NO},
+	{0xB8C6, UNICODE_NORM_QC_NO},
+	{0xB8C7, UNICODE_NORM_QC_NO},
+	{0xB8C8, UNICODE_NORM_QC_NO},
+	{0xB8C9, UNICODE_NORM_QC_NO},
+	{0xB8CA, UNICODE_NORM_QC_NO},
+	{0xB8CB, UNICODE_NORM_QC_NO},
+	{0xB8CC, UNICODE_NORM_QC_NO},
+	{0xB8CD, UNICODE_NORM_QC_NO},
+	{0xB8CE, UNICODE_NORM_QC_NO},
+	{0xB8CF, UNICODE_NORM_QC_NO},
+	{0xB8D0, UNICODE_NORM_QC_NO},
+	{0xB8D1, UNICODE_NORM_QC_NO},
+	{0xB8D2, UNICODE_NORM_QC_NO},
+	{0xB8D3, UNICODE_NORM_QC_NO},
+	{0xB8D4, UNICODE_NORM_QC_NO},
+	{0xB8D5, UNICODE_NORM_QC_NO},
+	{0xB8D6, UNICODE_NORM_QC_NO},
+	{0xB8D7, UNICODE_NORM_QC_NO},
+	{0xB8D8, UNICODE_NORM_QC_NO},
+	{0xB8D9, UNICODE_NORM_QC_NO},
+	{0xB8DA, UNICODE_NORM_QC_NO},
+	{0xB8DB, UNICODE_NORM_QC_NO},
+	{0xB8DC, UNICODE_NORM_QC_NO},
+	{0xB8DD, UNICODE_NORM_QC_NO},
+	{0xB8DE, UNICODE_NORM_QC_NO},
+	{0xB8DF, UNICODE_NORM_QC_NO},
+	{0xB8E0, UNICODE_NORM_QC_NO},
+	{0xB8E1, UNICODE_NORM_QC_NO},
+	{0xB8E2, UNICODE_NORM_QC_NO},
+	{0xB8E3, UNICODE_NORM_QC_NO},
+	{0xB8E4, UNICODE_NORM_QC_NO},
+	{0xB8E5, UNICODE_NORM_QC_NO},
+	{0xB8E6, UNICODE_NORM_QC_NO},
+	{0xB8E7, UNICODE_NORM_QC_NO},
+	{0xB8E8, UNICODE_NORM_QC_NO},
+	{0xB8E9, UNICODE_NORM_QC_NO},
+	{0xB8EA, UNICODE_NORM_QC_NO},
+	{0xB8EB, UNICODE_NORM_QC_NO},
+	{0xB8EC, UNICODE_NORM_QC_NO},
+	{0xB8ED, UNICODE_NORM_QC_NO},
+	{0xB8EE, UNICODE_NORM_QC_NO},
+	{0xB8EF, UNICODE_NORM_QC_NO},
+	{0xB8F0, UNICODE_NORM_QC_NO},
+	{0xB8F1, UNICODE_NORM_QC_NO},
+	{0xB8F2, UNICODE_NORM_QC_NO},
+	{0xB8F3, UNICODE_NORM_QC_NO},
+	{0xB8F4, UNICODE_NORM_QC_NO},
+	{0xB8F5, UNICODE_NORM_QC_NO},
+	{0xB8F6, UNICODE_NORM_QC_NO},
+	{0xB8F7, UNICODE_NORM_QC_NO},
+	{0xB8F8, UNICODE_NORM_QC_NO},
+	{0xB8F9, UNICODE_NORM_QC_NO},
+	{0xB8FA, UNICODE_NORM_QC_NO},
+	{0xB8FB, UNICODE_NORM_QC_NO},
+	{0xB8FC, UNICODE_NORM_QC_NO},
+	{0xB8FD, UNICODE_NORM_QC_NO},
+	{0xB8FE, UNICODE_NORM_QC_NO},
+	{0xB8FF, UNICODE_NORM_QC_NO},
+	{0xB900, UNICODE_NORM_QC_NO},
+	{0xB901, UNICODE_NORM_QC_NO},
+	{0xB902, UNICODE_NORM_QC_NO},
+	{0xB903, UNICODE_NORM_QC_NO},
+	{0xB904, UNICODE_NORM_QC_NO},
+	{0xB905, UNICODE_NORM_QC_NO},
+	{0xB906, UNICODE_NORM_QC_NO},
+	{0xB907, UNICODE_NORM_QC_NO},
+	{0xB908, UNICODE_NORM_QC_NO},
+	{0xB909, UNICODE_NORM_QC_NO},
+	{0xB90A, UNICODE_NORM_QC_NO},
+	{0xB90B, UNICODE_NORM_QC_NO},
+	{0xB90C, UNICODE_NORM_QC_NO},
+	{0xB90D, UNICODE_NORM_QC_NO},
+	{0xB90E, UNICODE_NORM_QC_NO},
+	{0xB90F, UNICODE_NORM_QC_NO},
+	{0xB910, UNICODE_NORM_QC_NO},
+	{0xB911, UNICODE_NORM_QC_NO},
+	{0xB912, UNICODE_NORM_QC_NO},
+	{0xB913, UNICODE_NORM_QC_NO},
+	{0xB914, UNICODE_NORM_QC_NO},
+	{0xB915, UNICODE_NORM_QC_NO},
+	{0xB916, UNICODE_NORM_QC_NO},
+	{0xB917, UNICODE_NORM_QC_NO},
+	{0xB918, UNICODE_NORM_QC_NO},
+	{0xB919, UNICODE_NORM_QC_NO},
+	{0xB91A, UNICODE_NORM_QC_NO},
+	{0xB91B, UNICODE_NORM_QC_NO},
+	{0xB91C, UNICODE_NORM_QC_NO},
+	{0xB91D, UNICODE_NORM_QC_NO},
+	{0xB91E, UNICODE_NORM_QC_NO},
+	{0xB91F, UNICODE_NORM_QC_NO},
+	{0xB920, UNICODE_NORM_QC_NO},
+	{0xB921, UNICODE_NORM_QC_NO},
+	{0xB922, UNICODE_NORM_QC_NO},
+	{0xB923, UNICODE_NORM_QC_NO},
+	{0xB924, UNICODE_NORM_QC_NO},
+	{0xB925, UNICODE_NORM_QC_NO},
+	{0xB926, UNICODE_NORM_QC_NO},
+	{0xB927, UNICODE_NORM_QC_NO},
+	{0xB928, UNICODE_NORM_QC_NO},
+	{0xB929, UNICODE_NORM_QC_NO},
+	{0xB92A, UNICODE_NORM_QC_NO},
+	{0xB92B, UNICODE_NORM_QC_NO},
+	{0xB92C, UNICODE_NORM_QC_NO},
+	{0xB92D, UNICODE_NORM_QC_NO},
+	{0xB92E, UNICODE_NORM_QC_NO},
+	{0xB92F, UNICODE_NORM_QC_NO},
+	{0xB930, UNICODE_NORM_QC_NO},
+	{0xB931, UNICODE_NORM_QC_NO},
+	{0xB932, UNICODE_NORM_QC_NO},
+	{0xB933, UNICODE_NORM_QC_NO},
+	{0xB934, UNICODE_NORM_QC_NO},
+	{0xB935, UNICODE_NORM_QC_NO},
+	{0xB936, UNICODE_NORM_QC_NO},
+	{0xB937, UNICODE_NORM_QC_NO},
+	{0xB938, UNICODE_NORM_QC_NO},
+	{0xB939, UNICODE_NORM_QC_NO},
+	{0xB93A, UNICODE_NORM_QC_NO},
+	{0xB93B, UNICODE_NORM_QC_NO},
+	{0xB93C, UNICODE_NORM_QC_NO},
+	{0xB93D, UNICODE_NORM_QC_NO},
+	{0xB93E, UNICODE_NORM_QC_NO},
+	{0xB93F, UNICODE_NORM_QC_NO},
+	{0xB940, UNICODE_NORM_QC_NO},
+	{0xB941, UNICODE_NORM_QC_NO},
+	{0xB942, UNICODE_NORM_QC_NO},
+	{0xB943, UNICODE_NORM_QC_NO},
+	{0xB944, UNICODE_NORM_QC_NO},
+	{0xB945, UNICODE_NORM_QC_NO},
+	{0xB946, UNICODE_NORM_QC_NO},
+	{0xB947, UNICODE_NORM_QC_NO},
+	{0xB948, UNICODE_NORM_QC_NO},
+	{0xB949, UNICODE_NORM_QC_NO},
+	{0xB94A, UNICODE_NORM_QC_NO},
+	{0xB94B, UNICODE_NORM_QC_NO},
+	{0xB94C, UNICODE_NORM_QC_NO},
+	{0xB94D, UNICODE_NORM_QC_NO},
+	{0xB94E, UNICODE_NORM_QC_NO},
+	{0xB94F, UNICODE_NORM_QC_NO},
+	{0xB950, UNICODE_NORM_QC_NO},
+	{0xB951, UNICODE_NORM_QC_NO},
+	{0xB952, UNICODE_NORM_QC_NO},
+	{0xB953, UNICODE_NORM_QC_NO},
+	{0xB954, UNICODE_NORM_QC_NO},
+	{0xB955, UNICODE_NORM_QC_NO},
+	{0xB956, UNICODE_NORM_QC_NO},
+	{0xB957, UNICODE_NORM_QC_NO},
+	{0xB958, UNICODE_NORM_QC_NO},
+	{0xB959, UNICODE_NORM_QC_NO},
+	{0xB95A, UNICODE_NORM_QC_NO},
+	{0xB95B, UNICODE_NORM_QC_NO},
+	{0xB95C, UNICODE_NORM_QC_NO},
+	{0xB95D, UNICODE_NORM_QC_NO},
+	{0xB95E, UNICODE_NORM_QC_NO},
+	{0xB95F, UNICODE_NORM_QC_NO},
+	{0xB960, UNICODE_NORM_QC_NO},
+	{0xB961, UNICODE_NORM_QC_NO},
+	{0xB962, UNICODE_NORM_QC_NO},
+	{0xB963, UNICODE_NORM_QC_NO},
+	{0xB964, UNICODE_NORM_QC_NO},
+	{0xB965, UNICODE_NORM_QC_NO},
+	{0xB966, UNICODE_NORM_QC_NO},
+	{0xB967, UNICODE_NORM_QC_NO},
+	{0xB968, UNICODE_NORM_QC_NO},
+	{0xB969, UNICODE_NORM_QC_NO},
+	{0xB96A, UNICODE_NORM_QC_NO},
+	{0xB96B, UNICODE_NORM_QC_NO},
+	{0xB96C, UNICODE_NORM_QC_NO},
+	{0xB96D, UNICODE_NORM_QC_NO},
+	{0xB96E, UNICODE_NORM_QC_NO},
+	{0xB96F, UNICODE_NORM_QC_NO},
+	{0xB970, UNICODE_NORM_QC_NO},
+	{0xB971, UNICODE_NORM_QC_NO},
+	{0xB972, UNICODE_NORM_QC_NO},
+	{0xB973, UNICODE_NORM_QC_NO},
+	{0xB974, UNICODE_NORM_QC_NO},
+	{0xB975, UNICODE_NORM_QC_NO},
+	{0xB976, UNICODE_NORM_QC_NO},
+	{0xB977, UNICODE_NORM_QC_NO},
+	{0xB978, UNICODE_NORM_QC_NO},
+	{0xB979, UNICODE_NORM_QC_NO},
+	{0xB97A, UNICODE_NORM_QC_NO},
+	{0xB97B, UNICODE_NORM_QC_NO},
+	{0xB97C, UNICODE_NORM_QC_NO},
+	{0xB97D, UNICODE_NORM_QC_NO},
+	{0xB97E, UNICODE_NORM_QC_NO},
+	{0xB97F, UNICODE_NORM_QC_NO},
+	{0xB980, UNICODE_NORM_QC_NO},
+	{0xB981, UNICODE_NORM_QC_NO},
+	{0xB982, UNICODE_NORM_QC_NO},
+	{0xB983, UNICODE_NORM_QC_NO},
+	{0xB984, UNICODE_NORM_QC_NO},
+	{0xB985, UNICODE_NORM_QC_NO},
+	{0xB986, UNICODE_NORM_QC_NO},
+	{0xB987, UNICODE_NORM_QC_NO},
+	{0xB988, UNICODE_NORM_QC_NO},
+	{0xB989, UNICODE_NORM_QC_NO},
+	{0xB98A, UNICODE_NORM_QC_NO},
+	{0xB98B, UNICODE_NORM_QC_NO},
+	{0xB98C, UNICODE_NORM_QC_NO},
+	{0xB98D, UNICODE_NORM_QC_NO},
+	{0xB98E, UNICODE_NORM_QC_NO},
+	{0xB98F, UNICODE_NORM_QC_NO},
+	{0xB990, UNICODE_NORM_QC_NO},
+	{0xB991, UNICODE_NORM_QC_NO},
+	{0xB992, UNICODE_NORM_QC_NO},
+	{0xB993, UNICODE_NORM_QC_NO},
+	{0xB994, UNICODE_NORM_QC_NO},
+	{0xB995, UNICODE_NORM_QC_NO},
+	{0xB996, UNICODE_NORM_QC_NO},
+	{0xB997, UNICODE_NORM_QC_NO},
+	{0xB998, UNICODE_NORM_QC_NO},
+	{0xB999, UNICODE_NORM_QC_NO},
+	{0xB99A, UNICODE_NORM_QC_NO},
+	{0xB99B, UNICODE_NORM_QC_NO},
+	{0xB99C, UNICODE_NORM_QC_NO},
+	{0xB99D, UNICODE_NORM_QC_NO},
+	{0xB99E, UNICODE_NORM_QC_NO},
+	{0xB99F, UNICODE_NORM_QC_NO},
+	{0xB9A0, UNICODE_NORM_QC_NO},
+	{0xB9A1, UNICODE_NORM_QC_NO},
+	{0xB9A2, UNICODE_NORM_QC_NO},
+	{0xB9A3, UNICODE_NORM_QC_NO},
+	{0xB9A4, UNICODE_NORM_QC_NO},
+	{0xB9A5, UNICODE_NORM_QC_NO},
+	{0xB9A6, UNICODE_NORM_QC_NO},
+	{0xB9A7, UNICODE_NORM_QC_NO},
+	{0xB9A8, UNICODE_NORM_QC_NO},
+	{0xB9A9, UNICODE_NORM_QC_NO},
+	{0xB9AA, UNICODE_NORM_QC_NO},
+	{0xB9AB, UNICODE_NORM_QC_NO},
+	{0xB9AC, UNICODE_NORM_QC_NO},
+	{0xB9AD, UNICODE_NORM_QC_NO},
+	{0xB9AE, UNICODE_NORM_QC_NO},
+	{0xB9AF, UNICODE_NORM_QC_NO},
+	{0xB9B0, UNICODE_NORM_QC_NO},
+	{0xB9B1, UNICODE_NORM_QC_NO},
+	{0xB9B2, UNICODE_NORM_QC_NO},
+	{0xB9B3, UNICODE_NORM_QC_NO},
+	{0xB9B4, UNICODE_NORM_QC_NO},
+	{0xB9B5, UNICODE_NORM_QC_NO},
+	{0xB9B6, UNICODE_NORM_QC_NO},
+	{0xB9B7, UNICODE_NORM_QC_NO},
+	{0xB9B8, UNICODE_NORM_QC_NO},
+	{0xB9B9, UNICODE_NORM_QC_NO},
+	{0xB9BA, UNICODE_NORM_QC_NO},
+	{0xB9BB, UNICODE_NORM_QC_NO},
+	{0xB9BC, UNICODE_NORM_QC_NO},
+	{0xB9BD, UNICODE_NORM_QC_NO},
+	{0xB9BE, UNICODE_NORM_QC_NO},
+	{0xB9BF, UNICODE_NORM_QC_NO},
+	{0xB9C0, UNICODE_NORM_QC_NO},
+	{0xB9C1, UNICODE_NORM_QC_NO},
+	{0xB9C2, UNICODE_NORM_QC_NO},
+	{0xB9C3, UNICODE_NORM_QC_NO},
+	{0xB9C4, UNICODE_NORM_QC_NO},
+	{0xB9C5, UNICODE_NORM_QC_NO},
+	{0xB9C6, UNICODE_NORM_QC_NO},
+	{0xB9C7, UNICODE_NORM_QC_NO},
+	{0xB9C8, UNICODE_NORM_QC_NO},
+	{0xB9C9, UNICODE_NORM_QC_NO},
+	{0xB9CA, UNICODE_NORM_QC_NO},
+	{0xB9CB, UNICODE_NORM_QC_NO},
+	{0xB9CC, UNICODE_NORM_QC_NO},
+	{0xB9CD, UNICODE_NORM_QC_NO},
+	{0xB9CE, UNICODE_NORM_QC_NO},
+	{0xB9CF, UNICODE_NORM_QC_NO},
+	{0xB9D0, UNICODE_NORM_QC_NO},
+	{0xB9D1, UNICODE_NORM_QC_NO},
+	{0xB9D2, UNICODE_NORM_QC_NO},
+	{0xB9D3, UNICODE_NORM_QC_NO},
+	{0xB9D4, UNICODE_NORM_QC_NO},
+	{0xB9D5, UNICODE_NORM_QC_NO},
+	{0xB9D6, UNICODE_NORM_QC_NO},
+	{0xB9D7, UNICODE_NORM_QC_NO},
+	{0xB9D8, UNICODE_NORM_QC_NO},
+	{0xB9D9, UNICODE_NORM_QC_NO},
+	{0xB9DA, UNICODE_NORM_QC_NO},
+	{0xB9DB, UNICODE_NORM_QC_NO},
+	{0xB9DC, UNICODE_NORM_QC_NO},
+	{0xB9DD, UNICODE_NORM_QC_NO},
+	{0xB9DE, UNICODE_NORM_QC_NO},
+	{0xB9DF, UNICODE_NORM_QC_NO},
+	{0xB9E0, UNICODE_NORM_QC_NO},
+	{0xB9E1, UNICODE_NORM_QC_NO},
+	{0xB9E2, UNICODE_NORM_QC_NO},
+	{0xB9E3, UNICODE_NORM_QC_NO},
+	{0xB9E4, UNICODE_NORM_QC_NO},
+	{0xB9E5, UNICODE_NORM_QC_NO},
+	{0xB9E6, UNICODE_NORM_QC_NO},
+	{0xB9E7, UNICODE_NORM_QC_NO},
+	{0xB9E8, UNICODE_NORM_QC_NO},
+	{0xB9E9, UNICODE_NORM_QC_NO},
+	{0xB9EA, UNICODE_NORM_QC_NO},
+	{0xB9EB, UNICODE_NORM_QC_NO},
+	{0xB9EC, UNICODE_NORM_QC_NO},
+	{0xB9ED, UNICODE_NORM_QC_NO},
+	{0xB9EE, UNICODE_NORM_QC_NO},
+	{0xB9EF, UNICODE_NORM_QC_NO},
+	{0xB9F0, UNICODE_NORM_QC_NO},
+	{0xB9F1, UNICODE_NORM_QC_NO},
+	{0xB9F2, UNICODE_NORM_QC_NO},
+	{0xB9F3, UNICODE_NORM_QC_NO},
+	{0xB9F4, UNICODE_NORM_QC_NO},
+	{0xB9F5, UNICODE_NORM_QC_NO},
+	{0xB9F6, UNICODE_NORM_QC_NO},
+	{0xB9F7, UNICODE_NORM_QC_NO},
+	{0xB9F8, UNICODE_NORM_QC_NO},
+	{0xB9F9, UNICODE_NORM_QC_NO},
+	{0xB9FA, UNICODE_NORM_QC_NO},
+	{0xB9FB, UNICODE_NORM_QC_NO},
+	{0xB9FC, UNICODE_NORM_QC_NO},
+	{0xB9FD, UNICODE_NORM_QC_NO},
+	{0xB9FE, UNICODE_NORM_QC_NO},
+	{0xB9FF, UNICODE_NORM_QC_NO},
+	{0xBA00, UNICODE_NORM_QC_NO},
+	{0xBA01, UNICODE_NORM_QC_NO},
+	{0xBA02, UNICODE_NORM_QC_NO},
+	{0xBA03, UNICODE_NORM_QC_NO},
+	{0xBA04, UNICODE_NORM_QC_NO},
+	{0xBA05, UNICODE_NORM_QC_NO},
+	{0xBA06, UNICODE_NORM_QC_NO},
+	{0xBA07, UNICODE_NORM_QC_NO},
+	{0xBA08, UNICODE_NORM_QC_NO},
+	{0xBA09, UNICODE_NORM_QC_NO},
+	{0xBA0A, UNICODE_NORM_QC_NO},
+	{0xBA0B, UNICODE_NORM_QC_NO},
+	{0xBA0C, UNICODE_NORM_QC_NO},
+	{0xBA0D, UNICODE_NORM_QC_NO},
+	{0xBA0E, UNICODE_NORM_QC_NO},
+	{0xBA0F, UNICODE_NORM_QC_NO},
+	{0xBA10, UNICODE_NORM_QC_NO},
+	{0xBA11, UNICODE_NORM_QC_NO},
+	{0xBA12, UNICODE_NORM_QC_NO},
+	{0xBA13, UNICODE_NORM_QC_NO},
+	{0xBA14, UNICODE_NORM_QC_NO},
+	{0xBA15, UNICODE_NORM_QC_NO},
+	{0xBA16, UNICODE_NORM_QC_NO},
+	{0xBA17, UNICODE_NORM_QC_NO},
+	{0xBA18, UNICODE_NORM_QC_NO},
+	{0xBA19, UNICODE_NORM_QC_NO},
+	{0xBA1A, UNICODE_NORM_QC_NO},
+	{0xBA1B, UNICODE_NORM_QC_NO},
+	{0xBA1C, UNICODE_NORM_QC_NO},
+	{0xBA1D, UNICODE_NORM_QC_NO},
+	{0xBA1E, UNICODE_NORM_QC_NO},
+	{0xBA1F, UNICODE_NORM_QC_NO},
+	{0xBA20, UNICODE_NORM_QC_NO},
+	{0xBA21, UNICODE_NORM_QC_NO},
+	{0xBA22, UNICODE_NORM_QC_NO},
+	{0xBA23, UNICODE_NORM_QC_NO},
+	{0xBA24, UNICODE_NORM_QC_NO},
+	{0xBA25, UNICODE_NORM_QC_NO},
+	{0xBA26, UNICODE_NORM_QC_NO},
+	{0xBA27, UNICODE_NORM_QC_NO},
+	{0xBA28, UNICODE_NORM_QC_NO},
+	{0xBA29, UNICODE_NORM_QC_NO},
+	{0xBA2A, UNICODE_NORM_QC_NO},
+	{0xBA2B, UNICODE_NORM_QC_NO},
+	{0xBA2C, UNICODE_NORM_QC_NO},
+	{0xBA2D, UNICODE_NORM_QC_NO},
+	{0xBA2E, UNICODE_NORM_QC_NO},
+	{0xBA2F, UNICODE_NORM_QC_NO},
+	{0xBA30, UNICODE_NORM_QC_NO},
+	{0xBA31, UNICODE_NORM_QC_NO},
+	{0xBA32, UNICODE_NORM_QC_NO},
+	{0xBA33, UNICODE_NORM_QC_NO},
+	{0xBA34, UNICODE_NORM_QC_NO},
+	{0xBA35, UNICODE_NORM_QC_NO},
+	{0xBA36, UNICODE_NORM_QC_NO},
+	{0xBA37, UNICODE_NORM_QC_NO},
+	{0xBA38, UNICODE_NORM_QC_NO},
+	{0xBA39, UNICODE_NORM_QC_NO},
+	{0xBA3A, UNICODE_NORM_QC_NO},
+	{0xBA3B, UNICODE_NORM_QC_NO},
+	{0xBA3C, UNICODE_NORM_QC_NO},
+	{0xBA3D, UNICODE_NORM_QC_NO},
+	{0xBA3E, UNICODE_NORM_QC_NO},
+	{0xBA3F, UNICODE_NORM_QC_NO},
+	{0xBA40, UNICODE_NORM_QC_NO},
+	{0xBA41, UNICODE_NORM_QC_NO},
+	{0xBA42, UNICODE_NORM_QC_NO},
+	{0xBA43, UNICODE_NORM_QC_NO},
+	{0xBA44, UNICODE_NORM_QC_NO},
+	{0xBA45, UNICODE_NORM_QC_NO},
+	{0xBA46, UNICODE_NORM_QC_NO},
+	{0xBA47, UNICODE_NORM_QC_NO},
+	{0xBA48, UNICODE_NORM_QC_NO},
+	{0xBA49, UNICODE_NORM_QC_NO},
+	{0xBA4A, UNICODE_NORM_QC_NO},
+	{0xBA4B, UNICODE_NORM_QC_NO},
+	{0xBA4C, UNICODE_NORM_QC_NO},
+	{0xBA4D, UNICODE_NORM_QC_NO},
+	{0xBA4E, UNICODE_NORM_QC_NO},
+	{0xBA4F, UNICODE_NORM_QC_NO},
+	{0xBA50, UNICODE_NORM_QC_NO},
+	{0xBA51, UNICODE_NORM_QC_NO},
+	{0xBA52, UNICODE_NORM_QC_NO},
+	{0xBA53, UNICODE_NORM_QC_NO},
+	{0xBA54, UNICODE_NORM_QC_NO},
+	{0xBA55, UNICODE_NORM_QC_NO},
+	{0xBA56, UNICODE_NORM_QC_NO},
+	{0xBA57, UNICODE_NORM_QC_NO},
+	{0xBA58, UNICODE_NORM_QC_NO},
+	{0xBA59, UNICODE_NORM_QC_NO},
+	{0xBA5A, UNICODE_NORM_QC_NO},
+	{0xBA5B, UNICODE_NORM_QC_NO},
+	{0xBA5C, UNICODE_NORM_QC_NO},
+	{0xBA5D, UNICODE_NORM_QC_NO},
+	{0xBA5E, UNICODE_NORM_QC_NO},
+	{0xBA5F, UNICODE_NORM_QC_NO},
+	{0xBA60, UNICODE_NORM_QC_NO},
+	{0xBA61, UNICODE_NORM_QC_NO},
+	{0xBA62, UNICODE_NORM_QC_NO},
+	{0xBA63, UNICODE_NORM_QC_NO},
+	{0xBA64, UNICODE_NORM_QC_NO},
+	{0xBA65, UNICODE_NORM_QC_NO},
+	{0xBA66, UNICODE_NORM_QC_NO},
+	{0xBA67, UNICODE_NORM_QC_NO},
+	{0xBA68, UNICODE_NORM_QC_NO},
+	{0xBA69, UNICODE_NORM_QC_NO},
+	{0xBA6A, UNICODE_NORM_QC_NO},
+	{0xBA6B, UNICODE_NORM_QC_NO},
+	{0xBA6C, UNICODE_NORM_QC_NO},
+	{0xBA6D, UNICODE_NORM_QC_NO},
+	{0xBA6E, UNICODE_NORM_QC_NO},
+	{0xBA6F, UNICODE_NORM_QC_NO},
+	{0xBA70, UNICODE_NORM_QC_NO},
+	{0xBA71, UNICODE_NORM_QC_NO},
+	{0xBA72, UNICODE_NORM_QC_NO},
+	{0xBA73, UNICODE_NORM_QC_NO},
+	{0xBA74, UNICODE_NORM_QC_NO},
+	{0xBA75, UNICODE_NORM_QC_NO},
+	{0xBA76, UNICODE_NORM_QC_NO},
+	{0xBA77, UNICODE_NORM_QC_NO},
+	{0xBA78, UNICODE_NORM_QC_NO},
+	{0xBA79, UNICODE_NORM_QC_NO},
+	{0xBA7A, UNICODE_NORM_QC_NO},
+	{0xBA7B, UNICODE_NORM_QC_NO},
+	{0xBA7C, UNICODE_NORM_QC_NO},
+	{0xBA7D, UNICODE_NORM_QC_NO},
+	{0xBA7E, UNICODE_NORM_QC_NO},
+	{0xBA7F, UNICODE_NORM_QC_NO},
+	{0xBA80, UNICODE_NORM_QC_NO},
+	{0xBA81, UNICODE_NORM_QC_NO},
+	{0xBA82, UNICODE_NORM_QC_NO},
+	{0xBA83, UNICODE_NORM_QC_NO},
+	{0xBA84, UNICODE_NORM_QC_NO},
+	{0xBA85, UNICODE_NORM_QC_NO},
+	{0xBA86, UNICODE_NORM_QC_NO},
+	{0xBA87, UNICODE_NORM_QC_NO},
+	{0xBA88, UNICODE_NORM_QC_NO},
+	{0xBA89, UNICODE_NORM_QC_NO},
+	{0xBA8A, UNICODE_NORM_QC_NO},
+	{0xBA8B, UNICODE_NORM_QC_NO},
+	{0xBA8C, UNICODE_NORM_QC_NO},
+	{0xBA8D, UNICODE_NORM_QC_NO},
+	{0xBA8E, UNICODE_NORM_QC_NO},
+	{0xBA8F, UNICODE_NORM_QC_NO},
+	{0xBA90, UNICODE_NORM_QC_NO},
+	{0xBA91, UNICODE_NORM_QC_NO},
+	{0xBA92, UNICODE_NORM_QC_NO},
+	{0xBA93, UNICODE_NORM_QC_NO},
+	{0xBA94, UNICODE_NORM_QC_NO},
+	{0xBA95, UNICODE_NORM_QC_NO},
+	{0xBA96, UNICODE_NORM_QC_NO},
+	{0xBA97, UNICODE_NORM_QC_NO},
+	{0xBA98, UNICODE_NORM_QC_NO},
+	{0xBA99, UNICODE_NORM_QC_NO},
+	{0xBA9A, UNICODE_NORM_QC_NO},
+	{0xBA9B, UNICODE_NORM_QC_NO},
+	{0xBA9C, UNICODE_NORM_QC_NO},
+	{0xBA9D, UNICODE_NORM_QC_NO},
+	{0xBA9E, UNICODE_NORM_QC_NO},
+	{0xBA9F, UNICODE_NORM_QC_NO},
+	{0xBAA0, UNICODE_NORM_QC_NO},
+	{0xBAA1, UNICODE_NORM_QC_NO},
+	{0xBAA2, UNICODE_NORM_QC_NO},
+	{0xBAA3, UNICODE_NORM_QC_NO},
+	{0xBAA4, UNICODE_NORM_QC_NO},
+	{0xBAA5, UNICODE_NORM_QC_NO},
+	{0xBAA6, UNICODE_NORM_QC_NO},
+	{0xBAA7, UNICODE_NORM_QC_NO},
+	{0xBAA8, UNICODE_NORM_QC_NO},
+	{0xBAA9, UNICODE_NORM_QC_NO},
+	{0xBAAA, UNICODE_NORM_QC_NO},
+	{0xBAAB, UNICODE_NORM_QC_NO},
+	{0xBAAC, UNICODE_NORM_QC_NO},
+	{0xBAAD, UNICODE_NORM_QC_NO},
+	{0xBAAE, UNICODE_NORM_QC_NO},
+	{0xBAAF, UNICODE_NORM_QC_NO},
+	{0xBAB0, UNICODE_NORM_QC_NO},
+	{0xBAB1, UNICODE_NORM_QC_NO},
+	{0xBAB2, UNICODE_NORM_QC_NO},
+	{0xBAB3, UNICODE_NORM_QC_NO},
+	{0xBAB4, UNICODE_NORM_QC_NO},
+	{0xBAB5, UNICODE_NORM_QC_NO},
+	{0xBAB6, UNICODE_NORM_QC_NO},
+	{0xBAB7, UNICODE_NORM_QC_NO},
+	{0xBAB8, UNICODE_NORM_QC_NO},
+	{0xBAB9, UNICODE_NORM_QC_NO},
+	{0xBABA, UNICODE_NORM_QC_NO},
+	{0xBABB, UNICODE_NORM_QC_NO},
+	{0xBABC, UNICODE_NORM_QC_NO},
+	{0xBABD, UNICODE_NORM_QC_NO},
+	{0xBABE, UNICODE_NORM_QC_NO},
+	{0xBABF, UNICODE_NORM_QC_NO},
+	{0xBAC0, UNICODE_NORM_QC_NO},
+	{0xBAC1, UNICODE_NORM_QC_NO},
+	{0xBAC2, UNICODE_NORM_QC_NO},
+	{0xBAC3, UNICODE_NORM_QC_NO},
+	{0xBAC4, UNICODE_NORM_QC_NO},
+	{0xBAC5, UNICODE_NORM_QC_NO},
+	{0xBAC6, UNICODE_NORM_QC_NO},
+	{0xBAC7, UNICODE_NORM_QC_NO},
+	{0xBAC8, UNICODE_NORM_QC_NO},
+	{0xBAC9, UNICODE_NORM_QC_NO},
+	{0xBACA, UNICODE_NORM_QC_NO},
+	{0xBACB, UNICODE_NORM_QC_NO},
+	{0xBACC, UNICODE_NORM_QC_NO},
+	{0xBACD, UNICODE_NORM_QC_NO},
+	{0xBACE, UNICODE_NORM_QC_NO},
+	{0xBACF, UNICODE_NORM_QC_NO},
+	{0xBAD0, UNICODE_NORM_QC_NO},
+	{0xBAD1, UNICODE_NORM_QC_NO},
+	{0xBAD2, UNICODE_NORM_QC_NO},
+	{0xBAD3, UNICODE_NORM_QC_NO},
+	{0xBAD4, UNICODE_NORM_QC_NO},
+	{0xBAD5, UNICODE_NORM_QC_NO},
+	{0xBAD6, UNICODE_NORM_QC_NO},
+	{0xBAD7, UNICODE_NORM_QC_NO},
+	{0xBAD8, UNICODE_NORM_QC_NO},
+	{0xBAD9, UNICODE_NORM_QC_NO},
+	{0xBADA, UNICODE_NORM_QC_NO},
+	{0xBADB, UNICODE_NORM_QC_NO},
+	{0xBADC, UNICODE_NORM_QC_NO},
+	{0xBADD, UNICODE_NORM_QC_NO},
+	{0xBADE, UNICODE_NORM_QC_NO},
+	{0xBADF, UNICODE_NORM_QC_NO},
+	{0xBAE0, UNICODE_NORM_QC_NO},
+	{0xBAE1, UNICODE_NORM_QC_NO},
+	{0xBAE2, UNICODE_NORM_QC_NO},
+	{0xBAE3, UNICODE_NORM_QC_NO},
+	{0xBAE4, UNICODE_NORM_QC_NO},
+	{0xBAE5, UNICODE_NORM_QC_NO},
+	{0xBAE6, UNICODE_NORM_QC_NO},
+	{0xBAE7, UNICODE_NORM_QC_NO},
+	{0xBAE8, UNICODE_NORM_QC_NO},
+	{0xBAE9, UNICODE_NORM_QC_NO},
+	{0xBAEA, UNICODE_NORM_QC_NO},
+	{0xBAEB, UNICODE_NORM_QC_NO},
+	{0xBAEC, UNICODE_NORM_QC_NO},
+	{0xBAED, UNICODE_NORM_QC_NO},
+	{0xBAEE, UNICODE_NORM_QC_NO},
+	{0xBAEF, UNICODE_NORM_QC_NO},
+	{0xBAF0, UNICODE_NORM_QC_NO},
+	{0xBAF1, UNICODE_NORM_QC_NO},
+	{0xBAF2, UNICODE_NORM_QC_NO},
+	{0xBAF3, UNICODE_NORM_QC_NO},
+	{0xBAF4, UNICODE_NORM_QC_NO},
+	{0xBAF5, UNICODE_NORM_QC_NO},
+	{0xBAF6, UNICODE_NORM_QC_NO},
+	{0xBAF7, UNICODE_NORM_QC_NO},
+	{0xBAF8, UNICODE_NORM_QC_NO},
+	{0xBAF9, UNICODE_NORM_QC_NO},
+	{0xBAFA, UNICODE_NORM_QC_NO},
+	{0xBAFB, UNICODE_NORM_QC_NO},
+	{0xBAFC, UNICODE_NORM_QC_NO},
+	{0xBAFD, UNICODE_NORM_QC_NO},
+	{0xBAFE, UNICODE_NORM_QC_NO},
+	{0xBAFF, UNICODE_NORM_QC_NO},
+	{0xBB00, UNICODE_NORM_QC_NO},
+	{0xBB01, UNICODE_NORM_QC_NO},
+	{0xBB02, UNICODE_NORM_QC_NO},
+	{0xBB03, UNICODE_NORM_QC_NO},
+	{0xBB04, UNICODE_NORM_QC_NO},
+	{0xBB05, UNICODE_NORM_QC_NO},
+	{0xBB06, UNICODE_NORM_QC_NO},
+	{0xBB07, UNICODE_NORM_QC_NO},
+	{0xBB08, UNICODE_NORM_QC_NO},
+	{0xBB09, UNICODE_NORM_QC_NO},
+	{0xBB0A, UNICODE_NORM_QC_NO},
+	{0xBB0B, UNICODE_NORM_QC_NO},
+	{0xBB0C, UNICODE_NORM_QC_NO},
+	{0xBB0D, UNICODE_NORM_QC_NO},
+	{0xBB0E, UNICODE_NORM_QC_NO},
+	{0xBB0F, UNICODE_NORM_QC_NO},
+	{0xBB10, UNICODE_NORM_QC_NO},
+	{0xBB11, UNICODE_NORM_QC_NO},
+	{0xBB12, UNICODE_NORM_QC_NO},
+	{0xBB13, UNICODE_NORM_QC_NO},
+	{0xBB14, UNICODE_NORM_QC_NO},
+	{0xBB15, UNICODE_NORM_QC_NO},
+	{0xBB16, UNICODE_NORM_QC_NO},
+	{0xBB17, UNICODE_NORM_QC_NO},
+	{0xBB18, UNICODE_NORM_QC_NO},
+	{0xBB19, UNICODE_NORM_QC_NO},
+	{0xBB1A, UNICODE_NORM_QC_NO},
+	{0xBB1B, UNICODE_NORM_QC_NO},
+	{0xBB1C, UNICODE_NORM_QC_NO},
+	{0xBB1D, UNICODE_NORM_QC_NO},
+	{0xBB1E, UNICODE_NORM_QC_NO},
+	{0xBB1F, UNICODE_NORM_QC_NO},
+	{0xBB20, UNICODE_NORM_QC_NO},
+	{0xBB21, UNICODE_NORM_QC_NO},
+	{0xBB22, UNICODE_NORM_QC_NO},
+	{0xBB23, UNICODE_NORM_QC_NO},
+	{0xBB24, UNICODE_NORM_QC_NO},
+	{0xBB25, UNICODE_NORM_QC_NO},
+	{0xBB26, UNICODE_NORM_QC_NO},
+	{0xBB27, UNICODE_NORM_QC_NO},
+	{0xBB28, UNICODE_NORM_QC_NO},
+	{0xBB29, UNICODE_NORM_QC_NO},
+	{0xBB2A, UNICODE_NORM_QC_NO},
+	{0xBB2B, UNICODE_NORM_QC_NO},
+	{0xBB2C, UNICODE_NORM_QC_NO},
+	{0xBB2D, UNICODE_NORM_QC_NO},
+	{0xBB2E, UNICODE_NORM_QC_NO},
+	{0xBB2F, UNICODE_NORM_QC_NO},
+	{0xBB30, UNICODE_NORM_QC_NO},
+	{0xBB31, UNICODE_NORM_QC_NO},
+	{0xBB32, UNICODE_NORM_QC_NO},
+	{0xBB33, UNICODE_NORM_QC_NO},
+	{0xBB34, UNICODE_NORM_QC_NO},
+	{0xBB35, UNICODE_NORM_QC_NO},
+	{0xBB36, UNICODE_NORM_QC_NO},
+	{0xBB37, UNICODE_NORM_QC_NO},
+	{0xBB38, UNICODE_NORM_QC_NO},
+	{0xBB39, UNICODE_NORM_QC_NO},
+	{0xBB3A, UNICODE_NORM_QC_NO},
+	{0xBB3B, UNICODE_NORM_QC_NO},
+	{0xBB3C, UNICODE_NORM_QC_NO},
+	{0xBB3D, UNICODE_NORM_QC_NO},
+	{0xBB3E, UNICODE_NORM_QC_NO},
+	{0xBB3F, UNICODE_NORM_QC_NO},
+	{0xBB40, UNICODE_NORM_QC_NO},
+	{0xBB41, UNICODE_NORM_QC_NO},
+	{0xBB42, UNICODE_NORM_QC_NO},
+	{0xBB43, UNICODE_NORM_QC_NO},
+	{0xBB44, UNICODE_NORM_QC_NO},
+	{0xBB45, UNICODE_NORM_QC_NO},
+	{0xBB46, UNICODE_NORM_QC_NO},
+	{0xBB47, UNICODE_NORM_QC_NO},
+	{0xBB48, UNICODE_NORM_QC_NO},
+	{0xBB49, UNICODE_NORM_QC_NO},
+	{0xBB4A, UNICODE_NORM_QC_NO},
+	{0xBB4B, UNICODE_NORM_QC_NO},
+	{0xBB4C, UNICODE_NORM_QC_NO},
+	{0xBB4D, UNICODE_NORM_QC_NO},
+	{0xBB4E, UNICODE_NORM_QC_NO},
+	{0xBB4F, UNICODE_NORM_QC_NO},
+	{0xBB50, UNICODE_NORM_QC_NO},
+	{0xBB51, UNICODE_NORM_QC_NO},
+	{0xBB52, UNICODE_NORM_QC_NO},
+	{0xBB53, UNICODE_NORM_QC_NO},
+	{0xBB54, UNICODE_NORM_QC_NO},
+	{0xBB55, UNICODE_NORM_QC_NO},
+	{0xBB56, UNICODE_NORM_QC_NO},
+	{0xBB57, UNICODE_NORM_QC_NO},
+	{0xBB58, UNICODE_NORM_QC_NO},
+	{0xBB59, UNICODE_NORM_QC_NO},
+	{0xBB5A, UNICODE_NORM_QC_NO},
+	{0xBB5B, UNICODE_NORM_QC_NO},
+	{0xBB5C, UNICODE_NORM_QC_NO},
+	{0xBB5D, UNICODE_NORM_QC_NO},
+	{0xBB5E, UNICODE_NORM_QC_NO},
+	{0xBB5F, UNICODE_NORM_QC_NO},
+	{0xBB60, UNICODE_NORM_QC_NO},
+	{0xBB61, UNICODE_NORM_QC_NO},
+	{0xBB62, UNICODE_NORM_QC_NO},
+	{0xBB63, UNICODE_NORM_QC_NO},
+	{0xBB64, UNICODE_NORM_QC_NO},
+	{0xBB65, UNICODE_NORM_QC_NO},
+	{0xBB66, UNICODE_NORM_QC_NO},
+	{0xBB67, UNICODE_NORM_QC_NO},
+	{0xBB68, UNICODE_NORM_QC_NO},
+	{0xBB69, UNICODE_NORM_QC_NO},
+	{0xBB6A, UNICODE_NORM_QC_NO},
+	{0xBB6B, UNICODE_NORM_QC_NO},
+	{0xBB6C, UNICODE_NORM_QC_NO},
+	{0xBB6D, UNICODE_NORM_QC_NO},
+	{0xBB6E, UNICODE_NORM_QC_NO},
+	{0xBB6F, UNICODE_NORM_QC_NO},
+	{0xBB70, UNICODE_NORM_QC_NO},
+	{0xBB71, UNICODE_NORM_QC_NO},
+	{0xBB72, UNICODE_NORM_QC_NO},
+	{0xBB73, UNICODE_NORM_QC_NO},
+	{0xBB74, UNICODE_NORM_QC_NO},
+	{0xBB75, UNICODE_NORM_QC_NO},
+	{0xBB76, UNICODE_NORM_QC_NO},
+	{0xBB77, UNICODE_NORM_QC_NO},
+	{0xBB78, UNICODE_NORM_QC_NO},
+	{0xBB79, UNICODE_NORM_QC_NO},
+	{0xBB7A, UNICODE_NORM_QC_NO},
+	{0xBB7B, UNICODE_NORM_QC_NO},
+	{0xBB7C, UNICODE_NORM_QC_NO},
+	{0xBB7D, UNICODE_NORM_QC_NO},
+	{0xBB7E, UNICODE_NORM_QC_NO},
+	{0xBB7F, UNICODE_NORM_QC_NO},
+	{0xBB80, UNICODE_NORM_QC_NO},
+	{0xBB81, UNICODE_NORM_QC_NO},
+	{0xBB82, UNICODE_NORM_QC_NO},
+	{0xBB83, UNICODE_NORM_QC_NO},
+	{0xBB84, UNICODE_NORM_QC_NO},
+	{0xBB85, UNICODE_NORM_QC_NO},
+	{0xBB86, UNICODE_NORM_QC_NO},
+	{0xBB87, UNICODE_NORM_QC_NO},
+	{0xBB88, UNICODE_NORM_QC_NO},
+	{0xBB89, UNICODE_NORM_QC_NO},
+	{0xBB8A, UNICODE_NORM_QC_NO},
+	{0xBB8B, UNICODE_NORM_QC_NO},
+	{0xBB8C, UNICODE_NORM_QC_NO},
+	{0xBB8D, UNICODE_NORM_QC_NO},
+	{0xBB8E, UNICODE_NORM_QC_NO},
+	{0xBB8F, UNICODE_NORM_QC_NO},
+	{0xBB90, UNICODE_NORM_QC_NO},
+	{0xBB91, UNICODE_NORM_QC_NO},
+	{0xBB92, UNICODE_NORM_QC_NO},
+	{0xBB93, UNICODE_NORM_QC_NO},
+	{0xBB94, UNICODE_NORM_QC_NO},
+	{0xBB95, UNICODE_NORM_QC_NO},
+	{0xBB96, UNICODE_NORM_QC_NO},
+	{0xBB97, UNICODE_NORM_QC_NO},
+	{0xBB98, UNICODE_NORM_QC_NO},
+	{0xBB99, UNICODE_NORM_QC_NO},
+	{0xBB9A, UNICODE_NORM_QC_NO},
+	{0xBB9B, UNICODE_NORM_QC_NO},
+	{0xBB9C, UNICODE_NORM_QC_NO},
+	{0xBB9D, UNICODE_NORM_QC_NO},
+	{0xBB9E, UNICODE_NORM_QC_NO},
+	{0xBB9F, UNICODE_NORM_QC_NO},
+	{0xBBA0, UNICODE_NORM_QC_NO},
+	{0xBBA1, UNICODE_NORM_QC_NO},
+	{0xBBA2, UNICODE_NORM_QC_NO},
+	{0xBBA3, UNICODE_NORM_QC_NO},
+	{0xBBA4, UNICODE_NORM_QC_NO},
+	{0xBBA5, UNICODE_NORM_QC_NO},
+	{0xBBA6, UNICODE_NORM_QC_NO},
+	{0xBBA7, UNICODE_NORM_QC_NO},
+	{0xBBA8, UNICODE_NORM_QC_NO},
+	{0xBBA9, UNICODE_NORM_QC_NO},
+	{0xBBAA, UNICODE_NORM_QC_NO},
+	{0xBBAB, UNICODE_NORM_QC_NO},
+	{0xBBAC, UNICODE_NORM_QC_NO},
+	{0xBBAD, UNICODE_NORM_QC_NO},
+	{0xBBAE, UNICODE_NORM_QC_NO},
+	{0xBBAF, UNICODE_NORM_QC_NO},
+	{0xBBB0, UNICODE_NORM_QC_NO},
+	{0xBBB1, UNICODE_NORM_QC_NO},
+	{0xBBB2, UNICODE_NORM_QC_NO},
+	{0xBBB3, UNICODE_NORM_QC_NO},
+	{0xBBB4, UNICODE_NORM_QC_NO},
+	{0xBBB5, UNICODE_NORM_QC_NO},
+	{0xBBB6, UNICODE_NORM_QC_NO},
+	{0xBBB7, UNICODE_NORM_QC_NO},
+	{0xBBB8, UNICODE_NORM_QC_NO},
+	{0xBBB9, UNICODE_NORM_QC_NO},
+	{0xBBBA, UNICODE_NORM_QC_NO},
+	{0xBBBB, UNICODE_NORM_QC_NO},
+	{0xBBBC, UNICODE_NORM_QC_NO},
+	{0xBBBD, UNICODE_NORM_QC_NO},
+	{0xBBBE, UNICODE_NORM_QC_NO},
+	{0xBBBF, UNICODE_NORM_QC_NO},
+	{0xBBC0, UNICODE_NORM_QC_NO},
+	{0xBBC1, UNICODE_NORM_QC_NO},
+	{0xBBC2, UNICODE_NORM_QC_NO},
+	{0xBBC3, UNICODE_NORM_QC_NO},
+	{0xBBC4, UNICODE_NORM_QC_NO},
+	{0xBBC5, UNICODE_NORM_QC_NO},
+	{0xBBC6, UNICODE_NORM_QC_NO},
+	{0xBBC7, UNICODE_NORM_QC_NO},
+	{0xBBC8, UNICODE_NORM_QC_NO},
+	{0xBBC9, UNICODE_NORM_QC_NO},
+	{0xBBCA, UNICODE_NORM_QC_NO},
+	{0xBBCB, UNICODE_NORM_QC_NO},
+	{0xBBCC, UNICODE_NORM_QC_NO},
+	{0xBBCD, UNICODE_NORM_QC_NO},
+	{0xBBCE, UNICODE_NORM_QC_NO},
+	{0xBBCF, UNICODE_NORM_QC_NO},
+	{0xBBD0, UNICODE_NORM_QC_NO},
+	{0xBBD1, UNICODE_NORM_QC_NO},
+	{0xBBD2, UNICODE_NORM_QC_NO},
+	{0xBBD3, UNICODE_NORM_QC_NO},
+	{0xBBD4, UNICODE_NORM_QC_NO},
+	{0xBBD5, UNICODE_NORM_QC_NO},
+	{0xBBD6, UNICODE_NORM_QC_NO},
+	{0xBBD7, UNICODE_NORM_QC_NO},
+	{0xBBD8, UNICODE_NORM_QC_NO},
+	{0xBBD9, UNICODE_NORM_QC_NO},
+	{0xBBDA, UNICODE_NORM_QC_NO},
+	{0xBBDB, UNICODE_NORM_QC_NO},
+	{0xBBDC, UNICODE_NORM_QC_NO},
+	{0xBBDD, UNICODE_NORM_QC_NO},
+	{0xBBDE, UNICODE_NORM_QC_NO},
+	{0xBBDF, UNICODE_NORM_QC_NO},
+	{0xBBE0, UNICODE_NORM_QC_NO},
+	{0xBBE1, UNICODE_NORM_QC_NO},
+	{0xBBE2, UNICODE_NORM_QC_NO},
+	{0xBBE3, UNICODE_NORM_QC_NO},
+	{0xBBE4, UNICODE_NORM_QC_NO},
+	{0xBBE5, UNICODE_NORM_QC_NO},
+	{0xBBE6, UNICODE_NORM_QC_NO},
+	{0xBBE7, UNICODE_NORM_QC_NO},
+	{0xBBE8, UNICODE_NORM_QC_NO},
+	{0xBBE9, UNICODE_NORM_QC_NO},
+	{0xBBEA, UNICODE_NORM_QC_NO},
+	{0xBBEB, UNICODE_NORM_QC_NO},
+	{0xBBEC, UNICODE_NORM_QC_NO},
+	{0xBBED, UNICODE_NORM_QC_NO},
+	{0xBBEE, UNICODE_NORM_QC_NO},
+	{0xBBEF, UNICODE_NORM_QC_NO},
+	{0xBBF0, UNICODE_NORM_QC_NO},
+	{0xBBF1, UNICODE_NORM_QC_NO},
+	{0xBBF2, UNICODE_NORM_QC_NO},
+	{0xBBF3, UNICODE_NORM_QC_NO},
+	{0xBBF4, UNICODE_NORM_QC_NO},
+	{0xBBF5, UNICODE_NORM_QC_NO},
+	{0xBBF6, UNICODE_NORM_QC_NO},
+	{0xBBF7, UNICODE_NORM_QC_NO},
+	{0xBBF8, UNICODE_NORM_QC_NO},
+	{0xBBF9, UNICODE_NORM_QC_NO},
+	{0xBBFA, UNICODE_NORM_QC_NO},
+	{0xBBFB, UNICODE_NORM_QC_NO},
+	{0xBBFC, UNICODE_NORM_QC_NO},
+	{0xBBFD, UNICODE_NORM_QC_NO},
+	{0xBBFE, UNICODE_NORM_QC_NO},
+	{0xBBFF, UNICODE_NORM_QC_NO},
+	{0xBC00, UNICODE_NORM_QC_NO},
+	{0xBC01, UNICODE_NORM_QC_NO},
+	{0xBC02, UNICODE_NORM_QC_NO},
+	{0xBC03, UNICODE_NORM_QC_NO},
+	{0xBC04, UNICODE_NORM_QC_NO},
+	{0xBC05, UNICODE_NORM_QC_NO},
+	{0xBC06, UNICODE_NORM_QC_NO},
+	{0xBC07, UNICODE_NORM_QC_NO},
+	{0xBC08, UNICODE_NORM_QC_NO},
+	{0xBC09, UNICODE_NORM_QC_NO},
+	{0xBC0A, UNICODE_NORM_QC_NO},
+	{0xBC0B, UNICODE_NORM_QC_NO},
+	{0xBC0C, UNICODE_NORM_QC_NO},
+	{0xBC0D, UNICODE_NORM_QC_NO},
+	{0xBC0E, UNICODE_NORM_QC_NO},
+	{0xBC0F, UNICODE_NORM_QC_NO},
+	{0xBC10, UNICODE_NORM_QC_NO},
+	{0xBC11, UNICODE_NORM_QC_NO},
+	{0xBC12, UNICODE_NORM_QC_NO},
+	{0xBC13, UNICODE_NORM_QC_NO},
+	{0xBC14, UNICODE_NORM_QC_NO},
+	{0xBC15, UNICODE_NORM_QC_NO},
+	{0xBC16, UNICODE_NORM_QC_NO},
+	{0xBC17, UNICODE_NORM_QC_NO},
+	{0xBC18, UNICODE_NORM_QC_NO},
+	{0xBC19, UNICODE_NORM_QC_NO},
+	{0xBC1A, UNICODE_NORM_QC_NO},
+	{0xBC1B, UNICODE_NORM_QC_NO},
+	{0xBC1C, UNICODE_NORM_QC_NO},
+	{0xBC1D, UNICODE_NORM_QC_NO},
+	{0xBC1E, UNICODE_NORM_QC_NO},
+	{0xBC1F, UNICODE_NORM_QC_NO},
+	{0xBC20, UNICODE_NORM_QC_NO},
+	{0xBC21, UNICODE_NORM_QC_NO},
+	{0xBC22, UNICODE_NORM_QC_NO},
+	{0xBC23, UNICODE_NORM_QC_NO},
+	{0xBC24, UNICODE_NORM_QC_NO},
+	{0xBC25, UNICODE_NORM_QC_NO},
+	{0xBC26, UNICODE_NORM_QC_NO},
+	{0xBC27, UNICODE_NORM_QC_NO},
+	{0xBC28, UNICODE_NORM_QC_NO},
+	{0xBC29, UNICODE_NORM_QC_NO},
+	{0xBC2A, UNICODE_NORM_QC_NO},
+	{0xBC2B, UNICODE_NORM_QC_NO},
+	{0xBC2C, UNICODE_NORM_QC_NO},
+	{0xBC2D, UNICODE_NORM_QC_NO},
+	{0xBC2E, UNICODE_NORM_QC_NO},
+	{0xBC2F, UNICODE_NORM_QC_NO},
+	{0xBC30, UNICODE_NORM_QC_NO},
+	{0xBC31, UNICODE_NORM_QC_NO},
+	{0xBC32, UNICODE_NORM_QC_NO},
+	{0xBC33, UNICODE_NORM_QC_NO},
+	{0xBC34, UNICODE_NORM_QC_NO},
+	{0xBC35, UNICODE_NORM_QC_NO},
+	{0xBC36, UNICODE_NORM_QC_NO},
+	{0xBC37, UNICODE_NORM_QC_NO},
+	{0xBC38, UNICODE_NORM_QC_NO},
+	{0xBC39, UNICODE_NORM_QC_NO},
+	{0xBC3A, UNICODE_NORM_QC_NO},
+	{0xBC3B, UNICODE_NORM_QC_NO},
+	{0xBC3C, UNICODE_NORM_QC_NO},
+	{0xBC3D, UNICODE_NORM_QC_NO},
+	{0xBC3E, UNICODE_NORM_QC_NO},
+	{0xBC3F, UNICODE_NORM_QC_NO},
+	{0xBC40, UNICODE_NORM_QC_NO},
+	{0xBC41, UNICODE_NORM_QC_NO},
+	{0xBC42, UNICODE_NORM_QC_NO},
+	{0xBC43, UNICODE_NORM_QC_NO},
+	{0xBC44, UNICODE_NORM_QC_NO},
+	{0xBC45, UNICODE_NORM_QC_NO},
+	{0xBC46, UNICODE_NORM_QC_NO},
+	{0xBC47, UNICODE_NORM_QC_NO},
+	{0xBC48, UNICODE_NORM_QC_NO},
+	{0xBC49, UNICODE_NORM_QC_NO},
+	{0xBC4A, UNICODE_NORM_QC_NO},
+	{0xBC4B, UNICODE_NORM_QC_NO},
+	{0xBC4C, UNICODE_NORM_QC_NO},
+	{0xBC4D, UNICODE_NORM_QC_NO},
+	{0xBC4E, UNICODE_NORM_QC_NO},
+	{0xBC4F, UNICODE_NORM_QC_NO},
+	{0xBC50, UNICODE_NORM_QC_NO},
+	{0xBC51, UNICODE_NORM_QC_NO},
+	{0xBC52, UNICODE_NORM_QC_NO},
+	{0xBC53, UNICODE_NORM_QC_NO},
+	{0xBC54, UNICODE_NORM_QC_NO},
+	{0xBC55, UNICODE_NORM_QC_NO},
+	{0xBC56, UNICODE_NORM_QC_NO},
+	{0xBC57, UNICODE_NORM_QC_NO},
+	{0xBC58, UNICODE_NORM_QC_NO},
+	{0xBC59, UNICODE_NORM_QC_NO},
+	{0xBC5A, UNICODE_NORM_QC_NO},
+	{0xBC5B, UNICODE_NORM_QC_NO},
+	{0xBC5C, UNICODE_NORM_QC_NO},
+	{0xBC5D, UNICODE_NORM_QC_NO},
+	{0xBC5E, UNICODE_NORM_QC_NO},
+	{0xBC5F, UNICODE_NORM_QC_NO},
+	{0xBC60, UNICODE_NORM_QC_NO},
+	{0xBC61, UNICODE_NORM_QC_NO},
+	{0xBC62, UNICODE_NORM_QC_NO},
+	{0xBC63, UNICODE_NORM_QC_NO},
+	{0xBC64, UNICODE_NORM_QC_NO},
+	{0xBC65, UNICODE_NORM_QC_NO},
+	{0xBC66, UNICODE_NORM_QC_NO},
+	{0xBC67, UNICODE_NORM_QC_NO},
+	{0xBC68, UNICODE_NORM_QC_NO},
+	{0xBC69, UNICODE_NORM_QC_NO},
+	{0xBC6A, UNICODE_NORM_QC_NO},
+	{0xBC6B, UNICODE_NORM_QC_NO},
+	{0xBC6C, UNICODE_NORM_QC_NO},
+	{0xBC6D, UNICODE_NORM_QC_NO},
+	{0xBC6E, UNICODE_NORM_QC_NO},
+	{0xBC6F, UNICODE_NORM_QC_NO},
+	{0xBC70, UNICODE_NORM_QC_NO},
+	{0xBC71, UNICODE_NORM_QC_NO},
+	{0xBC72, UNICODE_NORM_QC_NO},
+	{0xBC73, UNICODE_NORM_QC_NO},
+	{0xBC74, UNICODE_NORM_QC_NO},
+	{0xBC75, UNICODE_NORM_QC_NO},
+	{0xBC76, UNICODE_NORM_QC_NO},
+	{0xBC77, UNICODE_NORM_QC_NO},
+	{0xBC78, UNICODE_NORM_QC_NO},
+	{0xBC79, UNICODE_NORM_QC_NO},
+	{0xBC7A, UNICODE_NORM_QC_NO},
+	{0xBC7B, UNICODE_NORM_QC_NO},
+	{0xBC7C, UNICODE_NORM_QC_NO},
+	{0xBC7D, UNICODE_NORM_QC_NO},
+	{0xBC7E, UNICODE_NORM_QC_NO},
+	{0xBC7F, UNICODE_NORM_QC_NO},
+	{0xBC80, UNICODE_NORM_QC_NO},
+	{0xBC81, UNICODE_NORM_QC_NO},
+	{0xBC82, UNICODE_NORM_QC_NO},
+	{0xBC83, UNICODE_NORM_QC_NO},
+	{0xBC84, UNICODE_NORM_QC_NO},
+	{0xBC85, UNICODE_NORM_QC_NO},
+	{0xBC86, UNICODE_NORM_QC_NO},
+	{0xBC87, UNICODE_NORM_QC_NO},
+	{0xBC88, UNICODE_NORM_QC_NO},
+	{0xBC89, UNICODE_NORM_QC_NO},
+	{0xBC8A, UNICODE_NORM_QC_NO},
+	{0xBC8B, UNICODE_NORM_QC_NO},
+	{0xBC8C, UNICODE_NORM_QC_NO},
+	{0xBC8D, UNICODE_NORM_QC_NO},
+	{0xBC8E, UNICODE_NORM_QC_NO},
+	{0xBC8F, UNICODE_NORM_QC_NO},
+	{0xBC90, UNICODE_NORM_QC_NO},
+	{0xBC91, UNICODE_NORM_QC_NO},
+	{0xBC92, UNICODE_NORM_QC_NO},
+	{0xBC93, UNICODE_NORM_QC_NO},
+	{0xBC94, UNICODE_NORM_QC_NO},
+	{0xBC95, UNICODE_NORM_QC_NO},
+	{0xBC96, UNICODE_NORM_QC_NO},
+	{0xBC97, UNICODE_NORM_QC_NO},
+	{0xBC98, UNICODE_NORM_QC_NO},
+	{0xBC99, UNICODE_NORM_QC_NO},
+	{0xBC9A, UNICODE_NORM_QC_NO},
+	{0xBC9B, UNICODE_NORM_QC_NO},
+	{0xBC9C, UNICODE_NORM_QC_NO},
+	{0xBC9D, UNICODE_NORM_QC_NO},
+	{0xBC9E, UNICODE_NORM_QC_NO},
+	{0xBC9F, UNICODE_NORM_QC_NO},
+	{0xBCA0, UNICODE_NORM_QC_NO},
+	{0xBCA1, UNICODE_NORM_QC_NO},
+	{0xBCA2, UNICODE_NORM_QC_NO},
+	{0xBCA3, UNICODE_NORM_QC_NO},
+	{0xBCA4, UNICODE_NORM_QC_NO},
+	{0xBCA5, UNICODE_NORM_QC_NO},
+	{0xBCA6, UNICODE_NORM_QC_NO},
+	{0xBCA7, UNICODE_NORM_QC_NO},
+	{0xBCA8, UNICODE_NORM_QC_NO},
+	{0xBCA9, UNICODE_NORM_QC_NO},
+	{0xBCAA, UNICODE_NORM_QC_NO},
+	{0xBCAB, UNICODE_NORM_QC_NO},
+	{0xBCAC, UNICODE_NORM_QC_NO},
+	{0xBCAD, UNICODE_NORM_QC_NO},
+	{0xBCAE, UNICODE_NORM_QC_NO},
+	{0xBCAF, UNICODE_NORM_QC_NO},
+	{0xBCB0, UNICODE_NORM_QC_NO},
+	{0xBCB1, UNICODE_NORM_QC_NO},
+	{0xBCB2, UNICODE_NORM_QC_NO},
+	{0xBCB3, UNICODE_NORM_QC_NO},
+	{0xBCB4, UNICODE_NORM_QC_NO},
+	{0xBCB5, UNICODE_NORM_QC_NO},
+	{0xBCB6, UNICODE_NORM_QC_NO},
+	{0xBCB7, UNICODE_NORM_QC_NO},
+	{0xBCB8, UNICODE_NORM_QC_NO},
+	{0xBCB9, UNICODE_NORM_QC_NO},
+	{0xBCBA, UNICODE_NORM_QC_NO},
+	{0xBCBB, UNICODE_NORM_QC_NO},
+	{0xBCBC, UNICODE_NORM_QC_NO},
+	{0xBCBD, UNICODE_NORM_QC_NO},
+	{0xBCBE, UNICODE_NORM_QC_NO},
+	{0xBCBF, UNICODE_NORM_QC_NO},
+	{0xBCC0, UNICODE_NORM_QC_NO},
+	{0xBCC1, UNICODE_NORM_QC_NO},
+	{0xBCC2, UNICODE_NORM_QC_NO},
+	{0xBCC3, UNICODE_NORM_QC_NO},
+	{0xBCC4, UNICODE_NORM_QC_NO},
+	{0xBCC5, UNICODE_NORM_QC_NO},
+	{0xBCC6, UNICODE_NORM_QC_NO},
+	{0xBCC7, UNICODE_NORM_QC_NO},
+	{0xBCC8, UNICODE_NORM_QC_NO},
+	{0xBCC9, UNICODE_NORM_QC_NO},
+	{0xBCCA, UNICODE_NORM_QC_NO},
+	{0xBCCB, UNICODE_NORM_QC_NO},
+	{0xBCCC, UNICODE_NORM_QC_NO},
+	{0xBCCD, UNICODE_NORM_QC_NO},
+	{0xBCCE, UNICODE_NORM_QC_NO},
+	{0xBCCF, UNICODE_NORM_QC_NO},
+	{0xBCD0, UNICODE_NORM_QC_NO},
+	{0xBCD1, UNICODE_NORM_QC_NO},
+	{0xBCD2, UNICODE_NORM_QC_NO},
+	{0xBCD3, UNICODE_NORM_QC_NO},
+	{0xBCD4, UNICODE_NORM_QC_NO},
+	{0xBCD5, UNICODE_NORM_QC_NO},
+	{0xBCD6, UNICODE_NORM_QC_NO},
+	{0xBCD7, UNICODE_NORM_QC_NO},
+	{0xBCD8, UNICODE_NORM_QC_NO},
+	{0xBCD9, UNICODE_NORM_QC_NO},
+	{0xBCDA, UNICODE_NORM_QC_NO},
+	{0xBCDB, UNICODE_NORM_QC_NO},
+	{0xBCDC, UNICODE_NORM_QC_NO},
+	{0xBCDD, UNICODE_NORM_QC_NO},
+	{0xBCDE, UNICODE_NORM_QC_NO},
+	{0xBCDF, UNICODE_NORM_QC_NO},
+	{0xBCE0, UNICODE_NORM_QC_NO},
+	{0xBCE1, UNICODE_NORM_QC_NO},
+	{0xBCE2, UNICODE_NORM_QC_NO},
+	{0xBCE3, UNICODE_NORM_QC_NO},
+	{0xBCE4, UNICODE_NORM_QC_NO},
+	{0xBCE5, UNICODE_NORM_QC_NO},
+	{0xBCE6, UNICODE_NORM_QC_NO},
+	{0xBCE7, UNICODE_NORM_QC_NO},
+	{0xBCE8, UNICODE_NORM_QC_NO},
+	{0xBCE9, UNICODE_NORM_QC_NO},
+	{0xBCEA, UNICODE_NORM_QC_NO},
+	{0xBCEB, UNICODE_NORM_QC_NO},
+	{0xBCEC, UNICODE_NORM_QC_NO},
+	{0xBCED, UNICODE_NORM_QC_NO},
+	{0xBCEE, UNICODE_NORM_QC_NO},
+	{0xBCEF, UNICODE_NORM_QC_NO},
+	{0xBCF0, UNICODE_NORM_QC_NO},
+	{0xBCF1, UNICODE_NORM_QC_NO},
+	{0xBCF2, UNICODE_NORM_QC_NO},
+	{0xBCF3, UNICODE_NORM_QC_NO},
+	{0xBCF4, UNICODE_NORM_QC_NO},
+	{0xBCF5, UNICODE_NORM_QC_NO},
+	{0xBCF6, UNICODE_NORM_QC_NO},
+	{0xBCF7, UNICODE_NORM_QC_NO},
+	{0xBCF8, UNICODE_NORM_QC_NO},
+	{0xBCF9, UNICODE_NORM_QC_NO},
+	{0xBCFA, UNICODE_NORM_QC_NO},
+	{0xBCFB, UNICODE_NORM_QC_NO},
+	{0xBCFC, UNICODE_NORM_QC_NO},
+	{0xBCFD, UNICODE_NORM_QC_NO},
+	{0xBCFE, UNICODE_NORM_QC_NO},
+	{0xBCFF, UNICODE_NORM_QC_NO},
+	{0xBD00, UNICODE_NORM_QC_NO},
+	{0xBD01, UNICODE_NORM_QC_NO},
+	{0xBD02, UNICODE_NORM_QC_NO},
+	{0xBD03, UNICODE_NORM_QC_NO},
+	{0xBD04, UNICODE_NORM_QC_NO},
+	{0xBD05, UNICODE_NORM_QC_NO},
+	{0xBD06, UNICODE_NORM_QC_NO},
+	{0xBD07, UNICODE_NORM_QC_NO},
+	{0xBD08, UNICODE_NORM_QC_NO},
+	{0xBD09, UNICODE_NORM_QC_NO},
+	{0xBD0A, UNICODE_NORM_QC_NO},
+	{0xBD0B, UNICODE_NORM_QC_NO},
+	{0xBD0C, UNICODE_NORM_QC_NO},
+	{0xBD0D, UNICODE_NORM_QC_NO},
+	{0xBD0E, UNICODE_NORM_QC_NO},
+	{0xBD0F, UNICODE_NORM_QC_NO},
+	{0xBD10, UNICODE_NORM_QC_NO},
+	{0xBD11, UNICODE_NORM_QC_NO},
+	{0xBD12, UNICODE_NORM_QC_NO},
+	{0xBD13, UNICODE_NORM_QC_NO},
+	{0xBD14, UNICODE_NORM_QC_NO},
+	{0xBD15, UNICODE_NORM_QC_NO},
+	{0xBD16, UNICODE_NORM_QC_NO},
+	{0xBD17, UNICODE_NORM_QC_NO},
+	{0xBD18, UNICODE_NORM_QC_NO},
+	{0xBD19, UNICODE_NORM_QC_NO},
+	{0xBD1A, UNICODE_NORM_QC_NO},
+	{0xBD1B, UNICODE_NORM_QC_NO},
+	{0xBD1C, UNICODE_NORM_QC_NO},
+	{0xBD1D, UNICODE_NORM_QC_NO},
+	{0xBD1E, UNICODE_NORM_QC_NO},
+	{0xBD1F, UNICODE_NORM_QC_NO},
+	{0xBD20, UNICODE_NORM_QC_NO},
+	{0xBD21, UNICODE_NORM_QC_NO},
+	{0xBD22, UNICODE_NORM_QC_NO},
+	{0xBD23, UNICODE_NORM_QC_NO},
+	{0xBD24, UNICODE_NORM_QC_NO},
+	{0xBD25, UNICODE_NORM_QC_NO},
+	{0xBD26, UNICODE_NORM_QC_NO},
+	{0xBD27, UNICODE_NORM_QC_NO},
+	{0xBD28, UNICODE_NORM_QC_NO},
+	{0xBD29, UNICODE_NORM_QC_NO},
+	{0xBD2A, UNICODE_NORM_QC_NO},
+	{0xBD2B, UNICODE_NORM_QC_NO},
+	{0xBD2C, UNICODE_NORM_QC_NO},
+	{0xBD2D, UNICODE_NORM_QC_NO},
+	{0xBD2E, UNICODE_NORM_QC_NO},
+	{0xBD2F, UNICODE_NORM_QC_NO},
+	{0xBD30, UNICODE_NORM_QC_NO},
+	{0xBD31, UNICODE_NORM_QC_NO},
+	{0xBD32, UNICODE_NORM_QC_NO},
+	{0xBD33, UNICODE_NORM_QC_NO},
+	{0xBD34, UNICODE_NORM_QC_NO},
+	{0xBD35, UNICODE_NORM_QC_NO},
+	{0xBD36, UNICODE_NORM_QC_NO},
+	{0xBD37, UNICODE_NORM_QC_NO},
+	{0xBD38, UNICODE_NORM_QC_NO},
+	{0xBD39, UNICODE_NORM_QC_NO},
+	{0xBD3A, UNICODE_NORM_QC_NO},
+	{0xBD3B, UNICODE_NORM_QC_NO},
+	{0xBD3C, UNICODE_NORM_QC_NO},
+	{0xBD3D, UNICODE_NORM_QC_NO},
+	{0xBD3E, UNICODE_NORM_QC_NO},
+	{0xBD3F, UNICODE_NORM_QC_NO},
+	{0xBD40, UNICODE_NORM_QC_NO},
+	{0xBD41, UNICODE_NORM_QC_NO},
+	{0xBD42, UNICODE_NORM_QC_NO},
+	{0xBD43, UNICODE_NORM_QC_NO},
+	{0xBD44, UNICODE_NORM_QC_NO},
+	{0xBD45, UNICODE_NORM_QC_NO},
+	{0xBD46, UNICODE_NORM_QC_NO},
+	{0xBD47, UNICODE_NORM_QC_NO},
+	{0xBD48, UNICODE_NORM_QC_NO},
+	{0xBD49, UNICODE_NORM_QC_NO},
+	{0xBD4A, UNICODE_NORM_QC_NO},
+	{0xBD4B, UNICODE_NORM_QC_NO},
+	{0xBD4C, UNICODE_NORM_QC_NO},
+	{0xBD4D, UNICODE_NORM_QC_NO},
+	{0xBD4E, UNICODE_NORM_QC_NO},
+	{0xBD4F, UNICODE_NORM_QC_NO},
+	{0xBD50, UNICODE_NORM_QC_NO},
+	{0xBD51, UNICODE_NORM_QC_NO},
+	{0xBD52, UNICODE_NORM_QC_NO},
+	{0xBD53, UNICODE_NORM_QC_NO},
+	{0xBD54, UNICODE_NORM_QC_NO},
+	{0xBD55, UNICODE_NORM_QC_NO},
+	{0xBD56, UNICODE_NORM_QC_NO},
+	{0xBD57, UNICODE_NORM_QC_NO},
+	{0xBD58, UNICODE_NORM_QC_NO},
+	{0xBD59, UNICODE_NORM_QC_NO},
+	{0xBD5A, UNICODE_NORM_QC_NO},
+	{0xBD5B, UNICODE_NORM_QC_NO},
+	{0xBD5C, UNICODE_NORM_QC_NO},
+	{0xBD5D, UNICODE_NORM_QC_NO},
+	{0xBD5E, UNICODE_NORM_QC_NO},
+	{0xBD5F, UNICODE_NORM_QC_NO},
+	{0xBD60, UNICODE_NORM_QC_NO},
+	{0xBD61, UNICODE_NORM_QC_NO},
+	{0xBD62, UNICODE_NORM_QC_NO},
+	{0xBD63, UNICODE_NORM_QC_NO},
+	{0xBD64, UNICODE_NORM_QC_NO},
+	{0xBD65, UNICODE_NORM_QC_NO},
+	{0xBD66, UNICODE_NORM_QC_NO},
+	{0xBD67, UNICODE_NORM_QC_NO},
+	{0xBD68, UNICODE_NORM_QC_NO},
+	{0xBD69, UNICODE_NORM_QC_NO},
+	{0xBD6A, UNICODE_NORM_QC_NO},
+	{0xBD6B, UNICODE_NORM_QC_NO},
+	{0xBD6C, UNICODE_NORM_QC_NO},
+	{0xBD6D, UNICODE_NORM_QC_NO},
+	{0xBD6E, UNICODE_NORM_QC_NO},
+	{0xBD6F, UNICODE_NORM_QC_NO},
+	{0xBD70, UNICODE_NORM_QC_NO},
+	{0xBD71, UNICODE_NORM_QC_NO},
+	{0xBD72, UNICODE_NORM_QC_NO},
+	{0xBD73, UNICODE_NORM_QC_NO},
+	{0xBD74, UNICODE_NORM_QC_NO},
+	{0xBD75, UNICODE_NORM_QC_NO},
+	{0xBD76, UNICODE_NORM_QC_NO},
+	{0xBD77, UNICODE_NORM_QC_NO},
+	{0xBD78, UNICODE_NORM_QC_NO},
+	{0xBD79, UNICODE_NORM_QC_NO},
+	{0xBD7A, UNICODE_NORM_QC_NO},
+	{0xBD7B, UNICODE_NORM_QC_NO},
+	{0xBD7C, UNICODE_NORM_QC_NO},
+	{0xBD7D, UNICODE_NORM_QC_NO},
+	{0xBD7E, UNICODE_NORM_QC_NO},
+	{0xBD7F, UNICODE_NORM_QC_NO},
+	{0xBD80, UNICODE_NORM_QC_NO},
+	{0xBD81, UNICODE_NORM_QC_NO},
+	{0xBD82, UNICODE_NORM_QC_NO},
+	{0xBD83, UNICODE_NORM_QC_NO},
+	{0xBD84, UNICODE_NORM_QC_NO},
+	{0xBD85, UNICODE_NORM_QC_NO},
+	{0xBD86, UNICODE_NORM_QC_NO},
+	{0xBD87, UNICODE_NORM_QC_NO},
+	{0xBD88, UNICODE_NORM_QC_NO},
+	{0xBD89, UNICODE_NORM_QC_NO},
+	{0xBD8A, UNICODE_NORM_QC_NO},
+	{0xBD8B, UNICODE_NORM_QC_NO},
+	{0xBD8C, UNICODE_NORM_QC_NO},
+	{0xBD8D, UNICODE_NORM_QC_NO},
+	{0xBD8E, UNICODE_NORM_QC_NO},
+	{0xBD8F, UNICODE_NORM_QC_NO},
+	{0xBD90, UNICODE_NORM_QC_NO},
+	{0xBD91, UNICODE_NORM_QC_NO},
+	{0xBD92, UNICODE_NORM_QC_NO},
+	{0xBD93, UNICODE_NORM_QC_NO},
+	{0xBD94, UNICODE_NORM_QC_NO},
+	{0xBD95, UNICODE_NORM_QC_NO},
+	{0xBD96, UNICODE_NORM_QC_NO},
+	{0xBD97, UNICODE_NORM_QC_NO},
+	{0xBD98, UNICODE_NORM_QC_NO},
+	{0xBD99, UNICODE_NORM_QC_NO},
+	{0xBD9A, UNICODE_NORM_QC_NO},
+	{0xBD9B, UNICODE_NORM_QC_NO},
+	{0xBD9C, UNICODE_NORM_QC_NO},
+	{0xBD9D, UNICODE_NORM_QC_NO},
+	{0xBD9E, UNICODE_NORM_QC_NO},
+	{0xBD9F, UNICODE_NORM_QC_NO},
+	{0xBDA0, UNICODE_NORM_QC_NO},
+	{0xBDA1, UNICODE_NORM_QC_NO},
+	{0xBDA2, UNICODE_NORM_QC_NO},
+	{0xBDA3, UNICODE_NORM_QC_NO},
+	{0xBDA4, UNICODE_NORM_QC_NO},
+	{0xBDA5, UNICODE_NORM_QC_NO},
+	{0xBDA6, UNICODE_NORM_QC_NO},
+	{0xBDA7, UNICODE_NORM_QC_NO},
+	{0xBDA8, UNICODE_NORM_QC_NO},
+	{0xBDA9, UNICODE_NORM_QC_NO},
+	{0xBDAA, UNICODE_NORM_QC_NO},
+	{0xBDAB, UNICODE_NORM_QC_NO},
+	{0xBDAC, UNICODE_NORM_QC_NO},
+	{0xBDAD, UNICODE_NORM_QC_NO},
+	{0xBDAE, UNICODE_NORM_QC_NO},
+	{0xBDAF, UNICODE_NORM_QC_NO},
+	{0xBDB0, UNICODE_NORM_QC_NO},
+	{0xBDB1, UNICODE_NORM_QC_NO},
+	{0xBDB2, UNICODE_NORM_QC_NO},
+	{0xBDB3, UNICODE_NORM_QC_NO},
+	{0xBDB4, UNICODE_NORM_QC_NO},
+	{0xBDB5, UNICODE_NORM_QC_NO},
+	{0xBDB6, UNICODE_NORM_QC_NO},
+	{0xBDB7, UNICODE_NORM_QC_NO},
+	{0xBDB8, UNICODE_NORM_QC_NO},
+	{0xBDB9, UNICODE_NORM_QC_NO},
+	{0xBDBA, UNICODE_NORM_QC_NO},
+	{0xBDBB, UNICODE_NORM_QC_NO},
+	{0xBDBC, UNICODE_NORM_QC_NO},
+	{0xBDBD, UNICODE_NORM_QC_NO},
+	{0xBDBE, UNICODE_NORM_QC_NO},
+	{0xBDBF, UNICODE_NORM_QC_NO},
+	{0xBDC0, UNICODE_NORM_QC_NO},
+	{0xBDC1, UNICODE_NORM_QC_NO},
+	{0xBDC2, UNICODE_NORM_QC_NO},
+	{0xBDC3, UNICODE_NORM_QC_NO},
+	{0xBDC4, UNICODE_NORM_QC_NO},
+	{0xBDC5, UNICODE_NORM_QC_NO},
+	{0xBDC6, UNICODE_NORM_QC_NO},
+	{0xBDC7, UNICODE_NORM_QC_NO},
+	{0xBDC8, UNICODE_NORM_QC_NO},
+	{0xBDC9, UNICODE_NORM_QC_NO},
+	{0xBDCA, UNICODE_NORM_QC_NO},
+	{0xBDCB, UNICODE_NORM_QC_NO},
+	{0xBDCC, UNICODE_NORM_QC_NO},
+	{0xBDCD, UNICODE_NORM_QC_NO},
+	{0xBDCE, UNICODE_NORM_QC_NO},
+	{0xBDCF, UNICODE_NORM_QC_NO},
+	{0xBDD0, UNICODE_NORM_QC_NO},
+	{0xBDD1, UNICODE_NORM_QC_NO},
+	{0xBDD2, UNICODE_NORM_QC_NO},
+	{0xBDD3, UNICODE_NORM_QC_NO},
+	{0xBDD4, UNICODE_NORM_QC_NO},
+	{0xBDD5, UNICODE_NORM_QC_NO},
+	{0xBDD6, UNICODE_NORM_QC_NO},
+	{0xBDD7, UNICODE_NORM_QC_NO},
+	{0xBDD8, UNICODE_NORM_QC_NO},
+	{0xBDD9, UNICODE_NORM_QC_NO},
+	{0xBDDA, UNICODE_NORM_QC_NO},
+	{0xBDDB, UNICODE_NORM_QC_NO},
+	{0xBDDC, UNICODE_NORM_QC_NO},
+	{0xBDDD, UNICODE_NORM_QC_NO},
+	{0xBDDE, UNICODE_NORM_QC_NO},
+	{0xBDDF, UNICODE_NORM_QC_NO},
+	{0xBDE0, UNICODE_NORM_QC_NO},
+	{0xBDE1, UNICODE_NORM_QC_NO},
+	{0xBDE2, UNICODE_NORM_QC_NO},
+	{0xBDE3, UNICODE_NORM_QC_NO},
+	{0xBDE4, UNICODE_NORM_QC_NO},
+	{0xBDE5, UNICODE_NORM_QC_NO},
+	{0xBDE6, UNICODE_NORM_QC_NO},
+	{0xBDE7, UNICODE_NORM_QC_NO},
+	{0xBDE8, UNICODE_NORM_QC_NO},
+	{0xBDE9, UNICODE_NORM_QC_NO},
+	{0xBDEA, UNICODE_NORM_QC_NO},
+	{0xBDEB, UNICODE_NORM_QC_NO},
+	{0xBDEC, UNICODE_NORM_QC_NO},
+	{0xBDED, UNICODE_NORM_QC_NO},
+	{0xBDEE, UNICODE_NORM_QC_NO},
+	{0xBDEF, UNICODE_NORM_QC_NO},
+	{0xBDF0, UNICODE_NORM_QC_NO},
+	{0xBDF1, UNICODE_NORM_QC_NO},
+	{0xBDF2, UNICODE_NORM_QC_NO},
+	{0xBDF3, UNICODE_NORM_QC_NO},
+	{0xBDF4, UNICODE_NORM_QC_NO},
+	{0xBDF5, UNICODE_NORM_QC_NO},
+	{0xBDF6, UNICODE_NORM_QC_NO},
+	{0xBDF7, UNICODE_NORM_QC_NO},
+	{0xBDF8, UNICODE_NORM_QC_NO},
+	{0xBDF9, UNICODE_NORM_QC_NO},
+	{0xBDFA, UNICODE_NORM_QC_NO},
+	{0xBDFB, UNICODE_NORM_QC_NO},
+	{0xBDFC, UNICODE_NORM_QC_NO},
+	{0xBDFD, UNICODE_NORM_QC_NO},
+	{0xBDFE, UNICODE_NORM_QC_NO},
+	{0xBDFF, UNICODE_NORM_QC_NO},
+	{0xBE00, UNICODE_NORM_QC_NO},
+	{0xBE01, UNICODE_NORM_QC_NO},
+	{0xBE02, UNICODE_NORM_QC_NO},
+	{0xBE03, UNICODE_NORM_QC_NO},
+	{0xBE04, UNICODE_NORM_QC_NO},
+	{0xBE05, UNICODE_NORM_QC_NO},
+	{0xBE06, UNICODE_NORM_QC_NO},
+	{0xBE07, UNICODE_NORM_QC_NO},
+	{0xBE08, UNICODE_NORM_QC_NO},
+	{0xBE09, UNICODE_NORM_QC_NO},
+	{0xBE0A, UNICODE_NORM_QC_NO},
+	{0xBE0B, UNICODE_NORM_QC_NO},
+	{0xBE0C, UNICODE_NORM_QC_NO},
+	{0xBE0D, UNICODE_NORM_QC_NO},
+	{0xBE0E, UNICODE_NORM_QC_NO},
+	{0xBE0F, UNICODE_NORM_QC_NO},
+	{0xBE10, UNICODE_NORM_QC_NO},
+	{0xBE11, UNICODE_NORM_QC_NO},
+	{0xBE12, UNICODE_NORM_QC_NO},
+	{0xBE13, UNICODE_NORM_QC_NO},
+	{0xBE14, UNICODE_NORM_QC_NO},
+	{0xBE15, UNICODE_NORM_QC_NO},
+	{0xBE16, UNICODE_NORM_QC_NO},
+	{0xBE17, UNICODE_NORM_QC_NO},
+	{0xBE18, UNICODE_NORM_QC_NO},
+	{0xBE19, UNICODE_NORM_QC_NO},
+	{0xBE1A, UNICODE_NORM_QC_NO},
+	{0xBE1B, UNICODE_NORM_QC_NO},
+	{0xBE1C, UNICODE_NORM_QC_NO},
+	{0xBE1D, UNICODE_NORM_QC_NO},
+	{0xBE1E, UNICODE_NORM_QC_NO},
+	{0xBE1F, UNICODE_NORM_QC_NO},
+	{0xBE20, UNICODE_NORM_QC_NO},
+	{0xBE21, UNICODE_NORM_QC_NO},
+	{0xBE22, UNICODE_NORM_QC_NO},
+	{0xBE23, UNICODE_NORM_QC_NO},
+	{0xBE24, UNICODE_NORM_QC_NO},
+	{0xBE25, UNICODE_NORM_QC_NO},
+	{0xBE26, UNICODE_NORM_QC_NO},
+	{0xBE27, UNICODE_NORM_QC_NO},
+	{0xBE28, UNICODE_NORM_QC_NO},
+	{0xBE29, UNICODE_NORM_QC_NO},
+	{0xBE2A, UNICODE_NORM_QC_NO},
+	{0xBE2B, UNICODE_NORM_QC_NO},
+	{0xBE2C, UNICODE_NORM_QC_NO},
+	{0xBE2D, UNICODE_NORM_QC_NO},
+	{0xBE2E, UNICODE_NORM_QC_NO},
+	{0xBE2F, UNICODE_NORM_QC_NO},
+	{0xBE30, UNICODE_NORM_QC_NO},
+	{0xBE31, UNICODE_NORM_QC_NO},
+	{0xBE32, UNICODE_NORM_QC_NO},
+	{0xBE33, UNICODE_NORM_QC_NO},
+	{0xBE34, UNICODE_NORM_QC_NO},
+	{0xBE35, UNICODE_NORM_QC_NO},
+	{0xBE36, UNICODE_NORM_QC_NO},
+	{0xBE37, UNICODE_NORM_QC_NO},
+	{0xBE38, UNICODE_NORM_QC_NO},
+	{0xBE39, UNICODE_NORM_QC_NO},
+	{0xBE3A, UNICODE_NORM_QC_NO},
+	{0xBE3B, UNICODE_NORM_QC_NO},
+	{0xBE3C, UNICODE_NORM_QC_NO},
+	{0xBE3D, UNICODE_NORM_QC_NO},
+	{0xBE3E, UNICODE_NORM_QC_NO},
+	{0xBE3F, UNICODE_NORM_QC_NO},
+	{0xBE40, UNICODE_NORM_QC_NO},
+	{0xBE41, UNICODE_NORM_QC_NO},
+	{0xBE42, UNICODE_NORM_QC_NO},
+	{0xBE43, UNICODE_NORM_QC_NO},
+	{0xBE44, UNICODE_NORM_QC_NO},
+	{0xBE45, UNICODE_NORM_QC_NO},
+	{0xBE46, UNICODE_NORM_QC_NO},
+	{0xBE47, UNICODE_NORM_QC_NO},
+	{0xBE48, UNICODE_NORM_QC_NO},
+	{0xBE49, UNICODE_NORM_QC_NO},
+	{0xBE4A, UNICODE_NORM_QC_NO},
+	{0xBE4B, UNICODE_NORM_QC_NO},
+	{0xBE4C, UNICODE_NORM_QC_NO},
+	{0xBE4D, UNICODE_NORM_QC_NO},
+	{0xBE4E, UNICODE_NORM_QC_NO},
+	{0xBE4F, UNICODE_NORM_QC_NO},
+	{0xBE50, UNICODE_NORM_QC_NO},
+	{0xBE51, UNICODE_NORM_QC_NO},
+	{0xBE52, UNICODE_NORM_QC_NO},
+	{0xBE53, UNICODE_NORM_QC_NO},
+	{0xBE54, UNICODE_NORM_QC_NO},
+	{0xBE55, UNICODE_NORM_QC_NO},
+	{0xBE56, UNICODE_NORM_QC_NO},
+	{0xBE57, UNICODE_NORM_QC_NO},
+	{0xBE58, UNICODE_NORM_QC_NO},
+	{0xBE59, UNICODE_NORM_QC_NO},
+	{0xBE5A, UNICODE_NORM_QC_NO},
+	{0xBE5B, UNICODE_NORM_QC_NO},
+	{0xBE5C, UNICODE_NORM_QC_NO},
+	{0xBE5D, UNICODE_NORM_QC_NO},
+	{0xBE5E, UNICODE_NORM_QC_NO},
+	{0xBE5F, UNICODE_NORM_QC_NO},
+	{0xBE60, UNICODE_NORM_QC_NO},
+	{0xBE61, UNICODE_NORM_QC_NO},
+	{0xBE62, UNICODE_NORM_QC_NO},
+	{0xBE63, UNICODE_NORM_QC_NO},
+	{0xBE64, UNICODE_NORM_QC_NO},
+	{0xBE65, UNICODE_NORM_QC_NO},
+	{0xBE66, UNICODE_NORM_QC_NO},
+	{0xBE67, UNICODE_NORM_QC_NO},
+	{0xBE68, UNICODE_NORM_QC_NO},
+	{0xBE69, UNICODE_NORM_QC_NO},
+	{0xBE6A, UNICODE_NORM_QC_NO},
+	{0xBE6B, UNICODE_NORM_QC_NO},
+	{0xBE6C, UNICODE_NORM_QC_NO},
+	{0xBE6D, UNICODE_NORM_QC_NO},
+	{0xBE6E, UNICODE_NORM_QC_NO},
+	{0xBE6F, UNICODE_NORM_QC_NO},
+	{0xBE70, UNICODE_NORM_QC_NO},
+	{0xBE71, UNICODE_NORM_QC_NO},
+	{0xBE72, UNICODE_NORM_QC_NO},
+	{0xBE73, UNICODE_NORM_QC_NO},
+	{0xBE74, UNICODE_NORM_QC_NO},
+	{0xBE75, UNICODE_NORM_QC_NO},
+	{0xBE76, UNICODE_NORM_QC_NO},
+	{0xBE77, UNICODE_NORM_QC_NO},
+	{0xBE78, UNICODE_NORM_QC_NO},
+	{0xBE79, UNICODE_NORM_QC_NO},
+	{0xBE7A, UNICODE_NORM_QC_NO},
+	{0xBE7B, UNICODE_NORM_QC_NO},
+	{0xBE7C, UNICODE_NORM_QC_NO},
+	{0xBE7D, UNICODE_NORM_QC_NO},
+	{0xBE7E, UNICODE_NORM_QC_NO},
+	{0xBE7F, UNICODE_NORM_QC_NO},
+	{0xBE80, UNICODE_NORM_QC_NO},
+	{0xBE81, UNICODE_NORM_QC_NO},
+	{0xBE82, UNICODE_NORM_QC_NO},
+	{0xBE83, UNICODE_NORM_QC_NO},
+	{0xBE84, UNICODE_NORM_QC_NO},
+	{0xBE85, UNICODE_NORM_QC_NO},
+	{0xBE86, UNICODE_NORM_QC_NO},
+	{0xBE87, UNICODE_NORM_QC_NO},
+	{0xBE88, UNICODE_NORM_QC_NO},
+	{0xBE89, UNICODE_NORM_QC_NO},
+	{0xBE8A, UNICODE_NORM_QC_NO},
+	{0xBE8B, UNICODE_NORM_QC_NO},
+	{0xBE8C, UNICODE_NORM_QC_NO},
+	{0xBE8D, UNICODE_NORM_QC_NO},
+	{0xBE8E, UNICODE_NORM_QC_NO},
+	{0xBE8F, UNICODE_NORM_QC_NO},
+	{0xBE90, UNICODE_NORM_QC_NO},
+	{0xBE91, UNICODE_NORM_QC_NO},
+	{0xBE92, UNICODE_NORM_QC_NO},
+	{0xBE93, UNICODE_NORM_QC_NO},
+	{0xBE94, UNICODE_NORM_QC_NO},
+	{0xBE95, UNICODE_NORM_QC_NO},
+	{0xBE96, UNICODE_NORM_QC_NO},
+	{0xBE97, UNICODE_NORM_QC_NO},
+	{0xBE98, UNICODE_NORM_QC_NO},
+	{0xBE99, UNICODE_NORM_QC_NO},
+	{0xBE9A, UNICODE_NORM_QC_NO},
+	{0xBE9B, UNICODE_NORM_QC_NO},
+	{0xBE9C, UNICODE_NORM_QC_NO},
+	{0xBE9D, UNICODE_NORM_QC_NO},
+	{0xBE9E, UNICODE_NORM_QC_NO},
+	{0xBE9F, UNICODE_NORM_QC_NO},
+	{0xBEA0, UNICODE_NORM_QC_NO},
+	{0xBEA1, UNICODE_NORM_QC_NO},
+	{0xBEA2, UNICODE_NORM_QC_NO},
+	{0xBEA3, UNICODE_NORM_QC_NO},
+	{0xBEA4, UNICODE_NORM_QC_NO},
+	{0xBEA5, UNICODE_NORM_QC_NO},
+	{0xBEA6, UNICODE_NORM_QC_NO},
+	{0xBEA7, UNICODE_NORM_QC_NO},
+	{0xBEA8, UNICODE_NORM_QC_NO},
+	{0xBEA9, UNICODE_NORM_QC_NO},
+	{0xBEAA, UNICODE_NORM_QC_NO},
+	{0xBEAB, UNICODE_NORM_QC_NO},
+	{0xBEAC, UNICODE_NORM_QC_NO},
+	{0xBEAD, UNICODE_NORM_QC_NO},
+	{0xBEAE, UNICODE_NORM_QC_NO},
+	{0xBEAF, UNICODE_NORM_QC_NO},
+	{0xBEB0, UNICODE_NORM_QC_NO},
+	{0xBEB1, UNICODE_NORM_QC_NO},
+	{0xBEB2, UNICODE_NORM_QC_NO},
+	{0xBEB3, UNICODE_NORM_QC_NO},
+	{0xBEB4, UNICODE_NORM_QC_NO},
+	{0xBEB5, UNICODE_NORM_QC_NO},
+	{0xBEB6, UNICODE_NORM_QC_NO},
+	{0xBEB7, UNICODE_NORM_QC_NO},
+	{0xBEB8, UNICODE_NORM_QC_NO},
+	{0xBEB9, UNICODE_NORM_QC_NO},
+	{0xBEBA, UNICODE_NORM_QC_NO},
+	{0xBEBB, UNICODE_NORM_QC_NO},
+	{0xBEBC, UNICODE_NORM_QC_NO},
+	{0xBEBD, UNICODE_NORM_QC_NO},
+	{0xBEBE, UNICODE_NORM_QC_NO},
+	{0xBEBF, UNICODE_NORM_QC_NO},
+	{0xBEC0, UNICODE_NORM_QC_NO},
+	{0xBEC1, UNICODE_NORM_QC_NO},
+	{0xBEC2, UNICODE_NORM_QC_NO},
+	{0xBEC3, UNICODE_NORM_QC_NO},
+	{0xBEC4, UNICODE_NORM_QC_NO},
+	{0xBEC5, UNICODE_NORM_QC_NO},
+	{0xBEC6, UNICODE_NORM_QC_NO},
+	{0xBEC7, UNICODE_NORM_QC_NO},
+	{0xBEC8, UNICODE_NORM_QC_NO},
+	{0xBEC9, UNICODE_NORM_QC_NO},
+	{0xBECA, UNICODE_NORM_QC_NO},
+	{0xBECB, UNICODE_NORM_QC_NO},
+	{0xBECC, UNICODE_NORM_QC_NO},
+	{0xBECD, UNICODE_NORM_QC_NO},
+	{0xBECE, UNICODE_NORM_QC_NO},
+	{0xBECF, UNICODE_NORM_QC_NO},
+	{0xBED0, UNICODE_NORM_QC_NO},
+	{0xBED1, UNICODE_NORM_QC_NO},
+	{0xBED2, UNICODE_NORM_QC_NO},
+	{0xBED3, UNICODE_NORM_QC_NO},
+	{0xBED4, UNICODE_NORM_QC_NO},
+	{0xBED5, UNICODE_NORM_QC_NO},
+	{0xBED6, UNICODE_NORM_QC_NO},
+	{0xBED7, UNICODE_NORM_QC_NO},
+	{0xBED8, UNICODE_NORM_QC_NO},
+	{0xBED9, UNICODE_NORM_QC_NO},
+	{0xBEDA, UNICODE_NORM_QC_NO},
+	{0xBEDB, UNICODE_NORM_QC_NO},
+	{0xBEDC, UNICODE_NORM_QC_NO},
+	{0xBEDD, UNICODE_NORM_QC_NO},
+	{0xBEDE, UNICODE_NORM_QC_NO},
+	{0xBEDF, UNICODE_NORM_QC_NO},
+	{0xBEE0, UNICODE_NORM_QC_NO},
+	{0xBEE1, UNICODE_NORM_QC_NO},
+	{0xBEE2, UNICODE_NORM_QC_NO},
+	{0xBEE3, UNICODE_NORM_QC_NO},
+	{0xBEE4, UNICODE_NORM_QC_NO},
+	{0xBEE5, UNICODE_NORM_QC_NO},
+	{0xBEE6, UNICODE_NORM_QC_NO},
+	{0xBEE7, UNICODE_NORM_QC_NO},
+	{0xBEE8, UNICODE_NORM_QC_NO},
+	{0xBEE9, UNICODE_NORM_QC_NO},
+	{0xBEEA, UNICODE_NORM_QC_NO},
+	{0xBEEB, UNICODE_NORM_QC_NO},
+	{0xBEEC, UNICODE_NORM_QC_NO},
+	{0xBEED, UNICODE_NORM_QC_NO},
+	{0xBEEE, UNICODE_NORM_QC_NO},
+	{0xBEEF, UNICODE_NORM_QC_NO},
+	{0xBEF0, UNICODE_NORM_QC_NO},
+	{0xBEF1, UNICODE_NORM_QC_NO},
+	{0xBEF2, UNICODE_NORM_QC_NO},
+	{0xBEF3, UNICODE_NORM_QC_NO},
+	{0xBEF4, UNICODE_NORM_QC_NO},
+	{0xBEF5, UNICODE_NORM_QC_NO},
+	{0xBEF6, UNICODE_NORM_QC_NO},
+	{0xBEF7, UNICODE_NORM_QC_NO},
+	{0xBEF8, UNICODE_NORM_QC_NO},
+	{0xBEF9, UNICODE_NORM_QC_NO},
+	{0xBEFA, UNICODE_NORM_QC_NO},
+	{0xBEFB, UNICODE_NORM_QC_NO},
+	{0xBEFC, UNICODE_NORM_QC_NO},
+	{0xBEFD, UNICODE_NORM_QC_NO},
+	{0xBEFE, UNICODE_NORM_QC_NO},
+	{0xBEFF, UNICODE_NORM_QC_NO},
+	{0xBF00, UNICODE_NORM_QC_NO},
+	{0xBF01, UNICODE_NORM_QC_NO},
+	{0xBF02, UNICODE_NORM_QC_NO},
+	{0xBF03, UNICODE_NORM_QC_NO},
+	{0xBF04, UNICODE_NORM_QC_NO},
+	{0xBF05, UNICODE_NORM_QC_NO},
+	{0xBF06, UNICODE_NORM_QC_NO},
+	{0xBF07, UNICODE_NORM_QC_NO},
+	{0xBF08, UNICODE_NORM_QC_NO},
+	{0xBF09, UNICODE_NORM_QC_NO},
+	{0xBF0A, UNICODE_NORM_QC_NO},
+	{0xBF0B, UNICODE_NORM_QC_NO},
+	{0xBF0C, UNICODE_NORM_QC_NO},
+	{0xBF0D, UNICODE_NORM_QC_NO},
+	{0xBF0E, UNICODE_NORM_QC_NO},
+	{0xBF0F, UNICODE_NORM_QC_NO},
+	{0xBF10, UNICODE_NORM_QC_NO},
+	{0xBF11, UNICODE_NORM_QC_NO},
+	{0xBF12, UNICODE_NORM_QC_NO},
+	{0xBF13, UNICODE_NORM_QC_NO},
+	{0xBF14, UNICODE_NORM_QC_NO},
+	{0xBF15, UNICODE_NORM_QC_NO},
+	{0xBF16, UNICODE_NORM_QC_NO},
+	{0xBF17, UNICODE_NORM_QC_NO},
+	{0xBF18, UNICODE_NORM_QC_NO},
+	{0xBF19, UNICODE_NORM_QC_NO},
+	{0xBF1A, UNICODE_NORM_QC_NO},
+	{0xBF1B, UNICODE_NORM_QC_NO},
+	{0xBF1C, UNICODE_NORM_QC_NO},
+	{0xBF1D, UNICODE_NORM_QC_NO},
+	{0xBF1E, UNICODE_NORM_QC_NO},
+	{0xBF1F, UNICODE_NORM_QC_NO},
+	{0xBF20, UNICODE_NORM_QC_NO},
+	{0xBF21, UNICODE_NORM_QC_NO},
+	{0xBF22, UNICODE_NORM_QC_NO},
+	{0xBF23, UNICODE_NORM_QC_NO},
+	{0xBF24, UNICODE_NORM_QC_NO},
+	{0xBF25, UNICODE_NORM_QC_NO},
+	{0xBF26, UNICODE_NORM_QC_NO},
+	{0xBF27, UNICODE_NORM_QC_NO},
+	{0xBF28, UNICODE_NORM_QC_NO},
+	{0xBF29, UNICODE_NORM_QC_NO},
+	{0xBF2A, UNICODE_NORM_QC_NO},
+	{0xBF2B, UNICODE_NORM_QC_NO},
+	{0xBF2C, UNICODE_NORM_QC_NO},
+	{0xBF2D, UNICODE_NORM_QC_NO},
+	{0xBF2E, UNICODE_NORM_QC_NO},
+	{0xBF2F, UNICODE_NORM_QC_NO},
+	{0xBF30, UNICODE_NORM_QC_NO},
+	{0xBF31, UNICODE_NORM_QC_NO},
+	{0xBF32, UNICODE_NORM_QC_NO},
+	{0xBF33, UNICODE_NORM_QC_NO},
+	{0xBF34, UNICODE_NORM_QC_NO},
+	{0xBF35, UNICODE_NORM_QC_NO},
+	{0xBF36, UNICODE_NORM_QC_NO},
+	{0xBF37, UNICODE_NORM_QC_NO},
+	{0xBF38, UNICODE_NORM_QC_NO},
+	{0xBF39, UNICODE_NORM_QC_NO},
+	{0xBF3A, UNICODE_NORM_QC_NO},
+	{0xBF3B, UNICODE_NORM_QC_NO},
+	{0xBF3C, UNICODE_NORM_QC_NO},
+	{0xBF3D, UNICODE_NORM_QC_NO},
+	{0xBF3E, UNICODE_NORM_QC_NO},
+	{0xBF3F, UNICODE_NORM_QC_NO},
+	{0xBF40, UNICODE_NORM_QC_NO},
+	{0xBF41, UNICODE_NORM_QC_NO},
+	{0xBF42, UNICODE_NORM_QC_NO},
+	{0xBF43, UNICODE_NORM_QC_NO},
+	{0xBF44, UNICODE_NORM_QC_NO},
+	{0xBF45, UNICODE_NORM_QC_NO},
+	{0xBF46, UNICODE_NORM_QC_NO},
+	{0xBF47, UNICODE_NORM_QC_NO},
+	{0xBF48, UNICODE_NORM_QC_NO},
+	{0xBF49, UNICODE_NORM_QC_NO},
+	{0xBF4A, UNICODE_NORM_QC_NO},
+	{0xBF4B, UNICODE_NORM_QC_NO},
+	{0xBF4C, UNICODE_NORM_QC_NO},
+	{0xBF4D, UNICODE_NORM_QC_NO},
+	{0xBF4E, UNICODE_NORM_QC_NO},
+	{0xBF4F, UNICODE_NORM_QC_NO},
+	{0xBF50, UNICODE_NORM_QC_NO},
+	{0xBF51, UNICODE_NORM_QC_NO},
+	{0xBF52, UNICODE_NORM_QC_NO},
+	{0xBF53, UNICODE_NORM_QC_NO},
+	{0xBF54, UNICODE_NORM_QC_NO},
+	{0xBF55, UNICODE_NORM_QC_NO},
+	{0xBF56, UNICODE_NORM_QC_NO},
+	{0xBF57, UNICODE_NORM_QC_NO},
+	{0xBF58, UNICODE_NORM_QC_NO},
+	{0xBF59, UNICODE_NORM_QC_NO},
+	{0xBF5A, UNICODE_NORM_QC_NO},
+	{0xBF5B, UNICODE_NORM_QC_NO},
+	{0xBF5C, UNICODE_NORM_QC_NO},
+	{0xBF5D, UNICODE_NORM_QC_NO},
+	{0xBF5E, UNICODE_NORM_QC_NO},
+	{0xBF5F, UNICODE_NORM_QC_NO},
+	{0xBF60, UNICODE_NORM_QC_NO},
+	{0xBF61, UNICODE_NORM_QC_NO},
+	{0xBF62, UNICODE_NORM_QC_NO},
+	{0xBF63, UNICODE_NORM_QC_NO},
+	{0xBF64, UNICODE_NORM_QC_NO},
+	{0xBF65, UNICODE_NORM_QC_NO},
+	{0xBF66, UNICODE_NORM_QC_NO},
+	{0xBF67, UNICODE_NORM_QC_NO},
+	{0xBF68, UNICODE_NORM_QC_NO},
+	{0xBF69, UNICODE_NORM_QC_NO},
+	{0xBF6A, UNICODE_NORM_QC_NO},
+	{0xBF6B, UNICODE_NORM_QC_NO},
+	{0xBF6C, UNICODE_NORM_QC_NO},
+	{0xBF6D, UNICODE_NORM_QC_NO},
+	{0xBF6E, UNICODE_NORM_QC_NO},
+	{0xBF6F, UNICODE_NORM_QC_NO},
+	{0xBF70, UNICODE_NORM_QC_NO},
+	{0xBF71, UNICODE_NORM_QC_NO},
+	{0xBF72, UNICODE_NORM_QC_NO},
+	{0xBF73, UNICODE_NORM_QC_NO},
+	{0xBF74, UNICODE_NORM_QC_NO},
+	{0xBF75, UNICODE_NORM_QC_NO},
+	{0xBF76, UNICODE_NORM_QC_NO},
+	{0xBF77, UNICODE_NORM_QC_NO},
+	{0xBF78, UNICODE_NORM_QC_NO},
+	{0xBF79, UNICODE_NORM_QC_NO},
+	{0xBF7A, UNICODE_NORM_QC_NO},
+	{0xBF7B, UNICODE_NORM_QC_NO},
+	{0xBF7C, UNICODE_NORM_QC_NO},
+	{0xBF7D, UNICODE_NORM_QC_NO},
+	{0xBF7E, UNICODE_NORM_QC_NO},
+	{0xBF7F, UNICODE_NORM_QC_NO},
+	{0xBF80, UNICODE_NORM_QC_NO},
+	{0xBF81, UNICODE_NORM_QC_NO},
+	{0xBF82, UNICODE_NORM_QC_NO},
+	{0xBF83, UNICODE_NORM_QC_NO},
+	{0xBF84, UNICODE_NORM_QC_NO},
+	{0xBF85, UNICODE_NORM_QC_NO},
+	{0xBF86, UNICODE_NORM_QC_NO},
+	{0xBF87, UNICODE_NORM_QC_NO},
+	{0xBF88, UNICODE_NORM_QC_NO},
+	{0xBF89, UNICODE_NORM_QC_NO},
+	{0xBF8A, UNICODE_NORM_QC_NO},
+	{0xBF8B, UNICODE_NORM_QC_NO},
+	{0xBF8C, UNICODE_NORM_QC_NO},
+	{0xBF8D, UNICODE_NORM_QC_NO},
+	{0xBF8E, UNICODE_NORM_QC_NO},
+	{0xBF8F, UNICODE_NORM_QC_NO},
+	{0xBF90, UNICODE_NORM_QC_NO},
+	{0xBF91, UNICODE_NORM_QC_NO},
+	{0xBF92, UNICODE_NORM_QC_NO},
+	{0xBF93, UNICODE_NORM_QC_NO},
+	{0xBF94, UNICODE_NORM_QC_NO},
+	{0xBF95, UNICODE_NORM_QC_NO},
+	{0xBF96, UNICODE_NORM_QC_NO},
+	{0xBF97, UNICODE_NORM_QC_NO},
+	{0xBF98, UNICODE_NORM_QC_NO},
+	{0xBF99, UNICODE_NORM_QC_NO},
+	{0xBF9A, UNICODE_NORM_QC_NO},
+	{0xBF9B, UNICODE_NORM_QC_NO},
+	{0xBF9C, UNICODE_NORM_QC_NO},
+	{0xBF9D, UNICODE_NORM_QC_NO},
+	{0xBF9E, UNICODE_NORM_QC_NO},
+	{0xBF9F, UNICODE_NORM_QC_NO},
+	{0xBFA0, UNICODE_NORM_QC_NO},
+	{0xBFA1, UNICODE_NORM_QC_NO},
+	{0xBFA2, UNICODE_NORM_QC_NO},
+	{0xBFA3, UNICODE_NORM_QC_NO},
+	{0xBFA4, UNICODE_NORM_QC_NO},
+	{0xBFA5, UNICODE_NORM_QC_NO},
+	{0xBFA6, UNICODE_NORM_QC_NO},
+	{0xBFA7, UNICODE_NORM_QC_NO},
+	{0xBFA8, UNICODE_NORM_QC_NO},
+	{0xBFA9, UNICODE_NORM_QC_NO},
+	{0xBFAA, UNICODE_NORM_QC_NO},
+	{0xBFAB, UNICODE_NORM_QC_NO},
+	{0xBFAC, UNICODE_NORM_QC_NO},
+	{0xBFAD, UNICODE_NORM_QC_NO},
+	{0xBFAE, UNICODE_NORM_QC_NO},
+	{0xBFAF, UNICODE_NORM_QC_NO},
+	{0xBFB0, UNICODE_NORM_QC_NO},
+	{0xBFB1, UNICODE_NORM_QC_NO},
+	{0xBFB2, UNICODE_NORM_QC_NO},
+	{0xBFB3, UNICODE_NORM_QC_NO},
+	{0xBFB4, UNICODE_NORM_QC_NO},
+	{0xBFB5, UNICODE_NORM_QC_NO},
+	{0xBFB6, UNICODE_NORM_QC_NO},
+	{0xBFB7, UNICODE_NORM_QC_NO},
+	{0xBFB8, UNICODE_NORM_QC_NO},
+	{0xBFB9, UNICODE_NORM_QC_NO},
+	{0xBFBA, UNICODE_NORM_QC_NO},
+	{0xBFBB, UNICODE_NORM_QC_NO},
+	{0xBFBC, UNICODE_NORM_QC_NO},
+	{0xBFBD, UNICODE_NORM_QC_NO},
+	{0xBFBE, UNICODE_NORM_QC_NO},
+	{0xBFBF, UNICODE_NORM_QC_NO},
+	{0xBFC0, UNICODE_NORM_QC_NO},
+	{0xBFC1, UNICODE_NORM_QC_NO},
+	{0xBFC2, UNICODE_NORM_QC_NO},
+	{0xBFC3, UNICODE_NORM_QC_NO},
+	{0xBFC4, UNICODE_NORM_QC_NO},
+	{0xBFC5, UNICODE_NORM_QC_NO},
+	{0xBFC6, UNICODE_NORM_QC_NO},
+	{0xBFC7, UNICODE_NORM_QC_NO},
+	{0xBFC8, UNICODE_NORM_QC_NO},
+	{0xBFC9, UNICODE_NORM_QC_NO},
+	{0xBFCA, UNICODE_NORM_QC_NO},
+	{0xBFCB, UNICODE_NORM_QC_NO},
+	{0xBFCC, UNICODE_NORM_QC_NO},
+	{0xBFCD, UNICODE_NORM_QC_NO},
+	{0xBFCE, UNICODE_NORM_QC_NO},
+	{0xBFCF, UNICODE_NORM_QC_NO},
+	{0xBFD0, UNICODE_NORM_QC_NO},
+	{0xBFD1, UNICODE_NORM_QC_NO},
+	{0xBFD2, UNICODE_NORM_QC_NO},
+	{0xBFD3, UNICODE_NORM_QC_NO},
+	{0xBFD4, UNICODE_NORM_QC_NO},
+	{0xBFD5, UNICODE_NORM_QC_NO},
+	{0xBFD6, UNICODE_NORM_QC_NO},
+	{0xBFD7, UNICODE_NORM_QC_NO},
+	{0xBFD8, UNICODE_NORM_QC_NO},
+	{0xBFD9, UNICODE_NORM_QC_NO},
+	{0xBFDA, UNICODE_NORM_QC_NO},
+	{0xBFDB, UNICODE_NORM_QC_NO},
+	{0xBFDC, UNICODE_NORM_QC_NO},
+	{0xBFDD, UNICODE_NORM_QC_NO},
+	{0xBFDE, UNICODE_NORM_QC_NO},
+	{0xBFDF, UNICODE_NORM_QC_NO},
+	{0xBFE0, UNICODE_NORM_QC_NO},
+	{0xBFE1, UNICODE_NORM_QC_NO},
+	{0xBFE2, UNICODE_NORM_QC_NO},
+	{0xBFE3, UNICODE_NORM_QC_NO},
+	{0xBFE4, UNICODE_NORM_QC_NO},
+	{0xBFE5, UNICODE_NORM_QC_NO},
+	{0xBFE6, UNICODE_NORM_QC_NO},
+	{0xBFE7, UNICODE_NORM_QC_NO},
+	{0xBFE8, UNICODE_NORM_QC_NO},
+	{0xBFE9, UNICODE_NORM_QC_NO},
+	{0xBFEA, UNICODE_NORM_QC_NO},
+	{0xBFEB, UNICODE_NORM_QC_NO},
+	{0xBFEC, UNICODE_NORM_QC_NO},
+	{0xBFED, UNICODE_NORM_QC_NO},
+	{0xBFEE, UNICODE_NORM_QC_NO},
+	{0xBFEF, UNICODE_NORM_QC_NO},
+	{0xBFF0, UNICODE_NORM_QC_NO},
+	{0xBFF1, UNICODE_NORM_QC_NO},
+	{0xBFF2, UNICODE_NORM_QC_NO},
+	{0xBFF3, UNICODE_NORM_QC_NO},
+	{0xBFF4, UNICODE_NORM_QC_NO},
+	{0xBFF5, UNICODE_NORM_QC_NO},
+	{0xBFF6, UNICODE_NORM_QC_NO},
+	{0xBFF7, UNICODE_NORM_QC_NO},
+	{0xBFF8, UNICODE_NORM_QC_NO},
+	{0xBFF9, UNICODE_NORM_QC_NO},
+	{0xBFFA, UNICODE_NORM_QC_NO},
+	{0xBFFB, UNICODE_NORM_QC_NO},
+	{0xBFFC, UNICODE_NORM_QC_NO},
+	{0xBFFD, UNICODE_NORM_QC_NO},
+	{0xBFFE, UNICODE_NORM_QC_NO},
+	{0xBFFF, UNICODE_NORM_QC_NO},
+	{0xC000, UNICODE_NORM_QC_NO},
+	{0xC001, UNICODE_NORM_QC_NO},
+	{0xC002, UNICODE_NORM_QC_NO},
+	{0xC003, UNICODE_NORM_QC_NO},
+	{0xC004, UNICODE_NORM_QC_NO},
+	{0xC005, UNICODE_NORM_QC_NO},
+	{0xC006, UNICODE_NORM_QC_NO},
+	{0xC007, UNICODE_NORM_QC_NO},
+	{0xC008, UNICODE_NORM_QC_NO},
+	{0xC009, UNICODE_NORM_QC_NO},
+	{0xC00A, UNICODE_NORM_QC_NO},
+	{0xC00B, UNICODE_NORM_QC_NO},
+	{0xC00C, UNICODE_NORM_QC_NO},
+	{0xC00D, UNICODE_NORM_QC_NO},
+	{0xC00E, UNICODE_NORM_QC_NO},
+	{0xC00F, UNICODE_NORM_QC_NO},
+	{0xC010, UNICODE_NORM_QC_NO},
+	{0xC011, UNICODE_NORM_QC_NO},
+	{0xC012, UNICODE_NORM_QC_NO},
+	{0xC013, UNICODE_NORM_QC_NO},
+	{0xC014, UNICODE_NORM_QC_NO},
+	{0xC015, UNICODE_NORM_QC_NO},
+	{0xC016, UNICODE_NORM_QC_NO},
+	{0xC017, UNICODE_NORM_QC_NO},
+	{0xC018, UNICODE_NORM_QC_NO},
+	{0xC019, UNICODE_NORM_QC_NO},
+	{0xC01A, UNICODE_NORM_QC_NO},
+	{0xC01B, UNICODE_NORM_QC_NO},
+	{0xC01C, UNICODE_NORM_QC_NO},
+	{0xC01D, UNICODE_NORM_QC_NO},
+	{0xC01E, UNICODE_NORM_QC_NO},
+	{0xC01F, UNICODE_NORM_QC_NO},
+	{0xC020, UNICODE_NORM_QC_NO},
+	{0xC021, UNICODE_NORM_QC_NO},
+	{0xC022, UNICODE_NORM_QC_NO},
+	{0xC023, UNICODE_NORM_QC_NO},
+	{0xC024, UNICODE_NORM_QC_NO},
+	{0xC025, UNICODE_NORM_QC_NO},
+	{0xC026, UNICODE_NORM_QC_NO},
+	{0xC027, UNICODE_NORM_QC_NO},
+	{0xC028, UNICODE_NORM_QC_NO},
+	{0xC029, UNICODE_NORM_QC_NO},
+	{0xC02A, UNICODE_NORM_QC_NO},
+	{0xC02B, UNICODE_NORM_QC_NO},
+	{0xC02C, UNICODE_NORM_QC_NO},
+	{0xC02D, UNICODE_NORM_QC_NO},
+	{0xC02E, UNICODE_NORM_QC_NO},
+	{0xC02F, UNICODE_NORM_QC_NO},
+	{0xC030, UNICODE_NORM_QC_NO},
+	{0xC031, UNICODE_NORM_QC_NO},
+	{0xC032, UNICODE_NORM_QC_NO},
+	{0xC033, UNICODE_NORM_QC_NO},
+	{0xC034, UNICODE_NORM_QC_NO},
+	{0xC035, UNICODE_NORM_QC_NO},
+	{0xC036, UNICODE_NORM_QC_NO},
+	{0xC037, UNICODE_NORM_QC_NO},
+	{0xC038, UNICODE_NORM_QC_NO},
+	{0xC039, UNICODE_NORM_QC_NO},
+	{0xC03A, UNICODE_NORM_QC_NO},
+	{0xC03B, UNICODE_NORM_QC_NO},
+	{0xC03C, UNICODE_NORM_QC_NO},
+	{0xC03D, UNICODE_NORM_QC_NO},
+	{0xC03E, UNICODE_NORM_QC_NO},
+	{0xC03F, UNICODE_NORM_QC_NO},
+	{0xC040, UNICODE_NORM_QC_NO},
+	{0xC041, UNICODE_NORM_QC_NO},
+	{0xC042, UNICODE_NORM_QC_NO},
+	{0xC043, UNICODE_NORM_QC_NO},
+	{0xC044, UNICODE_NORM_QC_NO},
+	{0xC045, UNICODE_NORM_QC_NO},
+	{0xC046, UNICODE_NORM_QC_NO},
+	{0xC047, UNICODE_NORM_QC_NO},
+	{0xC048, UNICODE_NORM_QC_NO},
+	{0xC049, UNICODE_NORM_QC_NO},
+	{0xC04A, UNICODE_NORM_QC_NO},
+	{0xC04B, UNICODE_NORM_QC_NO},
+	{0xC04C, UNICODE_NORM_QC_NO},
+	{0xC04D, UNICODE_NORM_QC_NO},
+	{0xC04E, UNICODE_NORM_QC_NO},
+	{0xC04F, UNICODE_NORM_QC_NO},
+	{0xC050, UNICODE_NORM_QC_NO},
+	{0xC051, UNICODE_NORM_QC_NO},
+	{0xC052, UNICODE_NORM_QC_NO},
+	{0xC053, UNICODE_NORM_QC_NO},
+	{0xC054, UNICODE_NORM_QC_NO},
+	{0xC055, UNICODE_NORM_QC_NO},
+	{0xC056, UNICODE_NORM_QC_NO},
+	{0xC057, UNICODE_NORM_QC_NO},
+	{0xC058, UNICODE_NORM_QC_NO},
+	{0xC059, UNICODE_NORM_QC_NO},
+	{0xC05A, UNICODE_NORM_QC_NO},
+	{0xC05B, UNICODE_NORM_QC_NO},
+	{0xC05C, UNICODE_NORM_QC_NO},
+	{0xC05D, UNICODE_NORM_QC_NO},
+	{0xC05E, UNICODE_NORM_QC_NO},
+	{0xC05F, UNICODE_NORM_QC_NO},
+	{0xC060, UNICODE_NORM_QC_NO},
+	{0xC061, UNICODE_NORM_QC_NO},
+	{0xC062, UNICODE_NORM_QC_NO},
+	{0xC063, UNICODE_NORM_QC_NO},
+	{0xC064, UNICODE_NORM_QC_NO},
+	{0xC065, UNICODE_NORM_QC_NO},
+	{0xC066, UNICODE_NORM_QC_NO},
+	{0xC067, UNICODE_NORM_QC_NO},
+	{0xC068, UNICODE_NORM_QC_NO},
+	{0xC069, UNICODE_NORM_QC_NO},
+	{0xC06A, UNICODE_NORM_QC_NO},
+	{0xC06B, UNICODE_NORM_QC_NO},
+	{0xC06C, UNICODE_NORM_QC_NO},
+	{0xC06D, UNICODE_NORM_QC_NO},
+	{0xC06E, UNICODE_NORM_QC_NO},
+	{0xC06F, UNICODE_NORM_QC_NO},
+	{0xC070, UNICODE_NORM_QC_NO},
+	{0xC071, UNICODE_NORM_QC_NO},
+	{0xC072, UNICODE_NORM_QC_NO},
+	{0xC073, UNICODE_NORM_QC_NO},
+	{0xC074, UNICODE_NORM_QC_NO},
+	{0xC075, UNICODE_NORM_QC_NO},
+	{0xC076, UNICODE_NORM_QC_NO},
+	{0xC077, UNICODE_NORM_QC_NO},
+	{0xC078, UNICODE_NORM_QC_NO},
+	{0xC079, UNICODE_NORM_QC_NO},
+	{0xC07A, UNICODE_NORM_QC_NO},
+	{0xC07B, UNICODE_NORM_QC_NO},
+	{0xC07C, UNICODE_NORM_QC_NO},
+	{0xC07D, UNICODE_NORM_QC_NO},
+	{0xC07E, UNICODE_NORM_QC_NO},
+	{0xC07F, UNICODE_NORM_QC_NO},
+	{0xC080, UNICODE_NORM_QC_NO},
+	{0xC081, UNICODE_NORM_QC_NO},
+	{0xC082, UNICODE_NORM_QC_NO},
+	{0xC083, UNICODE_NORM_QC_NO},
+	{0xC084, UNICODE_NORM_QC_NO},
+	{0xC085, UNICODE_NORM_QC_NO},
+	{0xC086, UNICODE_NORM_QC_NO},
+	{0xC087, UNICODE_NORM_QC_NO},
+	{0xC088, UNICODE_NORM_QC_NO},
+	{0xC089, UNICODE_NORM_QC_NO},
+	{0xC08A, UNICODE_NORM_QC_NO},
+	{0xC08B, UNICODE_NORM_QC_NO},
+	{0xC08C, UNICODE_NORM_QC_NO},
+	{0xC08D, UNICODE_NORM_QC_NO},
+	{0xC08E, UNICODE_NORM_QC_NO},
+	{0xC08F, UNICODE_NORM_QC_NO},
+	{0xC090, UNICODE_NORM_QC_NO},
+	{0xC091, UNICODE_NORM_QC_NO},
+	{0xC092, UNICODE_NORM_QC_NO},
+	{0xC093, UNICODE_NORM_QC_NO},
+	{0xC094, UNICODE_NORM_QC_NO},
+	{0xC095, UNICODE_NORM_QC_NO},
+	{0xC096, UNICODE_NORM_QC_NO},
+	{0xC097, UNICODE_NORM_QC_NO},
+	{0xC098, UNICODE_NORM_QC_NO},
+	{0xC099, UNICODE_NORM_QC_NO},
+	{0xC09A, UNICODE_NORM_QC_NO},
+	{0xC09B, UNICODE_NORM_QC_NO},
+	{0xC09C, UNICODE_NORM_QC_NO},
+	{0xC09D, UNICODE_NORM_QC_NO},
+	{0xC09E, UNICODE_NORM_QC_NO},
+	{0xC09F, UNICODE_NORM_QC_NO},
+	{0xC0A0, UNICODE_NORM_QC_NO},
+	{0xC0A1, UNICODE_NORM_QC_NO},
+	{0xC0A2, UNICODE_NORM_QC_NO},
+	{0xC0A3, UNICODE_NORM_QC_NO},
+	{0xC0A4, UNICODE_NORM_QC_NO},
+	{0xC0A5, UNICODE_NORM_QC_NO},
+	{0xC0A6, UNICODE_NORM_QC_NO},
+	{0xC0A7, UNICODE_NORM_QC_NO},
+	{0xC0A8, UNICODE_NORM_QC_NO},
+	{0xC0A9, UNICODE_NORM_QC_NO},
+	{0xC0AA, UNICODE_NORM_QC_NO},
+	{0xC0AB, UNICODE_NORM_QC_NO},
+	{0xC0AC, UNICODE_NORM_QC_NO},
+	{0xC0AD, UNICODE_NORM_QC_NO},
+	{0xC0AE, UNICODE_NORM_QC_NO},
+	{0xC0AF, UNICODE_NORM_QC_NO},
+	{0xC0B0, UNICODE_NORM_QC_NO},
+	{0xC0B1, UNICODE_NORM_QC_NO},
+	{0xC0B2, UNICODE_NORM_QC_NO},
+	{0xC0B3, UNICODE_NORM_QC_NO},
+	{0xC0B4, UNICODE_NORM_QC_NO},
+	{0xC0B5, UNICODE_NORM_QC_NO},
+	{0xC0B6, UNICODE_NORM_QC_NO},
+	{0xC0B7, UNICODE_NORM_QC_NO},
+	{0xC0B8, UNICODE_NORM_QC_NO},
+	{0xC0B9, UNICODE_NORM_QC_NO},
+	{0xC0BA, UNICODE_NORM_QC_NO},
+	{0xC0BB, UNICODE_NORM_QC_NO},
+	{0xC0BC, UNICODE_NORM_QC_NO},
+	{0xC0BD, UNICODE_NORM_QC_NO},
+	{0xC0BE, UNICODE_NORM_QC_NO},
+	{0xC0BF, UNICODE_NORM_QC_NO},
+	{0xC0C0, UNICODE_NORM_QC_NO},
+	{0xC0C1, UNICODE_NORM_QC_NO},
+	{0xC0C2, UNICODE_NORM_QC_NO},
+	{0xC0C3, UNICODE_NORM_QC_NO},
+	{0xC0C4, UNICODE_NORM_QC_NO},
+	{0xC0C5, UNICODE_NORM_QC_NO},
+	{0xC0C6, UNICODE_NORM_QC_NO},
+	{0xC0C7, UNICODE_NORM_QC_NO},
+	{0xC0C8, UNICODE_NORM_QC_NO},
+	{0xC0C9, UNICODE_NORM_QC_NO},
+	{0xC0CA, UNICODE_NORM_QC_NO},
+	{0xC0CB, UNICODE_NORM_QC_NO},
+	{0xC0CC, UNICODE_NORM_QC_NO},
+	{0xC0CD, UNICODE_NORM_QC_NO},
+	{0xC0CE, UNICODE_NORM_QC_NO},
+	{0xC0CF, UNICODE_NORM_QC_NO},
+	{0xC0D0, UNICODE_NORM_QC_NO},
+	{0xC0D1, UNICODE_NORM_QC_NO},
+	{0xC0D2, UNICODE_NORM_QC_NO},
+	{0xC0D3, UNICODE_NORM_QC_NO},
+	{0xC0D4, UNICODE_NORM_QC_NO},
+	{0xC0D5, UNICODE_NORM_QC_NO},
+	{0xC0D6, UNICODE_NORM_QC_NO},
+	{0xC0D7, UNICODE_NORM_QC_NO},
+	{0xC0D8, UNICODE_NORM_QC_NO},
+	{0xC0D9, UNICODE_NORM_QC_NO},
+	{0xC0DA, UNICODE_NORM_QC_NO},
+	{0xC0DB, UNICODE_NORM_QC_NO},
+	{0xC0DC, UNICODE_NORM_QC_NO},
+	{0xC0DD, UNICODE_NORM_QC_NO},
+	{0xC0DE, UNICODE_NORM_QC_NO},
+	{0xC0DF, UNICODE_NORM_QC_NO},
+	{0xC0E0, UNICODE_NORM_QC_NO},
+	{0xC0E1, UNICODE_NORM_QC_NO},
+	{0xC0E2, UNICODE_NORM_QC_NO},
+	{0xC0E3, UNICODE_NORM_QC_NO},
+	{0xC0E4, UNICODE_NORM_QC_NO},
+	{0xC0E5, UNICODE_NORM_QC_NO},
+	{0xC0E6, UNICODE_NORM_QC_NO},
+	{0xC0E7, UNICODE_NORM_QC_NO},
+	{0xC0E8, UNICODE_NORM_QC_NO},
+	{0xC0E9, UNICODE_NORM_QC_NO},
+	{0xC0EA, UNICODE_NORM_QC_NO},
+	{0xC0EB, UNICODE_NORM_QC_NO},
+	{0xC0EC, UNICODE_NORM_QC_NO},
+	{0xC0ED, UNICODE_NORM_QC_NO},
+	{0xC0EE, UNICODE_NORM_QC_NO},
+	{0xC0EF, UNICODE_NORM_QC_NO},
+	{0xC0F0, UNICODE_NORM_QC_NO},
+	{0xC0F1, UNICODE_NORM_QC_NO},
+	{0xC0F2, UNICODE_NORM_QC_NO},
+	{0xC0F3, UNICODE_NORM_QC_NO},
+	{0xC0F4, UNICODE_NORM_QC_NO},
+	{0xC0F5, UNICODE_NORM_QC_NO},
+	{0xC0F6, UNICODE_NORM_QC_NO},
+	{0xC0F7, UNICODE_NORM_QC_NO},
+	{0xC0F8, UNICODE_NORM_QC_NO},
+	{0xC0F9, UNICODE_NORM_QC_NO},
+	{0xC0FA, UNICODE_NORM_QC_NO},
+	{0xC0FB, UNICODE_NORM_QC_NO},
+	{0xC0FC, UNICODE_NORM_QC_NO},
+	{0xC0FD, UNICODE_NORM_QC_NO},
+	{0xC0FE, UNICODE_NORM_QC_NO},
+	{0xC0FF, UNICODE_NORM_QC_NO},
+	{0xC100, UNICODE_NORM_QC_NO},
+	{0xC101, UNICODE_NORM_QC_NO},
+	{0xC102, UNICODE_NORM_QC_NO},
+	{0xC103, UNICODE_NORM_QC_NO},
+	{0xC104, UNICODE_NORM_QC_NO},
+	{0xC105, UNICODE_NORM_QC_NO},
+	{0xC106, UNICODE_NORM_QC_NO},
+	{0xC107, UNICODE_NORM_QC_NO},
+	{0xC108, UNICODE_NORM_QC_NO},
+	{0xC109, UNICODE_NORM_QC_NO},
+	{0xC10A, UNICODE_NORM_QC_NO},
+	{0xC10B, UNICODE_NORM_QC_NO},
+	{0xC10C, UNICODE_NORM_QC_NO},
+	{0xC10D, UNICODE_NORM_QC_NO},
+	{0xC10E, UNICODE_NORM_QC_NO},
+	{0xC10F, UNICODE_NORM_QC_NO},
+	{0xC110, UNICODE_NORM_QC_NO},
+	{0xC111, UNICODE_NORM_QC_NO},
+	{0xC112, UNICODE_NORM_QC_NO},
+	{0xC113, UNICODE_NORM_QC_NO},
+	{0xC114, UNICODE_NORM_QC_NO},
+	{0xC115, UNICODE_NORM_QC_NO},
+	{0xC116, UNICODE_NORM_QC_NO},
+	{0xC117, UNICODE_NORM_QC_NO},
+	{0xC118, UNICODE_NORM_QC_NO},
+	{0xC119, UNICODE_NORM_QC_NO},
+	{0xC11A, UNICODE_NORM_QC_NO},
+	{0xC11B, UNICODE_NORM_QC_NO},
+	{0xC11C, UNICODE_NORM_QC_NO},
+	{0xC11D, UNICODE_NORM_QC_NO},
+	{0xC11E, UNICODE_NORM_QC_NO},
+	{0xC11F, UNICODE_NORM_QC_NO},
+	{0xC120, UNICODE_NORM_QC_NO},
+	{0xC121, UNICODE_NORM_QC_NO},
+	{0xC122, UNICODE_NORM_QC_NO},
+	{0xC123, UNICODE_NORM_QC_NO},
+	{0xC124, UNICODE_NORM_QC_NO},
+	{0xC125, UNICODE_NORM_QC_NO},
+	{0xC126, UNICODE_NORM_QC_NO},
+	{0xC127, UNICODE_NORM_QC_NO},
+	{0xC128, UNICODE_NORM_QC_NO},
+	{0xC129, UNICODE_NORM_QC_NO},
+	{0xC12A, UNICODE_NORM_QC_NO},
+	{0xC12B, UNICODE_NORM_QC_NO},
+	{0xC12C, UNICODE_NORM_QC_NO},
+	{0xC12D, UNICODE_NORM_QC_NO},
+	{0xC12E, UNICODE_NORM_QC_NO},
+	{0xC12F, UNICODE_NORM_QC_NO},
+	{0xC130, UNICODE_NORM_QC_NO},
+	{0xC131, UNICODE_NORM_QC_NO},
+	{0xC132, UNICODE_NORM_QC_NO},
+	{0xC133, UNICODE_NORM_QC_NO},
+	{0xC134, UNICODE_NORM_QC_NO},
+	{0xC135, UNICODE_NORM_QC_NO},
+	{0xC136, UNICODE_NORM_QC_NO},
+	{0xC137, UNICODE_NORM_QC_NO},
+	{0xC138, UNICODE_NORM_QC_NO},
+	{0xC139, UNICODE_NORM_QC_NO},
+	{0xC13A, UNICODE_NORM_QC_NO},
+	{0xC13B, UNICODE_NORM_QC_NO},
+	{0xC13C, UNICODE_NORM_QC_NO},
+	{0xC13D, UNICODE_NORM_QC_NO},
+	{0xC13E, UNICODE_NORM_QC_NO},
+	{0xC13F, UNICODE_NORM_QC_NO},
+	{0xC140, UNICODE_NORM_QC_NO},
+	{0xC141, UNICODE_NORM_QC_NO},
+	{0xC142, UNICODE_NORM_QC_NO},
+	{0xC143, UNICODE_NORM_QC_NO},
+	{0xC144, UNICODE_NORM_QC_NO},
+	{0xC145, UNICODE_NORM_QC_NO},
+	{0xC146, UNICODE_NORM_QC_NO},
+	{0xC147, UNICODE_NORM_QC_NO},
+	{0xC148, UNICODE_NORM_QC_NO},
+	{0xC149, UNICODE_NORM_QC_NO},
+	{0xC14A, UNICODE_NORM_QC_NO},
+	{0xC14B, UNICODE_NORM_QC_NO},
+	{0xC14C, UNICODE_NORM_QC_NO},
+	{0xC14D, UNICODE_NORM_QC_NO},
+	{0xC14E, UNICODE_NORM_QC_NO},
+	{0xC14F, UNICODE_NORM_QC_NO},
+	{0xC150, UNICODE_NORM_QC_NO},
+	{0xC151, UNICODE_NORM_QC_NO},
+	{0xC152, UNICODE_NORM_QC_NO},
+	{0xC153, UNICODE_NORM_QC_NO},
+	{0xC154, UNICODE_NORM_QC_NO},
+	{0xC155, UNICODE_NORM_QC_NO},
+	{0xC156, UNICODE_NORM_QC_NO},
+	{0xC157, UNICODE_NORM_QC_NO},
+	{0xC158, UNICODE_NORM_QC_NO},
+	{0xC159, UNICODE_NORM_QC_NO},
+	{0xC15A, UNICODE_NORM_QC_NO},
+	{0xC15B, UNICODE_NORM_QC_NO},
+	{0xC15C, UNICODE_NORM_QC_NO},
+	{0xC15D, UNICODE_NORM_QC_NO},
+	{0xC15E, UNICODE_NORM_QC_NO},
+	{0xC15F, UNICODE_NORM_QC_NO},
+	{0xC160, UNICODE_NORM_QC_NO},
+	{0xC161, UNICODE_NORM_QC_NO},
+	{0xC162, UNICODE_NORM_QC_NO},
+	{0xC163, UNICODE_NORM_QC_NO},
+	{0xC164, UNICODE_NORM_QC_NO},
+	{0xC165, UNICODE_NORM_QC_NO},
+	{0xC166, UNICODE_NORM_QC_NO},
+	{0xC167, UNICODE_NORM_QC_NO},
+	{0xC168, UNICODE_NORM_QC_NO},
+	{0xC169, UNICODE_NORM_QC_NO},
+	{0xC16A, UNICODE_NORM_QC_NO},
+	{0xC16B, UNICODE_NORM_QC_NO},
+	{0xC16C, UNICODE_NORM_QC_NO},
+	{0xC16D, UNICODE_NORM_QC_NO},
+	{0xC16E, UNICODE_NORM_QC_NO},
+	{0xC16F, UNICODE_NORM_QC_NO},
+	{0xC170, UNICODE_NORM_QC_NO},
+	{0xC171, UNICODE_NORM_QC_NO},
+	{0xC172, UNICODE_NORM_QC_NO},
+	{0xC173, UNICODE_NORM_QC_NO},
+	{0xC174, UNICODE_NORM_QC_NO},
+	{0xC175, UNICODE_NORM_QC_NO},
+	{0xC176, UNICODE_NORM_QC_NO},
+	{0xC177, UNICODE_NORM_QC_NO},
+	{0xC178, UNICODE_NORM_QC_NO},
+	{0xC179, UNICODE_NORM_QC_NO},
+	{0xC17A, UNICODE_NORM_QC_NO},
+	{0xC17B, UNICODE_NORM_QC_NO},
+	{0xC17C, UNICODE_NORM_QC_NO},
+	{0xC17D, UNICODE_NORM_QC_NO},
+	{0xC17E, UNICODE_NORM_QC_NO},
+	{0xC17F, UNICODE_NORM_QC_NO},
+	{0xC180, UNICODE_NORM_QC_NO},
+	{0xC181, UNICODE_NORM_QC_NO},
+	{0xC182, UNICODE_NORM_QC_NO},
+	{0xC183, UNICODE_NORM_QC_NO},
+	{0xC184, UNICODE_NORM_QC_NO},
+	{0xC185, UNICODE_NORM_QC_NO},
+	{0xC186, UNICODE_NORM_QC_NO},
+	{0xC187, UNICODE_NORM_QC_NO},
+	{0xC188, UNICODE_NORM_QC_NO},
+	{0xC189, UNICODE_NORM_QC_NO},
+	{0xC18A, UNICODE_NORM_QC_NO},
+	{0xC18B, UNICODE_NORM_QC_NO},
+	{0xC18C, UNICODE_NORM_QC_NO},
+	{0xC18D, UNICODE_NORM_QC_NO},
+	{0xC18E, UNICODE_NORM_QC_NO},
+	{0xC18F, UNICODE_NORM_QC_NO},
+	{0xC190, UNICODE_NORM_QC_NO},
+	{0xC191, UNICODE_NORM_QC_NO},
+	{0xC192, UNICODE_NORM_QC_NO},
+	{0xC193, UNICODE_NORM_QC_NO},
+	{0xC194, UNICODE_NORM_QC_NO},
+	{0xC195, UNICODE_NORM_QC_NO},
+	{0xC196, UNICODE_NORM_QC_NO},
+	{0xC197, UNICODE_NORM_QC_NO},
+	{0xC198, UNICODE_NORM_QC_NO},
+	{0xC199, UNICODE_NORM_QC_NO},
+	{0xC19A, UNICODE_NORM_QC_NO},
+	{0xC19B, UNICODE_NORM_QC_NO},
+	{0xC19C, UNICODE_NORM_QC_NO},
+	{0xC19D, UNICODE_NORM_QC_NO},
+	{0xC19E, UNICODE_NORM_QC_NO},
+	{0xC19F, UNICODE_NORM_QC_NO},
+	{0xC1A0, UNICODE_NORM_QC_NO},
+	{0xC1A1, UNICODE_NORM_QC_NO},
+	{0xC1A2, UNICODE_NORM_QC_NO},
+	{0xC1A3, UNICODE_NORM_QC_NO},
+	{0xC1A4, UNICODE_NORM_QC_NO},
+	{0xC1A5, UNICODE_NORM_QC_NO},
+	{0xC1A6, UNICODE_NORM_QC_NO},
+	{0xC1A7, UNICODE_NORM_QC_NO},
+	{0xC1A8, UNICODE_NORM_QC_NO},
+	{0xC1A9, UNICODE_NORM_QC_NO},
+	{0xC1AA, UNICODE_NORM_QC_NO},
+	{0xC1AB, UNICODE_NORM_QC_NO},
+	{0xC1AC, UNICODE_NORM_QC_NO},
+	{0xC1AD, UNICODE_NORM_QC_NO},
+	{0xC1AE, UNICODE_NORM_QC_NO},
+	{0xC1AF, UNICODE_NORM_QC_NO},
+	{0xC1B0, UNICODE_NORM_QC_NO},
+	{0xC1B1, UNICODE_NORM_QC_NO},
+	{0xC1B2, UNICODE_NORM_QC_NO},
+	{0xC1B3, UNICODE_NORM_QC_NO},
+	{0xC1B4, UNICODE_NORM_QC_NO},
+	{0xC1B5, UNICODE_NORM_QC_NO},
+	{0xC1B6, UNICODE_NORM_QC_NO},
+	{0xC1B7, UNICODE_NORM_QC_NO},
+	{0xC1B8, UNICODE_NORM_QC_NO},
+	{0xC1B9, UNICODE_NORM_QC_NO},
+	{0xC1BA, UNICODE_NORM_QC_NO},
+	{0xC1BB, UNICODE_NORM_QC_NO},
+	{0xC1BC, UNICODE_NORM_QC_NO},
+	{0xC1BD, UNICODE_NORM_QC_NO},
+	{0xC1BE, UNICODE_NORM_QC_NO},
+	{0xC1BF, UNICODE_NORM_QC_NO},
+	{0xC1C0, UNICODE_NORM_QC_NO},
+	{0xC1C1, UNICODE_NORM_QC_NO},
+	{0xC1C2, UNICODE_NORM_QC_NO},
+	{0xC1C3, UNICODE_NORM_QC_NO},
+	{0xC1C4, UNICODE_NORM_QC_NO},
+	{0xC1C5, UNICODE_NORM_QC_NO},
+	{0xC1C6, UNICODE_NORM_QC_NO},
+	{0xC1C7, UNICODE_NORM_QC_NO},
+	{0xC1C8, UNICODE_NORM_QC_NO},
+	{0xC1C9, UNICODE_NORM_QC_NO},
+	{0xC1CA, UNICODE_NORM_QC_NO},
+	{0xC1CB, UNICODE_NORM_QC_NO},
+	{0xC1CC, UNICODE_NORM_QC_NO},
+	{0xC1CD, UNICODE_NORM_QC_NO},
+	{0xC1CE, UNICODE_NORM_QC_NO},
+	{0xC1CF, UNICODE_NORM_QC_NO},
+	{0xC1D0, UNICODE_NORM_QC_NO},
+	{0xC1D1, UNICODE_NORM_QC_NO},
+	{0xC1D2, UNICODE_NORM_QC_NO},
+	{0xC1D3, UNICODE_NORM_QC_NO},
+	{0xC1D4, UNICODE_NORM_QC_NO},
+	{0xC1D5, UNICODE_NORM_QC_NO},
+	{0xC1D6, UNICODE_NORM_QC_NO},
+	{0xC1D7, UNICODE_NORM_QC_NO},
+	{0xC1D8, UNICODE_NORM_QC_NO},
+	{0xC1D9, UNICODE_NORM_QC_NO},
+	{0xC1DA, UNICODE_NORM_QC_NO},
+	{0xC1DB, UNICODE_NORM_QC_NO},
+	{0xC1DC, UNICODE_NORM_QC_NO},
+	{0xC1DD, UNICODE_NORM_QC_NO},
+	{0xC1DE, UNICODE_NORM_QC_NO},
+	{0xC1DF, UNICODE_NORM_QC_NO},
+	{0xC1E0, UNICODE_NORM_QC_NO},
+	{0xC1E1, UNICODE_NORM_QC_NO},
+	{0xC1E2, UNICODE_NORM_QC_NO},
+	{0xC1E3, UNICODE_NORM_QC_NO},
+	{0xC1E4, UNICODE_NORM_QC_NO},
+	{0xC1E5, UNICODE_NORM_QC_NO},
+	{0xC1E6, UNICODE_NORM_QC_NO},
+	{0xC1E7, UNICODE_NORM_QC_NO},
+	{0xC1E8, UNICODE_NORM_QC_NO},
+	{0xC1E9, UNICODE_NORM_QC_NO},
+	{0xC1EA, UNICODE_NORM_QC_NO},
+	{0xC1EB, UNICODE_NORM_QC_NO},
+	{0xC1EC, UNICODE_NORM_QC_NO},
+	{0xC1ED, UNICODE_NORM_QC_NO},
+	{0xC1EE, UNICODE_NORM_QC_NO},
+	{0xC1EF, UNICODE_NORM_QC_NO},
+	{0xC1F0, UNICODE_NORM_QC_NO},
+	{0xC1F1, UNICODE_NORM_QC_NO},
+	{0xC1F2, UNICODE_NORM_QC_NO},
+	{0xC1F3, UNICODE_NORM_QC_NO},
+	{0xC1F4, UNICODE_NORM_QC_NO},
+	{0xC1F5, UNICODE_NORM_QC_NO},
+	{0xC1F6, UNICODE_NORM_QC_NO},
+	{0xC1F7, UNICODE_NORM_QC_NO},
+	{0xC1F8, UNICODE_NORM_QC_NO},
+	{0xC1F9, UNICODE_NORM_QC_NO},
+	{0xC1FA, UNICODE_NORM_QC_NO},
+	{0xC1FB, UNICODE_NORM_QC_NO},
+	{0xC1FC, UNICODE_NORM_QC_NO},
+	{0xC1FD, UNICODE_NORM_QC_NO},
+	{0xC1FE, UNICODE_NORM_QC_NO},
+	{0xC1FF, UNICODE_NORM_QC_NO},
+	{0xC200, UNICODE_NORM_QC_NO},
+	{0xC201, UNICODE_NORM_QC_NO},
+	{0xC202, UNICODE_NORM_QC_NO},
+	{0xC203, UNICODE_NORM_QC_NO},
+	{0xC204, UNICODE_NORM_QC_NO},
+	{0xC205, UNICODE_NORM_QC_NO},
+	{0xC206, UNICODE_NORM_QC_NO},
+	{0xC207, UNICODE_NORM_QC_NO},
+	{0xC208, UNICODE_NORM_QC_NO},
+	{0xC209, UNICODE_NORM_QC_NO},
+	{0xC20A, UNICODE_NORM_QC_NO},
+	{0xC20B, UNICODE_NORM_QC_NO},
+	{0xC20C, UNICODE_NORM_QC_NO},
+	{0xC20D, UNICODE_NORM_QC_NO},
+	{0xC20E, UNICODE_NORM_QC_NO},
+	{0xC20F, UNICODE_NORM_QC_NO},
+	{0xC210, UNICODE_NORM_QC_NO},
+	{0xC211, UNICODE_NORM_QC_NO},
+	{0xC212, UNICODE_NORM_QC_NO},
+	{0xC213, UNICODE_NORM_QC_NO},
+	{0xC214, UNICODE_NORM_QC_NO},
+	{0xC215, UNICODE_NORM_QC_NO},
+	{0xC216, UNICODE_NORM_QC_NO},
+	{0xC217, UNICODE_NORM_QC_NO},
+	{0xC218, UNICODE_NORM_QC_NO},
+	{0xC219, UNICODE_NORM_QC_NO},
+	{0xC21A, UNICODE_NORM_QC_NO},
+	{0xC21B, UNICODE_NORM_QC_NO},
+	{0xC21C, UNICODE_NORM_QC_NO},
+	{0xC21D, UNICODE_NORM_QC_NO},
+	{0xC21E, UNICODE_NORM_QC_NO},
+	{0xC21F, UNICODE_NORM_QC_NO},
+	{0xC220, UNICODE_NORM_QC_NO},
+	{0xC221, UNICODE_NORM_QC_NO},
+	{0xC222, UNICODE_NORM_QC_NO},
+	{0xC223, UNICODE_NORM_QC_NO},
+	{0xC224, UNICODE_NORM_QC_NO},
+	{0xC225, UNICODE_NORM_QC_NO},
+	{0xC226, UNICODE_NORM_QC_NO},
+	{0xC227, UNICODE_NORM_QC_NO},
+	{0xC228, UNICODE_NORM_QC_NO},
+	{0xC229, UNICODE_NORM_QC_NO},
+	{0xC22A, UNICODE_NORM_QC_NO},
+	{0xC22B, UNICODE_NORM_QC_NO},
+	{0xC22C, UNICODE_NORM_QC_NO},
+	{0xC22D, UNICODE_NORM_QC_NO},
+	{0xC22E, UNICODE_NORM_QC_NO},
+	{0xC22F, UNICODE_NORM_QC_NO},
+	{0xC230, UNICODE_NORM_QC_NO},
+	{0xC231, UNICODE_NORM_QC_NO},
+	{0xC232, UNICODE_NORM_QC_NO},
+	{0xC233, UNICODE_NORM_QC_NO},
+	{0xC234, UNICODE_NORM_QC_NO},
+	{0xC235, UNICODE_NORM_QC_NO},
+	{0xC236, UNICODE_NORM_QC_NO},
+	{0xC237, UNICODE_NORM_QC_NO},
+	{0xC238, UNICODE_NORM_QC_NO},
+	{0xC239, UNICODE_NORM_QC_NO},
+	{0xC23A, UNICODE_NORM_QC_NO},
+	{0xC23B, UNICODE_NORM_QC_NO},
+	{0xC23C, UNICODE_NORM_QC_NO},
+	{0xC23D, UNICODE_NORM_QC_NO},
+	{0xC23E, UNICODE_NORM_QC_NO},
+	{0xC23F, UNICODE_NORM_QC_NO},
+	{0xC240, UNICODE_NORM_QC_NO},
+	{0xC241, UNICODE_NORM_QC_NO},
+	{0xC242, UNICODE_NORM_QC_NO},
+	{0xC243, UNICODE_NORM_QC_NO},
+	{0xC244, UNICODE_NORM_QC_NO},
+	{0xC245, UNICODE_NORM_QC_NO},
+	{0xC246, UNICODE_NORM_QC_NO},
+	{0xC247, UNICODE_NORM_QC_NO},
+	{0xC248, UNICODE_NORM_QC_NO},
+	{0xC249, UNICODE_NORM_QC_NO},
+	{0xC24A, UNICODE_NORM_QC_NO},
+	{0xC24B, UNICODE_NORM_QC_NO},
+	{0xC24C, UNICODE_NORM_QC_NO},
+	{0xC24D, UNICODE_NORM_QC_NO},
+	{0xC24E, UNICODE_NORM_QC_NO},
+	{0xC24F, UNICODE_NORM_QC_NO},
+	{0xC250, UNICODE_NORM_QC_NO},
+	{0xC251, UNICODE_NORM_QC_NO},
+	{0xC252, UNICODE_NORM_QC_NO},
+	{0xC253, UNICODE_NORM_QC_NO},
+	{0xC254, UNICODE_NORM_QC_NO},
+	{0xC255, UNICODE_NORM_QC_NO},
+	{0xC256, UNICODE_NORM_QC_NO},
+	{0xC257, UNICODE_NORM_QC_NO},
+	{0xC258, UNICODE_NORM_QC_NO},
+	{0xC259, UNICODE_NORM_QC_NO},
+	{0xC25A, UNICODE_NORM_QC_NO},
+	{0xC25B, UNICODE_NORM_QC_NO},
+	{0xC25C, UNICODE_NORM_QC_NO},
+	{0xC25D, UNICODE_NORM_QC_NO},
+	{0xC25E, UNICODE_NORM_QC_NO},
+	{0xC25F, UNICODE_NORM_QC_NO},
+	{0xC260, UNICODE_NORM_QC_NO},
+	{0xC261, UNICODE_NORM_QC_NO},
+	{0xC262, UNICODE_NORM_QC_NO},
+	{0xC263, UNICODE_NORM_QC_NO},
+	{0xC264, UNICODE_NORM_QC_NO},
+	{0xC265, UNICODE_NORM_QC_NO},
+	{0xC266, UNICODE_NORM_QC_NO},
+	{0xC267, UNICODE_NORM_QC_NO},
+	{0xC268, UNICODE_NORM_QC_NO},
+	{0xC269, UNICODE_NORM_QC_NO},
+	{0xC26A, UNICODE_NORM_QC_NO},
+	{0xC26B, UNICODE_NORM_QC_NO},
+	{0xC26C, UNICODE_NORM_QC_NO},
+	{0xC26D, UNICODE_NORM_QC_NO},
+	{0xC26E, UNICODE_NORM_QC_NO},
+	{0xC26F, UNICODE_NORM_QC_NO},
+	{0xC270, UNICODE_NORM_QC_NO},
+	{0xC271, UNICODE_NORM_QC_NO},
+	{0xC272, UNICODE_NORM_QC_NO},
+	{0xC273, UNICODE_NORM_QC_NO},
+	{0xC274, UNICODE_NORM_QC_NO},
+	{0xC275, UNICODE_NORM_QC_NO},
+	{0xC276, UNICODE_NORM_QC_NO},
+	{0xC277, UNICODE_NORM_QC_NO},
+	{0xC278, UNICODE_NORM_QC_NO},
+	{0xC279, UNICODE_NORM_QC_NO},
+	{0xC27A, UNICODE_NORM_QC_NO},
+	{0xC27B, UNICODE_NORM_QC_NO},
+	{0xC27C, UNICODE_NORM_QC_NO},
+	{0xC27D, UNICODE_NORM_QC_NO},
+	{0xC27E, UNICODE_NORM_QC_NO},
+	{0xC27F, UNICODE_NORM_QC_NO},
+	{0xC280, UNICODE_NORM_QC_NO},
+	{0xC281, UNICODE_NORM_QC_NO},
+	{0xC282, UNICODE_NORM_QC_NO},
+	{0xC283, UNICODE_NORM_QC_NO},
+	{0xC284, UNICODE_NORM_QC_NO},
+	{0xC285, UNICODE_NORM_QC_NO},
+	{0xC286, UNICODE_NORM_QC_NO},
+	{0xC287, UNICODE_NORM_QC_NO},
+	{0xC288, UNICODE_NORM_QC_NO},
+	{0xC289, UNICODE_NORM_QC_NO},
+	{0xC28A, UNICODE_NORM_QC_NO},
+	{0xC28B, UNICODE_NORM_QC_NO},
+	{0xC28C, UNICODE_NORM_QC_NO},
+	{0xC28D, UNICODE_NORM_QC_NO},
+	{0xC28E, UNICODE_NORM_QC_NO},
+	{0xC28F, UNICODE_NORM_QC_NO},
+	{0xC290, UNICODE_NORM_QC_NO},
+	{0xC291, UNICODE_NORM_QC_NO},
+	{0xC292, UNICODE_NORM_QC_NO},
+	{0xC293, UNICODE_NORM_QC_NO},
+	{0xC294, UNICODE_NORM_QC_NO},
+	{0xC295, UNICODE_NORM_QC_NO},
+	{0xC296, UNICODE_NORM_QC_NO},
+	{0xC297, UNICODE_NORM_QC_NO},
+	{0xC298, UNICODE_NORM_QC_NO},
+	{0xC299, UNICODE_NORM_QC_NO},
+	{0xC29A, UNICODE_NORM_QC_NO},
+	{0xC29B, UNICODE_NORM_QC_NO},
+	{0xC29C, UNICODE_NORM_QC_NO},
+	{0xC29D, UNICODE_NORM_QC_NO},
+	{0xC29E, UNICODE_NORM_QC_NO},
+	{0xC29F, UNICODE_NORM_QC_NO},
+	{0xC2A0, UNICODE_NORM_QC_NO},
+	{0xC2A1, UNICODE_NORM_QC_NO},
+	{0xC2A2, UNICODE_NORM_QC_NO},
+	{0xC2A3, UNICODE_NORM_QC_NO},
+	{0xC2A4, UNICODE_NORM_QC_NO},
+	{0xC2A5, UNICODE_NORM_QC_NO},
+	{0xC2A6, UNICODE_NORM_QC_NO},
+	{0xC2A7, UNICODE_NORM_QC_NO},
+	{0xC2A8, UNICODE_NORM_QC_NO},
+	{0xC2A9, UNICODE_NORM_QC_NO},
+	{0xC2AA, UNICODE_NORM_QC_NO},
+	{0xC2AB, UNICODE_NORM_QC_NO},
+	{0xC2AC, UNICODE_NORM_QC_NO},
+	{0xC2AD, UNICODE_NORM_QC_NO},
+	{0xC2AE, UNICODE_NORM_QC_NO},
+	{0xC2AF, UNICODE_NORM_QC_NO},
+	{0xC2B0, UNICODE_NORM_QC_NO},
+	{0xC2B1, UNICODE_NORM_QC_NO},
+	{0xC2B2, UNICODE_NORM_QC_NO},
+	{0xC2B3, UNICODE_NORM_QC_NO},
+	{0xC2B4, UNICODE_NORM_QC_NO},
+	{0xC2B5, UNICODE_NORM_QC_NO},
+	{0xC2B6, UNICODE_NORM_QC_NO},
+	{0xC2B7, UNICODE_NORM_QC_NO},
+	{0xC2B8, UNICODE_NORM_QC_NO},
+	{0xC2B9, UNICODE_NORM_QC_NO},
+	{0xC2BA, UNICODE_NORM_QC_NO},
+	{0xC2BB, UNICODE_NORM_QC_NO},
+	{0xC2BC, UNICODE_NORM_QC_NO},
+	{0xC2BD, UNICODE_NORM_QC_NO},
+	{0xC2BE, UNICODE_NORM_QC_NO},
+	{0xC2BF, UNICODE_NORM_QC_NO},
+	{0xC2C0, UNICODE_NORM_QC_NO},
+	{0xC2C1, UNICODE_NORM_QC_NO},
+	{0xC2C2, UNICODE_NORM_QC_NO},
+	{0xC2C3, UNICODE_NORM_QC_NO},
+	{0xC2C4, UNICODE_NORM_QC_NO},
+	{0xC2C5, UNICODE_NORM_QC_NO},
+	{0xC2C6, UNICODE_NORM_QC_NO},
+	{0xC2C7, UNICODE_NORM_QC_NO},
+	{0xC2C8, UNICODE_NORM_QC_NO},
+	{0xC2C9, UNICODE_NORM_QC_NO},
+	{0xC2CA, UNICODE_NORM_QC_NO},
+	{0xC2CB, UNICODE_NORM_QC_NO},
+	{0xC2CC, UNICODE_NORM_QC_NO},
+	{0xC2CD, UNICODE_NORM_QC_NO},
+	{0xC2CE, UNICODE_NORM_QC_NO},
+	{0xC2CF, UNICODE_NORM_QC_NO},
+	{0xC2D0, UNICODE_NORM_QC_NO},
+	{0xC2D1, UNICODE_NORM_QC_NO},
+	{0xC2D2, UNICODE_NORM_QC_NO},
+	{0xC2D3, UNICODE_NORM_QC_NO},
+	{0xC2D4, UNICODE_NORM_QC_NO},
+	{0xC2D5, UNICODE_NORM_QC_NO},
+	{0xC2D6, UNICODE_NORM_QC_NO},
+	{0xC2D7, UNICODE_NORM_QC_NO},
+	{0xC2D8, UNICODE_NORM_QC_NO},
+	{0xC2D9, UNICODE_NORM_QC_NO},
+	{0xC2DA, UNICODE_NORM_QC_NO},
+	{0xC2DB, UNICODE_NORM_QC_NO},
+	{0xC2DC, UNICODE_NORM_QC_NO},
+	{0xC2DD, UNICODE_NORM_QC_NO},
+	{0xC2DE, UNICODE_NORM_QC_NO},
+	{0xC2DF, UNICODE_NORM_QC_NO},
+	{0xC2E0, UNICODE_NORM_QC_NO},
+	{0xC2E1, UNICODE_NORM_QC_NO},
+	{0xC2E2, UNICODE_NORM_QC_NO},
+	{0xC2E3, UNICODE_NORM_QC_NO},
+	{0xC2E4, UNICODE_NORM_QC_NO},
+	{0xC2E5, UNICODE_NORM_QC_NO},
+	{0xC2E6, UNICODE_NORM_QC_NO},
+	{0xC2E7, UNICODE_NORM_QC_NO},
+	{0xC2E8, UNICODE_NORM_QC_NO},
+	{0xC2E9, UNICODE_NORM_QC_NO},
+	{0xC2EA, UNICODE_NORM_QC_NO},
+	{0xC2EB, UNICODE_NORM_QC_NO},
+	{0xC2EC, UNICODE_NORM_QC_NO},
+	{0xC2ED, UNICODE_NORM_QC_NO},
+	{0xC2EE, UNICODE_NORM_QC_NO},
+	{0xC2EF, UNICODE_NORM_QC_NO},
+	{0xC2F0, UNICODE_NORM_QC_NO},
+	{0xC2F1, UNICODE_NORM_QC_NO},
+	{0xC2F2, UNICODE_NORM_QC_NO},
+	{0xC2F3, UNICODE_NORM_QC_NO},
+	{0xC2F4, UNICODE_NORM_QC_NO},
+	{0xC2F5, UNICODE_NORM_QC_NO},
+	{0xC2F6, UNICODE_NORM_QC_NO},
+	{0xC2F7, UNICODE_NORM_QC_NO},
+	{0xC2F8, UNICODE_NORM_QC_NO},
+	{0xC2F9, UNICODE_NORM_QC_NO},
+	{0xC2FA, UNICODE_NORM_QC_NO},
+	{0xC2FB, UNICODE_NORM_QC_NO},
+	{0xC2FC, UNICODE_NORM_QC_NO},
+	{0xC2FD, UNICODE_NORM_QC_NO},
+	{0xC2FE, UNICODE_NORM_QC_NO},
+	{0xC2FF, UNICODE_NORM_QC_NO},
+	{0xC300, UNICODE_NORM_QC_NO},
+	{0xC301, UNICODE_NORM_QC_NO},
+	{0xC302, UNICODE_NORM_QC_NO},
+	{0xC303, UNICODE_NORM_QC_NO},
+	{0xC304, UNICODE_NORM_QC_NO},
+	{0xC305, UNICODE_NORM_QC_NO},
+	{0xC306, UNICODE_NORM_QC_NO},
+	{0xC307, UNICODE_NORM_QC_NO},
+	{0xC308, UNICODE_NORM_QC_NO},
+	{0xC309, UNICODE_NORM_QC_NO},
+	{0xC30A, UNICODE_NORM_QC_NO},
+	{0xC30B, UNICODE_NORM_QC_NO},
+	{0xC30C, UNICODE_NORM_QC_NO},
+	{0xC30D, UNICODE_NORM_QC_NO},
+	{0xC30E, UNICODE_NORM_QC_NO},
+	{0xC30F, UNICODE_NORM_QC_NO},
+	{0xC310, UNICODE_NORM_QC_NO},
+	{0xC311, UNICODE_NORM_QC_NO},
+	{0xC312, UNICODE_NORM_QC_NO},
+	{0xC313, UNICODE_NORM_QC_NO},
+	{0xC314, UNICODE_NORM_QC_NO},
+	{0xC315, UNICODE_NORM_QC_NO},
+	{0xC316, UNICODE_NORM_QC_NO},
+	{0xC317, UNICODE_NORM_QC_NO},
+	{0xC318, UNICODE_NORM_QC_NO},
+	{0xC319, UNICODE_NORM_QC_NO},
+	{0xC31A, UNICODE_NORM_QC_NO},
+	{0xC31B, UNICODE_NORM_QC_NO},
+	{0xC31C, UNICODE_NORM_QC_NO},
+	{0xC31D, UNICODE_NORM_QC_NO},
+	{0xC31E, UNICODE_NORM_QC_NO},
+	{0xC31F, UNICODE_NORM_QC_NO},
+	{0xC320, UNICODE_NORM_QC_NO},
+	{0xC321, UNICODE_NORM_QC_NO},
+	{0xC322, UNICODE_NORM_QC_NO},
+	{0xC323, UNICODE_NORM_QC_NO},
+	{0xC324, UNICODE_NORM_QC_NO},
+	{0xC325, UNICODE_NORM_QC_NO},
+	{0xC326, UNICODE_NORM_QC_NO},
+	{0xC327, UNICODE_NORM_QC_NO},
+	{0xC328, UNICODE_NORM_QC_NO},
+	{0xC329, UNICODE_NORM_QC_NO},
+	{0xC32A, UNICODE_NORM_QC_NO},
+	{0xC32B, UNICODE_NORM_QC_NO},
+	{0xC32C, UNICODE_NORM_QC_NO},
+	{0xC32D, UNICODE_NORM_QC_NO},
+	{0xC32E, UNICODE_NORM_QC_NO},
+	{0xC32F, UNICODE_NORM_QC_NO},
+	{0xC330, UNICODE_NORM_QC_NO},
+	{0xC331, UNICODE_NORM_QC_NO},
+	{0xC332, UNICODE_NORM_QC_NO},
+	{0xC333, UNICODE_NORM_QC_NO},
+	{0xC334, UNICODE_NORM_QC_NO},
+	{0xC335, UNICODE_NORM_QC_NO},
+	{0xC336, UNICODE_NORM_QC_NO},
+	{0xC337, UNICODE_NORM_QC_NO},
+	{0xC338, UNICODE_NORM_QC_NO},
+	{0xC339, UNICODE_NORM_QC_NO},
+	{0xC33A, UNICODE_NORM_QC_NO},
+	{0xC33B, UNICODE_NORM_QC_NO},
+	{0xC33C, UNICODE_NORM_QC_NO},
+	{0xC33D, UNICODE_NORM_QC_NO},
+	{0xC33E, UNICODE_NORM_QC_NO},
+	{0xC33F, UNICODE_NORM_QC_NO},
+	{0xC340, UNICODE_NORM_QC_NO},
+	{0xC341, UNICODE_NORM_QC_NO},
+	{0xC342, UNICODE_NORM_QC_NO},
+	{0xC343, UNICODE_NORM_QC_NO},
+	{0xC344, UNICODE_NORM_QC_NO},
+	{0xC345, UNICODE_NORM_QC_NO},
+	{0xC346, UNICODE_NORM_QC_NO},
+	{0xC347, UNICODE_NORM_QC_NO},
+	{0xC348, UNICODE_NORM_QC_NO},
+	{0xC349, UNICODE_NORM_QC_NO},
+	{0xC34A, UNICODE_NORM_QC_NO},
+	{0xC34B, UNICODE_NORM_QC_NO},
+	{0xC34C, UNICODE_NORM_QC_NO},
+	{0xC34D, UNICODE_NORM_QC_NO},
+	{0xC34E, UNICODE_NORM_QC_NO},
+	{0xC34F, UNICODE_NORM_QC_NO},
+	{0xC350, UNICODE_NORM_QC_NO},
+	{0xC351, UNICODE_NORM_QC_NO},
+	{0xC352, UNICODE_NORM_QC_NO},
+	{0xC353, UNICODE_NORM_QC_NO},
+	{0xC354, UNICODE_NORM_QC_NO},
+	{0xC355, UNICODE_NORM_QC_NO},
+	{0xC356, UNICODE_NORM_QC_NO},
+	{0xC357, UNICODE_NORM_QC_NO},
+	{0xC358, UNICODE_NORM_QC_NO},
+	{0xC359, UNICODE_NORM_QC_NO},
+	{0xC35A, UNICODE_NORM_QC_NO},
+	{0xC35B, UNICODE_NORM_QC_NO},
+	{0xC35C, UNICODE_NORM_QC_NO},
+	{0xC35D, UNICODE_NORM_QC_NO},
+	{0xC35E, UNICODE_NORM_QC_NO},
+	{0xC35F, UNICODE_NORM_QC_NO},
+	{0xC360, UNICODE_NORM_QC_NO},
+	{0xC361, UNICODE_NORM_QC_NO},
+	{0xC362, UNICODE_NORM_QC_NO},
+	{0xC363, UNICODE_NORM_QC_NO},
+	{0xC364, UNICODE_NORM_QC_NO},
+	{0xC365, UNICODE_NORM_QC_NO},
+	{0xC366, UNICODE_NORM_QC_NO},
+	{0xC367, UNICODE_NORM_QC_NO},
+	{0xC368, UNICODE_NORM_QC_NO},
+	{0xC369, UNICODE_NORM_QC_NO},
+	{0xC36A, UNICODE_NORM_QC_NO},
+	{0xC36B, UNICODE_NORM_QC_NO},
+	{0xC36C, UNICODE_NORM_QC_NO},
+	{0xC36D, UNICODE_NORM_QC_NO},
+	{0xC36E, UNICODE_NORM_QC_NO},
+	{0xC36F, UNICODE_NORM_QC_NO},
+	{0xC370, UNICODE_NORM_QC_NO},
+	{0xC371, UNICODE_NORM_QC_NO},
+	{0xC372, UNICODE_NORM_QC_NO},
+	{0xC373, UNICODE_NORM_QC_NO},
+	{0xC374, UNICODE_NORM_QC_NO},
+	{0xC375, UNICODE_NORM_QC_NO},
+	{0xC376, UNICODE_NORM_QC_NO},
+	{0xC377, UNICODE_NORM_QC_NO},
+	{0xC378, UNICODE_NORM_QC_NO},
+	{0xC379, UNICODE_NORM_QC_NO},
+	{0xC37A, UNICODE_NORM_QC_NO},
+	{0xC37B, UNICODE_NORM_QC_NO},
+	{0xC37C, UNICODE_NORM_QC_NO},
+	{0xC37D, UNICODE_NORM_QC_NO},
+	{0xC37E, UNICODE_NORM_QC_NO},
+	{0xC37F, UNICODE_NORM_QC_NO},
+	{0xC380, UNICODE_NORM_QC_NO},
+	{0xC381, UNICODE_NORM_QC_NO},
+	{0xC382, UNICODE_NORM_QC_NO},
+	{0xC383, UNICODE_NORM_QC_NO},
+	{0xC384, UNICODE_NORM_QC_NO},
+	{0xC385, UNICODE_NORM_QC_NO},
+	{0xC386, UNICODE_NORM_QC_NO},
+	{0xC387, UNICODE_NORM_QC_NO},
+	{0xC388, UNICODE_NORM_QC_NO},
+	{0xC389, UNICODE_NORM_QC_NO},
+	{0xC38A, UNICODE_NORM_QC_NO},
+	{0xC38B, UNICODE_NORM_QC_NO},
+	{0xC38C, UNICODE_NORM_QC_NO},
+	{0xC38D, UNICODE_NORM_QC_NO},
+	{0xC38E, UNICODE_NORM_QC_NO},
+	{0xC38F, UNICODE_NORM_QC_NO},
+	{0xC390, UNICODE_NORM_QC_NO},
+	{0xC391, UNICODE_NORM_QC_NO},
+	{0xC392, UNICODE_NORM_QC_NO},
+	{0xC393, UNICODE_NORM_QC_NO},
+	{0xC394, UNICODE_NORM_QC_NO},
+	{0xC395, UNICODE_NORM_QC_NO},
+	{0xC396, UNICODE_NORM_QC_NO},
+	{0xC397, UNICODE_NORM_QC_NO},
+	{0xC398, UNICODE_NORM_QC_NO},
+	{0xC399, UNICODE_NORM_QC_NO},
+	{0xC39A, UNICODE_NORM_QC_NO},
+	{0xC39B, UNICODE_NORM_QC_NO},
+	{0xC39C, UNICODE_NORM_QC_NO},
+	{0xC39D, UNICODE_NORM_QC_NO},
+	{0xC39E, UNICODE_NORM_QC_NO},
+	{0xC39F, UNICODE_NORM_QC_NO},
+	{0xC3A0, UNICODE_NORM_QC_NO},
+	{0xC3A1, UNICODE_NORM_QC_NO},
+	{0xC3A2, UNICODE_NORM_QC_NO},
+	{0xC3A3, UNICODE_NORM_QC_NO},
+	{0xC3A4, UNICODE_NORM_QC_NO},
+	{0xC3A5, UNICODE_NORM_QC_NO},
+	{0xC3A6, UNICODE_NORM_QC_NO},
+	{0xC3A7, UNICODE_NORM_QC_NO},
+	{0xC3A8, UNICODE_NORM_QC_NO},
+	{0xC3A9, UNICODE_NORM_QC_NO},
+	{0xC3AA, UNICODE_NORM_QC_NO},
+	{0xC3AB, UNICODE_NORM_QC_NO},
+	{0xC3AC, UNICODE_NORM_QC_NO},
+	{0xC3AD, UNICODE_NORM_QC_NO},
+	{0xC3AE, UNICODE_NORM_QC_NO},
+	{0xC3AF, UNICODE_NORM_QC_NO},
+	{0xC3B0, UNICODE_NORM_QC_NO},
+	{0xC3B1, UNICODE_NORM_QC_NO},
+	{0xC3B2, UNICODE_NORM_QC_NO},
+	{0xC3B3, UNICODE_NORM_QC_NO},
+	{0xC3B4, UNICODE_NORM_QC_NO},
+	{0xC3B5, UNICODE_NORM_QC_NO},
+	{0xC3B6, UNICODE_NORM_QC_NO},
+	{0xC3B7, UNICODE_NORM_QC_NO},
+	{0xC3B8, UNICODE_NORM_QC_NO},
+	{0xC3B9, UNICODE_NORM_QC_NO},
+	{0xC3BA, UNICODE_NORM_QC_NO},
+	{0xC3BB, UNICODE_NORM_QC_NO},
+	{0xC3BC, UNICODE_NORM_QC_NO},
+	{0xC3BD, UNICODE_NORM_QC_NO},
+	{0xC3BE, UNICODE_NORM_QC_NO},
+	{0xC3BF, UNICODE_NORM_QC_NO},
+	{0xC3C0, UNICODE_NORM_QC_NO},
+	{0xC3C1, UNICODE_NORM_QC_NO},
+	{0xC3C2, UNICODE_NORM_QC_NO},
+	{0xC3C3, UNICODE_NORM_QC_NO},
+	{0xC3C4, UNICODE_NORM_QC_NO},
+	{0xC3C5, UNICODE_NORM_QC_NO},
+	{0xC3C6, UNICODE_NORM_QC_NO},
+	{0xC3C7, UNICODE_NORM_QC_NO},
+	{0xC3C8, UNICODE_NORM_QC_NO},
+	{0xC3C9, UNICODE_NORM_QC_NO},
+	{0xC3CA, UNICODE_NORM_QC_NO},
+	{0xC3CB, UNICODE_NORM_QC_NO},
+	{0xC3CC, UNICODE_NORM_QC_NO},
+	{0xC3CD, UNICODE_NORM_QC_NO},
+	{0xC3CE, UNICODE_NORM_QC_NO},
+	{0xC3CF, UNICODE_NORM_QC_NO},
+	{0xC3D0, UNICODE_NORM_QC_NO},
+	{0xC3D1, UNICODE_NORM_QC_NO},
+	{0xC3D2, UNICODE_NORM_QC_NO},
+	{0xC3D3, UNICODE_NORM_QC_NO},
+	{0xC3D4, UNICODE_NORM_QC_NO},
+	{0xC3D5, UNICODE_NORM_QC_NO},
+	{0xC3D6, UNICODE_NORM_QC_NO},
+	{0xC3D7, UNICODE_NORM_QC_NO},
+	{0xC3D8, UNICODE_NORM_QC_NO},
+	{0xC3D9, UNICODE_NORM_QC_NO},
+	{0xC3DA, UNICODE_NORM_QC_NO},
+	{0xC3DB, UNICODE_NORM_QC_NO},
+	{0xC3DC, UNICODE_NORM_QC_NO},
+	{0xC3DD, UNICODE_NORM_QC_NO},
+	{0xC3DE, UNICODE_NORM_QC_NO},
+	{0xC3DF, UNICODE_NORM_QC_NO},
+	{0xC3E0, UNICODE_NORM_QC_NO},
+	{0xC3E1, UNICODE_NORM_QC_NO},
+	{0xC3E2, UNICODE_NORM_QC_NO},
+	{0xC3E3, UNICODE_NORM_QC_NO},
+	{0xC3E4, UNICODE_NORM_QC_NO},
+	{0xC3E5, UNICODE_NORM_QC_NO},
+	{0xC3E6, UNICODE_NORM_QC_NO},
+	{0xC3E7, UNICODE_NORM_QC_NO},
+	{0xC3E8, UNICODE_NORM_QC_NO},
+	{0xC3E9, UNICODE_NORM_QC_NO},
+	{0xC3EA, UNICODE_NORM_QC_NO},
+	{0xC3EB, UNICODE_NORM_QC_NO},
+	{0xC3EC, UNICODE_NORM_QC_NO},
+	{0xC3ED, UNICODE_NORM_QC_NO},
+	{0xC3EE, UNICODE_NORM_QC_NO},
+	{0xC3EF, UNICODE_NORM_QC_NO},
+	{0xC3F0, UNICODE_NORM_QC_NO},
+	{0xC3F1, UNICODE_NORM_QC_NO},
+	{0xC3F2, UNICODE_NORM_QC_NO},
+	{0xC3F3, UNICODE_NORM_QC_NO},
+	{0xC3F4, UNICODE_NORM_QC_NO},
+	{0xC3F5, UNICODE_NORM_QC_NO},
+	{0xC3F6, UNICODE_NORM_QC_NO},
+	{0xC3F7, UNICODE_NORM_QC_NO},
+	{0xC3F8, UNICODE_NORM_QC_NO},
+	{0xC3F9, UNICODE_NORM_QC_NO},
+	{0xC3FA, UNICODE_NORM_QC_NO},
+	{0xC3FB, UNICODE_NORM_QC_NO},
+	{0xC3FC, UNICODE_NORM_QC_NO},
+	{0xC3FD, UNICODE_NORM_QC_NO},
+	{0xC3FE, UNICODE_NORM_QC_NO},
+	{0xC3FF, UNICODE_NORM_QC_NO},
+	{0xC400, UNICODE_NORM_QC_NO},
+	{0xC401, UNICODE_NORM_QC_NO},
+	{0xC402, UNICODE_NORM_QC_NO},
+	{0xC403, UNICODE_NORM_QC_NO},
+	{0xC404, UNICODE_NORM_QC_NO},
+	{0xC405, UNICODE_NORM_QC_NO},
+	{0xC406, UNICODE_NORM_QC_NO},
+	{0xC407, UNICODE_NORM_QC_NO},
+	{0xC408, UNICODE_NORM_QC_NO},
+	{0xC409, UNICODE_NORM_QC_NO},
+	{0xC40A, UNICODE_NORM_QC_NO},
+	{0xC40B, UNICODE_NORM_QC_NO},
+	{0xC40C, UNICODE_NORM_QC_NO},
+	{0xC40D, UNICODE_NORM_QC_NO},
+	{0xC40E, UNICODE_NORM_QC_NO},
+	{0xC40F, UNICODE_NORM_QC_NO},
+	{0xC410, UNICODE_NORM_QC_NO},
+	{0xC411, UNICODE_NORM_QC_NO},
+	{0xC412, UNICODE_NORM_QC_NO},
+	{0xC413, UNICODE_NORM_QC_NO},
+	{0xC414, UNICODE_NORM_QC_NO},
+	{0xC415, UNICODE_NORM_QC_NO},
+	{0xC416, UNICODE_NORM_QC_NO},
+	{0xC417, UNICODE_NORM_QC_NO},
+	{0xC418, UNICODE_NORM_QC_NO},
+	{0xC419, UNICODE_NORM_QC_NO},
+	{0xC41A, UNICODE_NORM_QC_NO},
+	{0xC41B, UNICODE_NORM_QC_NO},
+	{0xC41C, UNICODE_NORM_QC_NO},
+	{0xC41D, UNICODE_NORM_QC_NO},
+	{0xC41E, UNICODE_NORM_QC_NO},
+	{0xC41F, UNICODE_NORM_QC_NO},
+	{0xC420, UNICODE_NORM_QC_NO},
+	{0xC421, UNICODE_NORM_QC_NO},
+	{0xC422, UNICODE_NORM_QC_NO},
+	{0xC423, UNICODE_NORM_QC_NO},
+	{0xC424, UNICODE_NORM_QC_NO},
+	{0xC425, UNICODE_NORM_QC_NO},
+	{0xC426, UNICODE_NORM_QC_NO},
+	{0xC427, UNICODE_NORM_QC_NO},
+	{0xC428, UNICODE_NORM_QC_NO},
+	{0xC429, UNICODE_NORM_QC_NO},
+	{0xC42A, UNICODE_NORM_QC_NO},
+	{0xC42B, UNICODE_NORM_QC_NO},
+	{0xC42C, UNICODE_NORM_QC_NO},
+	{0xC42D, UNICODE_NORM_QC_NO},
+	{0xC42E, UNICODE_NORM_QC_NO},
+	{0xC42F, UNICODE_NORM_QC_NO},
+	{0xC430, UNICODE_NORM_QC_NO},
+	{0xC431, UNICODE_NORM_QC_NO},
+	{0xC432, UNICODE_NORM_QC_NO},
+	{0xC433, UNICODE_NORM_QC_NO},
+	{0xC434, UNICODE_NORM_QC_NO},
+	{0xC435, UNICODE_NORM_QC_NO},
+	{0xC436, UNICODE_NORM_QC_NO},
+	{0xC437, UNICODE_NORM_QC_NO},
+	{0xC438, UNICODE_NORM_QC_NO},
+	{0xC439, UNICODE_NORM_QC_NO},
+	{0xC43A, UNICODE_NORM_QC_NO},
+	{0xC43B, UNICODE_NORM_QC_NO},
+	{0xC43C, UNICODE_NORM_QC_NO},
+	{0xC43D, UNICODE_NORM_QC_NO},
+	{0xC43E, UNICODE_NORM_QC_NO},
+	{0xC43F, UNICODE_NORM_QC_NO},
+	{0xC440, UNICODE_NORM_QC_NO},
+	{0xC441, UNICODE_NORM_QC_NO},
+	{0xC442, UNICODE_NORM_QC_NO},
+	{0xC443, UNICODE_NORM_QC_NO},
+	{0xC444, UNICODE_NORM_QC_NO},
+	{0xC445, UNICODE_NORM_QC_NO},
+	{0xC446, UNICODE_NORM_QC_NO},
+	{0xC447, UNICODE_NORM_QC_NO},
+	{0xC448, UNICODE_NORM_QC_NO},
+	{0xC449, UNICODE_NORM_QC_NO},
+	{0xC44A, UNICODE_NORM_QC_NO},
+	{0xC44B, UNICODE_NORM_QC_NO},
+	{0xC44C, UNICODE_NORM_QC_NO},
+	{0xC44D, UNICODE_NORM_QC_NO},
+	{0xC44E, UNICODE_NORM_QC_NO},
+	{0xC44F, UNICODE_NORM_QC_NO},
+	{0xC450, UNICODE_NORM_QC_NO},
+	{0xC451, UNICODE_NORM_QC_NO},
+	{0xC452, UNICODE_NORM_QC_NO},
+	{0xC453, UNICODE_NORM_QC_NO},
+	{0xC454, UNICODE_NORM_QC_NO},
+	{0xC455, UNICODE_NORM_QC_NO},
+	{0xC456, UNICODE_NORM_QC_NO},
+	{0xC457, UNICODE_NORM_QC_NO},
+	{0xC458, UNICODE_NORM_QC_NO},
+	{0xC459, UNICODE_NORM_QC_NO},
+	{0xC45A, UNICODE_NORM_QC_NO},
+	{0xC45B, UNICODE_NORM_QC_NO},
+	{0xC45C, UNICODE_NORM_QC_NO},
+	{0xC45D, UNICODE_NORM_QC_NO},
+	{0xC45E, UNICODE_NORM_QC_NO},
+	{0xC45F, UNICODE_NORM_QC_NO},
+	{0xC460, UNICODE_NORM_QC_NO},
+	{0xC461, UNICODE_NORM_QC_NO},
+	{0xC462, UNICODE_NORM_QC_NO},
+	{0xC463, UNICODE_NORM_QC_NO},
+	{0xC464, UNICODE_NORM_QC_NO},
+	{0xC465, UNICODE_NORM_QC_NO},
+	{0xC466, UNICODE_NORM_QC_NO},
+	{0xC467, UNICODE_NORM_QC_NO},
+	{0xC468, UNICODE_NORM_QC_NO},
+	{0xC469, UNICODE_NORM_QC_NO},
+	{0xC46A, UNICODE_NORM_QC_NO},
+	{0xC46B, UNICODE_NORM_QC_NO},
+	{0xC46C, UNICODE_NORM_QC_NO},
+	{0xC46D, UNICODE_NORM_QC_NO},
+	{0xC46E, UNICODE_NORM_QC_NO},
+	{0xC46F, UNICODE_NORM_QC_NO},
+	{0xC470, UNICODE_NORM_QC_NO},
+	{0xC471, UNICODE_NORM_QC_NO},
+	{0xC472, UNICODE_NORM_QC_NO},
+	{0xC473, UNICODE_NORM_QC_NO},
+	{0xC474, UNICODE_NORM_QC_NO},
+	{0xC475, UNICODE_NORM_QC_NO},
+	{0xC476, UNICODE_NORM_QC_NO},
+	{0xC477, UNICODE_NORM_QC_NO},
+	{0xC478, UNICODE_NORM_QC_NO},
+	{0xC479, UNICODE_NORM_QC_NO},
+	{0xC47A, UNICODE_NORM_QC_NO},
+	{0xC47B, UNICODE_NORM_QC_NO},
+	{0xC47C, UNICODE_NORM_QC_NO},
+	{0xC47D, UNICODE_NORM_QC_NO},
+	{0xC47E, UNICODE_NORM_QC_NO},
+	{0xC47F, UNICODE_NORM_QC_NO},
+	{0xC480, UNICODE_NORM_QC_NO},
+	{0xC481, UNICODE_NORM_QC_NO},
+	{0xC482, UNICODE_NORM_QC_NO},
+	{0xC483, UNICODE_NORM_QC_NO},
+	{0xC484, UNICODE_NORM_QC_NO},
+	{0xC485, UNICODE_NORM_QC_NO},
+	{0xC486, UNICODE_NORM_QC_NO},
+	{0xC487, UNICODE_NORM_QC_NO},
+	{0xC488, UNICODE_NORM_QC_NO},
+	{0xC489, UNICODE_NORM_QC_NO},
+	{0xC48A, UNICODE_NORM_QC_NO},
+	{0xC48B, UNICODE_NORM_QC_NO},
+	{0xC48C, UNICODE_NORM_QC_NO},
+	{0xC48D, UNICODE_NORM_QC_NO},
+	{0xC48E, UNICODE_NORM_QC_NO},
+	{0xC48F, UNICODE_NORM_QC_NO},
+	{0xC490, UNICODE_NORM_QC_NO},
+	{0xC491, UNICODE_NORM_QC_NO},
+	{0xC492, UNICODE_NORM_QC_NO},
+	{0xC493, UNICODE_NORM_QC_NO},
+	{0xC494, UNICODE_NORM_QC_NO},
+	{0xC495, UNICODE_NORM_QC_NO},
+	{0xC496, UNICODE_NORM_QC_NO},
+	{0xC497, UNICODE_NORM_QC_NO},
+	{0xC498, UNICODE_NORM_QC_NO},
+	{0xC499, UNICODE_NORM_QC_NO},
+	{0xC49A, UNICODE_NORM_QC_NO},
+	{0xC49B, UNICODE_NORM_QC_NO},
+	{0xC49C, UNICODE_NORM_QC_NO},
+	{0xC49D, UNICODE_NORM_QC_NO},
+	{0xC49E, UNICODE_NORM_QC_NO},
+	{0xC49F, UNICODE_NORM_QC_NO},
+	{0xC4A0, UNICODE_NORM_QC_NO},
+	{0xC4A1, UNICODE_NORM_QC_NO},
+	{0xC4A2, UNICODE_NORM_QC_NO},
+	{0xC4A3, UNICODE_NORM_QC_NO},
+	{0xC4A4, UNICODE_NORM_QC_NO},
+	{0xC4A5, UNICODE_NORM_QC_NO},
+	{0xC4A6, UNICODE_NORM_QC_NO},
+	{0xC4A7, UNICODE_NORM_QC_NO},
+	{0xC4A8, UNICODE_NORM_QC_NO},
+	{0xC4A9, UNICODE_NORM_QC_NO},
+	{0xC4AA, UNICODE_NORM_QC_NO},
+	{0xC4AB, UNICODE_NORM_QC_NO},
+	{0xC4AC, UNICODE_NORM_QC_NO},
+	{0xC4AD, UNICODE_NORM_QC_NO},
+	{0xC4AE, UNICODE_NORM_QC_NO},
+	{0xC4AF, UNICODE_NORM_QC_NO},
+	{0xC4B0, UNICODE_NORM_QC_NO},
+	{0xC4B1, UNICODE_NORM_QC_NO},
+	{0xC4B2, UNICODE_NORM_QC_NO},
+	{0xC4B3, UNICODE_NORM_QC_NO},
+	{0xC4B4, UNICODE_NORM_QC_NO},
+	{0xC4B5, UNICODE_NORM_QC_NO},
+	{0xC4B6, UNICODE_NORM_QC_NO},
+	{0xC4B7, UNICODE_NORM_QC_NO},
+	{0xC4B8, UNICODE_NORM_QC_NO},
+	{0xC4B9, UNICODE_NORM_QC_NO},
+	{0xC4BA, UNICODE_NORM_QC_NO},
+	{0xC4BB, UNICODE_NORM_QC_NO},
+	{0xC4BC, UNICODE_NORM_QC_NO},
+	{0xC4BD, UNICODE_NORM_QC_NO},
+	{0xC4BE, UNICODE_NORM_QC_NO},
+	{0xC4BF, UNICODE_NORM_QC_NO},
+	{0xC4C0, UNICODE_NORM_QC_NO},
+	{0xC4C1, UNICODE_NORM_QC_NO},
+	{0xC4C2, UNICODE_NORM_QC_NO},
+	{0xC4C3, UNICODE_NORM_QC_NO},
+	{0xC4C4, UNICODE_NORM_QC_NO},
+	{0xC4C5, UNICODE_NORM_QC_NO},
+	{0xC4C6, UNICODE_NORM_QC_NO},
+	{0xC4C7, UNICODE_NORM_QC_NO},
+	{0xC4C8, UNICODE_NORM_QC_NO},
+	{0xC4C9, UNICODE_NORM_QC_NO},
+	{0xC4CA, UNICODE_NORM_QC_NO},
+	{0xC4CB, UNICODE_NORM_QC_NO},
+	{0xC4CC, UNICODE_NORM_QC_NO},
+	{0xC4CD, UNICODE_NORM_QC_NO},
+	{0xC4CE, UNICODE_NORM_QC_NO},
+	{0xC4CF, UNICODE_NORM_QC_NO},
+	{0xC4D0, UNICODE_NORM_QC_NO},
+	{0xC4D1, UNICODE_NORM_QC_NO},
+	{0xC4D2, UNICODE_NORM_QC_NO},
+	{0xC4D3, UNICODE_NORM_QC_NO},
+	{0xC4D4, UNICODE_NORM_QC_NO},
+	{0xC4D5, UNICODE_NORM_QC_NO},
+	{0xC4D6, UNICODE_NORM_QC_NO},
+	{0xC4D7, UNICODE_NORM_QC_NO},
+	{0xC4D8, UNICODE_NORM_QC_NO},
+	{0xC4D9, UNICODE_NORM_QC_NO},
+	{0xC4DA, UNICODE_NORM_QC_NO},
+	{0xC4DB, UNICODE_NORM_QC_NO},
+	{0xC4DC, UNICODE_NORM_QC_NO},
+	{0xC4DD, UNICODE_NORM_QC_NO},
+	{0xC4DE, UNICODE_NORM_QC_NO},
+	{0xC4DF, UNICODE_NORM_QC_NO},
+	{0xC4E0, UNICODE_NORM_QC_NO},
+	{0xC4E1, UNICODE_NORM_QC_NO},
+	{0xC4E2, UNICODE_NORM_QC_NO},
+	{0xC4E3, UNICODE_NORM_QC_NO},
+	{0xC4E4, UNICODE_NORM_QC_NO},
+	{0xC4E5, UNICODE_NORM_QC_NO},
+	{0xC4E6, UNICODE_NORM_QC_NO},
+	{0xC4E7, UNICODE_NORM_QC_NO},
+	{0xC4E8, UNICODE_NORM_QC_NO},
+	{0xC4E9, UNICODE_NORM_QC_NO},
+	{0xC4EA, UNICODE_NORM_QC_NO},
+	{0xC4EB, UNICODE_NORM_QC_NO},
+	{0xC4EC, UNICODE_NORM_QC_NO},
+	{0xC4ED, UNICODE_NORM_QC_NO},
+	{0xC4EE, UNICODE_NORM_QC_NO},
+	{0xC4EF, UNICODE_NORM_QC_NO},
+	{0xC4F0, UNICODE_NORM_QC_NO},
+	{0xC4F1, UNICODE_NORM_QC_NO},
+	{0xC4F2, UNICODE_NORM_QC_NO},
+	{0xC4F3, UNICODE_NORM_QC_NO},
+	{0xC4F4, UNICODE_NORM_QC_NO},
+	{0xC4F5, UNICODE_NORM_QC_NO},
+	{0xC4F6, UNICODE_NORM_QC_NO},
+	{0xC4F7, UNICODE_NORM_QC_NO},
+	{0xC4F8, UNICODE_NORM_QC_NO},
+	{0xC4F9, UNICODE_NORM_QC_NO},
+	{0xC4FA, UNICODE_NORM_QC_NO},
+	{0xC4FB, UNICODE_NORM_QC_NO},
+	{0xC4FC, UNICODE_NORM_QC_NO},
+	{0xC4FD, UNICODE_NORM_QC_NO},
+	{0xC4FE, UNICODE_NORM_QC_NO},
+	{0xC4FF, UNICODE_NORM_QC_NO},
+	{0xC500, UNICODE_NORM_QC_NO},
+	{0xC501, UNICODE_NORM_QC_NO},
+	{0xC502, UNICODE_NORM_QC_NO},
+	{0xC503, UNICODE_NORM_QC_NO},
+	{0xC504, UNICODE_NORM_QC_NO},
+	{0xC505, UNICODE_NORM_QC_NO},
+	{0xC506, UNICODE_NORM_QC_NO},
+	{0xC507, UNICODE_NORM_QC_NO},
+	{0xC508, UNICODE_NORM_QC_NO},
+	{0xC509, UNICODE_NORM_QC_NO},
+	{0xC50A, UNICODE_NORM_QC_NO},
+	{0xC50B, UNICODE_NORM_QC_NO},
+	{0xC50C, UNICODE_NORM_QC_NO},
+	{0xC50D, UNICODE_NORM_QC_NO},
+	{0xC50E, UNICODE_NORM_QC_NO},
+	{0xC50F, UNICODE_NORM_QC_NO},
+	{0xC510, UNICODE_NORM_QC_NO},
+	{0xC511, UNICODE_NORM_QC_NO},
+	{0xC512, UNICODE_NORM_QC_NO},
+	{0xC513, UNICODE_NORM_QC_NO},
+	{0xC514, UNICODE_NORM_QC_NO},
+	{0xC515, UNICODE_NORM_QC_NO},
+	{0xC516, UNICODE_NORM_QC_NO},
+	{0xC517, UNICODE_NORM_QC_NO},
+	{0xC518, UNICODE_NORM_QC_NO},
+	{0xC519, UNICODE_NORM_QC_NO},
+	{0xC51A, UNICODE_NORM_QC_NO},
+	{0xC51B, UNICODE_NORM_QC_NO},
+	{0xC51C, UNICODE_NORM_QC_NO},
+	{0xC51D, UNICODE_NORM_QC_NO},
+	{0xC51E, UNICODE_NORM_QC_NO},
+	{0xC51F, UNICODE_NORM_QC_NO},
+	{0xC520, UNICODE_NORM_QC_NO},
+	{0xC521, UNICODE_NORM_QC_NO},
+	{0xC522, UNICODE_NORM_QC_NO},
+	{0xC523, UNICODE_NORM_QC_NO},
+	{0xC524, UNICODE_NORM_QC_NO},
+	{0xC525, UNICODE_NORM_QC_NO},
+	{0xC526, UNICODE_NORM_QC_NO},
+	{0xC527, UNICODE_NORM_QC_NO},
+	{0xC528, UNICODE_NORM_QC_NO},
+	{0xC529, UNICODE_NORM_QC_NO},
+	{0xC52A, UNICODE_NORM_QC_NO},
+	{0xC52B, UNICODE_NORM_QC_NO},
+	{0xC52C, UNICODE_NORM_QC_NO},
+	{0xC52D, UNICODE_NORM_QC_NO},
+	{0xC52E, UNICODE_NORM_QC_NO},
+	{0xC52F, UNICODE_NORM_QC_NO},
+	{0xC530, UNICODE_NORM_QC_NO},
+	{0xC531, UNICODE_NORM_QC_NO},
+	{0xC532, UNICODE_NORM_QC_NO},
+	{0xC533, UNICODE_NORM_QC_NO},
+	{0xC534, UNICODE_NORM_QC_NO},
+	{0xC535, UNICODE_NORM_QC_NO},
+	{0xC536, UNICODE_NORM_QC_NO},
+	{0xC537, UNICODE_NORM_QC_NO},
+	{0xC538, UNICODE_NORM_QC_NO},
+	{0xC539, UNICODE_NORM_QC_NO},
+	{0xC53A, UNICODE_NORM_QC_NO},
+	{0xC53B, UNICODE_NORM_QC_NO},
+	{0xC53C, UNICODE_NORM_QC_NO},
+	{0xC53D, UNICODE_NORM_QC_NO},
+	{0xC53E, UNICODE_NORM_QC_NO},
+	{0xC53F, UNICODE_NORM_QC_NO},
+	{0xC540, UNICODE_NORM_QC_NO},
+	{0xC541, UNICODE_NORM_QC_NO},
+	{0xC542, UNICODE_NORM_QC_NO},
+	{0xC543, UNICODE_NORM_QC_NO},
+	{0xC544, UNICODE_NORM_QC_NO},
+	{0xC545, UNICODE_NORM_QC_NO},
+	{0xC546, UNICODE_NORM_QC_NO},
+	{0xC547, UNICODE_NORM_QC_NO},
+	{0xC548, UNICODE_NORM_QC_NO},
+	{0xC549, UNICODE_NORM_QC_NO},
+	{0xC54A, UNICODE_NORM_QC_NO},
+	{0xC54B, UNICODE_NORM_QC_NO},
+	{0xC54C, UNICODE_NORM_QC_NO},
+	{0xC54D, UNICODE_NORM_QC_NO},
+	{0xC54E, UNICODE_NORM_QC_NO},
+	{0xC54F, UNICODE_NORM_QC_NO},
+	{0xC550, UNICODE_NORM_QC_NO},
+	{0xC551, UNICODE_NORM_QC_NO},
+	{0xC552, UNICODE_NORM_QC_NO},
+	{0xC553, UNICODE_NORM_QC_NO},
+	{0xC554, UNICODE_NORM_QC_NO},
+	{0xC555, UNICODE_NORM_QC_NO},
+	{0xC556, UNICODE_NORM_QC_NO},
+	{0xC557, UNICODE_NORM_QC_NO},
+	{0xC558, UNICODE_NORM_QC_NO},
+	{0xC559, UNICODE_NORM_QC_NO},
+	{0xC55A, UNICODE_NORM_QC_NO},
+	{0xC55B, UNICODE_NORM_QC_NO},
+	{0xC55C, UNICODE_NORM_QC_NO},
+	{0xC55D, UNICODE_NORM_QC_NO},
+	{0xC55E, UNICODE_NORM_QC_NO},
+	{0xC55F, UNICODE_NORM_QC_NO},
+	{0xC560, UNICODE_NORM_QC_NO},
+	{0xC561, UNICODE_NORM_QC_NO},
+	{0xC562, UNICODE_NORM_QC_NO},
+	{0xC563, UNICODE_NORM_QC_NO},
+	{0xC564, UNICODE_NORM_QC_NO},
+	{0xC565, UNICODE_NORM_QC_NO},
+	{0xC566, UNICODE_NORM_QC_NO},
+	{0xC567, UNICODE_NORM_QC_NO},
+	{0xC568, UNICODE_NORM_QC_NO},
+	{0xC569, UNICODE_NORM_QC_NO},
+	{0xC56A, UNICODE_NORM_QC_NO},
+	{0xC56B, UNICODE_NORM_QC_NO},
+	{0xC56C, UNICODE_NORM_QC_NO},
+	{0xC56D, UNICODE_NORM_QC_NO},
+	{0xC56E, UNICODE_NORM_QC_NO},
+	{0xC56F, UNICODE_NORM_QC_NO},
+	{0xC570, UNICODE_NORM_QC_NO},
+	{0xC571, UNICODE_NORM_QC_NO},
+	{0xC572, UNICODE_NORM_QC_NO},
+	{0xC573, UNICODE_NORM_QC_NO},
+	{0xC574, UNICODE_NORM_QC_NO},
+	{0xC575, UNICODE_NORM_QC_NO},
+	{0xC576, UNICODE_NORM_QC_NO},
+	{0xC577, UNICODE_NORM_QC_NO},
+	{0xC578, UNICODE_NORM_QC_NO},
+	{0xC579, UNICODE_NORM_QC_NO},
+	{0xC57A, UNICODE_NORM_QC_NO},
+	{0xC57B, UNICODE_NORM_QC_NO},
+	{0xC57C, UNICODE_NORM_QC_NO},
+	{0xC57D, UNICODE_NORM_QC_NO},
+	{0xC57E, UNICODE_NORM_QC_NO},
+	{0xC57F, UNICODE_NORM_QC_NO},
+	{0xC580, UNICODE_NORM_QC_NO},
+	{0xC581, UNICODE_NORM_QC_NO},
+	{0xC582, UNICODE_NORM_QC_NO},
+	{0xC583, UNICODE_NORM_QC_NO},
+	{0xC584, UNICODE_NORM_QC_NO},
+	{0xC585, UNICODE_NORM_QC_NO},
+	{0xC586, UNICODE_NORM_QC_NO},
+	{0xC587, UNICODE_NORM_QC_NO},
+	{0xC588, UNICODE_NORM_QC_NO},
+	{0xC589, UNICODE_NORM_QC_NO},
+	{0xC58A, UNICODE_NORM_QC_NO},
+	{0xC58B, UNICODE_NORM_QC_NO},
+	{0xC58C, UNICODE_NORM_QC_NO},
+	{0xC58D, UNICODE_NORM_QC_NO},
+	{0xC58E, UNICODE_NORM_QC_NO},
+	{0xC58F, UNICODE_NORM_QC_NO},
+	{0xC590, UNICODE_NORM_QC_NO},
+	{0xC591, UNICODE_NORM_QC_NO},
+	{0xC592, UNICODE_NORM_QC_NO},
+	{0xC593, UNICODE_NORM_QC_NO},
+	{0xC594, UNICODE_NORM_QC_NO},
+	{0xC595, UNICODE_NORM_QC_NO},
+	{0xC596, UNICODE_NORM_QC_NO},
+	{0xC597, UNICODE_NORM_QC_NO},
+	{0xC598, UNICODE_NORM_QC_NO},
+	{0xC599, UNICODE_NORM_QC_NO},
+	{0xC59A, UNICODE_NORM_QC_NO},
+	{0xC59B, UNICODE_NORM_QC_NO},
+	{0xC59C, UNICODE_NORM_QC_NO},
+	{0xC59D, UNICODE_NORM_QC_NO},
+	{0xC59E, UNICODE_NORM_QC_NO},
+	{0xC59F, UNICODE_NORM_QC_NO},
+	{0xC5A0, UNICODE_NORM_QC_NO},
+	{0xC5A1, UNICODE_NORM_QC_NO},
+	{0xC5A2, UNICODE_NORM_QC_NO},
+	{0xC5A3, UNICODE_NORM_QC_NO},
+	{0xC5A4, UNICODE_NORM_QC_NO},
+	{0xC5A5, UNICODE_NORM_QC_NO},
+	{0xC5A6, UNICODE_NORM_QC_NO},
+	{0xC5A7, UNICODE_NORM_QC_NO},
+	{0xC5A8, UNICODE_NORM_QC_NO},
+	{0xC5A9, UNICODE_NORM_QC_NO},
+	{0xC5AA, UNICODE_NORM_QC_NO},
+	{0xC5AB, UNICODE_NORM_QC_NO},
+	{0xC5AC, UNICODE_NORM_QC_NO},
+	{0xC5AD, UNICODE_NORM_QC_NO},
+	{0xC5AE, UNICODE_NORM_QC_NO},
+	{0xC5AF, UNICODE_NORM_QC_NO},
+	{0xC5B0, UNICODE_NORM_QC_NO},
+	{0xC5B1, UNICODE_NORM_QC_NO},
+	{0xC5B2, UNICODE_NORM_QC_NO},
+	{0xC5B3, UNICODE_NORM_QC_NO},
+	{0xC5B4, UNICODE_NORM_QC_NO},
+	{0xC5B5, UNICODE_NORM_QC_NO},
+	{0xC5B6, UNICODE_NORM_QC_NO},
+	{0xC5B7, UNICODE_NORM_QC_NO},
+	{0xC5B8, UNICODE_NORM_QC_NO},
+	{0xC5B9, UNICODE_NORM_QC_NO},
+	{0xC5BA, UNICODE_NORM_QC_NO},
+	{0xC5BB, UNICODE_NORM_QC_NO},
+	{0xC5BC, UNICODE_NORM_QC_NO},
+	{0xC5BD, UNICODE_NORM_QC_NO},
+	{0xC5BE, UNICODE_NORM_QC_NO},
+	{0xC5BF, UNICODE_NORM_QC_NO},
+	{0xC5C0, UNICODE_NORM_QC_NO},
+	{0xC5C1, UNICODE_NORM_QC_NO},
+	{0xC5C2, UNICODE_NORM_QC_NO},
+	{0xC5C3, UNICODE_NORM_QC_NO},
+	{0xC5C4, UNICODE_NORM_QC_NO},
+	{0xC5C5, UNICODE_NORM_QC_NO},
+	{0xC5C6, UNICODE_NORM_QC_NO},
+	{0xC5C7, UNICODE_NORM_QC_NO},
+	{0xC5C8, UNICODE_NORM_QC_NO},
+	{0xC5C9, UNICODE_NORM_QC_NO},
+	{0xC5CA, UNICODE_NORM_QC_NO},
+	{0xC5CB, UNICODE_NORM_QC_NO},
+	{0xC5CC, UNICODE_NORM_QC_NO},
+	{0xC5CD, UNICODE_NORM_QC_NO},
+	{0xC5CE, UNICODE_NORM_QC_NO},
+	{0xC5CF, UNICODE_NORM_QC_NO},
+	{0xC5D0, UNICODE_NORM_QC_NO},
+	{0xC5D1, UNICODE_NORM_QC_NO},
+	{0xC5D2, UNICODE_NORM_QC_NO},
+	{0xC5D3, UNICODE_NORM_QC_NO},
+	{0xC5D4, UNICODE_NORM_QC_NO},
+	{0xC5D5, UNICODE_NORM_QC_NO},
+	{0xC5D6, UNICODE_NORM_QC_NO},
+	{0xC5D7, UNICODE_NORM_QC_NO},
+	{0xC5D8, UNICODE_NORM_QC_NO},
+	{0xC5D9, UNICODE_NORM_QC_NO},
+	{0xC5DA, UNICODE_NORM_QC_NO},
+	{0xC5DB, UNICODE_NORM_QC_NO},
+	{0xC5DC, UNICODE_NORM_QC_NO},
+	{0xC5DD, UNICODE_NORM_QC_NO},
+	{0xC5DE, UNICODE_NORM_QC_NO},
+	{0xC5DF, UNICODE_NORM_QC_NO},
+	{0xC5E0, UNICODE_NORM_QC_NO},
+	{0xC5E1, UNICODE_NORM_QC_NO},
+	{0xC5E2, UNICODE_NORM_QC_NO},
+	{0xC5E3, UNICODE_NORM_QC_NO},
+	{0xC5E4, UNICODE_NORM_QC_NO},
+	{0xC5E5, UNICODE_NORM_QC_NO},
+	{0xC5E6, UNICODE_NORM_QC_NO},
+	{0xC5E7, UNICODE_NORM_QC_NO},
+	{0xC5E8, UNICODE_NORM_QC_NO},
+	{0xC5E9, UNICODE_NORM_QC_NO},
+	{0xC5EA, UNICODE_NORM_QC_NO},
+	{0xC5EB, UNICODE_NORM_QC_NO},
+	{0xC5EC, UNICODE_NORM_QC_NO},
+	{0xC5ED, UNICODE_NORM_QC_NO},
+	{0xC5EE, UNICODE_NORM_QC_NO},
+	{0xC5EF, UNICODE_NORM_QC_NO},
+	{0xC5F0, UNICODE_NORM_QC_NO},
+	{0xC5F1, UNICODE_NORM_QC_NO},
+	{0xC5F2, UNICODE_NORM_QC_NO},
+	{0xC5F3, UNICODE_NORM_QC_NO},
+	{0xC5F4, UNICODE_NORM_QC_NO},
+	{0xC5F5, UNICODE_NORM_QC_NO},
+	{0xC5F6, UNICODE_NORM_QC_NO},
+	{0xC5F7, UNICODE_NORM_QC_NO},
+	{0xC5F8, UNICODE_NORM_QC_NO},
+	{0xC5F9, UNICODE_NORM_QC_NO},
+	{0xC5FA, UNICODE_NORM_QC_NO},
+	{0xC5FB, UNICODE_NORM_QC_NO},
+	{0xC5FC, UNICODE_NORM_QC_NO},
+	{0xC5FD, UNICODE_NORM_QC_NO},
+	{0xC5FE, UNICODE_NORM_QC_NO},
+	{0xC5FF, UNICODE_NORM_QC_NO},
+	{0xC600, UNICODE_NORM_QC_NO},
+	{0xC601, UNICODE_NORM_QC_NO},
+	{0xC602, UNICODE_NORM_QC_NO},
+	{0xC603, UNICODE_NORM_QC_NO},
+	{0xC604, UNICODE_NORM_QC_NO},
+	{0xC605, UNICODE_NORM_QC_NO},
+	{0xC606, UNICODE_NORM_QC_NO},
+	{0xC607, UNICODE_NORM_QC_NO},
+	{0xC608, UNICODE_NORM_QC_NO},
+	{0xC609, UNICODE_NORM_QC_NO},
+	{0xC60A, UNICODE_NORM_QC_NO},
+	{0xC60B, UNICODE_NORM_QC_NO},
+	{0xC60C, UNICODE_NORM_QC_NO},
+	{0xC60D, UNICODE_NORM_QC_NO},
+	{0xC60E, UNICODE_NORM_QC_NO},
+	{0xC60F, UNICODE_NORM_QC_NO},
+	{0xC610, UNICODE_NORM_QC_NO},
+	{0xC611, UNICODE_NORM_QC_NO},
+	{0xC612, UNICODE_NORM_QC_NO},
+	{0xC613, UNICODE_NORM_QC_NO},
+	{0xC614, UNICODE_NORM_QC_NO},
+	{0xC615, UNICODE_NORM_QC_NO},
+	{0xC616, UNICODE_NORM_QC_NO},
+	{0xC617, UNICODE_NORM_QC_NO},
+	{0xC618, UNICODE_NORM_QC_NO},
+	{0xC619, UNICODE_NORM_QC_NO},
+	{0xC61A, UNICODE_NORM_QC_NO},
+	{0xC61B, UNICODE_NORM_QC_NO},
+	{0xC61C, UNICODE_NORM_QC_NO},
+	{0xC61D, UNICODE_NORM_QC_NO},
+	{0xC61E, UNICODE_NORM_QC_NO},
+	{0xC61F, UNICODE_NORM_QC_NO},
+	{0xC620, UNICODE_NORM_QC_NO},
+	{0xC621, UNICODE_NORM_QC_NO},
+	{0xC622, UNICODE_NORM_QC_NO},
+	{0xC623, UNICODE_NORM_QC_NO},
+	{0xC624, UNICODE_NORM_QC_NO},
+	{0xC625, UNICODE_NORM_QC_NO},
+	{0xC626, UNICODE_NORM_QC_NO},
+	{0xC627, UNICODE_NORM_QC_NO},
+	{0xC628, UNICODE_NORM_QC_NO},
+	{0xC629, UNICODE_NORM_QC_NO},
+	{0xC62A, UNICODE_NORM_QC_NO},
+	{0xC62B, UNICODE_NORM_QC_NO},
+	{0xC62C, UNICODE_NORM_QC_NO},
+	{0xC62D, UNICODE_NORM_QC_NO},
+	{0xC62E, UNICODE_NORM_QC_NO},
+	{0xC62F, UNICODE_NORM_QC_NO},
+	{0xC630, UNICODE_NORM_QC_NO},
+	{0xC631, UNICODE_NORM_QC_NO},
+	{0xC632, UNICODE_NORM_QC_NO},
+	{0xC633, UNICODE_NORM_QC_NO},
+	{0xC634, UNICODE_NORM_QC_NO},
+	{0xC635, UNICODE_NORM_QC_NO},
+	{0xC636, UNICODE_NORM_QC_NO},
+	{0xC637, UNICODE_NORM_QC_NO},
+	{0xC638, UNICODE_NORM_QC_NO},
+	{0xC639, UNICODE_NORM_QC_NO},
+	{0xC63A, UNICODE_NORM_QC_NO},
+	{0xC63B, UNICODE_NORM_QC_NO},
+	{0xC63C, UNICODE_NORM_QC_NO},
+	{0xC63D, UNICODE_NORM_QC_NO},
+	{0xC63E, UNICODE_NORM_QC_NO},
+	{0xC63F, UNICODE_NORM_QC_NO},
+	{0xC640, UNICODE_NORM_QC_NO},
+	{0xC641, UNICODE_NORM_QC_NO},
+	{0xC642, UNICODE_NORM_QC_NO},
+	{0xC643, UNICODE_NORM_QC_NO},
+	{0xC644, UNICODE_NORM_QC_NO},
+	{0xC645, UNICODE_NORM_QC_NO},
+	{0xC646, UNICODE_NORM_QC_NO},
+	{0xC647, UNICODE_NORM_QC_NO},
+	{0xC648, UNICODE_NORM_QC_NO},
+	{0xC649, UNICODE_NORM_QC_NO},
+	{0xC64A, UNICODE_NORM_QC_NO},
+	{0xC64B, UNICODE_NORM_QC_NO},
+	{0xC64C, UNICODE_NORM_QC_NO},
+	{0xC64D, UNICODE_NORM_QC_NO},
+	{0xC64E, UNICODE_NORM_QC_NO},
+	{0xC64F, UNICODE_NORM_QC_NO},
+	{0xC650, UNICODE_NORM_QC_NO},
+	{0xC651, UNICODE_NORM_QC_NO},
+	{0xC652, UNICODE_NORM_QC_NO},
+	{0xC653, UNICODE_NORM_QC_NO},
+	{0xC654, UNICODE_NORM_QC_NO},
+	{0xC655, UNICODE_NORM_QC_NO},
+	{0xC656, UNICODE_NORM_QC_NO},
+	{0xC657, UNICODE_NORM_QC_NO},
+	{0xC658, UNICODE_NORM_QC_NO},
+	{0xC659, UNICODE_NORM_QC_NO},
+	{0xC65A, UNICODE_NORM_QC_NO},
+	{0xC65B, UNICODE_NORM_QC_NO},
+	{0xC65C, UNICODE_NORM_QC_NO},
+	{0xC65D, UNICODE_NORM_QC_NO},
+	{0xC65E, UNICODE_NORM_QC_NO},
+	{0xC65F, UNICODE_NORM_QC_NO},
+	{0xC660, UNICODE_NORM_QC_NO},
+	{0xC661, UNICODE_NORM_QC_NO},
+	{0xC662, UNICODE_NORM_QC_NO},
+	{0xC663, UNICODE_NORM_QC_NO},
+	{0xC664, UNICODE_NORM_QC_NO},
+	{0xC665, UNICODE_NORM_QC_NO},
+	{0xC666, UNICODE_NORM_QC_NO},
+	{0xC667, UNICODE_NORM_QC_NO},
+	{0xC668, UNICODE_NORM_QC_NO},
+	{0xC669, UNICODE_NORM_QC_NO},
+	{0xC66A, UNICODE_NORM_QC_NO},
+	{0xC66B, UNICODE_NORM_QC_NO},
+	{0xC66C, UNICODE_NORM_QC_NO},
+	{0xC66D, UNICODE_NORM_QC_NO},
+	{0xC66E, UNICODE_NORM_QC_NO},
+	{0xC66F, UNICODE_NORM_QC_NO},
+	{0xC670, UNICODE_NORM_QC_NO},
+	{0xC671, UNICODE_NORM_QC_NO},
+	{0xC672, UNICODE_NORM_QC_NO},
+	{0xC673, UNICODE_NORM_QC_NO},
+	{0xC674, UNICODE_NORM_QC_NO},
+	{0xC675, UNICODE_NORM_QC_NO},
+	{0xC676, UNICODE_NORM_QC_NO},
+	{0xC677, UNICODE_NORM_QC_NO},
+	{0xC678, UNICODE_NORM_QC_NO},
+	{0xC679, UNICODE_NORM_QC_NO},
+	{0xC67A, UNICODE_NORM_QC_NO},
+	{0xC67B, UNICODE_NORM_QC_NO},
+	{0xC67C, UNICODE_NORM_QC_NO},
+	{0xC67D, UNICODE_NORM_QC_NO},
+	{0xC67E, UNICODE_NORM_QC_NO},
+	{0xC67F, UNICODE_NORM_QC_NO},
+	{0xC680, UNICODE_NORM_QC_NO},
+	{0xC681, UNICODE_NORM_QC_NO},
+	{0xC682, UNICODE_NORM_QC_NO},
+	{0xC683, UNICODE_NORM_QC_NO},
+	{0xC684, UNICODE_NORM_QC_NO},
+	{0xC685, UNICODE_NORM_QC_NO},
+	{0xC686, UNICODE_NORM_QC_NO},
+	{0xC687, UNICODE_NORM_QC_NO},
+	{0xC688, UNICODE_NORM_QC_NO},
+	{0xC689, UNICODE_NORM_QC_NO},
+	{0xC68A, UNICODE_NORM_QC_NO},
+	{0xC68B, UNICODE_NORM_QC_NO},
+	{0xC68C, UNICODE_NORM_QC_NO},
+	{0xC68D, UNICODE_NORM_QC_NO},
+	{0xC68E, UNICODE_NORM_QC_NO},
+	{0xC68F, UNICODE_NORM_QC_NO},
+	{0xC690, UNICODE_NORM_QC_NO},
+	{0xC691, UNICODE_NORM_QC_NO},
+	{0xC692, UNICODE_NORM_QC_NO},
+	{0xC693, UNICODE_NORM_QC_NO},
+	{0xC694, UNICODE_NORM_QC_NO},
+	{0xC695, UNICODE_NORM_QC_NO},
+	{0xC696, UNICODE_NORM_QC_NO},
+	{0xC697, UNICODE_NORM_QC_NO},
+	{0xC698, UNICODE_NORM_QC_NO},
+	{0xC699, UNICODE_NORM_QC_NO},
+	{0xC69A, UNICODE_NORM_QC_NO},
+	{0xC69B, UNICODE_NORM_QC_NO},
+	{0xC69C, UNICODE_NORM_QC_NO},
+	{0xC69D, UNICODE_NORM_QC_NO},
+	{0xC69E, UNICODE_NORM_QC_NO},
+	{0xC69F, UNICODE_NORM_QC_NO},
+	{0xC6A0, UNICODE_NORM_QC_NO},
+	{0xC6A1, UNICODE_NORM_QC_NO},
+	{0xC6A2, UNICODE_NORM_QC_NO},
+	{0xC6A3, UNICODE_NORM_QC_NO},
+	{0xC6A4, UNICODE_NORM_QC_NO},
+	{0xC6A5, UNICODE_NORM_QC_NO},
+	{0xC6A6, UNICODE_NORM_QC_NO},
+	{0xC6A7, UNICODE_NORM_QC_NO},
+	{0xC6A8, UNICODE_NORM_QC_NO},
+	{0xC6A9, UNICODE_NORM_QC_NO},
+	{0xC6AA, UNICODE_NORM_QC_NO},
+	{0xC6AB, UNICODE_NORM_QC_NO},
+	{0xC6AC, UNICODE_NORM_QC_NO},
+	{0xC6AD, UNICODE_NORM_QC_NO},
+	{0xC6AE, UNICODE_NORM_QC_NO},
+	{0xC6AF, UNICODE_NORM_QC_NO},
+	{0xC6B0, UNICODE_NORM_QC_NO},
+	{0xC6B1, UNICODE_NORM_QC_NO},
+	{0xC6B2, UNICODE_NORM_QC_NO},
+	{0xC6B3, UNICODE_NORM_QC_NO},
+	{0xC6B4, UNICODE_NORM_QC_NO},
+	{0xC6B5, UNICODE_NORM_QC_NO},
+	{0xC6B6, UNICODE_NORM_QC_NO},
+	{0xC6B7, UNICODE_NORM_QC_NO},
+	{0xC6B8, UNICODE_NORM_QC_NO},
+	{0xC6B9, UNICODE_NORM_QC_NO},
+	{0xC6BA, UNICODE_NORM_QC_NO},
+	{0xC6BB, UNICODE_NORM_QC_NO},
+	{0xC6BC, UNICODE_NORM_QC_NO},
+	{0xC6BD, UNICODE_NORM_QC_NO},
+	{0xC6BE, UNICODE_NORM_QC_NO},
+	{0xC6BF, UNICODE_NORM_QC_NO},
+	{0xC6C0, UNICODE_NORM_QC_NO},
+	{0xC6C1, UNICODE_NORM_QC_NO},
+	{0xC6C2, UNICODE_NORM_QC_NO},
+	{0xC6C3, UNICODE_NORM_QC_NO},
+	{0xC6C4, UNICODE_NORM_QC_NO},
+	{0xC6C5, UNICODE_NORM_QC_NO},
+	{0xC6C6, UNICODE_NORM_QC_NO},
+	{0xC6C7, UNICODE_NORM_QC_NO},
+	{0xC6C8, UNICODE_NORM_QC_NO},
+	{0xC6C9, UNICODE_NORM_QC_NO},
+	{0xC6CA, UNICODE_NORM_QC_NO},
+	{0xC6CB, UNICODE_NORM_QC_NO},
+	{0xC6CC, UNICODE_NORM_QC_NO},
+	{0xC6CD, UNICODE_NORM_QC_NO},
+	{0xC6CE, UNICODE_NORM_QC_NO},
+	{0xC6CF, UNICODE_NORM_QC_NO},
+	{0xC6D0, UNICODE_NORM_QC_NO},
+	{0xC6D1, UNICODE_NORM_QC_NO},
+	{0xC6D2, UNICODE_NORM_QC_NO},
+	{0xC6D3, UNICODE_NORM_QC_NO},
+	{0xC6D4, UNICODE_NORM_QC_NO},
+	{0xC6D5, UNICODE_NORM_QC_NO},
+	{0xC6D6, UNICODE_NORM_QC_NO},
+	{0xC6D7, UNICODE_NORM_QC_NO},
+	{0xC6D8, UNICODE_NORM_QC_NO},
+	{0xC6D9, UNICODE_NORM_QC_NO},
+	{0xC6DA, UNICODE_NORM_QC_NO},
+	{0xC6DB, UNICODE_NORM_QC_NO},
+	{0xC6DC, UNICODE_NORM_QC_NO},
+	{0xC6DD, UNICODE_NORM_QC_NO},
+	{0xC6DE, UNICODE_NORM_QC_NO},
+	{0xC6DF, UNICODE_NORM_QC_NO},
+	{0xC6E0, UNICODE_NORM_QC_NO},
+	{0xC6E1, UNICODE_NORM_QC_NO},
+	{0xC6E2, UNICODE_NORM_QC_NO},
+	{0xC6E3, UNICODE_NORM_QC_NO},
+	{0xC6E4, UNICODE_NORM_QC_NO},
+	{0xC6E5, UNICODE_NORM_QC_NO},
+	{0xC6E6, UNICODE_NORM_QC_NO},
+	{0xC6E7, UNICODE_NORM_QC_NO},
+	{0xC6E8, UNICODE_NORM_QC_NO},
+	{0xC6E9, UNICODE_NORM_QC_NO},
+	{0xC6EA, UNICODE_NORM_QC_NO},
+	{0xC6EB, UNICODE_NORM_QC_NO},
+	{0xC6EC, UNICODE_NORM_QC_NO},
+	{0xC6ED, UNICODE_NORM_QC_NO},
+	{0xC6EE, UNICODE_NORM_QC_NO},
+	{0xC6EF, UNICODE_NORM_QC_NO},
+	{0xC6F0, UNICODE_NORM_QC_NO},
+	{0xC6F1, UNICODE_NORM_QC_NO},
+	{0xC6F2, UNICODE_NORM_QC_NO},
+	{0xC6F3, UNICODE_NORM_QC_NO},
+	{0xC6F4, UNICODE_NORM_QC_NO},
+	{0xC6F5, UNICODE_NORM_QC_NO},
+	{0xC6F6, UNICODE_NORM_QC_NO},
+	{0xC6F7, UNICODE_NORM_QC_NO},
+	{0xC6F8, UNICODE_NORM_QC_NO},
+	{0xC6F9, UNICODE_NORM_QC_NO},
+	{0xC6FA, UNICODE_NORM_QC_NO},
+	{0xC6FB, UNICODE_NORM_QC_NO},
+	{0xC6FC, UNICODE_NORM_QC_NO},
+	{0xC6FD, UNICODE_NORM_QC_NO},
+	{0xC6FE, UNICODE_NORM_QC_NO},
+	{0xC6FF, UNICODE_NORM_QC_NO},
+	{0xC700, UNICODE_NORM_QC_NO},
+	{0xC701, UNICODE_NORM_QC_NO},
+	{0xC702, UNICODE_NORM_QC_NO},
+	{0xC703, UNICODE_NORM_QC_NO},
+	{0xC704, UNICODE_NORM_QC_NO},
+	{0xC705, UNICODE_NORM_QC_NO},
+	{0xC706, UNICODE_NORM_QC_NO},
+	{0xC707, UNICODE_NORM_QC_NO},
+	{0xC708, UNICODE_NORM_QC_NO},
+	{0xC709, UNICODE_NORM_QC_NO},
+	{0xC70A, UNICODE_NORM_QC_NO},
+	{0xC70B, UNICODE_NORM_QC_NO},
+	{0xC70C, UNICODE_NORM_QC_NO},
+	{0xC70D, UNICODE_NORM_QC_NO},
+	{0xC70E, UNICODE_NORM_QC_NO},
+	{0xC70F, UNICODE_NORM_QC_NO},
+	{0xC710, UNICODE_NORM_QC_NO},
+	{0xC711, UNICODE_NORM_QC_NO},
+	{0xC712, UNICODE_NORM_QC_NO},
+	{0xC713, UNICODE_NORM_QC_NO},
+	{0xC714, UNICODE_NORM_QC_NO},
+	{0xC715, UNICODE_NORM_QC_NO},
+	{0xC716, UNICODE_NORM_QC_NO},
+	{0xC717, UNICODE_NORM_QC_NO},
+	{0xC718, UNICODE_NORM_QC_NO},
+	{0xC719, UNICODE_NORM_QC_NO},
+	{0xC71A, UNICODE_NORM_QC_NO},
+	{0xC71B, UNICODE_NORM_QC_NO},
+	{0xC71C, UNICODE_NORM_QC_NO},
+	{0xC71D, UNICODE_NORM_QC_NO},
+	{0xC71E, UNICODE_NORM_QC_NO},
+	{0xC71F, UNICODE_NORM_QC_NO},
+	{0xC720, UNICODE_NORM_QC_NO},
+	{0xC721, UNICODE_NORM_QC_NO},
+	{0xC722, UNICODE_NORM_QC_NO},
+	{0xC723, UNICODE_NORM_QC_NO},
+	{0xC724, UNICODE_NORM_QC_NO},
+	{0xC725, UNICODE_NORM_QC_NO},
+	{0xC726, UNICODE_NORM_QC_NO},
+	{0xC727, UNICODE_NORM_QC_NO},
+	{0xC728, UNICODE_NORM_QC_NO},
+	{0xC729, UNICODE_NORM_QC_NO},
+	{0xC72A, UNICODE_NORM_QC_NO},
+	{0xC72B, UNICODE_NORM_QC_NO},
+	{0xC72C, UNICODE_NORM_QC_NO},
+	{0xC72D, UNICODE_NORM_QC_NO},
+	{0xC72E, UNICODE_NORM_QC_NO},
+	{0xC72F, UNICODE_NORM_QC_NO},
+	{0xC730, UNICODE_NORM_QC_NO},
+	{0xC731, UNICODE_NORM_QC_NO},
+	{0xC732, UNICODE_NORM_QC_NO},
+	{0xC733, UNICODE_NORM_QC_NO},
+	{0xC734, UNICODE_NORM_QC_NO},
+	{0xC735, UNICODE_NORM_QC_NO},
+	{0xC736, UNICODE_NORM_QC_NO},
+	{0xC737, UNICODE_NORM_QC_NO},
+	{0xC738, UNICODE_NORM_QC_NO},
+	{0xC739, UNICODE_NORM_QC_NO},
+	{0xC73A, UNICODE_NORM_QC_NO},
+	{0xC73B, UNICODE_NORM_QC_NO},
+	{0xC73C, UNICODE_NORM_QC_NO},
+	{0xC73D, UNICODE_NORM_QC_NO},
+	{0xC73E, UNICODE_NORM_QC_NO},
+	{0xC73F, UNICODE_NORM_QC_NO},
+	{0xC740, UNICODE_NORM_QC_NO},
+	{0xC741, UNICODE_NORM_QC_NO},
+	{0xC742, UNICODE_NORM_QC_NO},
+	{0xC743, UNICODE_NORM_QC_NO},
+	{0xC744, UNICODE_NORM_QC_NO},
+	{0xC745, UNICODE_NORM_QC_NO},
+	{0xC746, UNICODE_NORM_QC_NO},
+	{0xC747, UNICODE_NORM_QC_NO},
+	{0xC748, UNICODE_NORM_QC_NO},
+	{0xC749, UNICODE_NORM_QC_NO},
+	{0xC74A, UNICODE_NORM_QC_NO},
+	{0xC74B, UNICODE_NORM_QC_NO},
+	{0xC74C, UNICODE_NORM_QC_NO},
+	{0xC74D, UNICODE_NORM_QC_NO},
+	{0xC74E, UNICODE_NORM_QC_NO},
+	{0xC74F, UNICODE_NORM_QC_NO},
+	{0xC750, UNICODE_NORM_QC_NO},
+	{0xC751, UNICODE_NORM_QC_NO},
+	{0xC752, UNICODE_NORM_QC_NO},
+	{0xC753, UNICODE_NORM_QC_NO},
+	{0xC754, UNICODE_NORM_QC_NO},
+	{0xC755, UNICODE_NORM_QC_NO},
+	{0xC756, UNICODE_NORM_QC_NO},
+	{0xC757, UNICODE_NORM_QC_NO},
+	{0xC758, UNICODE_NORM_QC_NO},
+	{0xC759, UNICODE_NORM_QC_NO},
+	{0xC75A, UNICODE_NORM_QC_NO},
+	{0xC75B, UNICODE_NORM_QC_NO},
+	{0xC75C, UNICODE_NORM_QC_NO},
+	{0xC75D, UNICODE_NORM_QC_NO},
+	{0xC75E, UNICODE_NORM_QC_NO},
+	{0xC75F, UNICODE_NORM_QC_NO},
+	{0xC760, UNICODE_NORM_QC_NO},
+	{0xC761, UNICODE_NORM_QC_NO},
+	{0xC762, UNICODE_NORM_QC_NO},
+	{0xC763, UNICODE_NORM_QC_NO},
+	{0xC764, UNICODE_NORM_QC_NO},
+	{0xC765, UNICODE_NORM_QC_NO},
+	{0xC766, UNICODE_NORM_QC_NO},
+	{0xC767, UNICODE_NORM_QC_NO},
+	{0xC768, UNICODE_NORM_QC_NO},
+	{0xC769, UNICODE_NORM_QC_NO},
+	{0xC76A, UNICODE_NORM_QC_NO},
+	{0xC76B, UNICODE_NORM_QC_NO},
+	{0xC76C, UNICODE_NORM_QC_NO},
+	{0xC76D, UNICODE_NORM_QC_NO},
+	{0xC76E, UNICODE_NORM_QC_NO},
+	{0xC76F, UNICODE_NORM_QC_NO},
+	{0xC770, UNICODE_NORM_QC_NO},
+	{0xC771, UNICODE_NORM_QC_NO},
+	{0xC772, UNICODE_NORM_QC_NO},
+	{0xC773, UNICODE_NORM_QC_NO},
+	{0xC774, UNICODE_NORM_QC_NO},
+	{0xC775, UNICODE_NORM_QC_NO},
+	{0xC776, UNICODE_NORM_QC_NO},
+	{0xC777, UNICODE_NORM_QC_NO},
+	{0xC778, UNICODE_NORM_QC_NO},
+	{0xC779, UNICODE_NORM_QC_NO},
+	{0xC77A, UNICODE_NORM_QC_NO},
+	{0xC77B, UNICODE_NORM_QC_NO},
+	{0xC77C, UNICODE_NORM_QC_NO},
+	{0xC77D, UNICODE_NORM_QC_NO},
+	{0xC77E, UNICODE_NORM_QC_NO},
+	{0xC77F, UNICODE_NORM_QC_NO},
+	{0xC780, UNICODE_NORM_QC_NO},
+	{0xC781, UNICODE_NORM_QC_NO},
+	{0xC782, UNICODE_NORM_QC_NO},
+	{0xC783, UNICODE_NORM_QC_NO},
+	{0xC784, UNICODE_NORM_QC_NO},
+	{0xC785, UNICODE_NORM_QC_NO},
+	{0xC786, UNICODE_NORM_QC_NO},
+	{0xC787, UNICODE_NORM_QC_NO},
+	{0xC788, UNICODE_NORM_QC_NO},
+	{0xC789, UNICODE_NORM_QC_NO},
+	{0xC78A, UNICODE_NORM_QC_NO},
+	{0xC78B, UNICODE_NORM_QC_NO},
+	{0xC78C, UNICODE_NORM_QC_NO},
+	{0xC78D, UNICODE_NORM_QC_NO},
+	{0xC78E, UNICODE_NORM_QC_NO},
+	{0xC78F, UNICODE_NORM_QC_NO},
+	{0xC790, UNICODE_NORM_QC_NO},
+	{0xC791, UNICODE_NORM_QC_NO},
+	{0xC792, UNICODE_NORM_QC_NO},
+	{0xC793, UNICODE_NORM_QC_NO},
+	{0xC794, UNICODE_NORM_QC_NO},
+	{0xC795, UNICODE_NORM_QC_NO},
+	{0xC796, UNICODE_NORM_QC_NO},
+	{0xC797, UNICODE_NORM_QC_NO},
+	{0xC798, UNICODE_NORM_QC_NO},
+	{0xC799, UNICODE_NORM_QC_NO},
+	{0xC79A, UNICODE_NORM_QC_NO},
+	{0xC79B, UNICODE_NORM_QC_NO},
+	{0xC79C, UNICODE_NORM_QC_NO},
+	{0xC79D, UNICODE_NORM_QC_NO},
+	{0xC79E, UNICODE_NORM_QC_NO},
+	{0xC79F, UNICODE_NORM_QC_NO},
+	{0xC7A0, UNICODE_NORM_QC_NO},
+	{0xC7A1, UNICODE_NORM_QC_NO},
+	{0xC7A2, UNICODE_NORM_QC_NO},
+	{0xC7A3, UNICODE_NORM_QC_NO},
+	{0xC7A4, UNICODE_NORM_QC_NO},
+	{0xC7A5, UNICODE_NORM_QC_NO},
+	{0xC7A6, UNICODE_NORM_QC_NO},
+	{0xC7A7, UNICODE_NORM_QC_NO},
+	{0xC7A8, UNICODE_NORM_QC_NO},
+	{0xC7A9, UNICODE_NORM_QC_NO},
+	{0xC7AA, UNICODE_NORM_QC_NO},
+	{0xC7AB, UNICODE_NORM_QC_NO},
+	{0xC7AC, UNICODE_NORM_QC_NO},
+	{0xC7AD, UNICODE_NORM_QC_NO},
+	{0xC7AE, UNICODE_NORM_QC_NO},
+	{0xC7AF, UNICODE_NORM_QC_NO},
+	{0xC7B0, UNICODE_NORM_QC_NO},
+	{0xC7B1, UNICODE_NORM_QC_NO},
+	{0xC7B2, UNICODE_NORM_QC_NO},
+	{0xC7B3, UNICODE_NORM_QC_NO},
+	{0xC7B4, UNICODE_NORM_QC_NO},
+	{0xC7B5, UNICODE_NORM_QC_NO},
+	{0xC7B6, UNICODE_NORM_QC_NO},
+	{0xC7B7, UNICODE_NORM_QC_NO},
+	{0xC7B8, UNICODE_NORM_QC_NO},
+	{0xC7B9, UNICODE_NORM_QC_NO},
+	{0xC7BA, UNICODE_NORM_QC_NO},
+	{0xC7BB, UNICODE_NORM_QC_NO},
+	{0xC7BC, UNICODE_NORM_QC_NO},
+	{0xC7BD, UNICODE_NORM_QC_NO},
+	{0xC7BE, UNICODE_NORM_QC_NO},
+	{0xC7BF, UNICODE_NORM_QC_NO},
+	{0xC7C0, UNICODE_NORM_QC_NO},
+	{0xC7C1, UNICODE_NORM_QC_NO},
+	{0xC7C2, UNICODE_NORM_QC_NO},
+	{0xC7C3, UNICODE_NORM_QC_NO},
+	{0xC7C4, UNICODE_NORM_QC_NO},
+	{0xC7C5, UNICODE_NORM_QC_NO},
+	{0xC7C6, UNICODE_NORM_QC_NO},
+	{0xC7C7, UNICODE_NORM_QC_NO},
+	{0xC7C8, UNICODE_NORM_QC_NO},
+	{0xC7C9, UNICODE_NORM_QC_NO},
+	{0xC7CA, UNICODE_NORM_QC_NO},
+	{0xC7CB, UNICODE_NORM_QC_NO},
+	{0xC7CC, UNICODE_NORM_QC_NO},
+	{0xC7CD, UNICODE_NORM_QC_NO},
+	{0xC7CE, UNICODE_NORM_QC_NO},
+	{0xC7CF, UNICODE_NORM_QC_NO},
+	{0xC7D0, UNICODE_NORM_QC_NO},
+	{0xC7D1, UNICODE_NORM_QC_NO},
+	{0xC7D2, UNICODE_NORM_QC_NO},
+	{0xC7D3, UNICODE_NORM_QC_NO},
+	{0xC7D4, UNICODE_NORM_QC_NO},
+	{0xC7D5, UNICODE_NORM_QC_NO},
+	{0xC7D6, UNICODE_NORM_QC_NO},
+	{0xC7D7, UNICODE_NORM_QC_NO},
+	{0xC7D8, UNICODE_NORM_QC_NO},
+	{0xC7D9, UNICODE_NORM_QC_NO},
+	{0xC7DA, UNICODE_NORM_QC_NO},
+	{0xC7DB, UNICODE_NORM_QC_NO},
+	{0xC7DC, UNICODE_NORM_QC_NO},
+	{0xC7DD, UNICODE_NORM_QC_NO},
+	{0xC7DE, UNICODE_NORM_QC_NO},
+	{0xC7DF, UNICODE_NORM_QC_NO},
+	{0xC7E0, UNICODE_NORM_QC_NO},
+	{0xC7E1, UNICODE_NORM_QC_NO},
+	{0xC7E2, UNICODE_NORM_QC_NO},
+	{0xC7E3, UNICODE_NORM_QC_NO},
+	{0xC7E4, UNICODE_NORM_QC_NO},
+	{0xC7E5, UNICODE_NORM_QC_NO},
+	{0xC7E6, UNICODE_NORM_QC_NO},
+	{0xC7E7, UNICODE_NORM_QC_NO},
+	{0xC7E8, UNICODE_NORM_QC_NO},
+	{0xC7E9, UNICODE_NORM_QC_NO},
+	{0xC7EA, UNICODE_NORM_QC_NO},
+	{0xC7EB, UNICODE_NORM_QC_NO},
+	{0xC7EC, UNICODE_NORM_QC_NO},
+	{0xC7ED, UNICODE_NORM_QC_NO},
+	{0xC7EE, UNICODE_NORM_QC_NO},
+	{0xC7EF, UNICODE_NORM_QC_NO},
+	{0xC7F0, UNICODE_NORM_QC_NO},
+	{0xC7F1, UNICODE_NORM_QC_NO},
+	{0xC7F2, UNICODE_NORM_QC_NO},
+	{0xC7F3, UNICODE_NORM_QC_NO},
+	{0xC7F4, UNICODE_NORM_QC_NO},
+	{0xC7F5, UNICODE_NORM_QC_NO},
+	{0xC7F6, UNICODE_NORM_QC_NO},
+	{0xC7F7, UNICODE_NORM_QC_NO},
+	{0xC7F8, UNICODE_NORM_QC_NO},
+	{0xC7F9, UNICODE_NORM_QC_NO},
+	{0xC7FA, UNICODE_NORM_QC_NO},
+	{0xC7FB, UNICODE_NORM_QC_NO},
+	{0xC7FC, UNICODE_NORM_QC_NO},
+	{0xC7FD, UNICODE_NORM_QC_NO},
+	{0xC7FE, UNICODE_NORM_QC_NO},
+	{0xC7FF, UNICODE_NORM_QC_NO},
+	{0xC800, UNICODE_NORM_QC_NO},
+	{0xC801, UNICODE_NORM_QC_NO},
+	{0xC802, UNICODE_NORM_QC_NO},
+	{0xC803, UNICODE_NORM_QC_NO},
+	{0xC804, UNICODE_NORM_QC_NO},
+	{0xC805, UNICODE_NORM_QC_NO},
+	{0xC806, UNICODE_NORM_QC_NO},
+	{0xC807, UNICODE_NORM_QC_NO},
+	{0xC808, UNICODE_NORM_QC_NO},
+	{0xC809, UNICODE_NORM_QC_NO},
+	{0xC80A, UNICODE_NORM_QC_NO},
+	{0xC80B, UNICODE_NORM_QC_NO},
+	{0xC80C, UNICODE_NORM_QC_NO},
+	{0xC80D, UNICODE_NORM_QC_NO},
+	{0xC80E, UNICODE_NORM_QC_NO},
+	{0xC80F, UNICODE_NORM_QC_NO},
+	{0xC810, UNICODE_NORM_QC_NO},
+	{0xC811, UNICODE_NORM_QC_NO},
+	{0xC812, UNICODE_NORM_QC_NO},
+	{0xC813, UNICODE_NORM_QC_NO},
+	{0xC814, UNICODE_NORM_QC_NO},
+	{0xC815, UNICODE_NORM_QC_NO},
+	{0xC816, UNICODE_NORM_QC_NO},
+	{0xC817, UNICODE_NORM_QC_NO},
+	{0xC818, UNICODE_NORM_QC_NO},
+	{0xC819, UNICODE_NORM_QC_NO},
+	{0xC81A, UNICODE_NORM_QC_NO},
+	{0xC81B, UNICODE_NORM_QC_NO},
+	{0xC81C, UNICODE_NORM_QC_NO},
+	{0xC81D, UNICODE_NORM_QC_NO},
+	{0xC81E, UNICODE_NORM_QC_NO},
+	{0xC81F, UNICODE_NORM_QC_NO},
+	{0xC820, UNICODE_NORM_QC_NO},
+	{0xC821, UNICODE_NORM_QC_NO},
+	{0xC822, UNICODE_NORM_QC_NO},
+	{0xC823, UNICODE_NORM_QC_NO},
+	{0xC824, UNICODE_NORM_QC_NO},
+	{0xC825, UNICODE_NORM_QC_NO},
+	{0xC826, UNICODE_NORM_QC_NO},
+	{0xC827, UNICODE_NORM_QC_NO},
+	{0xC828, UNICODE_NORM_QC_NO},
+	{0xC829, UNICODE_NORM_QC_NO},
+	{0xC82A, UNICODE_NORM_QC_NO},
+	{0xC82B, UNICODE_NORM_QC_NO},
+	{0xC82C, UNICODE_NORM_QC_NO},
+	{0xC82D, UNICODE_NORM_QC_NO},
+	{0xC82E, UNICODE_NORM_QC_NO},
+	{0xC82F, UNICODE_NORM_QC_NO},
+	{0xC830, UNICODE_NORM_QC_NO},
+	{0xC831, UNICODE_NORM_QC_NO},
+	{0xC832, UNICODE_NORM_QC_NO},
+	{0xC833, UNICODE_NORM_QC_NO},
+	{0xC834, UNICODE_NORM_QC_NO},
+	{0xC835, UNICODE_NORM_QC_NO},
+	{0xC836, UNICODE_NORM_QC_NO},
+	{0xC837, UNICODE_NORM_QC_NO},
+	{0xC838, UNICODE_NORM_QC_NO},
+	{0xC839, UNICODE_NORM_QC_NO},
+	{0xC83A, UNICODE_NORM_QC_NO},
+	{0xC83B, UNICODE_NORM_QC_NO},
+	{0xC83C, UNICODE_NORM_QC_NO},
+	{0xC83D, UNICODE_NORM_QC_NO},
+	{0xC83E, UNICODE_NORM_QC_NO},
+	{0xC83F, UNICODE_NORM_QC_NO},
+	{0xC840, UNICODE_NORM_QC_NO},
+	{0xC841, UNICODE_NORM_QC_NO},
+	{0xC842, UNICODE_NORM_QC_NO},
+	{0xC843, UNICODE_NORM_QC_NO},
+	{0xC844, UNICODE_NORM_QC_NO},
+	{0xC845, UNICODE_NORM_QC_NO},
+	{0xC846, UNICODE_NORM_QC_NO},
+	{0xC847, UNICODE_NORM_QC_NO},
+	{0xC848, UNICODE_NORM_QC_NO},
+	{0xC849, UNICODE_NORM_QC_NO},
+	{0xC84A, UNICODE_NORM_QC_NO},
+	{0xC84B, UNICODE_NORM_QC_NO},
+	{0xC84C, UNICODE_NORM_QC_NO},
+	{0xC84D, UNICODE_NORM_QC_NO},
+	{0xC84E, UNICODE_NORM_QC_NO},
+	{0xC84F, UNICODE_NORM_QC_NO},
+	{0xC850, UNICODE_NORM_QC_NO},
+	{0xC851, UNICODE_NORM_QC_NO},
+	{0xC852, UNICODE_NORM_QC_NO},
+	{0xC853, UNICODE_NORM_QC_NO},
+	{0xC854, UNICODE_NORM_QC_NO},
+	{0xC855, UNICODE_NORM_QC_NO},
+	{0xC856, UNICODE_NORM_QC_NO},
+	{0xC857, UNICODE_NORM_QC_NO},
+	{0xC858, UNICODE_NORM_QC_NO},
+	{0xC859, UNICODE_NORM_QC_NO},
+	{0xC85A, UNICODE_NORM_QC_NO},
+	{0xC85B, UNICODE_NORM_QC_NO},
+	{0xC85C, UNICODE_NORM_QC_NO},
+	{0xC85D, UNICODE_NORM_QC_NO},
+	{0xC85E, UNICODE_NORM_QC_NO},
+	{0xC85F, UNICODE_NORM_QC_NO},
+	{0xC860, UNICODE_NORM_QC_NO},
+	{0xC861, UNICODE_NORM_QC_NO},
+	{0xC862, UNICODE_NORM_QC_NO},
+	{0xC863, UNICODE_NORM_QC_NO},
+	{0xC864, UNICODE_NORM_QC_NO},
+	{0xC865, UNICODE_NORM_QC_NO},
+	{0xC866, UNICODE_NORM_QC_NO},
+	{0xC867, UNICODE_NORM_QC_NO},
+	{0xC868, UNICODE_NORM_QC_NO},
+	{0xC869, UNICODE_NORM_QC_NO},
+	{0xC86A, UNICODE_NORM_QC_NO},
+	{0xC86B, UNICODE_NORM_QC_NO},
+	{0xC86C, UNICODE_NORM_QC_NO},
+	{0xC86D, UNICODE_NORM_QC_NO},
+	{0xC86E, UNICODE_NORM_QC_NO},
+	{0xC86F, UNICODE_NORM_QC_NO},
+	{0xC870, UNICODE_NORM_QC_NO},
+	{0xC871, UNICODE_NORM_QC_NO},
+	{0xC872, UNICODE_NORM_QC_NO},
+	{0xC873, UNICODE_NORM_QC_NO},
+	{0xC874, UNICODE_NORM_QC_NO},
+	{0xC875, UNICODE_NORM_QC_NO},
+	{0xC876, UNICODE_NORM_QC_NO},
+	{0xC877, UNICODE_NORM_QC_NO},
+	{0xC878, UNICODE_NORM_QC_NO},
+	{0xC879, UNICODE_NORM_QC_NO},
+	{0xC87A, UNICODE_NORM_QC_NO},
+	{0xC87B, UNICODE_NORM_QC_NO},
+	{0xC87C, UNICODE_NORM_QC_NO},
+	{0xC87D, UNICODE_NORM_QC_NO},
+	{0xC87E, UNICODE_NORM_QC_NO},
+	{0xC87F, UNICODE_NORM_QC_NO},
+	{0xC880, UNICODE_NORM_QC_NO},
+	{0xC881, UNICODE_NORM_QC_NO},
+	{0xC882, UNICODE_NORM_QC_NO},
+	{0xC883, UNICODE_NORM_QC_NO},
+	{0xC884, UNICODE_NORM_QC_NO},
+	{0xC885, UNICODE_NORM_QC_NO},
+	{0xC886, UNICODE_NORM_QC_NO},
+	{0xC887, UNICODE_NORM_QC_NO},
+	{0xC888, UNICODE_NORM_QC_NO},
+	{0xC889, UNICODE_NORM_QC_NO},
+	{0xC88A, UNICODE_NORM_QC_NO},
+	{0xC88B, UNICODE_NORM_QC_NO},
+	{0xC88C, UNICODE_NORM_QC_NO},
+	{0xC88D, UNICODE_NORM_QC_NO},
+	{0xC88E, UNICODE_NORM_QC_NO},
+	{0xC88F, UNICODE_NORM_QC_NO},
+	{0xC890, UNICODE_NORM_QC_NO},
+	{0xC891, UNICODE_NORM_QC_NO},
+	{0xC892, UNICODE_NORM_QC_NO},
+	{0xC893, UNICODE_NORM_QC_NO},
+	{0xC894, UNICODE_NORM_QC_NO},
+	{0xC895, UNICODE_NORM_QC_NO},
+	{0xC896, UNICODE_NORM_QC_NO},
+	{0xC897, UNICODE_NORM_QC_NO},
+	{0xC898, UNICODE_NORM_QC_NO},
+	{0xC899, UNICODE_NORM_QC_NO},
+	{0xC89A, UNICODE_NORM_QC_NO},
+	{0xC89B, UNICODE_NORM_QC_NO},
+	{0xC89C, UNICODE_NORM_QC_NO},
+	{0xC89D, UNICODE_NORM_QC_NO},
+	{0xC89E, UNICODE_NORM_QC_NO},
+	{0xC89F, UNICODE_NORM_QC_NO},
+	{0xC8A0, UNICODE_NORM_QC_NO},
+	{0xC8A1, UNICODE_NORM_QC_NO},
+	{0xC8A2, UNICODE_NORM_QC_NO},
+	{0xC8A3, UNICODE_NORM_QC_NO},
+	{0xC8A4, UNICODE_NORM_QC_NO},
+	{0xC8A5, UNICODE_NORM_QC_NO},
+	{0xC8A6, UNICODE_NORM_QC_NO},
+	{0xC8A7, UNICODE_NORM_QC_NO},
+	{0xC8A8, UNICODE_NORM_QC_NO},
+	{0xC8A9, UNICODE_NORM_QC_NO},
+	{0xC8AA, UNICODE_NORM_QC_NO},
+	{0xC8AB, UNICODE_NORM_QC_NO},
+	{0xC8AC, UNICODE_NORM_QC_NO},
+	{0xC8AD, UNICODE_NORM_QC_NO},
+	{0xC8AE, UNICODE_NORM_QC_NO},
+	{0xC8AF, UNICODE_NORM_QC_NO},
+	{0xC8B0, UNICODE_NORM_QC_NO},
+	{0xC8B1, UNICODE_NORM_QC_NO},
+	{0xC8B2, UNICODE_NORM_QC_NO},
+	{0xC8B3, UNICODE_NORM_QC_NO},
+	{0xC8B4, UNICODE_NORM_QC_NO},
+	{0xC8B5, UNICODE_NORM_QC_NO},
+	{0xC8B6, UNICODE_NORM_QC_NO},
+	{0xC8B7, UNICODE_NORM_QC_NO},
+	{0xC8B8, UNICODE_NORM_QC_NO},
+	{0xC8B9, UNICODE_NORM_QC_NO},
+	{0xC8BA, UNICODE_NORM_QC_NO},
+	{0xC8BB, UNICODE_NORM_QC_NO},
+	{0xC8BC, UNICODE_NORM_QC_NO},
+	{0xC8BD, UNICODE_NORM_QC_NO},
+	{0xC8BE, UNICODE_NORM_QC_NO},
+	{0xC8BF, UNICODE_NORM_QC_NO},
+	{0xC8C0, UNICODE_NORM_QC_NO},
+	{0xC8C1, UNICODE_NORM_QC_NO},
+	{0xC8C2, UNICODE_NORM_QC_NO},
+	{0xC8C3, UNICODE_NORM_QC_NO},
+	{0xC8C4, UNICODE_NORM_QC_NO},
+	{0xC8C5, UNICODE_NORM_QC_NO},
+	{0xC8C6, UNICODE_NORM_QC_NO},
+	{0xC8C7, UNICODE_NORM_QC_NO},
+	{0xC8C8, UNICODE_NORM_QC_NO},
+	{0xC8C9, UNICODE_NORM_QC_NO},
+	{0xC8CA, UNICODE_NORM_QC_NO},
+	{0xC8CB, UNICODE_NORM_QC_NO},
+	{0xC8CC, UNICODE_NORM_QC_NO},
+	{0xC8CD, UNICODE_NORM_QC_NO},
+	{0xC8CE, UNICODE_NORM_QC_NO},
+	{0xC8CF, UNICODE_NORM_QC_NO},
+	{0xC8D0, UNICODE_NORM_QC_NO},
+	{0xC8D1, UNICODE_NORM_QC_NO},
+	{0xC8D2, UNICODE_NORM_QC_NO},
+	{0xC8D3, UNICODE_NORM_QC_NO},
+	{0xC8D4, UNICODE_NORM_QC_NO},
+	{0xC8D5, UNICODE_NORM_QC_NO},
+	{0xC8D6, UNICODE_NORM_QC_NO},
+	{0xC8D7, UNICODE_NORM_QC_NO},
+	{0xC8D8, UNICODE_NORM_QC_NO},
+	{0xC8D9, UNICODE_NORM_QC_NO},
+	{0xC8DA, UNICODE_NORM_QC_NO},
+	{0xC8DB, UNICODE_NORM_QC_NO},
+	{0xC8DC, UNICODE_NORM_QC_NO},
+	{0xC8DD, UNICODE_NORM_QC_NO},
+	{0xC8DE, UNICODE_NORM_QC_NO},
+	{0xC8DF, UNICODE_NORM_QC_NO},
+	{0xC8E0, UNICODE_NORM_QC_NO},
+	{0xC8E1, UNICODE_NORM_QC_NO},
+	{0xC8E2, UNICODE_NORM_QC_NO},
+	{0xC8E3, UNICODE_NORM_QC_NO},
+	{0xC8E4, UNICODE_NORM_QC_NO},
+	{0xC8E5, UNICODE_NORM_QC_NO},
+	{0xC8E6, UNICODE_NORM_QC_NO},
+	{0xC8E7, UNICODE_NORM_QC_NO},
+	{0xC8E8, UNICODE_NORM_QC_NO},
+	{0xC8E9, UNICODE_NORM_QC_NO},
+	{0xC8EA, UNICODE_NORM_QC_NO},
+	{0xC8EB, UNICODE_NORM_QC_NO},
+	{0xC8EC, UNICODE_NORM_QC_NO},
+	{0xC8ED, UNICODE_NORM_QC_NO},
+	{0xC8EE, UNICODE_NORM_QC_NO},
+	{0xC8EF, UNICODE_NORM_QC_NO},
+	{0xC8F0, UNICODE_NORM_QC_NO},
+	{0xC8F1, UNICODE_NORM_QC_NO},
+	{0xC8F2, UNICODE_NORM_QC_NO},
+	{0xC8F3, UNICODE_NORM_QC_NO},
+	{0xC8F4, UNICODE_NORM_QC_NO},
+	{0xC8F5, UNICODE_NORM_QC_NO},
+	{0xC8F6, UNICODE_NORM_QC_NO},
+	{0xC8F7, UNICODE_NORM_QC_NO},
+	{0xC8F8, UNICODE_NORM_QC_NO},
+	{0xC8F9, UNICODE_NORM_QC_NO},
+	{0xC8FA, UNICODE_NORM_QC_NO},
+	{0xC8FB, UNICODE_NORM_QC_NO},
+	{0xC8FC, UNICODE_NORM_QC_NO},
+	{0xC8FD, UNICODE_NORM_QC_NO},
+	{0xC8FE, UNICODE_NORM_QC_NO},
+	{0xC8FF, UNICODE_NORM_QC_NO},
+	{0xC900, UNICODE_NORM_QC_NO},
+	{0xC901, UNICODE_NORM_QC_NO},
+	{0xC902, UNICODE_NORM_QC_NO},
+	{0xC903, UNICODE_NORM_QC_NO},
+	{0xC904, UNICODE_NORM_QC_NO},
+	{0xC905, UNICODE_NORM_QC_NO},
+	{0xC906, UNICODE_NORM_QC_NO},
+	{0xC907, UNICODE_NORM_QC_NO},
+	{0xC908, UNICODE_NORM_QC_NO},
+	{0xC909, UNICODE_NORM_QC_NO},
+	{0xC90A, UNICODE_NORM_QC_NO},
+	{0xC90B, UNICODE_NORM_QC_NO},
+	{0xC90C, UNICODE_NORM_QC_NO},
+	{0xC90D, UNICODE_NORM_QC_NO},
+	{0xC90E, UNICODE_NORM_QC_NO},
+	{0xC90F, UNICODE_NORM_QC_NO},
+	{0xC910, UNICODE_NORM_QC_NO},
+	{0xC911, UNICODE_NORM_QC_NO},
+	{0xC912, UNICODE_NORM_QC_NO},
+	{0xC913, UNICODE_NORM_QC_NO},
+	{0xC914, UNICODE_NORM_QC_NO},
+	{0xC915, UNICODE_NORM_QC_NO},
+	{0xC916, UNICODE_NORM_QC_NO},
+	{0xC917, UNICODE_NORM_QC_NO},
+	{0xC918, UNICODE_NORM_QC_NO},
+	{0xC919, UNICODE_NORM_QC_NO},
+	{0xC91A, UNICODE_NORM_QC_NO},
+	{0xC91B, UNICODE_NORM_QC_NO},
+	{0xC91C, UNICODE_NORM_QC_NO},
+	{0xC91D, UNICODE_NORM_QC_NO},
+	{0xC91E, UNICODE_NORM_QC_NO},
+	{0xC91F, UNICODE_NORM_QC_NO},
+	{0xC920, UNICODE_NORM_QC_NO},
+	{0xC921, UNICODE_NORM_QC_NO},
+	{0xC922, UNICODE_NORM_QC_NO},
+	{0xC923, UNICODE_NORM_QC_NO},
+	{0xC924, UNICODE_NORM_QC_NO},
+	{0xC925, UNICODE_NORM_QC_NO},
+	{0xC926, UNICODE_NORM_QC_NO},
+	{0xC927, UNICODE_NORM_QC_NO},
+	{0xC928, UNICODE_NORM_QC_NO},
+	{0xC929, UNICODE_NORM_QC_NO},
+	{0xC92A, UNICODE_NORM_QC_NO},
+	{0xC92B, UNICODE_NORM_QC_NO},
+	{0xC92C, UNICODE_NORM_QC_NO},
+	{0xC92D, UNICODE_NORM_QC_NO},
+	{0xC92E, UNICODE_NORM_QC_NO},
+	{0xC92F, UNICODE_NORM_QC_NO},
+	{0xC930, UNICODE_NORM_QC_NO},
+	{0xC931, UNICODE_NORM_QC_NO},
+	{0xC932, UNICODE_NORM_QC_NO},
+	{0xC933, UNICODE_NORM_QC_NO},
+	{0xC934, UNICODE_NORM_QC_NO},
+	{0xC935, UNICODE_NORM_QC_NO},
+	{0xC936, UNICODE_NORM_QC_NO},
+	{0xC937, UNICODE_NORM_QC_NO},
+	{0xC938, UNICODE_NORM_QC_NO},
+	{0xC939, UNICODE_NORM_QC_NO},
+	{0xC93A, UNICODE_NORM_QC_NO},
+	{0xC93B, UNICODE_NORM_QC_NO},
+	{0xC93C, UNICODE_NORM_QC_NO},
+	{0xC93D, UNICODE_NORM_QC_NO},
+	{0xC93E, UNICODE_NORM_QC_NO},
+	{0xC93F, UNICODE_NORM_QC_NO},
+	{0xC940, UNICODE_NORM_QC_NO},
+	{0xC941, UNICODE_NORM_QC_NO},
+	{0xC942, UNICODE_NORM_QC_NO},
+	{0xC943, UNICODE_NORM_QC_NO},
+	{0xC944, UNICODE_NORM_QC_NO},
+	{0xC945, UNICODE_NORM_QC_NO},
+	{0xC946, UNICODE_NORM_QC_NO},
+	{0xC947, UNICODE_NORM_QC_NO},
+	{0xC948, UNICODE_NORM_QC_NO},
+	{0xC949, UNICODE_NORM_QC_NO},
+	{0xC94A, UNICODE_NORM_QC_NO},
+	{0xC94B, UNICODE_NORM_QC_NO},
+	{0xC94C, UNICODE_NORM_QC_NO},
+	{0xC94D, UNICODE_NORM_QC_NO},
+	{0xC94E, UNICODE_NORM_QC_NO},
+	{0xC94F, UNICODE_NORM_QC_NO},
+	{0xC950, UNICODE_NORM_QC_NO},
+	{0xC951, UNICODE_NORM_QC_NO},
+	{0xC952, UNICODE_NORM_QC_NO},
+	{0xC953, UNICODE_NORM_QC_NO},
+	{0xC954, UNICODE_NORM_QC_NO},
+	{0xC955, UNICODE_NORM_QC_NO},
+	{0xC956, UNICODE_NORM_QC_NO},
+	{0xC957, UNICODE_NORM_QC_NO},
+	{0xC958, UNICODE_NORM_QC_NO},
+	{0xC959, UNICODE_NORM_QC_NO},
+	{0xC95A, UNICODE_NORM_QC_NO},
+	{0xC95B, UNICODE_NORM_QC_NO},
+	{0xC95C, UNICODE_NORM_QC_NO},
+	{0xC95D, UNICODE_NORM_QC_NO},
+	{0xC95E, UNICODE_NORM_QC_NO},
+	{0xC95F, UNICODE_NORM_QC_NO},
+	{0xC960, UNICODE_NORM_QC_NO},
+	{0xC961, UNICODE_NORM_QC_NO},
+	{0xC962, UNICODE_NORM_QC_NO},
+	{0xC963, UNICODE_NORM_QC_NO},
+	{0xC964, UNICODE_NORM_QC_NO},
+	{0xC965, UNICODE_NORM_QC_NO},
+	{0xC966, UNICODE_NORM_QC_NO},
+	{0xC967, UNICODE_NORM_QC_NO},
+	{0xC968, UNICODE_NORM_QC_NO},
+	{0xC969, UNICODE_NORM_QC_NO},
+	{0xC96A, UNICODE_NORM_QC_NO},
+	{0xC96B, UNICODE_NORM_QC_NO},
+	{0xC96C, UNICODE_NORM_QC_NO},
+	{0xC96D, UNICODE_NORM_QC_NO},
+	{0xC96E, UNICODE_NORM_QC_NO},
+	{0xC96F, UNICODE_NORM_QC_NO},
+	{0xC970, UNICODE_NORM_QC_NO},
+	{0xC971, UNICODE_NORM_QC_NO},
+	{0xC972, UNICODE_NORM_QC_NO},
+	{0xC973, UNICODE_NORM_QC_NO},
+	{0xC974, UNICODE_NORM_QC_NO},
+	{0xC975, UNICODE_NORM_QC_NO},
+	{0xC976, UNICODE_NORM_QC_NO},
+	{0xC977, UNICODE_NORM_QC_NO},
+	{0xC978, UNICODE_NORM_QC_NO},
+	{0xC979, UNICODE_NORM_QC_NO},
+	{0xC97A, UNICODE_NORM_QC_NO},
+	{0xC97B, UNICODE_NORM_QC_NO},
+	{0xC97C, UNICODE_NORM_QC_NO},
+	{0xC97D, UNICODE_NORM_QC_NO},
+	{0xC97E, UNICODE_NORM_QC_NO},
+	{0xC97F, UNICODE_NORM_QC_NO},
+	{0xC980, UNICODE_NORM_QC_NO},
+	{0xC981, UNICODE_NORM_QC_NO},
+	{0xC982, UNICODE_NORM_QC_NO},
+	{0xC983, UNICODE_NORM_QC_NO},
+	{0xC984, UNICODE_NORM_QC_NO},
+	{0xC985, UNICODE_NORM_QC_NO},
+	{0xC986, UNICODE_NORM_QC_NO},
+	{0xC987, UNICODE_NORM_QC_NO},
+	{0xC988, UNICODE_NORM_QC_NO},
+	{0xC989, UNICODE_NORM_QC_NO},
+	{0xC98A, UNICODE_NORM_QC_NO},
+	{0xC98B, UNICODE_NORM_QC_NO},
+	{0xC98C, UNICODE_NORM_QC_NO},
+	{0xC98D, UNICODE_NORM_QC_NO},
+	{0xC98E, UNICODE_NORM_QC_NO},
+	{0xC98F, UNICODE_NORM_QC_NO},
+	{0xC990, UNICODE_NORM_QC_NO},
+	{0xC991, UNICODE_NORM_QC_NO},
+	{0xC992, UNICODE_NORM_QC_NO},
+	{0xC993, UNICODE_NORM_QC_NO},
+	{0xC994, UNICODE_NORM_QC_NO},
+	{0xC995, UNICODE_NORM_QC_NO},
+	{0xC996, UNICODE_NORM_QC_NO},
+	{0xC997, UNICODE_NORM_QC_NO},
+	{0xC998, UNICODE_NORM_QC_NO},
+	{0xC999, UNICODE_NORM_QC_NO},
+	{0xC99A, UNICODE_NORM_QC_NO},
+	{0xC99B, UNICODE_NORM_QC_NO},
+	{0xC99C, UNICODE_NORM_QC_NO},
+	{0xC99D, UNICODE_NORM_QC_NO},
+	{0xC99E, UNICODE_NORM_QC_NO},
+	{0xC99F, UNICODE_NORM_QC_NO},
+	{0xC9A0, UNICODE_NORM_QC_NO},
+	{0xC9A1, UNICODE_NORM_QC_NO},
+	{0xC9A2, UNICODE_NORM_QC_NO},
+	{0xC9A3, UNICODE_NORM_QC_NO},
+	{0xC9A4, UNICODE_NORM_QC_NO},
+	{0xC9A5, UNICODE_NORM_QC_NO},
+	{0xC9A6, UNICODE_NORM_QC_NO},
+	{0xC9A7, UNICODE_NORM_QC_NO},
+	{0xC9A8, UNICODE_NORM_QC_NO},
+	{0xC9A9, UNICODE_NORM_QC_NO},
+	{0xC9AA, UNICODE_NORM_QC_NO},
+	{0xC9AB, UNICODE_NORM_QC_NO},
+	{0xC9AC, UNICODE_NORM_QC_NO},
+	{0xC9AD, UNICODE_NORM_QC_NO},
+	{0xC9AE, UNICODE_NORM_QC_NO},
+	{0xC9AF, UNICODE_NORM_QC_NO},
+	{0xC9B0, UNICODE_NORM_QC_NO},
+	{0xC9B1, UNICODE_NORM_QC_NO},
+	{0xC9B2, UNICODE_NORM_QC_NO},
+	{0xC9B3, UNICODE_NORM_QC_NO},
+	{0xC9B4, UNICODE_NORM_QC_NO},
+	{0xC9B5, UNICODE_NORM_QC_NO},
+	{0xC9B6, UNICODE_NORM_QC_NO},
+	{0xC9B7, UNICODE_NORM_QC_NO},
+	{0xC9B8, UNICODE_NORM_QC_NO},
+	{0xC9B9, UNICODE_NORM_QC_NO},
+	{0xC9BA, UNICODE_NORM_QC_NO},
+	{0xC9BB, UNICODE_NORM_QC_NO},
+	{0xC9BC, UNICODE_NORM_QC_NO},
+	{0xC9BD, UNICODE_NORM_QC_NO},
+	{0xC9BE, UNICODE_NORM_QC_NO},
+	{0xC9BF, UNICODE_NORM_QC_NO},
+	{0xC9C0, UNICODE_NORM_QC_NO},
+	{0xC9C1, UNICODE_NORM_QC_NO},
+	{0xC9C2, UNICODE_NORM_QC_NO},
+	{0xC9C3, UNICODE_NORM_QC_NO},
+	{0xC9C4, UNICODE_NORM_QC_NO},
+	{0xC9C5, UNICODE_NORM_QC_NO},
+	{0xC9C6, UNICODE_NORM_QC_NO},
+	{0xC9C7, UNICODE_NORM_QC_NO},
+	{0xC9C8, UNICODE_NORM_QC_NO},
+	{0xC9C9, UNICODE_NORM_QC_NO},
+	{0xC9CA, UNICODE_NORM_QC_NO},
+	{0xC9CB, UNICODE_NORM_QC_NO},
+	{0xC9CC, UNICODE_NORM_QC_NO},
+	{0xC9CD, UNICODE_NORM_QC_NO},
+	{0xC9CE, UNICODE_NORM_QC_NO},
+	{0xC9CF, UNICODE_NORM_QC_NO},
+	{0xC9D0, UNICODE_NORM_QC_NO},
+	{0xC9D1, UNICODE_NORM_QC_NO},
+	{0xC9D2, UNICODE_NORM_QC_NO},
+	{0xC9D3, UNICODE_NORM_QC_NO},
+	{0xC9D4, UNICODE_NORM_QC_NO},
+	{0xC9D5, UNICODE_NORM_QC_NO},
+	{0xC9D6, UNICODE_NORM_QC_NO},
+	{0xC9D7, UNICODE_NORM_QC_NO},
+	{0xC9D8, UNICODE_NORM_QC_NO},
+	{0xC9D9, UNICODE_NORM_QC_NO},
+	{0xC9DA, UNICODE_NORM_QC_NO},
+	{0xC9DB, UNICODE_NORM_QC_NO},
+	{0xC9DC, UNICODE_NORM_QC_NO},
+	{0xC9DD, UNICODE_NORM_QC_NO},
+	{0xC9DE, UNICODE_NORM_QC_NO},
+	{0xC9DF, UNICODE_NORM_QC_NO},
+	{0xC9E0, UNICODE_NORM_QC_NO},
+	{0xC9E1, UNICODE_NORM_QC_NO},
+	{0xC9E2, UNICODE_NORM_QC_NO},
+	{0xC9E3, UNICODE_NORM_QC_NO},
+	{0xC9E4, UNICODE_NORM_QC_NO},
+	{0xC9E5, UNICODE_NORM_QC_NO},
+	{0xC9E6, UNICODE_NORM_QC_NO},
+	{0xC9E7, UNICODE_NORM_QC_NO},
+	{0xC9E8, UNICODE_NORM_QC_NO},
+	{0xC9E9, UNICODE_NORM_QC_NO},
+	{0xC9EA, UNICODE_NORM_QC_NO},
+	{0xC9EB, UNICODE_NORM_QC_NO},
+	{0xC9EC, UNICODE_NORM_QC_NO},
+	{0xC9ED, UNICODE_NORM_QC_NO},
+	{0xC9EE, UNICODE_NORM_QC_NO},
+	{0xC9EF, UNICODE_NORM_QC_NO},
+	{0xC9F0, UNICODE_NORM_QC_NO},
+	{0xC9F1, UNICODE_NORM_QC_NO},
+	{0xC9F2, UNICODE_NORM_QC_NO},
+	{0xC9F3, UNICODE_NORM_QC_NO},
+	{0xC9F4, UNICODE_NORM_QC_NO},
+	{0xC9F5, UNICODE_NORM_QC_NO},
+	{0xC9F6, UNICODE_NORM_QC_NO},
+	{0xC9F7, UNICODE_NORM_QC_NO},
+	{0xC9F8, UNICODE_NORM_QC_NO},
+	{0xC9F9, UNICODE_NORM_QC_NO},
+	{0xC9FA, UNICODE_NORM_QC_NO},
+	{0xC9FB, UNICODE_NORM_QC_NO},
+	{0xC9FC, UNICODE_NORM_QC_NO},
+	{0xC9FD, UNICODE_NORM_QC_NO},
+	{0xC9FE, UNICODE_NORM_QC_NO},
+	{0xC9FF, UNICODE_NORM_QC_NO},
+	{0xCA00, UNICODE_NORM_QC_NO},
+	{0xCA01, UNICODE_NORM_QC_NO},
+	{0xCA02, UNICODE_NORM_QC_NO},
+	{0xCA03, UNICODE_NORM_QC_NO},
+	{0xCA04, UNICODE_NORM_QC_NO},
+	{0xCA05, UNICODE_NORM_QC_NO},
+	{0xCA06, UNICODE_NORM_QC_NO},
+	{0xCA07, UNICODE_NORM_QC_NO},
+	{0xCA08, UNICODE_NORM_QC_NO},
+	{0xCA09, UNICODE_NORM_QC_NO},
+	{0xCA0A, UNICODE_NORM_QC_NO},
+	{0xCA0B, UNICODE_NORM_QC_NO},
+	{0xCA0C, UNICODE_NORM_QC_NO},
+	{0xCA0D, UNICODE_NORM_QC_NO},
+	{0xCA0E, UNICODE_NORM_QC_NO},
+	{0xCA0F, UNICODE_NORM_QC_NO},
+	{0xCA10, UNICODE_NORM_QC_NO},
+	{0xCA11, UNICODE_NORM_QC_NO},
+	{0xCA12, UNICODE_NORM_QC_NO},
+	{0xCA13, UNICODE_NORM_QC_NO},
+	{0xCA14, UNICODE_NORM_QC_NO},
+	{0xCA15, UNICODE_NORM_QC_NO},
+	{0xCA16, UNICODE_NORM_QC_NO},
+	{0xCA17, UNICODE_NORM_QC_NO},
+	{0xCA18, UNICODE_NORM_QC_NO},
+	{0xCA19, UNICODE_NORM_QC_NO},
+	{0xCA1A, UNICODE_NORM_QC_NO},
+	{0xCA1B, UNICODE_NORM_QC_NO},
+	{0xCA1C, UNICODE_NORM_QC_NO},
+	{0xCA1D, UNICODE_NORM_QC_NO},
+	{0xCA1E, UNICODE_NORM_QC_NO},
+	{0xCA1F, UNICODE_NORM_QC_NO},
+	{0xCA20, UNICODE_NORM_QC_NO},
+	{0xCA21, UNICODE_NORM_QC_NO},
+	{0xCA22, UNICODE_NORM_QC_NO},
+	{0xCA23, UNICODE_NORM_QC_NO},
+	{0xCA24, UNICODE_NORM_QC_NO},
+	{0xCA25, UNICODE_NORM_QC_NO},
+	{0xCA26, UNICODE_NORM_QC_NO},
+	{0xCA27, UNICODE_NORM_QC_NO},
+	{0xCA28, UNICODE_NORM_QC_NO},
+	{0xCA29, UNICODE_NORM_QC_NO},
+	{0xCA2A, UNICODE_NORM_QC_NO},
+	{0xCA2B, UNICODE_NORM_QC_NO},
+	{0xCA2C, UNICODE_NORM_QC_NO},
+	{0xCA2D, UNICODE_NORM_QC_NO},
+	{0xCA2E, UNICODE_NORM_QC_NO},
+	{0xCA2F, UNICODE_NORM_QC_NO},
+	{0xCA30, UNICODE_NORM_QC_NO},
+	{0xCA31, UNICODE_NORM_QC_NO},
+	{0xCA32, UNICODE_NORM_QC_NO},
+	{0xCA33, UNICODE_NORM_QC_NO},
+	{0xCA34, UNICODE_NORM_QC_NO},
+	{0xCA35, UNICODE_NORM_QC_NO},
+	{0xCA36, UNICODE_NORM_QC_NO},
+	{0xCA37, UNICODE_NORM_QC_NO},
+	{0xCA38, UNICODE_NORM_QC_NO},
+	{0xCA39, UNICODE_NORM_QC_NO},
+	{0xCA3A, UNICODE_NORM_QC_NO},
+	{0xCA3B, UNICODE_NORM_QC_NO},
+	{0xCA3C, UNICODE_NORM_QC_NO},
+	{0xCA3D, UNICODE_NORM_QC_NO},
+	{0xCA3E, UNICODE_NORM_QC_NO},
+	{0xCA3F, UNICODE_NORM_QC_NO},
+	{0xCA40, UNICODE_NORM_QC_NO},
+	{0xCA41, UNICODE_NORM_QC_NO},
+	{0xCA42, UNICODE_NORM_QC_NO},
+	{0xCA43, UNICODE_NORM_QC_NO},
+	{0xCA44, UNICODE_NORM_QC_NO},
+	{0xCA45, UNICODE_NORM_QC_NO},
+	{0xCA46, UNICODE_NORM_QC_NO},
+	{0xCA47, UNICODE_NORM_QC_NO},
+	{0xCA48, UNICODE_NORM_QC_NO},
+	{0xCA49, UNICODE_NORM_QC_NO},
+	{0xCA4A, UNICODE_NORM_QC_NO},
+	{0xCA4B, UNICODE_NORM_QC_NO},
+	{0xCA4C, UNICODE_NORM_QC_NO},
+	{0xCA4D, UNICODE_NORM_QC_NO},
+	{0xCA4E, UNICODE_NORM_QC_NO},
+	{0xCA4F, UNICODE_NORM_QC_NO},
+	{0xCA50, UNICODE_NORM_QC_NO},
+	{0xCA51, UNICODE_NORM_QC_NO},
+	{0xCA52, UNICODE_NORM_QC_NO},
+	{0xCA53, UNICODE_NORM_QC_NO},
+	{0xCA54, UNICODE_NORM_QC_NO},
+	{0xCA55, UNICODE_NORM_QC_NO},
+	{0xCA56, UNICODE_NORM_QC_NO},
+	{0xCA57, UNICODE_NORM_QC_NO},
+	{0xCA58, UNICODE_NORM_QC_NO},
+	{0xCA59, UNICODE_NORM_QC_NO},
+	{0xCA5A, UNICODE_NORM_QC_NO},
+	{0xCA5B, UNICODE_NORM_QC_NO},
+	{0xCA5C, UNICODE_NORM_QC_NO},
+	{0xCA5D, UNICODE_NORM_QC_NO},
+	{0xCA5E, UNICODE_NORM_QC_NO},
+	{0xCA5F, UNICODE_NORM_QC_NO},
+	{0xCA60, UNICODE_NORM_QC_NO},
+	{0xCA61, UNICODE_NORM_QC_NO},
+	{0xCA62, UNICODE_NORM_QC_NO},
+	{0xCA63, UNICODE_NORM_QC_NO},
+	{0xCA64, UNICODE_NORM_QC_NO},
+	{0xCA65, UNICODE_NORM_QC_NO},
+	{0xCA66, UNICODE_NORM_QC_NO},
+	{0xCA67, UNICODE_NORM_QC_NO},
+	{0xCA68, UNICODE_NORM_QC_NO},
+	{0xCA69, UNICODE_NORM_QC_NO},
+	{0xCA6A, UNICODE_NORM_QC_NO},
+	{0xCA6B, UNICODE_NORM_QC_NO},
+	{0xCA6C, UNICODE_NORM_QC_NO},
+	{0xCA6D, UNICODE_NORM_QC_NO},
+	{0xCA6E, UNICODE_NORM_QC_NO},
+	{0xCA6F, UNICODE_NORM_QC_NO},
+	{0xCA70, UNICODE_NORM_QC_NO},
+	{0xCA71, UNICODE_NORM_QC_NO},
+	{0xCA72, UNICODE_NORM_QC_NO},
+	{0xCA73, UNICODE_NORM_QC_NO},
+	{0xCA74, UNICODE_NORM_QC_NO},
+	{0xCA75, UNICODE_NORM_QC_NO},
+	{0xCA76, UNICODE_NORM_QC_NO},
+	{0xCA77, UNICODE_NORM_QC_NO},
+	{0xCA78, UNICODE_NORM_QC_NO},
+	{0xCA79, UNICODE_NORM_QC_NO},
+	{0xCA7A, UNICODE_NORM_QC_NO},
+	{0xCA7B, UNICODE_NORM_QC_NO},
+	{0xCA7C, UNICODE_NORM_QC_NO},
+	{0xCA7D, UNICODE_NORM_QC_NO},
+	{0xCA7E, UNICODE_NORM_QC_NO},
+	{0xCA7F, UNICODE_NORM_QC_NO},
+	{0xCA80, UNICODE_NORM_QC_NO},
+	{0xCA81, UNICODE_NORM_QC_NO},
+	{0xCA82, UNICODE_NORM_QC_NO},
+	{0xCA83, UNICODE_NORM_QC_NO},
+	{0xCA84, UNICODE_NORM_QC_NO},
+	{0xCA85, UNICODE_NORM_QC_NO},
+	{0xCA86, UNICODE_NORM_QC_NO},
+	{0xCA87, UNICODE_NORM_QC_NO},
+	{0xCA88, UNICODE_NORM_QC_NO},
+	{0xCA89, UNICODE_NORM_QC_NO},
+	{0xCA8A, UNICODE_NORM_QC_NO},
+	{0xCA8B, UNICODE_NORM_QC_NO},
+	{0xCA8C, UNICODE_NORM_QC_NO},
+	{0xCA8D, UNICODE_NORM_QC_NO},
+	{0xCA8E, UNICODE_NORM_QC_NO},
+	{0xCA8F, UNICODE_NORM_QC_NO},
+	{0xCA90, UNICODE_NORM_QC_NO},
+	{0xCA91, UNICODE_NORM_QC_NO},
+	{0xCA92, UNICODE_NORM_QC_NO},
+	{0xCA93, UNICODE_NORM_QC_NO},
+	{0xCA94, UNICODE_NORM_QC_NO},
+	{0xCA95, UNICODE_NORM_QC_NO},
+	{0xCA96, UNICODE_NORM_QC_NO},
+	{0xCA97, UNICODE_NORM_QC_NO},
+	{0xCA98, UNICODE_NORM_QC_NO},
+	{0xCA99, UNICODE_NORM_QC_NO},
+	{0xCA9A, UNICODE_NORM_QC_NO},
+	{0xCA9B, UNICODE_NORM_QC_NO},
+	{0xCA9C, UNICODE_NORM_QC_NO},
+	{0xCA9D, UNICODE_NORM_QC_NO},
+	{0xCA9E, UNICODE_NORM_QC_NO},
+	{0xCA9F, UNICODE_NORM_QC_NO},
+	{0xCAA0, UNICODE_NORM_QC_NO},
+	{0xCAA1, UNICODE_NORM_QC_NO},
+	{0xCAA2, UNICODE_NORM_QC_NO},
+	{0xCAA3, UNICODE_NORM_QC_NO},
+	{0xCAA4, UNICODE_NORM_QC_NO},
+	{0xCAA5, UNICODE_NORM_QC_NO},
+	{0xCAA6, UNICODE_NORM_QC_NO},
+	{0xCAA7, UNICODE_NORM_QC_NO},
+	{0xCAA8, UNICODE_NORM_QC_NO},
+	{0xCAA9, UNICODE_NORM_QC_NO},
+	{0xCAAA, UNICODE_NORM_QC_NO},
+	{0xCAAB, UNICODE_NORM_QC_NO},
+	{0xCAAC, UNICODE_NORM_QC_NO},
+	{0xCAAD, UNICODE_NORM_QC_NO},
+	{0xCAAE, UNICODE_NORM_QC_NO},
+	{0xCAAF, UNICODE_NORM_QC_NO},
+	{0xCAB0, UNICODE_NORM_QC_NO},
+	{0xCAB1, UNICODE_NORM_QC_NO},
+	{0xCAB2, UNICODE_NORM_QC_NO},
+	{0xCAB3, UNICODE_NORM_QC_NO},
+	{0xCAB4, UNICODE_NORM_QC_NO},
+	{0xCAB5, UNICODE_NORM_QC_NO},
+	{0xCAB6, UNICODE_NORM_QC_NO},
+	{0xCAB7, UNICODE_NORM_QC_NO},
+	{0xCAB8, UNICODE_NORM_QC_NO},
+	{0xCAB9, UNICODE_NORM_QC_NO},
+	{0xCABA, UNICODE_NORM_QC_NO},
+	{0xCABB, UNICODE_NORM_QC_NO},
+	{0xCABC, UNICODE_NORM_QC_NO},
+	{0xCABD, UNICODE_NORM_QC_NO},
+	{0xCABE, UNICODE_NORM_QC_NO},
+	{0xCABF, UNICODE_NORM_QC_NO},
+	{0xCAC0, UNICODE_NORM_QC_NO},
+	{0xCAC1, UNICODE_NORM_QC_NO},
+	{0xCAC2, UNICODE_NORM_QC_NO},
+	{0xCAC3, UNICODE_NORM_QC_NO},
+	{0xCAC4, UNICODE_NORM_QC_NO},
+	{0xCAC5, UNICODE_NORM_QC_NO},
+	{0xCAC6, UNICODE_NORM_QC_NO},
+	{0xCAC7, UNICODE_NORM_QC_NO},
+	{0xCAC8, UNICODE_NORM_QC_NO},
+	{0xCAC9, UNICODE_NORM_QC_NO},
+	{0xCACA, UNICODE_NORM_QC_NO},
+	{0xCACB, UNICODE_NORM_QC_NO},
+	{0xCACC, UNICODE_NORM_QC_NO},
+	{0xCACD, UNICODE_NORM_QC_NO},
+	{0xCACE, UNICODE_NORM_QC_NO},
+	{0xCACF, UNICODE_NORM_QC_NO},
+	{0xCAD0, UNICODE_NORM_QC_NO},
+	{0xCAD1, UNICODE_NORM_QC_NO},
+	{0xCAD2, UNICODE_NORM_QC_NO},
+	{0xCAD3, UNICODE_NORM_QC_NO},
+	{0xCAD4, UNICODE_NORM_QC_NO},
+	{0xCAD5, UNICODE_NORM_QC_NO},
+	{0xCAD6, UNICODE_NORM_QC_NO},
+	{0xCAD7, UNICODE_NORM_QC_NO},
+	{0xCAD8, UNICODE_NORM_QC_NO},
+	{0xCAD9, UNICODE_NORM_QC_NO},
+	{0xCADA, UNICODE_NORM_QC_NO},
+	{0xCADB, UNICODE_NORM_QC_NO},
+	{0xCADC, UNICODE_NORM_QC_NO},
+	{0xCADD, UNICODE_NORM_QC_NO},
+	{0xCADE, UNICODE_NORM_QC_NO},
+	{0xCADF, UNICODE_NORM_QC_NO},
+	{0xCAE0, UNICODE_NORM_QC_NO},
+	{0xCAE1, UNICODE_NORM_QC_NO},
+	{0xCAE2, UNICODE_NORM_QC_NO},
+	{0xCAE3, UNICODE_NORM_QC_NO},
+	{0xCAE4, UNICODE_NORM_QC_NO},
+	{0xCAE5, UNICODE_NORM_QC_NO},
+	{0xCAE6, UNICODE_NORM_QC_NO},
+	{0xCAE7, UNICODE_NORM_QC_NO},
+	{0xCAE8, UNICODE_NORM_QC_NO},
+	{0xCAE9, UNICODE_NORM_QC_NO},
+	{0xCAEA, UNICODE_NORM_QC_NO},
+	{0xCAEB, UNICODE_NORM_QC_NO},
+	{0xCAEC, UNICODE_NORM_QC_NO},
+	{0xCAED, UNICODE_NORM_QC_NO},
+	{0xCAEE, UNICODE_NORM_QC_NO},
+	{0xCAEF, UNICODE_NORM_QC_NO},
+	{0xCAF0, UNICODE_NORM_QC_NO},
+	{0xCAF1, UNICODE_NORM_QC_NO},
+	{0xCAF2, UNICODE_NORM_QC_NO},
+	{0xCAF3, UNICODE_NORM_QC_NO},
+	{0xCAF4, UNICODE_NORM_QC_NO},
+	{0xCAF5, UNICODE_NORM_QC_NO},
+	{0xCAF6, UNICODE_NORM_QC_NO},
+	{0xCAF7, UNICODE_NORM_QC_NO},
+	{0xCAF8, UNICODE_NORM_QC_NO},
+	{0xCAF9, UNICODE_NORM_QC_NO},
+	{0xCAFA, UNICODE_NORM_QC_NO},
+	{0xCAFB, UNICODE_NORM_QC_NO},
+	{0xCAFC, UNICODE_NORM_QC_NO},
+	{0xCAFD, UNICODE_NORM_QC_NO},
+	{0xCAFE, UNICODE_NORM_QC_NO},
+	{0xCAFF, UNICODE_NORM_QC_NO},
+	{0xCB00, UNICODE_NORM_QC_NO},
+	{0xCB01, UNICODE_NORM_QC_NO},
+	{0xCB02, UNICODE_NORM_QC_NO},
+	{0xCB03, UNICODE_NORM_QC_NO},
+	{0xCB04, UNICODE_NORM_QC_NO},
+	{0xCB05, UNICODE_NORM_QC_NO},
+	{0xCB06, UNICODE_NORM_QC_NO},
+	{0xCB07, UNICODE_NORM_QC_NO},
+	{0xCB08, UNICODE_NORM_QC_NO},
+	{0xCB09, UNICODE_NORM_QC_NO},
+	{0xCB0A, UNICODE_NORM_QC_NO},
+	{0xCB0B, UNICODE_NORM_QC_NO},
+	{0xCB0C, UNICODE_NORM_QC_NO},
+	{0xCB0D, UNICODE_NORM_QC_NO},
+	{0xCB0E, UNICODE_NORM_QC_NO},
+	{0xCB0F, UNICODE_NORM_QC_NO},
+	{0xCB10, UNICODE_NORM_QC_NO},
+	{0xCB11, UNICODE_NORM_QC_NO},
+	{0xCB12, UNICODE_NORM_QC_NO},
+	{0xCB13, UNICODE_NORM_QC_NO},
+	{0xCB14, UNICODE_NORM_QC_NO},
+	{0xCB15, UNICODE_NORM_QC_NO},
+	{0xCB16, UNICODE_NORM_QC_NO},
+	{0xCB17, UNICODE_NORM_QC_NO},
+	{0xCB18, UNICODE_NORM_QC_NO},
+	{0xCB19, UNICODE_NORM_QC_NO},
+	{0xCB1A, UNICODE_NORM_QC_NO},
+	{0xCB1B, UNICODE_NORM_QC_NO},
+	{0xCB1C, UNICODE_NORM_QC_NO},
+	{0xCB1D, UNICODE_NORM_QC_NO},
+	{0xCB1E, UNICODE_NORM_QC_NO},
+	{0xCB1F, UNICODE_NORM_QC_NO},
+	{0xCB20, UNICODE_NORM_QC_NO},
+	{0xCB21, UNICODE_NORM_QC_NO},
+	{0xCB22, UNICODE_NORM_QC_NO},
+	{0xCB23, UNICODE_NORM_QC_NO},
+	{0xCB24, UNICODE_NORM_QC_NO},
+	{0xCB25, UNICODE_NORM_QC_NO},
+	{0xCB26, UNICODE_NORM_QC_NO},
+	{0xCB27, UNICODE_NORM_QC_NO},
+	{0xCB28, UNICODE_NORM_QC_NO},
+	{0xCB29, UNICODE_NORM_QC_NO},
+	{0xCB2A, UNICODE_NORM_QC_NO},
+	{0xCB2B, UNICODE_NORM_QC_NO},
+	{0xCB2C, UNICODE_NORM_QC_NO},
+	{0xCB2D, UNICODE_NORM_QC_NO},
+	{0xCB2E, UNICODE_NORM_QC_NO},
+	{0xCB2F, UNICODE_NORM_QC_NO},
+	{0xCB30, UNICODE_NORM_QC_NO},
+	{0xCB31, UNICODE_NORM_QC_NO},
+	{0xCB32, UNICODE_NORM_QC_NO},
+	{0xCB33, UNICODE_NORM_QC_NO},
+	{0xCB34, UNICODE_NORM_QC_NO},
+	{0xCB35, UNICODE_NORM_QC_NO},
+	{0xCB36, UNICODE_NORM_QC_NO},
+	{0xCB37, UNICODE_NORM_QC_NO},
+	{0xCB38, UNICODE_NORM_QC_NO},
+	{0xCB39, UNICODE_NORM_QC_NO},
+	{0xCB3A, UNICODE_NORM_QC_NO},
+	{0xCB3B, UNICODE_NORM_QC_NO},
+	{0xCB3C, UNICODE_NORM_QC_NO},
+	{0xCB3D, UNICODE_NORM_QC_NO},
+	{0xCB3E, UNICODE_NORM_QC_NO},
+	{0xCB3F, UNICODE_NORM_QC_NO},
+	{0xCB40, UNICODE_NORM_QC_NO},
+	{0xCB41, UNICODE_NORM_QC_NO},
+	{0xCB42, UNICODE_NORM_QC_NO},
+	{0xCB43, UNICODE_NORM_QC_NO},
+	{0xCB44, UNICODE_NORM_QC_NO},
+	{0xCB45, UNICODE_NORM_QC_NO},
+	{0xCB46, UNICODE_NORM_QC_NO},
+	{0xCB47, UNICODE_NORM_QC_NO},
+	{0xCB48, UNICODE_NORM_QC_NO},
+	{0xCB49, UNICODE_NORM_QC_NO},
+	{0xCB4A, UNICODE_NORM_QC_NO},
+	{0xCB4B, UNICODE_NORM_QC_NO},
+	{0xCB4C, UNICODE_NORM_QC_NO},
+	{0xCB4D, UNICODE_NORM_QC_NO},
+	{0xCB4E, UNICODE_NORM_QC_NO},
+	{0xCB4F, UNICODE_NORM_QC_NO},
+	{0xCB50, UNICODE_NORM_QC_NO},
+	{0xCB51, UNICODE_NORM_QC_NO},
+	{0xCB52, UNICODE_NORM_QC_NO},
+	{0xCB53, UNICODE_NORM_QC_NO},
+	{0xCB54, UNICODE_NORM_QC_NO},
+	{0xCB55, UNICODE_NORM_QC_NO},
+	{0xCB56, UNICODE_NORM_QC_NO},
+	{0xCB57, UNICODE_NORM_QC_NO},
+	{0xCB58, UNICODE_NORM_QC_NO},
+	{0xCB59, UNICODE_NORM_QC_NO},
+	{0xCB5A, UNICODE_NORM_QC_NO},
+	{0xCB5B, UNICODE_NORM_QC_NO},
+	{0xCB5C, UNICODE_NORM_QC_NO},
+	{0xCB5D, UNICODE_NORM_QC_NO},
+	{0xCB5E, UNICODE_NORM_QC_NO},
+	{0xCB5F, UNICODE_NORM_QC_NO},
+	{0xCB60, UNICODE_NORM_QC_NO},
+	{0xCB61, UNICODE_NORM_QC_NO},
+	{0xCB62, UNICODE_NORM_QC_NO},
+	{0xCB63, UNICODE_NORM_QC_NO},
+	{0xCB64, UNICODE_NORM_QC_NO},
+	{0xCB65, UNICODE_NORM_QC_NO},
+	{0xCB66, UNICODE_NORM_QC_NO},
+	{0xCB67, UNICODE_NORM_QC_NO},
+	{0xCB68, UNICODE_NORM_QC_NO},
+	{0xCB69, UNICODE_NORM_QC_NO},
+	{0xCB6A, UNICODE_NORM_QC_NO},
+	{0xCB6B, UNICODE_NORM_QC_NO},
+	{0xCB6C, UNICODE_NORM_QC_NO},
+	{0xCB6D, UNICODE_NORM_QC_NO},
+	{0xCB6E, UNICODE_NORM_QC_NO},
+	{0xCB6F, UNICODE_NORM_QC_NO},
+	{0xCB70, UNICODE_NORM_QC_NO},
+	{0xCB71, UNICODE_NORM_QC_NO},
+	{0xCB72, UNICODE_NORM_QC_NO},
+	{0xCB73, UNICODE_NORM_QC_NO},
+	{0xCB74, UNICODE_NORM_QC_NO},
+	{0xCB75, UNICODE_NORM_QC_NO},
+	{0xCB76, UNICODE_NORM_QC_NO},
+	{0xCB77, UNICODE_NORM_QC_NO},
+	{0xCB78, UNICODE_NORM_QC_NO},
+	{0xCB79, UNICODE_NORM_QC_NO},
+	{0xCB7A, UNICODE_NORM_QC_NO},
+	{0xCB7B, UNICODE_NORM_QC_NO},
+	{0xCB7C, UNICODE_NORM_QC_NO},
+	{0xCB7D, UNICODE_NORM_QC_NO},
+	{0xCB7E, UNICODE_NORM_QC_NO},
+	{0xCB7F, UNICODE_NORM_QC_NO},
+	{0xCB80, UNICODE_NORM_QC_NO},
+	{0xCB81, UNICODE_NORM_QC_NO},
+	{0xCB82, UNICODE_NORM_QC_NO},
+	{0xCB83, UNICODE_NORM_QC_NO},
+	{0xCB84, UNICODE_NORM_QC_NO},
+	{0xCB85, UNICODE_NORM_QC_NO},
+	{0xCB86, UNICODE_NORM_QC_NO},
+	{0xCB87, UNICODE_NORM_QC_NO},
+	{0xCB88, UNICODE_NORM_QC_NO},
+	{0xCB89, UNICODE_NORM_QC_NO},
+	{0xCB8A, UNICODE_NORM_QC_NO},
+	{0xCB8B, UNICODE_NORM_QC_NO},
+	{0xCB8C, UNICODE_NORM_QC_NO},
+	{0xCB8D, UNICODE_NORM_QC_NO},
+	{0xCB8E, UNICODE_NORM_QC_NO},
+	{0xCB8F, UNICODE_NORM_QC_NO},
+	{0xCB90, UNICODE_NORM_QC_NO},
+	{0xCB91, UNICODE_NORM_QC_NO},
+	{0xCB92, UNICODE_NORM_QC_NO},
+	{0xCB93, UNICODE_NORM_QC_NO},
+	{0xCB94, UNICODE_NORM_QC_NO},
+	{0xCB95, UNICODE_NORM_QC_NO},
+	{0xCB96, UNICODE_NORM_QC_NO},
+	{0xCB97, UNICODE_NORM_QC_NO},
+	{0xCB98, UNICODE_NORM_QC_NO},
+	{0xCB99, UNICODE_NORM_QC_NO},
+	{0xCB9A, UNICODE_NORM_QC_NO},
+	{0xCB9B, UNICODE_NORM_QC_NO},
+	{0xCB9C, UNICODE_NORM_QC_NO},
+	{0xCB9D, UNICODE_NORM_QC_NO},
+	{0xCB9E, UNICODE_NORM_QC_NO},
+	{0xCB9F, UNICODE_NORM_QC_NO},
+	{0xCBA0, UNICODE_NORM_QC_NO},
+	{0xCBA1, UNICODE_NORM_QC_NO},
+	{0xCBA2, UNICODE_NORM_QC_NO},
+	{0xCBA3, UNICODE_NORM_QC_NO},
+	{0xCBA4, UNICODE_NORM_QC_NO},
+	{0xCBA5, UNICODE_NORM_QC_NO},
+	{0xCBA6, UNICODE_NORM_QC_NO},
+	{0xCBA7, UNICODE_NORM_QC_NO},
+	{0xCBA8, UNICODE_NORM_QC_NO},
+	{0xCBA9, UNICODE_NORM_QC_NO},
+	{0xCBAA, UNICODE_NORM_QC_NO},
+	{0xCBAB, UNICODE_NORM_QC_NO},
+	{0xCBAC, UNICODE_NORM_QC_NO},
+	{0xCBAD, UNICODE_NORM_QC_NO},
+	{0xCBAE, UNICODE_NORM_QC_NO},
+	{0xCBAF, UNICODE_NORM_QC_NO},
+	{0xCBB0, UNICODE_NORM_QC_NO},
+	{0xCBB1, UNICODE_NORM_QC_NO},
+	{0xCBB2, UNICODE_NORM_QC_NO},
+	{0xCBB3, UNICODE_NORM_QC_NO},
+	{0xCBB4, UNICODE_NORM_QC_NO},
+	{0xCBB5, UNICODE_NORM_QC_NO},
+	{0xCBB6, UNICODE_NORM_QC_NO},
+	{0xCBB7, UNICODE_NORM_QC_NO},
+	{0xCBB8, UNICODE_NORM_QC_NO},
+	{0xCBB9, UNICODE_NORM_QC_NO},
+	{0xCBBA, UNICODE_NORM_QC_NO},
+	{0xCBBB, UNICODE_NORM_QC_NO},
+	{0xCBBC, UNICODE_NORM_QC_NO},
+	{0xCBBD, UNICODE_NORM_QC_NO},
+	{0xCBBE, UNICODE_NORM_QC_NO},
+	{0xCBBF, UNICODE_NORM_QC_NO},
+	{0xCBC0, UNICODE_NORM_QC_NO},
+	{0xCBC1, UNICODE_NORM_QC_NO},
+	{0xCBC2, UNICODE_NORM_QC_NO},
+	{0xCBC3, UNICODE_NORM_QC_NO},
+	{0xCBC4, UNICODE_NORM_QC_NO},
+	{0xCBC5, UNICODE_NORM_QC_NO},
+	{0xCBC6, UNICODE_NORM_QC_NO},
+	{0xCBC7, UNICODE_NORM_QC_NO},
+	{0xCBC8, UNICODE_NORM_QC_NO},
+	{0xCBC9, UNICODE_NORM_QC_NO},
+	{0xCBCA, UNICODE_NORM_QC_NO},
+	{0xCBCB, UNICODE_NORM_QC_NO},
+	{0xCBCC, UNICODE_NORM_QC_NO},
+	{0xCBCD, UNICODE_NORM_QC_NO},
+	{0xCBCE, UNICODE_NORM_QC_NO},
+	{0xCBCF, UNICODE_NORM_QC_NO},
+	{0xCBD0, UNICODE_NORM_QC_NO},
+	{0xCBD1, UNICODE_NORM_QC_NO},
+	{0xCBD2, UNICODE_NORM_QC_NO},
+	{0xCBD3, UNICODE_NORM_QC_NO},
+	{0xCBD4, UNICODE_NORM_QC_NO},
+	{0xCBD5, UNICODE_NORM_QC_NO},
+	{0xCBD6, UNICODE_NORM_QC_NO},
+	{0xCBD7, UNICODE_NORM_QC_NO},
+	{0xCBD8, UNICODE_NORM_QC_NO},
+	{0xCBD9, UNICODE_NORM_QC_NO},
+	{0xCBDA, UNICODE_NORM_QC_NO},
+	{0xCBDB, UNICODE_NORM_QC_NO},
+	{0xCBDC, UNICODE_NORM_QC_NO},
+	{0xCBDD, UNICODE_NORM_QC_NO},
+	{0xCBDE, UNICODE_NORM_QC_NO},
+	{0xCBDF, UNICODE_NORM_QC_NO},
+	{0xCBE0, UNICODE_NORM_QC_NO},
+	{0xCBE1, UNICODE_NORM_QC_NO},
+	{0xCBE2, UNICODE_NORM_QC_NO},
+	{0xCBE3, UNICODE_NORM_QC_NO},
+	{0xCBE4, UNICODE_NORM_QC_NO},
+	{0xCBE5, UNICODE_NORM_QC_NO},
+	{0xCBE6, UNICODE_NORM_QC_NO},
+	{0xCBE7, UNICODE_NORM_QC_NO},
+	{0xCBE8, UNICODE_NORM_QC_NO},
+	{0xCBE9, UNICODE_NORM_QC_NO},
+	{0xCBEA, UNICODE_NORM_QC_NO},
+	{0xCBEB, UNICODE_NORM_QC_NO},
+	{0xCBEC, UNICODE_NORM_QC_NO},
+	{0xCBED, UNICODE_NORM_QC_NO},
+	{0xCBEE, UNICODE_NORM_QC_NO},
+	{0xCBEF, UNICODE_NORM_QC_NO},
+	{0xCBF0, UNICODE_NORM_QC_NO},
+	{0xCBF1, UNICODE_NORM_QC_NO},
+	{0xCBF2, UNICODE_NORM_QC_NO},
+	{0xCBF3, UNICODE_NORM_QC_NO},
+	{0xCBF4, UNICODE_NORM_QC_NO},
+	{0xCBF5, UNICODE_NORM_QC_NO},
+	{0xCBF6, UNICODE_NORM_QC_NO},
+	{0xCBF7, UNICODE_NORM_QC_NO},
+	{0xCBF8, UNICODE_NORM_QC_NO},
+	{0xCBF9, UNICODE_NORM_QC_NO},
+	{0xCBFA, UNICODE_NORM_QC_NO},
+	{0xCBFB, UNICODE_NORM_QC_NO},
+	{0xCBFC, UNICODE_NORM_QC_NO},
+	{0xCBFD, UNICODE_NORM_QC_NO},
+	{0xCBFE, UNICODE_NORM_QC_NO},
+	{0xCBFF, UNICODE_NORM_QC_NO},
+	{0xCC00, UNICODE_NORM_QC_NO},
+	{0xCC01, UNICODE_NORM_QC_NO},
+	{0xCC02, UNICODE_NORM_QC_NO},
+	{0xCC03, UNICODE_NORM_QC_NO},
+	{0xCC04, UNICODE_NORM_QC_NO},
+	{0xCC05, UNICODE_NORM_QC_NO},
+	{0xCC06, UNICODE_NORM_QC_NO},
+	{0xCC07, UNICODE_NORM_QC_NO},
+	{0xCC08, UNICODE_NORM_QC_NO},
+	{0xCC09, UNICODE_NORM_QC_NO},
+	{0xCC0A, UNICODE_NORM_QC_NO},
+	{0xCC0B, UNICODE_NORM_QC_NO},
+	{0xCC0C, UNICODE_NORM_QC_NO},
+	{0xCC0D, UNICODE_NORM_QC_NO},
+	{0xCC0E, UNICODE_NORM_QC_NO},
+	{0xCC0F, UNICODE_NORM_QC_NO},
+	{0xCC10, UNICODE_NORM_QC_NO},
+	{0xCC11, UNICODE_NORM_QC_NO},
+	{0xCC12, UNICODE_NORM_QC_NO},
+	{0xCC13, UNICODE_NORM_QC_NO},
+	{0xCC14, UNICODE_NORM_QC_NO},
+	{0xCC15, UNICODE_NORM_QC_NO},
+	{0xCC16, UNICODE_NORM_QC_NO},
+	{0xCC17, UNICODE_NORM_QC_NO},
+	{0xCC18, UNICODE_NORM_QC_NO},
+	{0xCC19, UNICODE_NORM_QC_NO},
+	{0xCC1A, UNICODE_NORM_QC_NO},
+	{0xCC1B, UNICODE_NORM_QC_NO},
+	{0xCC1C, UNICODE_NORM_QC_NO},
+	{0xCC1D, UNICODE_NORM_QC_NO},
+	{0xCC1E, UNICODE_NORM_QC_NO},
+	{0xCC1F, UNICODE_NORM_QC_NO},
+	{0xCC20, UNICODE_NORM_QC_NO},
+	{0xCC21, UNICODE_NORM_QC_NO},
+	{0xCC22, UNICODE_NORM_QC_NO},
+	{0xCC23, UNICODE_NORM_QC_NO},
+	{0xCC24, UNICODE_NORM_QC_NO},
+	{0xCC25, UNICODE_NORM_QC_NO},
+	{0xCC26, UNICODE_NORM_QC_NO},
+	{0xCC27, UNICODE_NORM_QC_NO},
+	{0xCC28, UNICODE_NORM_QC_NO},
+	{0xCC29, UNICODE_NORM_QC_NO},
+	{0xCC2A, UNICODE_NORM_QC_NO},
+	{0xCC2B, UNICODE_NORM_QC_NO},
+	{0xCC2C, UNICODE_NORM_QC_NO},
+	{0xCC2D, UNICODE_NORM_QC_NO},
+	{0xCC2E, UNICODE_NORM_QC_NO},
+	{0xCC2F, UNICODE_NORM_QC_NO},
+	{0xCC30, UNICODE_NORM_QC_NO},
+	{0xCC31, UNICODE_NORM_QC_NO},
+	{0xCC32, UNICODE_NORM_QC_NO},
+	{0xCC33, UNICODE_NORM_QC_NO},
+	{0xCC34, UNICODE_NORM_QC_NO},
+	{0xCC35, UNICODE_NORM_QC_NO},
+	{0xCC36, UNICODE_NORM_QC_NO},
+	{0xCC37, UNICODE_NORM_QC_NO},
+	{0xCC38, UNICODE_NORM_QC_NO},
+	{0xCC39, UNICODE_NORM_QC_NO},
+	{0xCC3A, UNICODE_NORM_QC_NO},
+	{0xCC3B, UNICODE_NORM_QC_NO},
+	{0xCC3C, UNICODE_NORM_QC_NO},
+	{0xCC3D, UNICODE_NORM_QC_NO},
+	{0xCC3E, UNICODE_NORM_QC_NO},
+	{0xCC3F, UNICODE_NORM_QC_NO},
+	{0xCC40, UNICODE_NORM_QC_NO},
+	{0xCC41, UNICODE_NORM_QC_NO},
+	{0xCC42, UNICODE_NORM_QC_NO},
+	{0xCC43, UNICODE_NORM_QC_NO},
+	{0xCC44, UNICODE_NORM_QC_NO},
+	{0xCC45, UNICODE_NORM_QC_NO},
+	{0xCC46, UNICODE_NORM_QC_NO},
+	{0xCC47, UNICODE_NORM_QC_NO},
+	{0xCC48, UNICODE_NORM_QC_NO},
+	{0xCC49, UNICODE_NORM_QC_NO},
+	{0xCC4A, UNICODE_NORM_QC_NO},
+	{0xCC4B, UNICODE_NORM_QC_NO},
+	{0xCC4C, UNICODE_NORM_QC_NO},
+	{0xCC4D, UNICODE_NORM_QC_NO},
+	{0xCC4E, UNICODE_NORM_QC_NO},
+	{0xCC4F, UNICODE_NORM_QC_NO},
+	{0xCC50, UNICODE_NORM_QC_NO},
+	{0xCC51, UNICODE_NORM_QC_NO},
+	{0xCC52, UNICODE_NORM_QC_NO},
+	{0xCC53, UNICODE_NORM_QC_NO},
+	{0xCC54, UNICODE_NORM_QC_NO},
+	{0xCC55, UNICODE_NORM_QC_NO},
+	{0xCC56, UNICODE_NORM_QC_NO},
+	{0xCC57, UNICODE_NORM_QC_NO},
+	{0xCC58, UNICODE_NORM_QC_NO},
+	{0xCC59, UNICODE_NORM_QC_NO},
+	{0xCC5A, UNICODE_NORM_QC_NO},
+	{0xCC5B, UNICODE_NORM_QC_NO},
+	{0xCC5C, UNICODE_NORM_QC_NO},
+	{0xCC5D, UNICODE_NORM_QC_NO},
+	{0xCC5E, UNICODE_NORM_QC_NO},
+	{0xCC5F, UNICODE_NORM_QC_NO},
+	{0xCC60, UNICODE_NORM_QC_NO},
+	{0xCC61, UNICODE_NORM_QC_NO},
+	{0xCC62, UNICODE_NORM_QC_NO},
+	{0xCC63, UNICODE_NORM_QC_NO},
+	{0xCC64, UNICODE_NORM_QC_NO},
+	{0xCC65, UNICODE_NORM_QC_NO},
+	{0xCC66, UNICODE_NORM_QC_NO},
+	{0xCC67, UNICODE_NORM_QC_NO},
+	{0xCC68, UNICODE_NORM_QC_NO},
+	{0xCC69, UNICODE_NORM_QC_NO},
+	{0xCC6A, UNICODE_NORM_QC_NO},
+	{0xCC6B, UNICODE_NORM_QC_NO},
+	{0xCC6C, UNICODE_NORM_QC_NO},
+	{0xCC6D, UNICODE_NORM_QC_NO},
+	{0xCC6E, UNICODE_NORM_QC_NO},
+	{0xCC6F, UNICODE_NORM_QC_NO},
+	{0xCC70, UNICODE_NORM_QC_NO},
+	{0xCC71, UNICODE_NORM_QC_NO},
+	{0xCC72, UNICODE_NORM_QC_NO},
+	{0xCC73, UNICODE_NORM_QC_NO},
+	{0xCC74, UNICODE_NORM_QC_NO},
+	{0xCC75, UNICODE_NORM_QC_NO},
+	{0xCC76, UNICODE_NORM_QC_NO},
+	{0xCC77, UNICODE_NORM_QC_NO},
+	{0xCC78, UNICODE_NORM_QC_NO},
+	{0xCC79, UNICODE_NORM_QC_NO},
+	{0xCC7A, UNICODE_NORM_QC_NO},
+	{0xCC7B, UNICODE_NORM_QC_NO},
+	{0xCC7C, UNICODE_NORM_QC_NO},
+	{0xCC7D, UNICODE_NORM_QC_NO},
+	{0xCC7E, UNICODE_NORM_QC_NO},
+	{0xCC7F, UNICODE_NORM_QC_NO},
+	{0xCC80, UNICODE_NORM_QC_NO},
+	{0xCC81, UNICODE_NORM_QC_NO},
+	{0xCC82, UNICODE_NORM_QC_NO},
+	{0xCC83, UNICODE_NORM_QC_NO},
+	{0xCC84, UNICODE_NORM_QC_NO},
+	{0xCC85, UNICODE_NORM_QC_NO},
+	{0xCC86, UNICODE_NORM_QC_NO},
+	{0xCC87, UNICODE_NORM_QC_NO},
+	{0xCC88, UNICODE_NORM_QC_NO},
+	{0xCC89, UNICODE_NORM_QC_NO},
+	{0xCC8A, UNICODE_NORM_QC_NO},
+	{0xCC8B, UNICODE_NORM_QC_NO},
+	{0xCC8C, UNICODE_NORM_QC_NO},
+	{0xCC8D, UNICODE_NORM_QC_NO},
+	{0xCC8E, UNICODE_NORM_QC_NO},
+	{0xCC8F, UNICODE_NORM_QC_NO},
+	{0xCC90, UNICODE_NORM_QC_NO},
+	{0xCC91, UNICODE_NORM_QC_NO},
+	{0xCC92, UNICODE_NORM_QC_NO},
+	{0xCC93, UNICODE_NORM_QC_NO},
+	{0xCC94, UNICODE_NORM_QC_NO},
+	{0xCC95, UNICODE_NORM_QC_NO},
+	{0xCC96, UNICODE_NORM_QC_NO},
+	{0xCC97, UNICODE_NORM_QC_NO},
+	{0xCC98, UNICODE_NORM_QC_NO},
+	{0xCC99, UNICODE_NORM_QC_NO},
+	{0xCC9A, UNICODE_NORM_QC_NO},
+	{0xCC9B, UNICODE_NORM_QC_NO},
+	{0xCC9C, UNICODE_NORM_QC_NO},
+	{0xCC9D, UNICODE_NORM_QC_NO},
+	{0xCC9E, UNICODE_NORM_QC_NO},
+	{0xCC9F, UNICODE_NORM_QC_NO},
+	{0xCCA0, UNICODE_NORM_QC_NO},
+	{0xCCA1, UNICODE_NORM_QC_NO},
+	{0xCCA2, UNICODE_NORM_QC_NO},
+	{0xCCA3, UNICODE_NORM_QC_NO},
+	{0xCCA4, UNICODE_NORM_QC_NO},
+	{0xCCA5, UNICODE_NORM_QC_NO},
+	{0xCCA6, UNICODE_NORM_QC_NO},
+	{0xCCA7, UNICODE_NORM_QC_NO},
+	{0xCCA8, UNICODE_NORM_QC_NO},
+	{0xCCA9, UNICODE_NORM_QC_NO},
+	{0xCCAA, UNICODE_NORM_QC_NO},
+	{0xCCAB, UNICODE_NORM_QC_NO},
+	{0xCCAC, UNICODE_NORM_QC_NO},
+	{0xCCAD, UNICODE_NORM_QC_NO},
+	{0xCCAE, UNICODE_NORM_QC_NO},
+	{0xCCAF, UNICODE_NORM_QC_NO},
+	{0xCCB0, UNICODE_NORM_QC_NO},
+	{0xCCB1, UNICODE_NORM_QC_NO},
+	{0xCCB2, UNICODE_NORM_QC_NO},
+	{0xCCB3, UNICODE_NORM_QC_NO},
+	{0xCCB4, UNICODE_NORM_QC_NO},
+	{0xCCB5, UNICODE_NORM_QC_NO},
+	{0xCCB6, UNICODE_NORM_QC_NO},
+	{0xCCB7, UNICODE_NORM_QC_NO},
+	{0xCCB8, UNICODE_NORM_QC_NO},
+	{0xCCB9, UNICODE_NORM_QC_NO},
+	{0xCCBA, UNICODE_NORM_QC_NO},
+	{0xCCBB, UNICODE_NORM_QC_NO},
+	{0xCCBC, UNICODE_NORM_QC_NO},
+	{0xCCBD, UNICODE_NORM_QC_NO},
+	{0xCCBE, UNICODE_NORM_QC_NO},
+	{0xCCBF, UNICODE_NORM_QC_NO},
+	{0xCCC0, UNICODE_NORM_QC_NO},
+	{0xCCC1, UNICODE_NORM_QC_NO},
+	{0xCCC2, UNICODE_NORM_QC_NO},
+	{0xCCC3, UNICODE_NORM_QC_NO},
+	{0xCCC4, UNICODE_NORM_QC_NO},
+	{0xCCC5, UNICODE_NORM_QC_NO},
+	{0xCCC6, UNICODE_NORM_QC_NO},
+	{0xCCC7, UNICODE_NORM_QC_NO},
+	{0xCCC8, UNICODE_NORM_QC_NO},
+	{0xCCC9, UNICODE_NORM_QC_NO},
+	{0xCCCA, UNICODE_NORM_QC_NO},
+	{0xCCCB, UNICODE_NORM_QC_NO},
+	{0xCCCC, UNICODE_NORM_QC_NO},
+	{0xCCCD, UNICODE_NORM_QC_NO},
+	{0xCCCE, UNICODE_NORM_QC_NO},
+	{0xCCCF, UNICODE_NORM_QC_NO},
+	{0xCCD0, UNICODE_NORM_QC_NO},
+	{0xCCD1, UNICODE_NORM_QC_NO},
+	{0xCCD2, UNICODE_NORM_QC_NO},
+	{0xCCD3, UNICODE_NORM_QC_NO},
+	{0xCCD4, UNICODE_NORM_QC_NO},
+	{0xCCD5, UNICODE_NORM_QC_NO},
+	{0xCCD6, UNICODE_NORM_QC_NO},
+	{0xCCD7, UNICODE_NORM_QC_NO},
+	{0xCCD8, UNICODE_NORM_QC_NO},
+	{0xCCD9, UNICODE_NORM_QC_NO},
+	{0xCCDA, UNICODE_NORM_QC_NO},
+	{0xCCDB, UNICODE_NORM_QC_NO},
+	{0xCCDC, UNICODE_NORM_QC_NO},
+	{0xCCDD, UNICODE_NORM_QC_NO},
+	{0xCCDE, UNICODE_NORM_QC_NO},
+	{0xCCDF, UNICODE_NORM_QC_NO},
+	{0xCCE0, UNICODE_NORM_QC_NO},
+	{0xCCE1, UNICODE_NORM_QC_NO},
+	{0xCCE2, UNICODE_NORM_QC_NO},
+	{0xCCE3, UNICODE_NORM_QC_NO},
+	{0xCCE4, UNICODE_NORM_QC_NO},
+	{0xCCE5, UNICODE_NORM_QC_NO},
+	{0xCCE6, UNICODE_NORM_QC_NO},
+	{0xCCE7, UNICODE_NORM_QC_NO},
+	{0xCCE8, UNICODE_NORM_QC_NO},
+	{0xCCE9, UNICODE_NORM_QC_NO},
+	{0xCCEA, UNICODE_NORM_QC_NO},
+	{0xCCEB, UNICODE_NORM_QC_NO},
+	{0xCCEC, UNICODE_NORM_QC_NO},
+	{0xCCED, UNICODE_NORM_QC_NO},
+	{0xCCEE, UNICODE_NORM_QC_NO},
+	{0xCCEF, UNICODE_NORM_QC_NO},
+	{0xCCF0, UNICODE_NORM_QC_NO},
+	{0xCCF1, UNICODE_NORM_QC_NO},
+	{0xCCF2, UNICODE_NORM_QC_NO},
+	{0xCCF3, UNICODE_NORM_QC_NO},
+	{0xCCF4, UNICODE_NORM_QC_NO},
+	{0xCCF5, UNICODE_NORM_QC_NO},
+	{0xCCF6, UNICODE_NORM_QC_NO},
+	{0xCCF7, UNICODE_NORM_QC_NO},
+	{0xCCF8, UNICODE_NORM_QC_NO},
+	{0xCCF9, UNICODE_NORM_QC_NO},
+	{0xCCFA, UNICODE_NORM_QC_NO},
+	{0xCCFB, UNICODE_NORM_QC_NO},
+	{0xCCFC, UNICODE_NORM_QC_NO},
+	{0xCCFD, UNICODE_NORM_QC_NO},
+	{0xCCFE, UNICODE_NORM_QC_NO},
+	{0xCCFF, UNICODE_NORM_QC_NO},
+	{0xCD00, UNICODE_NORM_QC_NO},
+	{0xCD01, UNICODE_NORM_QC_NO},
+	{0xCD02, UNICODE_NORM_QC_NO},
+	{0xCD03, UNICODE_NORM_QC_NO},
+	{0xCD04, UNICODE_NORM_QC_NO},
+	{0xCD05, UNICODE_NORM_QC_NO},
+	{0xCD06, UNICODE_NORM_QC_NO},
+	{0xCD07, UNICODE_NORM_QC_NO},
+	{0xCD08, UNICODE_NORM_QC_NO},
+	{0xCD09, UNICODE_NORM_QC_NO},
+	{0xCD0A, UNICODE_NORM_QC_NO},
+	{0xCD0B, UNICODE_NORM_QC_NO},
+	{0xCD0C, UNICODE_NORM_QC_NO},
+	{0xCD0D, UNICODE_NORM_QC_NO},
+	{0xCD0E, UNICODE_NORM_QC_NO},
+	{0xCD0F, UNICODE_NORM_QC_NO},
+	{0xCD10, UNICODE_NORM_QC_NO},
+	{0xCD11, UNICODE_NORM_QC_NO},
+	{0xCD12, UNICODE_NORM_QC_NO},
+	{0xCD13, UNICODE_NORM_QC_NO},
+	{0xCD14, UNICODE_NORM_QC_NO},
+	{0xCD15, UNICODE_NORM_QC_NO},
+	{0xCD16, UNICODE_NORM_QC_NO},
+	{0xCD17, UNICODE_NORM_QC_NO},
+	{0xCD18, UNICODE_NORM_QC_NO},
+	{0xCD19, UNICODE_NORM_QC_NO},
+	{0xCD1A, UNICODE_NORM_QC_NO},
+	{0xCD1B, UNICODE_NORM_QC_NO},
+	{0xCD1C, UNICODE_NORM_QC_NO},
+	{0xCD1D, UNICODE_NORM_QC_NO},
+	{0xCD1E, UNICODE_NORM_QC_NO},
+	{0xCD1F, UNICODE_NORM_QC_NO},
+	{0xCD20, UNICODE_NORM_QC_NO},
+	{0xCD21, UNICODE_NORM_QC_NO},
+	{0xCD22, UNICODE_NORM_QC_NO},
+	{0xCD23, UNICODE_NORM_QC_NO},
+	{0xCD24, UNICODE_NORM_QC_NO},
+	{0xCD25, UNICODE_NORM_QC_NO},
+	{0xCD26, UNICODE_NORM_QC_NO},
+	{0xCD27, UNICODE_NORM_QC_NO},
+	{0xCD28, UNICODE_NORM_QC_NO},
+	{0xCD29, UNICODE_NORM_QC_NO},
+	{0xCD2A, UNICODE_NORM_QC_NO},
+	{0xCD2B, UNICODE_NORM_QC_NO},
+	{0xCD2C, UNICODE_NORM_QC_NO},
+	{0xCD2D, UNICODE_NORM_QC_NO},
+	{0xCD2E, UNICODE_NORM_QC_NO},
+	{0xCD2F, UNICODE_NORM_QC_NO},
+	{0xCD30, UNICODE_NORM_QC_NO},
+	{0xCD31, UNICODE_NORM_QC_NO},
+	{0xCD32, UNICODE_NORM_QC_NO},
+	{0xCD33, UNICODE_NORM_QC_NO},
+	{0xCD34, UNICODE_NORM_QC_NO},
+	{0xCD35, UNICODE_NORM_QC_NO},
+	{0xCD36, UNICODE_NORM_QC_NO},
+	{0xCD37, UNICODE_NORM_QC_NO},
+	{0xCD38, UNICODE_NORM_QC_NO},
+	{0xCD39, UNICODE_NORM_QC_NO},
+	{0xCD3A, UNICODE_NORM_QC_NO},
+	{0xCD3B, UNICODE_NORM_QC_NO},
+	{0xCD3C, UNICODE_NORM_QC_NO},
+	{0xCD3D, UNICODE_NORM_QC_NO},
+	{0xCD3E, UNICODE_NORM_QC_NO},
+	{0xCD3F, UNICODE_NORM_QC_NO},
+	{0xCD40, UNICODE_NORM_QC_NO},
+	{0xCD41, UNICODE_NORM_QC_NO},
+	{0xCD42, UNICODE_NORM_QC_NO},
+	{0xCD43, UNICODE_NORM_QC_NO},
+	{0xCD44, UNICODE_NORM_QC_NO},
+	{0xCD45, UNICODE_NORM_QC_NO},
+	{0xCD46, UNICODE_NORM_QC_NO},
+	{0xCD47, UNICODE_NORM_QC_NO},
+	{0xCD48, UNICODE_NORM_QC_NO},
+	{0xCD49, UNICODE_NORM_QC_NO},
+	{0xCD4A, UNICODE_NORM_QC_NO},
+	{0xCD4B, UNICODE_NORM_QC_NO},
+	{0xCD4C, UNICODE_NORM_QC_NO},
+	{0xCD4D, UNICODE_NORM_QC_NO},
+	{0xCD4E, UNICODE_NORM_QC_NO},
+	{0xCD4F, UNICODE_NORM_QC_NO},
+	{0xCD50, UNICODE_NORM_QC_NO},
+	{0xCD51, UNICODE_NORM_QC_NO},
+	{0xCD52, UNICODE_NORM_QC_NO},
+	{0xCD53, UNICODE_NORM_QC_NO},
+	{0xCD54, UNICODE_NORM_QC_NO},
+	{0xCD55, UNICODE_NORM_QC_NO},
+	{0xCD56, UNICODE_NORM_QC_NO},
+	{0xCD57, UNICODE_NORM_QC_NO},
+	{0xCD58, UNICODE_NORM_QC_NO},
+	{0xCD59, UNICODE_NORM_QC_NO},
+	{0xCD5A, UNICODE_NORM_QC_NO},
+	{0xCD5B, UNICODE_NORM_QC_NO},
+	{0xCD5C, UNICODE_NORM_QC_NO},
+	{0xCD5D, UNICODE_NORM_QC_NO},
+	{0xCD5E, UNICODE_NORM_QC_NO},
+	{0xCD5F, UNICODE_NORM_QC_NO},
+	{0xCD60, UNICODE_NORM_QC_NO},
+	{0xCD61, UNICODE_NORM_QC_NO},
+	{0xCD62, UNICODE_NORM_QC_NO},
+	{0xCD63, UNICODE_NORM_QC_NO},
+	{0xCD64, UNICODE_NORM_QC_NO},
+	{0xCD65, UNICODE_NORM_QC_NO},
+	{0xCD66, UNICODE_NORM_QC_NO},
+	{0xCD67, UNICODE_NORM_QC_NO},
+	{0xCD68, UNICODE_NORM_QC_NO},
+	{0xCD69, UNICODE_NORM_QC_NO},
+	{0xCD6A, UNICODE_NORM_QC_NO},
+	{0xCD6B, UNICODE_NORM_QC_NO},
+	{0xCD6C, UNICODE_NORM_QC_NO},
+	{0xCD6D, UNICODE_NORM_QC_NO},
+	{0xCD6E, UNICODE_NORM_QC_NO},
+	{0xCD6F, UNICODE_NORM_QC_NO},
+	{0xCD70, UNICODE_NORM_QC_NO},
+	{0xCD71, UNICODE_NORM_QC_NO},
+	{0xCD72, UNICODE_NORM_QC_NO},
+	{0xCD73, UNICODE_NORM_QC_NO},
+	{0xCD74, UNICODE_NORM_QC_NO},
+	{0xCD75, UNICODE_NORM_QC_NO},
+	{0xCD76, UNICODE_NORM_QC_NO},
+	{0xCD77, UNICODE_NORM_QC_NO},
+	{0xCD78, UNICODE_NORM_QC_NO},
+	{0xCD79, UNICODE_NORM_QC_NO},
+	{0xCD7A, UNICODE_NORM_QC_NO},
+	{0xCD7B, UNICODE_NORM_QC_NO},
+	{0xCD7C, UNICODE_NORM_QC_NO},
+	{0xCD7D, UNICODE_NORM_QC_NO},
+	{0xCD7E, UNICODE_NORM_QC_NO},
+	{0xCD7F, UNICODE_NORM_QC_NO},
+	{0xCD80, UNICODE_NORM_QC_NO},
+	{0xCD81, UNICODE_NORM_QC_NO},
+	{0xCD82, UNICODE_NORM_QC_NO},
+	{0xCD83, UNICODE_NORM_QC_NO},
+	{0xCD84, UNICODE_NORM_QC_NO},
+	{0xCD85, UNICODE_NORM_QC_NO},
+	{0xCD86, UNICODE_NORM_QC_NO},
+	{0xCD87, UNICODE_NORM_QC_NO},
+	{0xCD88, UNICODE_NORM_QC_NO},
+	{0xCD89, UNICODE_NORM_QC_NO},
+	{0xCD8A, UNICODE_NORM_QC_NO},
+	{0xCD8B, UNICODE_NORM_QC_NO},
+	{0xCD8C, UNICODE_NORM_QC_NO},
+	{0xCD8D, UNICODE_NORM_QC_NO},
+	{0xCD8E, UNICODE_NORM_QC_NO},
+	{0xCD8F, UNICODE_NORM_QC_NO},
+	{0xCD90, UNICODE_NORM_QC_NO},
+	{0xCD91, UNICODE_NORM_QC_NO},
+	{0xCD92, UNICODE_NORM_QC_NO},
+	{0xCD93, UNICODE_NORM_QC_NO},
+	{0xCD94, UNICODE_NORM_QC_NO},
+	{0xCD95, UNICODE_NORM_QC_NO},
+	{0xCD96, UNICODE_NORM_QC_NO},
+	{0xCD97, UNICODE_NORM_QC_NO},
+	{0xCD98, UNICODE_NORM_QC_NO},
+	{0xCD99, UNICODE_NORM_QC_NO},
+	{0xCD9A, UNICODE_NORM_QC_NO},
+	{0xCD9B, UNICODE_NORM_QC_NO},
+	{0xCD9C, UNICODE_NORM_QC_NO},
+	{0xCD9D, UNICODE_NORM_QC_NO},
+	{0xCD9E, UNICODE_NORM_QC_NO},
+	{0xCD9F, UNICODE_NORM_QC_NO},
+	{0xCDA0, UNICODE_NORM_QC_NO},
+	{0xCDA1, UNICODE_NORM_QC_NO},
+	{0xCDA2, UNICODE_NORM_QC_NO},
+	{0xCDA3, UNICODE_NORM_QC_NO},
+	{0xCDA4, UNICODE_NORM_QC_NO},
+	{0xCDA5, UNICODE_NORM_QC_NO},
+	{0xCDA6, UNICODE_NORM_QC_NO},
+	{0xCDA7, UNICODE_NORM_QC_NO},
+	{0xCDA8, UNICODE_NORM_QC_NO},
+	{0xCDA9, UNICODE_NORM_QC_NO},
+	{0xCDAA, UNICODE_NORM_QC_NO},
+	{0xCDAB, UNICODE_NORM_QC_NO},
+	{0xCDAC, UNICODE_NORM_QC_NO},
+	{0xCDAD, UNICODE_NORM_QC_NO},
+	{0xCDAE, UNICODE_NORM_QC_NO},
+	{0xCDAF, UNICODE_NORM_QC_NO},
+	{0xCDB0, UNICODE_NORM_QC_NO},
+	{0xCDB1, UNICODE_NORM_QC_NO},
+	{0xCDB2, UNICODE_NORM_QC_NO},
+	{0xCDB3, UNICODE_NORM_QC_NO},
+	{0xCDB4, UNICODE_NORM_QC_NO},
+	{0xCDB5, UNICODE_NORM_QC_NO},
+	{0xCDB6, UNICODE_NORM_QC_NO},
+	{0xCDB7, UNICODE_NORM_QC_NO},
+	{0xCDB8, UNICODE_NORM_QC_NO},
+	{0xCDB9, UNICODE_NORM_QC_NO},
+	{0xCDBA, UNICODE_NORM_QC_NO},
+	{0xCDBB, UNICODE_NORM_QC_NO},
+	{0xCDBC, UNICODE_NORM_QC_NO},
+	{0xCDBD, UNICODE_NORM_QC_NO},
+	{0xCDBE, UNICODE_NORM_QC_NO},
+	{0xCDBF, UNICODE_NORM_QC_NO},
+	{0xCDC0, UNICODE_NORM_QC_NO},
+	{0xCDC1, UNICODE_NORM_QC_NO},
+	{0xCDC2, UNICODE_NORM_QC_NO},
+	{0xCDC3, UNICODE_NORM_QC_NO},
+	{0xCDC4, UNICODE_NORM_QC_NO},
+	{0xCDC5, UNICODE_NORM_QC_NO},
+	{0xCDC6, UNICODE_NORM_QC_NO},
+	{0xCDC7, UNICODE_NORM_QC_NO},
+	{0xCDC8, UNICODE_NORM_QC_NO},
+	{0xCDC9, UNICODE_NORM_QC_NO},
+	{0xCDCA, UNICODE_NORM_QC_NO},
+	{0xCDCB, UNICODE_NORM_QC_NO},
+	{0xCDCC, UNICODE_NORM_QC_NO},
+	{0xCDCD, UNICODE_NORM_QC_NO},
+	{0xCDCE, UNICODE_NORM_QC_NO},
+	{0xCDCF, UNICODE_NORM_QC_NO},
+	{0xCDD0, UNICODE_NORM_QC_NO},
+	{0xCDD1, UNICODE_NORM_QC_NO},
+	{0xCDD2, UNICODE_NORM_QC_NO},
+	{0xCDD3, UNICODE_NORM_QC_NO},
+	{0xCDD4, UNICODE_NORM_QC_NO},
+	{0xCDD5, UNICODE_NORM_QC_NO},
+	{0xCDD6, UNICODE_NORM_QC_NO},
+	{0xCDD7, UNICODE_NORM_QC_NO},
+	{0xCDD8, UNICODE_NORM_QC_NO},
+	{0xCDD9, UNICODE_NORM_QC_NO},
+	{0xCDDA, UNICODE_NORM_QC_NO},
+	{0xCDDB, UNICODE_NORM_QC_NO},
+	{0xCDDC, UNICODE_NORM_QC_NO},
+	{0xCDDD, UNICODE_NORM_QC_NO},
+	{0xCDDE, UNICODE_NORM_QC_NO},
+	{0xCDDF, UNICODE_NORM_QC_NO},
+	{0xCDE0, UNICODE_NORM_QC_NO},
+	{0xCDE1, UNICODE_NORM_QC_NO},
+	{0xCDE2, UNICODE_NORM_QC_NO},
+	{0xCDE3, UNICODE_NORM_QC_NO},
+	{0xCDE4, UNICODE_NORM_QC_NO},
+	{0xCDE5, UNICODE_NORM_QC_NO},
+	{0xCDE6, UNICODE_NORM_QC_NO},
+	{0xCDE7, UNICODE_NORM_QC_NO},
+	{0xCDE8, UNICODE_NORM_QC_NO},
+	{0xCDE9, UNICODE_NORM_QC_NO},
+	{0xCDEA, UNICODE_NORM_QC_NO},
+	{0xCDEB, UNICODE_NORM_QC_NO},
+	{0xCDEC, UNICODE_NORM_QC_NO},
+	{0xCDED, UNICODE_NORM_QC_NO},
+	{0xCDEE, UNICODE_NORM_QC_NO},
+	{0xCDEF, UNICODE_NORM_QC_NO},
+	{0xCDF0, UNICODE_NORM_QC_NO},
+	{0xCDF1, UNICODE_NORM_QC_NO},
+	{0xCDF2, UNICODE_NORM_QC_NO},
+	{0xCDF3, UNICODE_NORM_QC_NO},
+	{0xCDF4, UNICODE_NORM_QC_NO},
+	{0xCDF5, UNICODE_NORM_QC_NO},
+	{0xCDF6, UNICODE_NORM_QC_NO},
+	{0xCDF7, UNICODE_NORM_QC_NO},
+	{0xCDF8, UNICODE_NORM_QC_NO},
+	{0xCDF9, UNICODE_NORM_QC_NO},
+	{0xCDFA, UNICODE_NORM_QC_NO},
+	{0xCDFB, UNICODE_NORM_QC_NO},
+	{0xCDFC, UNICODE_NORM_QC_NO},
+	{0xCDFD, UNICODE_NORM_QC_NO},
+	{0xCDFE, UNICODE_NORM_QC_NO},
+	{0xCDFF, UNICODE_NORM_QC_NO},
+	{0xCE00, UNICODE_NORM_QC_NO},
+	{0xCE01, UNICODE_NORM_QC_NO},
+	{0xCE02, UNICODE_NORM_QC_NO},
+	{0xCE03, UNICODE_NORM_QC_NO},
+	{0xCE04, UNICODE_NORM_QC_NO},
+	{0xCE05, UNICODE_NORM_QC_NO},
+	{0xCE06, UNICODE_NORM_QC_NO},
+	{0xCE07, UNICODE_NORM_QC_NO},
+	{0xCE08, UNICODE_NORM_QC_NO},
+	{0xCE09, UNICODE_NORM_QC_NO},
+	{0xCE0A, UNICODE_NORM_QC_NO},
+	{0xCE0B, UNICODE_NORM_QC_NO},
+	{0xCE0C, UNICODE_NORM_QC_NO},
+	{0xCE0D, UNICODE_NORM_QC_NO},
+	{0xCE0E, UNICODE_NORM_QC_NO},
+	{0xCE0F, UNICODE_NORM_QC_NO},
+	{0xCE10, UNICODE_NORM_QC_NO},
+	{0xCE11, UNICODE_NORM_QC_NO},
+	{0xCE12, UNICODE_NORM_QC_NO},
+	{0xCE13, UNICODE_NORM_QC_NO},
+	{0xCE14, UNICODE_NORM_QC_NO},
+	{0xCE15, UNICODE_NORM_QC_NO},
+	{0xCE16, UNICODE_NORM_QC_NO},
+	{0xCE17, UNICODE_NORM_QC_NO},
+	{0xCE18, UNICODE_NORM_QC_NO},
+	{0xCE19, UNICODE_NORM_QC_NO},
+	{0xCE1A, UNICODE_NORM_QC_NO},
+	{0xCE1B, UNICODE_NORM_QC_NO},
+	{0xCE1C, UNICODE_NORM_QC_NO},
+	{0xCE1D, UNICODE_NORM_QC_NO},
+	{0xCE1E, UNICODE_NORM_QC_NO},
+	{0xCE1F, UNICODE_NORM_QC_NO},
+	{0xCE20, UNICODE_NORM_QC_NO},
+	{0xCE21, UNICODE_NORM_QC_NO},
+	{0xCE22, UNICODE_NORM_QC_NO},
+	{0xCE23, UNICODE_NORM_QC_NO},
+	{0xCE24, UNICODE_NORM_QC_NO},
+	{0xCE25, UNICODE_NORM_QC_NO},
+	{0xCE26, UNICODE_NORM_QC_NO},
+	{0xCE27, UNICODE_NORM_QC_NO},
+	{0xCE28, UNICODE_NORM_QC_NO},
+	{0xCE29, UNICODE_NORM_QC_NO},
+	{0xCE2A, UNICODE_NORM_QC_NO},
+	{0xCE2B, UNICODE_NORM_QC_NO},
+	{0xCE2C, UNICODE_NORM_QC_NO},
+	{0xCE2D, UNICODE_NORM_QC_NO},
+	{0xCE2E, UNICODE_NORM_QC_NO},
+	{0xCE2F, UNICODE_NORM_QC_NO},
+	{0xCE30, UNICODE_NORM_QC_NO},
+	{0xCE31, UNICODE_NORM_QC_NO},
+	{0xCE32, UNICODE_NORM_QC_NO},
+	{0xCE33, UNICODE_NORM_QC_NO},
+	{0xCE34, UNICODE_NORM_QC_NO},
+	{0xCE35, UNICODE_NORM_QC_NO},
+	{0xCE36, UNICODE_NORM_QC_NO},
+	{0xCE37, UNICODE_NORM_QC_NO},
+	{0xCE38, UNICODE_NORM_QC_NO},
+	{0xCE39, UNICODE_NORM_QC_NO},
+	{0xCE3A, UNICODE_NORM_QC_NO},
+	{0xCE3B, UNICODE_NORM_QC_NO},
+	{0xCE3C, UNICODE_NORM_QC_NO},
+	{0xCE3D, UNICODE_NORM_QC_NO},
+	{0xCE3E, UNICODE_NORM_QC_NO},
+	{0xCE3F, UNICODE_NORM_QC_NO},
+	{0xCE40, UNICODE_NORM_QC_NO},
+	{0xCE41, UNICODE_NORM_QC_NO},
+	{0xCE42, UNICODE_NORM_QC_NO},
+	{0xCE43, UNICODE_NORM_QC_NO},
+	{0xCE44, UNICODE_NORM_QC_NO},
+	{0xCE45, UNICODE_NORM_QC_NO},
+	{0xCE46, UNICODE_NORM_QC_NO},
+	{0xCE47, UNICODE_NORM_QC_NO},
+	{0xCE48, UNICODE_NORM_QC_NO},
+	{0xCE49, UNICODE_NORM_QC_NO},
+	{0xCE4A, UNICODE_NORM_QC_NO},
+	{0xCE4B, UNICODE_NORM_QC_NO},
+	{0xCE4C, UNICODE_NORM_QC_NO},
+	{0xCE4D, UNICODE_NORM_QC_NO},
+	{0xCE4E, UNICODE_NORM_QC_NO},
+	{0xCE4F, UNICODE_NORM_QC_NO},
+	{0xCE50, UNICODE_NORM_QC_NO},
+	{0xCE51, UNICODE_NORM_QC_NO},
+	{0xCE52, UNICODE_NORM_QC_NO},
+	{0xCE53, UNICODE_NORM_QC_NO},
+	{0xCE54, UNICODE_NORM_QC_NO},
+	{0xCE55, UNICODE_NORM_QC_NO},
+	{0xCE56, UNICODE_NORM_QC_NO},
+	{0xCE57, UNICODE_NORM_QC_NO},
+	{0xCE58, UNICODE_NORM_QC_NO},
+	{0xCE59, UNICODE_NORM_QC_NO},
+	{0xCE5A, UNICODE_NORM_QC_NO},
+	{0xCE5B, UNICODE_NORM_QC_NO},
+	{0xCE5C, UNICODE_NORM_QC_NO},
+	{0xCE5D, UNICODE_NORM_QC_NO},
+	{0xCE5E, UNICODE_NORM_QC_NO},
+	{0xCE5F, UNICODE_NORM_QC_NO},
+	{0xCE60, UNICODE_NORM_QC_NO},
+	{0xCE61, UNICODE_NORM_QC_NO},
+	{0xCE62, UNICODE_NORM_QC_NO},
+	{0xCE63, UNICODE_NORM_QC_NO},
+	{0xCE64, UNICODE_NORM_QC_NO},
+	{0xCE65, UNICODE_NORM_QC_NO},
+	{0xCE66, UNICODE_NORM_QC_NO},
+	{0xCE67, UNICODE_NORM_QC_NO},
+	{0xCE68, UNICODE_NORM_QC_NO},
+	{0xCE69, UNICODE_NORM_QC_NO},
+	{0xCE6A, UNICODE_NORM_QC_NO},
+	{0xCE6B, UNICODE_NORM_QC_NO},
+	{0xCE6C, UNICODE_NORM_QC_NO},
+	{0xCE6D, UNICODE_NORM_QC_NO},
+	{0xCE6E, UNICODE_NORM_QC_NO},
+	{0xCE6F, UNICODE_NORM_QC_NO},
+	{0xCE70, UNICODE_NORM_QC_NO},
+	{0xCE71, UNICODE_NORM_QC_NO},
+	{0xCE72, UNICODE_NORM_QC_NO},
+	{0xCE73, UNICODE_NORM_QC_NO},
+	{0xCE74, UNICODE_NORM_QC_NO},
+	{0xCE75, UNICODE_NORM_QC_NO},
+	{0xCE76, UNICODE_NORM_QC_NO},
+	{0xCE77, UNICODE_NORM_QC_NO},
+	{0xCE78, UNICODE_NORM_QC_NO},
+	{0xCE79, UNICODE_NORM_QC_NO},
+	{0xCE7A, UNICODE_NORM_QC_NO},
+	{0xCE7B, UNICODE_NORM_QC_NO},
+	{0xCE7C, UNICODE_NORM_QC_NO},
+	{0xCE7D, UNICODE_NORM_QC_NO},
+	{0xCE7E, UNICODE_NORM_QC_NO},
+	{0xCE7F, UNICODE_NORM_QC_NO},
+	{0xCE80, UNICODE_NORM_QC_NO},
+	{0xCE81, UNICODE_NORM_QC_NO},
+	{0xCE82, UNICODE_NORM_QC_NO},
+	{0xCE83, UNICODE_NORM_QC_NO},
+	{0xCE84, UNICODE_NORM_QC_NO},
+	{0xCE85, UNICODE_NORM_QC_NO},
+	{0xCE86, UNICODE_NORM_QC_NO},
+	{0xCE87, UNICODE_NORM_QC_NO},
+	{0xCE88, UNICODE_NORM_QC_NO},
+	{0xCE89, UNICODE_NORM_QC_NO},
+	{0xCE8A, UNICODE_NORM_QC_NO},
+	{0xCE8B, UNICODE_NORM_QC_NO},
+	{0xCE8C, UNICODE_NORM_QC_NO},
+	{0xCE8D, UNICODE_NORM_QC_NO},
+	{0xCE8E, UNICODE_NORM_QC_NO},
+	{0xCE8F, UNICODE_NORM_QC_NO},
+	{0xCE90, UNICODE_NORM_QC_NO},
+	{0xCE91, UNICODE_NORM_QC_NO},
+	{0xCE92, UNICODE_NORM_QC_NO},
+	{0xCE93, UNICODE_NORM_QC_NO},
+	{0xCE94, UNICODE_NORM_QC_NO},
+	{0xCE95, UNICODE_NORM_QC_NO},
+	{0xCE96, UNICODE_NORM_QC_NO},
+	{0xCE97, UNICODE_NORM_QC_NO},
+	{0xCE98, UNICODE_NORM_QC_NO},
+	{0xCE99, UNICODE_NORM_QC_NO},
+	{0xCE9A, UNICODE_NORM_QC_NO},
+	{0xCE9B, UNICODE_NORM_QC_NO},
+	{0xCE9C, UNICODE_NORM_QC_NO},
+	{0xCE9D, UNICODE_NORM_QC_NO},
+	{0xCE9E, UNICODE_NORM_QC_NO},
+	{0xCE9F, UNICODE_NORM_QC_NO},
+	{0xCEA0, UNICODE_NORM_QC_NO},
+	{0xCEA1, UNICODE_NORM_QC_NO},
+	{0xCEA2, UNICODE_NORM_QC_NO},
+	{0xCEA3, UNICODE_NORM_QC_NO},
+	{0xCEA4, UNICODE_NORM_QC_NO},
+	{0xCEA5, UNICODE_NORM_QC_NO},
+	{0xCEA6, UNICODE_NORM_QC_NO},
+	{0xCEA7, UNICODE_NORM_QC_NO},
+	{0xCEA8, UNICODE_NORM_QC_NO},
+	{0xCEA9, UNICODE_NORM_QC_NO},
+	{0xCEAA, UNICODE_NORM_QC_NO},
+	{0xCEAB, UNICODE_NORM_QC_NO},
+	{0xCEAC, UNICODE_NORM_QC_NO},
+	{0xCEAD, UNICODE_NORM_QC_NO},
+	{0xCEAE, UNICODE_NORM_QC_NO},
+	{0xCEAF, UNICODE_NORM_QC_NO},
+	{0xCEB0, UNICODE_NORM_QC_NO},
+	{0xCEB1, UNICODE_NORM_QC_NO},
+	{0xCEB2, UNICODE_NORM_QC_NO},
+	{0xCEB3, UNICODE_NORM_QC_NO},
+	{0xCEB4, UNICODE_NORM_QC_NO},
+	{0xCEB5, UNICODE_NORM_QC_NO},
+	{0xCEB6, UNICODE_NORM_QC_NO},
+	{0xCEB7, UNICODE_NORM_QC_NO},
+	{0xCEB8, UNICODE_NORM_QC_NO},
+	{0xCEB9, UNICODE_NORM_QC_NO},
+	{0xCEBA, UNICODE_NORM_QC_NO},
+	{0xCEBB, UNICODE_NORM_QC_NO},
+	{0xCEBC, UNICODE_NORM_QC_NO},
+	{0xCEBD, UNICODE_NORM_QC_NO},
+	{0xCEBE, UNICODE_NORM_QC_NO},
+	{0xCEBF, UNICODE_NORM_QC_NO},
+	{0xCEC0, UNICODE_NORM_QC_NO},
+	{0xCEC1, UNICODE_NORM_QC_NO},
+	{0xCEC2, UNICODE_NORM_QC_NO},
+	{0xCEC3, UNICODE_NORM_QC_NO},
+	{0xCEC4, UNICODE_NORM_QC_NO},
+	{0xCEC5, UNICODE_NORM_QC_NO},
+	{0xCEC6, UNICODE_NORM_QC_NO},
+	{0xCEC7, UNICODE_NORM_QC_NO},
+	{0xCEC8, UNICODE_NORM_QC_NO},
+	{0xCEC9, UNICODE_NORM_QC_NO},
+	{0xCECA, UNICODE_NORM_QC_NO},
+	{0xCECB, UNICODE_NORM_QC_NO},
+	{0xCECC, UNICODE_NORM_QC_NO},
+	{0xCECD, UNICODE_NORM_QC_NO},
+	{0xCECE, UNICODE_NORM_QC_NO},
+	{0xCECF, UNICODE_NORM_QC_NO},
+	{0xCED0, UNICODE_NORM_QC_NO},
+	{0xCED1, UNICODE_NORM_QC_NO},
+	{0xCED2, UNICODE_NORM_QC_NO},
+	{0xCED3, UNICODE_NORM_QC_NO},
+	{0xCED4, UNICODE_NORM_QC_NO},
+	{0xCED5, UNICODE_NORM_QC_NO},
+	{0xCED6, UNICODE_NORM_QC_NO},
+	{0xCED7, UNICODE_NORM_QC_NO},
+	{0xCED8, UNICODE_NORM_QC_NO},
+	{0xCED9, UNICODE_NORM_QC_NO},
+	{0xCEDA, UNICODE_NORM_QC_NO},
+	{0xCEDB, UNICODE_NORM_QC_NO},
+	{0xCEDC, UNICODE_NORM_QC_NO},
+	{0xCEDD, UNICODE_NORM_QC_NO},
+	{0xCEDE, UNICODE_NORM_QC_NO},
+	{0xCEDF, UNICODE_NORM_QC_NO},
+	{0xCEE0, UNICODE_NORM_QC_NO},
+	{0xCEE1, UNICODE_NORM_QC_NO},
+	{0xCEE2, UNICODE_NORM_QC_NO},
+	{0xCEE3, UNICODE_NORM_QC_NO},
+	{0xCEE4, UNICODE_NORM_QC_NO},
+	{0xCEE5, UNICODE_NORM_QC_NO},
+	{0xCEE6, UNICODE_NORM_QC_NO},
+	{0xCEE7, UNICODE_NORM_QC_NO},
+	{0xCEE8, UNICODE_NORM_QC_NO},
+	{0xCEE9, UNICODE_NORM_QC_NO},
+	{0xCEEA, UNICODE_NORM_QC_NO},
+	{0xCEEB, UNICODE_NORM_QC_NO},
+	{0xCEEC, UNICODE_NORM_QC_NO},
+	{0xCEED, UNICODE_NORM_QC_NO},
+	{0xCEEE, UNICODE_NORM_QC_NO},
+	{0xCEEF, UNICODE_NORM_QC_NO},
+	{0xCEF0, UNICODE_NORM_QC_NO},
+	{0xCEF1, UNICODE_NORM_QC_NO},
+	{0xCEF2, UNICODE_NORM_QC_NO},
+	{0xCEF3, UNICODE_NORM_QC_NO},
+	{0xCEF4, UNICODE_NORM_QC_NO},
+	{0xCEF5, UNICODE_NORM_QC_NO},
+	{0xCEF6, UNICODE_NORM_QC_NO},
+	{0xCEF7, UNICODE_NORM_QC_NO},
+	{0xCEF8, UNICODE_NORM_QC_NO},
+	{0xCEF9, UNICODE_NORM_QC_NO},
+	{0xCEFA, UNICODE_NORM_QC_NO},
+	{0xCEFB, UNICODE_NORM_QC_NO},
+	{0xCEFC, UNICODE_NORM_QC_NO},
+	{0xCEFD, UNICODE_NORM_QC_NO},
+	{0xCEFE, UNICODE_NORM_QC_NO},
+	{0xCEFF, UNICODE_NORM_QC_NO},
+	{0xCF00, UNICODE_NORM_QC_NO},
+	{0xCF01, UNICODE_NORM_QC_NO},
+	{0xCF02, UNICODE_NORM_QC_NO},
+	{0xCF03, UNICODE_NORM_QC_NO},
+	{0xCF04, UNICODE_NORM_QC_NO},
+	{0xCF05, UNICODE_NORM_QC_NO},
+	{0xCF06, UNICODE_NORM_QC_NO},
+	{0xCF07, UNICODE_NORM_QC_NO},
+	{0xCF08, UNICODE_NORM_QC_NO},
+	{0xCF09, UNICODE_NORM_QC_NO},
+	{0xCF0A, UNICODE_NORM_QC_NO},
+	{0xCF0B, UNICODE_NORM_QC_NO},
+	{0xCF0C, UNICODE_NORM_QC_NO},
+	{0xCF0D, UNICODE_NORM_QC_NO},
+	{0xCF0E, UNICODE_NORM_QC_NO},
+	{0xCF0F, UNICODE_NORM_QC_NO},
+	{0xCF10, UNICODE_NORM_QC_NO},
+	{0xCF11, UNICODE_NORM_QC_NO},
+	{0xCF12, UNICODE_NORM_QC_NO},
+	{0xCF13, UNICODE_NORM_QC_NO},
+	{0xCF14, UNICODE_NORM_QC_NO},
+	{0xCF15, UNICODE_NORM_QC_NO},
+	{0xCF16, UNICODE_NORM_QC_NO},
+	{0xCF17, UNICODE_NORM_QC_NO},
+	{0xCF18, UNICODE_NORM_QC_NO},
+	{0xCF19, UNICODE_NORM_QC_NO},
+	{0xCF1A, UNICODE_NORM_QC_NO},
+	{0xCF1B, UNICODE_NORM_QC_NO},
+	{0xCF1C, UNICODE_NORM_QC_NO},
+	{0xCF1D, UNICODE_NORM_QC_NO},
+	{0xCF1E, UNICODE_NORM_QC_NO},
+	{0xCF1F, UNICODE_NORM_QC_NO},
+	{0xCF20, UNICODE_NORM_QC_NO},
+	{0xCF21, UNICODE_NORM_QC_NO},
+	{0xCF22, UNICODE_NORM_QC_NO},
+	{0xCF23, UNICODE_NORM_QC_NO},
+	{0xCF24, UNICODE_NORM_QC_NO},
+	{0xCF25, UNICODE_NORM_QC_NO},
+	{0xCF26, UNICODE_NORM_QC_NO},
+	{0xCF27, UNICODE_NORM_QC_NO},
+	{0xCF28, UNICODE_NORM_QC_NO},
+	{0xCF29, UNICODE_NORM_QC_NO},
+	{0xCF2A, UNICODE_NORM_QC_NO},
+	{0xCF2B, UNICODE_NORM_QC_NO},
+	{0xCF2C, UNICODE_NORM_QC_NO},
+	{0xCF2D, UNICODE_NORM_QC_NO},
+	{0xCF2E, UNICODE_NORM_QC_NO},
+	{0xCF2F, UNICODE_NORM_QC_NO},
+	{0xCF30, UNICODE_NORM_QC_NO},
+	{0xCF31, UNICODE_NORM_QC_NO},
+	{0xCF32, UNICODE_NORM_QC_NO},
+	{0xCF33, UNICODE_NORM_QC_NO},
+	{0xCF34, UNICODE_NORM_QC_NO},
+	{0xCF35, UNICODE_NORM_QC_NO},
+	{0xCF36, UNICODE_NORM_QC_NO},
+	{0xCF37, UNICODE_NORM_QC_NO},
+	{0xCF38, UNICODE_NORM_QC_NO},
+	{0xCF39, UNICODE_NORM_QC_NO},
+	{0xCF3A, UNICODE_NORM_QC_NO},
+	{0xCF3B, UNICODE_NORM_QC_NO},
+	{0xCF3C, UNICODE_NORM_QC_NO},
+	{0xCF3D, UNICODE_NORM_QC_NO},
+	{0xCF3E, UNICODE_NORM_QC_NO},
+	{0xCF3F, UNICODE_NORM_QC_NO},
+	{0xCF40, UNICODE_NORM_QC_NO},
+	{0xCF41, UNICODE_NORM_QC_NO},
+	{0xCF42, UNICODE_NORM_QC_NO},
+	{0xCF43, UNICODE_NORM_QC_NO},
+	{0xCF44, UNICODE_NORM_QC_NO},
+	{0xCF45, UNICODE_NORM_QC_NO},
+	{0xCF46, UNICODE_NORM_QC_NO},
+	{0xCF47, UNICODE_NORM_QC_NO},
+	{0xCF48, UNICODE_NORM_QC_NO},
+	{0xCF49, UNICODE_NORM_QC_NO},
+	{0xCF4A, UNICODE_NORM_QC_NO},
+	{0xCF4B, UNICODE_NORM_QC_NO},
+	{0xCF4C, UNICODE_NORM_QC_NO},
+	{0xCF4D, UNICODE_NORM_QC_NO},
+	{0xCF4E, UNICODE_NORM_QC_NO},
+	{0xCF4F, UNICODE_NORM_QC_NO},
+	{0xCF50, UNICODE_NORM_QC_NO},
+	{0xCF51, UNICODE_NORM_QC_NO},
+	{0xCF52, UNICODE_NORM_QC_NO},
+	{0xCF53, UNICODE_NORM_QC_NO},
+	{0xCF54, UNICODE_NORM_QC_NO},
+	{0xCF55, UNICODE_NORM_QC_NO},
+	{0xCF56, UNICODE_NORM_QC_NO},
+	{0xCF57, UNICODE_NORM_QC_NO},
+	{0xCF58, UNICODE_NORM_QC_NO},
+	{0xCF59, UNICODE_NORM_QC_NO},
+	{0xCF5A, UNICODE_NORM_QC_NO},
+	{0xCF5B, UNICODE_NORM_QC_NO},
+	{0xCF5C, UNICODE_NORM_QC_NO},
+	{0xCF5D, UNICODE_NORM_QC_NO},
+	{0xCF5E, UNICODE_NORM_QC_NO},
+	{0xCF5F, UNICODE_NORM_QC_NO},
+	{0xCF60, UNICODE_NORM_QC_NO},
+	{0xCF61, UNICODE_NORM_QC_NO},
+	{0xCF62, UNICODE_NORM_QC_NO},
+	{0xCF63, UNICODE_NORM_QC_NO},
+	{0xCF64, UNICODE_NORM_QC_NO},
+	{0xCF65, UNICODE_NORM_QC_NO},
+	{0xCF66, UNICODE_NORM_QC_NO},
+	{0xCF67, UNICODE_NORM_QC_NO},
+	{0xCF68, UNICODE_NORM_QC_NO},
+	{0xCF69, UNICODE_NORM_QC_NO},
+	{0xCF6A, UNICODE_NORM_QC_NO},
+	{0xCF6B, UNICODE_NORM_QC_NO},
+	{0xCF6C, UNICODE_NORM_QC_NO},
+	{0xCF6D, UNICODE_NORM_QC_NO},
+	{0xCF6E, UNICODE_NORM_QC_NO},
+	{0xCF6F, UNICODE_NORM_QC_NO},
+	{0xCF70, UNICODE_NORM_QC_NO},
+	{0xCF71, UNICODE_NORM_QC_NO},
+	{0xCF72, UNICODE_NORM_QC_NO},
+	{0xCF73, UNICODE_NORM_QC_NO},
+	{0xCF74, UNICODE_NORM_QC_NO},
+	{0xCF75, UNICODE_NORM_QC_NO},
+	{0xCF76, UNICODE_NORM_QC_NO},
+	{0xCF77, UNICODE_NORM_QC_NO},
+	{0xCF78, UNICODE_NORM_QC_NO},
+	{0xCF79, UNICODE_NORM_QC_NO},
+	{0xCF7A, UNICODE_NORM_QC_NO},
+	{0xCF7B, UNICODE_NORM_QC_NO},
+	{0xCF7C, UNICODE_NORM_QC_NO},
+	{0xCF7D, UNICODE_NORM_QC_NO},
+	{0xCF7E, UNICODE_NORM_QC_NO},
+	{0xCF7F, UNICODE_NORM_QC_NO},
+	{0xCF80, UNICODE_NORM_QC_NO},
+	{0xCF81, UNICODE_NORM_QC_NO},
+	{0xCF82, UNICODE_NORM_QC_NO},
+	{0xCF83, UNICODE_NORM_QC_NO},
+	{0xCF84, UNICODE_NORM_QC_NO},
+	{0xCF85, UNICODE_NORM_QC_NO},
+	{0xCF86, UNICODE_NORM_QC_NO},
+	{0xCF87, UNICODE_NORM_QC_NO},
+	{0xCF88, UNICODE_NORM_QC_NO},
+	{0xCF89, UNICODE_NORM_QC_NO},
+	{0xCF8A, UNICODE_NORM_QC_NO},
+	{0xCF8B, UNICODE_NORM_QC_NO},
+	{0xCF8C, UNICODE_NORM_QC_NO},
+	{0xCF8D, UNICODE_NORM_QC_NO},
+	{0xCF8E, UNICODE_NORM_QC_NO},
+	{0xCF8F, UNICODE_NORM_QC_NO},
+	{0xCF90, UNICODE_NORM_QC_NO},
+	{0xCF91, UNICODE_NORM_QC_NO},
+	{0xCF92, UNICODE_NORM_QC_NO},
+	{0xCF93, UNICODE_NORM_QC_NO},
+	{0xCF94, UNICODE_NORM_QC_NO},
+	{0xCF95, UNICODE_NORM_QC_NO},
+	{0xCF96, UNICODE_NORM_QC_NO},
+	{0xCF97, UNICODE_NORM_QC_NO},
+	{0xCF98, UNICODE_NORM_QC_NO},
+	{0xCF99, UNICODE_NORM_QC_NO},
+	{0xCF9A, UNICODE_NORM_QC_NO},
+	{0xCF9B, UNICODE_NORM_QC_NO},
+	{0xCF9C, UNICODE_NORM_QC_NO},
+	{0xCF9D, UNICODE_NORM_QC_NO},
+	{0xCF9E, UNICODE_NORM_QC_NO},
+	{0xCF9F, UNICODE_NORM_QC_NO},
+	{0xCFA0, UNICODE_NORM_QC_NO},
+	{0xCFA1, UNICODE_NORM_QC_NO},
+	{0xCFA2, UNICODE_NORM_QC_NO},
+	{0xCFA3, UNICODE_NORM_QC_NO},
+	{0xCFA4, UNICODE_NORM_QC_NO},
+	{0xCFA5, UNICODE_NORM_QC_NO},
+	{0xCFA6, UNICODE_NORM_QC_NO},
+	{0xCFA7, UNICODE_NORM_QC_NO},
+	{0xCFA8, UNICODE_NORM_QC_NO},
+	{0xCFA9, UNICODE_NORM_QC_NO},
+	{0xCFAA, UNICODE_NORM_QC_NO},
+	{0xCFAB, UNICODE_NORM_QC_NO},
+	{0xCFAC, UNICODE_NORM_QC_NO},
+	{0xCFAD, UNICODE_NORM_QC_NO},
+	{0xCFAE, UNICODE_NORM_QC_NO},
+	{0xCFAF, UNICODE_NORM_QC_NO},
+	{0xCFB0, UNICODE_NORM_QC_NO},
+	{0xCFB1, UNICODE_NORM_QC_NO},
+	{0xCFB2, UNICODE_NORM_QC_NO},
+	{0xCFB3, UNICODE_NORM_QC_NO},
+	{0xCFB4, UNICODE_NORM_QC_NO},
+	{0xCFB5, UNICODE_NORM_QC_NO},
+	{0xCFB6, UNICODE_NORM_QC_NO},
+	{0xCFB7, UNICODE_NORM_QC_NO},
+	{0xCFB8, UNICODE_NORM_QC_NO},
+	{0xCFB9, UNICODE_NORM_QC_NO},
+	{0xCFBA, UNICODE_NORM_QC_NO},
+	{0xCFBB, UNICODE_NORM_QC_NO},
+	{0xCFBC, UNICODE_NORM_QC_NO},
+	{0xCFBD, UNICODE_NORM_QC_NO},
+	{0xCFBE, UNICODE_NORM_QC_NO},
+	{0xCFBF, UNICODE_NORM_QC_NO},
+	{0xCFC0, UNICODE_NORM_QC_NO},
+	{0xCFC1, UNICODE_NORM_QC_NO},
+	{0xCFC2, UNICODE_NORM_QC_NO},
+	{0xCFC3, UNICODE_NORM_QC_NO},
+	{0xCFC4, UNICODE_NORM_QC_NO},
+	{0xCFC5, UNICODE_NORM_QC_NO},
+	{0xCFC6, UNICODE_NORM_QC_NO},
+	{0xCFC7, UNICODE_NORM_QC_NO},
+	{0xCFC8, UNICODE_NORM_QC_NO},
+	{0xCFC9, UNICODE_NORM_QC_NO},
+	{0xCFCA, UNICODE_NORM_QC_NO},
+	{0xCFCB, UNICODE_NORM_QC_NO},
+	{0xCFCC, UNICODE_NORM_QC_NO},
+	{0xCFCD, UNICODE_NORM_QC_NO},
+	{0xCFCE, UNICODE_NORM_QC_NO},
+	{0xCFCF, UNICODE_NORM_QC_NO},
+	{0xCFD0, UNICODE_NORM_QC_NO},
+	{0xCFD1, UNICODE_NORM_QC_NO},
+	{0xCFD2, UNICODE_NORM_QC_NO},
+	{0xCFD3, UNICODE_NORM_QC_NO},
+	{0xCFD4, UNICODE_NORM_QC_NO},
+	{0xCFD5, UNICODE_NORM_QC_NO},
+	{0xCFD6, UNICODE_NORM_QC_NO},
+	{0xCFD7, UNICODE_NORM_QC_NO},
+	{0xCFD8, UNICODE_NORM_QC_NO},
+	{0xCFD9, UNICODE_NORM_QC_NO},
+	{0xCFDA, UNICODE_NORM_QC_NO},
+	{0xCFDB, UNICODE_NORM_QC_NO},
+	{0xCFDC, UNICODE_NORM_QC_NO},
+	{0xCFDD, UNICODE_NORM_QC_NO},
+	{0xCFDE, UNICODE_NORM_QC_NO},
+	{0xCFDF, UNICODE_NORM_QC_NO},
+	{0xCFE0, UNICODE_NORM_QC_NO},
+	{0xCFE1, UNICODE_NORM_QC_NO},
+	{0xCFE2, UNICODE_NORM_QC_NO},
+	{0xCFE3, UNICODE_NORM_QC_NO},
+	{0xCFE4, UNICODE_NORM_QC_NO},
+	{0xCFE5, UNICODE_NORM_QC_NO},
+	{0xCFE6, UNICODE_NORM_QC_NO},
+	{0xCFE7, UNICODE_NORM_QC_NO},
+	{0xCFE8, UNICODE_NORM_QC_NO},
+	{0xCFE9, UNICODE_NORM_QC_NO},
+	{0xCFEA, UNICODE_NORM_QC_NO},
+	{0xCFEB, UNICODE_NORM_QC_NO},
+	{0xCFEC, UNICODE_NORM_QC_NO},
+	{0xCFED, UNICODE_NORM_QC_NO},
+	{0xCFEE, UNICODE_NORM_QC_NO},
+	{0xCFEF, UNICODE_NORM_QC_NO},
+	{0xCFF0, UNICODE_NORM_QC_NO},
+	{0xCFF1, UNICODE_NORM_QC_NO},
+	{0xCFF2, UNICODE_NORM_QC_NO},
+	{0xCFF3, UNICODE_NORM_QC_NO},
+	{0xCFF4, UNICODE_NORM_QC_NO},
+	{0xCFF5, UNICODE_NORM_QC_NO},
+	{0xCFF6, UNICODE_NORM_QC_NO},
+	{0xCFF7, UNICODE_NORM_QC_NO},
+	{0xCFF8, UNICODE_NORM_QC_NO},
+	{0xCFF9, UNICODE_NORM_QC_NO},
+	{0xCFFA, UNICODE_NORM_QC_NO},
+	{0xCFFB, UNICODE_NORM_QC_NO},
+	{0xCFFC, UNICODE_NORM_QC_NO},
+	{0xCFFD, UNICODE_NORM_QC_NO},
+	{0xCFFE, UNICODE_NORM_QC_NO},
+	{0xCFFF, UNICODE_NORM_QC_NO},
+	{0xD000, UNICODE_NORM_QC_NO},
+	{0xD001, UNICODE_NORM_QC_NO},
+	{0xD002, UNICODE_NORM_QC_NO},
+	{0xD003, UNICODE_NORM_QC_NO},
+	{0xD004, UNICODE_NORM_QC_NO},
+	{0xD005, UNICODE_NORM_QC_NO},
+	{0xD006, UNICODE_NORM_QC_NO},
+	{0xD007, UNICODE_NORM_QC_NO},
+	{0xD008, UNICODE_NORM_QC_NO},
+	{0xD009, UNICODE_NORM_QC_NO},
+	{0xD00A, UNICODE_NORM_QC_NO},
+	{0xD00B, UNICODE_NORM_QC_NO},
+	{0xD00C, UNICODE_NORM_QC_NO},
+	{0xD00D, UNICODE_NORM_QC_NO},
+	{0xD00E, UNICODE_NORM_QC_NO},
+	{0xD00F, UNICODE_NORM_QC_NO},
+	{0xD010, UNICODE_NORM_QC_NO},
+	{0xD011, UNICODE_NORM_QC_NO},
+	{0xD012, UNICODE_NORM_QC_NO},
+	{0xD013, UNICODE_NORM_QC_NO},
+	{0xD014, UNICODE_NORM_QC_NO},
+	{0xD015, UNICODE_NORM_QC_NO},
+	{0xD016, UNICODE_NORM_QC_NO},
+	{0xD017, UNICODE_NORM_QC_NO},
+	{0xD018, UNICODE_NORM_QC_NO},
+	{0xD019, UNICODE_NORM_QC_NO},
+	{0xD01A, UNICODE_NORM_QC_NO},
+	{0xD01B, UNICODE_NORM_QC_NO},
+	{0xD01C, UNICODE_NORM_QC_NO},
+	{0xD01D, UNICODE_NORM_QC_NO},
+	{0xD01E, UNICODE_NORM_QC_NO},
+	{0xD01F, UNICODE_NORM_QC_NO},
+	{0xD020, UNICODE_NORM_QC_NO},
+	{0xD021, UNICODE_NORM_QC_NO},
+	{0xD022, UNICODE_NORM_QC_NO},
+	{0xD023, UNICODE_NORM_QC_NO},
+	{0xD024, UNICODE_NORM_QC_NO},
+	{0xD025, UNICODE_NORM_QC_NO},
+	{0xD026, UNICODE_NORM_QC_NO},
+	{0xD027, UNICODE_NORM_QC_NO},
+	{0xD028, UNICODE_NORM_QC_NO},
+	{0xD029, UNICODE_NORM_QC_NO},
+	{0xD02A, UNICODE_NORM_QC_NO},
+	{0xD02B, UNICODE_NORM_QC_NO},
+	{0xD02C, UNICODE_NORM_QC_NO},
+	{0xD02D, UNICODE_NORM_QC_NO},
+	{0xD02E, UNICODE_NORM_QC_NO},
+	{0xD02F, UNICODE_NORM_QC_NO},
+	{0xD030, UNICODE_NORM_QC_NO},
+	{0xD031, UNICODE_NORM_QC_NO},
+	{0xD032, UNICODE_NORM_QC_NO},
+	{0xD033, UNICODE_NORM_QC_NO},
+	{0xD034, UNICODE_NORM_QC_NO},
+	{0xD035, UNICODE_NORM_QC_NO},
+	{0xD036, UNICODE_NORM_QC_NO},
+	{0xD037, UNICODE_NORM_QC_NO},
+	{0xD038, UNICODE_NORM_QC_NO},
+	{0xD039, UNICODE_NORM_QC_NO},
+	{0xD03A, UNICODE_NORM_QC_NO},
+	{0xD03B, UNICODE_NORM_QC_NO},
+	{0xD03C, UNICODE_NORM_QC_NO},
+	{0xD03D, UNICODE_NORM_QC_NO},
+	{0xD03E, UNICODE_NORM_QC_NO},
+	{0xD03F, UNICODE_NORM_QC_NO},
+	{0xD040, UNICODE_NORM_QC_NO},
+	{0xD041, UNICODE_NORM_QC_NO},
+	{0xD042, UNICODE_NORM_QC_NO},
+	{0xD043, UNICODE_NORM_QC_NO},
+	{0xD044, UNICODE_NORM_QC_NO},
+	{0xD045, UNICODE_NORM_QC_NO},
+	{0xD046, UNICODE_NORM_QC_NO},
+	{0xD047, UNICODE_NORM_QC_NO},
+	{0xD048, UNICODE_NORM_QC_NO},
+	{0xD049, UNICODE_NORM_QC_NO},
+	{0xD04A, UNICODE_NORM_QC_NO},
+	{0xD04B, UNICODE_NORM_QC_NO},
+	{0xD04C, UNICODE_NORM_QC_NO},
+	{0xD04D, UNICODE_NORM_QC_NO},
+	{0xD04E, UNICODE_NORM_QC_NO},
+	{0xD04F, UNICODE_NORM_QC_NO},
+	{0xD050, UNICODE_NORM_QC_NO},
+	{0xD051, UNICODE_NORM_QC_NO},
+	{0xD052, UNICODE_NORM_QC_NO},
+	{0xD053, UNICODE_NORM_QC_NO},
+	{0xD054, UNICODE_NORM_QC_NO},
+	{0xD055, UNICODE_NORM_QC_NO},
+	{0xD056, UNICODE_NORM_QC_NO},
+	{0xD057, UNICODE_NORM_QC_NO},
+	{0xD058, UNICODE_NORM_QC_NO},
+	{0xD059, UNICODE_NORM_QC_NO},
+	{0xD05A, UNICODE_NORM_QC_NO},
+	{0xD05B, UNICODE_NORM_QC_NO},
+	{0xD05C, UNICODE_NORM_QC_NO},
+	{0xD05D, UNICODE_NORM_QC_NO},
+	{0xD05E, UNICODE_NORM_QC_NO},
+	{0xD05F, UNICODE_NORM_QC_NO},
+	{0xD060, UNICODE_NORM_QC_NO},
+	{0xD061, UNICODE_NORM_QC_NO},
+	{0xD062, UNICODE_NORM_QC_NO},
+	{0xD063, UNICODE_NORM_QC_NO},
+	{0xD064, UNICODE_NORM_QC_NO},
+	{0xD065, UNICODE_NORM_QC_NO},
+	{0xD066, UNICODE_NORM_QC_NO},
+	{0xD067, UNICODE_NORM_QC_NO},
+	{0xD068, UNICODE_NORM_QC_NO},
+	{0xD069, UNICODE_NORM_QC_NO},
+	{0xD06A, UNICODE_NORM_QC_NO},
+	{0xD06B, UNICODE_NORM_QC_NO},
+	{0xD06C, UNICODE_NORM_QC_NO},
+	{0xD06D, UNICODE_NORM_QC_NO},
+	{0xD06E, UNICODE_NORM_QC_NO},
+	{0xD06F, UNICODE_NORM_QC_NO},
+	{0xD070, UNICODE_NORM_QC_NO},
+	{0xD071, UNICODE_NORM_QC_NO},
+	{0xD072, UNICODE_NORM_QC_NO},
+	{0xD073, UNICODE_NORM_QC_NO},
+	{0xD074, UNICODE_NORM_QC_NO},
+	{0xD075, UNICODE_NORM_QC_NO},
+	{0xD076, UNICODE_NORM_QC_NO},
+	{0xD077, UNICODE_NORM_QC_NO},
+	{0xD078, UNICODE_NORM_QC_NO},
+	{0xD079, UNICODE_NORM_QC_NO},
+	{0xD07A, UNICODE_NORM_QC_NO},
+	{0xD07B, UNICODE_NORM_QC_NO},
+	{0xD07C, UNICODE_NORM_QC_NO},
+	{0xD07D, UNICODE_NORM_QC_NO},
+	{0xD07E, UNICODE_NORM_QC_NO},
+	{0xD07F, UNICODE_NORM_QC_NO},
+	{0xD080, UNICODE_NORM_QC_NO},
+	{0xD081, UNICODE_NORM_QC_NO},
+	{0xD082, UNICODE_NORM_QC_NO},
+	{0xD083, UNICODE_NORM_QC_NO},
+	{0xD084, UNICODE_NORM_QC_NO},
+	{0xD085, UNICODE_NORM_QC_NO},
+	{0xD086, UNICODE_NORM_QC_NO},
+	{0xD087, UNICODE_NORM_QC_NO},
+	{0xD088, UNICODE_NORM_QC_NO},
+	{0xD089, UNICODE_NORM_QC_NO},
+	{0xD08A, UNICODE_NORM_QC_NO},
+	{0xD08B, UNICODE_NORM_QC_NO},
+	{0xD08C, UNICODE_NORM_QC_NO},
+	{0xD08D, UNICODE_NORM_QC_NO},
+	{0xD08E, UNICODE_NORM_QC_NO},
+	{0xD08F, UNICODE_NORM_QC_NO},
+	{0xD090, UNICODE_NORM_QC_NO},
+	{0xD091, UNICODE_NORM_QC_NO},
+	{0xD092, UNICODE_NORM_QC_NO},
+	{0xD093, UNICODE_NORM_QC_NO},
+	{0xD094, UNICODE_NORM_QC_NO},
+	{0xD095, UNICODE_NORM_QC_NO},
+	{0xD096, UNICODE_NORM_QC_NO},
+	{0xD097, UNICODE_NORM_QC_NO},
+	{0xD098, UNICODE_NORM_QC_NO},
+	{0xD099, UNICODE_NORM_QC_NO},
+	{0xD09A, UNICODE_NORM_QC_NO},
+	{0xD09B, UNICODE_NORM_QC_NO},
+	{0xD09C, UNICODE_NORM_QC_NO},
+	{0xD09D, UNICODE_NORM_QC_NO},
+	{0xD09E, UNICODE_NORM_QC_NO},
+	{0xD09F, UNICODE_NORM_QC_NO},
+	{0xD0A0, UNICODE_NORM_QC_NO},
+	{0xD0A1, UNICODE_NORM_QC_NO},
+	{0xD0A2, UNICODE_NORM_QC_NO},
+	{0xD0A3, UNICODE_NORM_QC_NO},
+	{0xD0A4, UNICODE_NORM_QC_NO},
+	{0xD0A5, UNICODE_NORM_QC_NO},
+	{0xD0A6, UNICODE_NORM_QC_NO},
+	{0xD0A7, UNICODE_NORM_QC_NO},
+	{0xD0A8, UNICODE_NORM_QC_NO},
+	{0xD0A9, UNICODE_NORM_QC_NO},
+	{0xD0AA, UNICODE_NORM_QC_NO},
+	{0xD0AB, UNICODE_NORM_QC_NO},
+	{0xD0AC, UNICODE_NORM_QC_NO},
+	{0xD0AD, UNICODE_NORM_QC_NO},
+	{0xD0AE, UNICODE_NORM_QC_NO},
+	{0xD0AF, UNICODE_NORM_QC_NO},
+	{0xD0B0, UNICODE_NORM_QC_NO},
+	{0xD0B1, UNICODE_NORM_QC_NO},
+	{0xD0B2, UNICODE_NORM_QC_NO},
+	{0xD0B3, UNICODE_NORM_QC_NO},
+	{0xD0B4, UNICODE_NORM_QC_NO},
+	{0xD0B5, UNICODE_NORM_QC_NO},
+	{0xD0B6, UNICODE_NORM_QC_NO},
+	{0xD0B7, UNICODE_NORM_QC_NO},
+	{0xD0B8, UNICODE_NORM_QC_NO},
+	{0xD0B9, UNICODE_NORM_QC_NO},
+	{0xD0BA, UNICODE_NORM_QC_NO},
+	{0xD0BB, UNICODE_NORM_QC_NO},
+	{0xD0BC, UNICODE_NORM_QC_NO},
+	{0xD0BD, UNICODE_NORM_QC_NO},
+	{0xD0BE, UNICODE_NORM_QC_NO},
+	{0xD0BF, UNICODE_NORM_QC_NO},
+	{0xD0C0, UNICODE_NORM_QC_NO},
+	{0xD0C1, UNICODE_NORM_QC_NO},
+	{0xD0C2, UNICODE_NORM_QC_NO},
+	{0xD0C3, UNICODE_NORM_QC_NO},
+	{0xD0C4, UNICODE_NORM_QC_NO},
+	{0xD0C5, UNICODE_NORM_QC_NO},
+	{0xD0C6, UNICODE_NORM_QC_NO},
+	{0xD0C7, UNICODE_NORM_QC_NO},
+	{0xD0C8, UNICODE_NORM_QC_NO},
+	{0xD0C9, UNICODE_NORM_QC_NO},
+	{0xD0CA, UNICODE_NORM_QC_NO},
+	{0xD0CB, UNICODE_NORM_QC_NO},
+	{0xD0CC, UNICODE_NORM_QC_NO},
+	{0xD0CD, UNICODE_NORM_QC_NO},
+	{0xD0CE, UNICODE_NORM_QC_NO},
+	{0xD0CF, UNICODE_NORM_QC_NO},
+	{0xD0D0, UNICODE_NORM_QC_NO},
+	{0xD0D1, UNICODE_NORM_QC_NO},
+	{0xD0D2, UNICODE_NORM_QC_NO},
+	{0xD0D3, UNICODE_NORM_QC_NO},
+	{0xD0D4, UNICODE_NORM_QC_NO},
+	{0xD0D5, UNICODE_NORM_QC_NO},
+	{0xD0D6, UNICODE_NORM_QC_NO},
+	{0xD0D7, UNICODE_NORM_QC_NO},
+	{0xD0D8, UNICODE_NORM_QC_NO},
+	{0xD0D9, UNICODE_NORM_QC_NO},
+	{0xD0DA, UNICODE_NORM_QC_NO},
+	{0xD0DB, UNICODE_NORM_QC_NO},
+	{0xD0DC, UNICODE_NORM_QC_NO},
+	{0xD0DD, UNICODE_NORM_QC_NO},
+	{0xD0DE, UNICODE_NORM_QC_NO},
+	{0xD0DF, UNICODE_NORM_QC_NO},
+	{0xD0E0, UNICODE_NORM_QC_NO},
+	{0xD0E1, UNICODE_NORM_QC_NO},
+	{0xD0E2, UNICODE_NORM_QC_NO},
+	{0xD0E3, UNICODE_NORM_QC_NO},
+	{0xD0E4, UNICODE_NORM_QC_NO},
+	{0xD0E5, UNICODE_NORM_QC_NO},
+	{0xD0E6, UNICODE_NORM_QC_NO},
+	{0xD0E7, UNICODE_NORM_QC_NO},
+	{0xD0E8, UNICODE_NORM_QC_NO},
+	{0xD0E9, UNICODE_NORM_QC_NO},
+	{0xD0EA, UNICODE_NORM_QC_NO},
+	{0xD0EB, UNICODE_NORM_QC_NO},
+	{0xD0EC, UNICODE_NORM_QC_NO},
+	{0xD0ED, UNICODE_NORM_QC_NO},
+	{0xD0EE, UNICODE_NORM_QC_NO},
+	{0xD0EF, UNICODE_NORM_QC_NO},
+	{0xD0F0, UNICODE_NORM_QC_NO},
+	{0xD0F1, UNICODE_NORM_QC_NO},
+	{0xD0F2, UNICODE_NORM_QC_NO},
+	{0xD0F3, UNICODE_NORM_QC_NO},
+	{0xD0F4, UNICODE_NORM_QC_NO},
+	{0xD0F5, UNICODE_NORM_QC_NO},
+	{0xD0F6, UNICODE_NORM_QC_NO},
+	{0xD0F7, UNICODE_NORM_QC_NO},
+	{0xD0F8, UNICODE_NORM_QC_NO},
+	{0xD0F9, UNICODE_NORM_QC_NO},
+	{0xD0FA, UNICODE_NORM_QC_NO},
+	{0xD0FB, UNICODE_NORM_QC_NO},
+	{0xD0FC, UNICODE_NORM_QC_NO},
+	{0xD0FD, UNICODE_NORM_QC_NO},
+	{0xD0FE, UNICODE_NORM_QC_NO},
+	{0xD0FF, UNICODE_NORM_QC_NO},
+	{0xD100, UNICODE_NORM_QC_NO},
+	{0xD101, UNICODE_NORM_QC_NO},
+	{0xD102, UNICODE_NORM_QC_NO},
+	{0xD103, UNICODE_NORM_QC_NO},
+	{0xD104, UNICODE_NORM_QC_NO},
+	{0xD105, UNICODE_NORM_QC_NO},
+	{0xD106, UNICODE_NORM_QC_NO},
+	{0xD107, UNICODE_NORM_QC_NO},
+	{0xD108, UNICODE_NORM_QC_NO},
+	{0xD109, UNICODE_NORM_QC_NO},
+	{0xD10A, UNICODE_NORM_QC_NO},
+	{0xD10B, UNICODE_NORM_QC_NO},
+	{0xD10C, UNICODE_NORM_QC_NO},
+	{0xD10D, UNICODE_NORM_QC_NO},
+	{0xD10E, UNICODE_NORM_QC_NO},
+	{0xD10F, UNICODE_NORM_QC_NO},
+	{0xD110, UNICODE_NORM_QC_NO},
+	{0xD111, UNICODE_NORM_QC_NO},
+	{0xD112, UNICODE_NORM_QC_NO},
+	{0xD113, UNICODE_NORM_QC_NO},
+	{0xD114, UNICODE_NORM_QC_NO},
+	{0xD115, UNICODE_NORM_QC_NO},
+	{0xD116, UNICODE_NORM_QC_NO},
+	{0xD117, UNICODE_NORM_QC_NO},
+	{0xD118, UNICODE_NORM_QC_NO},
+	{0xD119, UNICODE_NORM_QC_NO},
+	{0xD11A, UNICODE_NORM_QC_NO},
+	{0xD11B, UNICODE_NORM_QC_NO},
+	{0xD11C, UNICODE_NORM_QC_NO},
+	{0xD11D, UNICODE_NORM_QC_NO},
+	{0xD11E, UNICODE_NORM_QC_NO},
+	{0xD11F, UNICODE_NORM_QC_NO},
+	{0xD120, UNICODE_NORM_QC_NO},
+	{0xD121, UNICODE_NORM_QC_NO},
+	{0xD122, UNICODE_NORM_QC_NO},
+	{0xD123, UNICODE_NORM_QC_NO},
+	{0xD124, UNICODE_NORM_QC_NO},
+	{0xD125, UNICODE_NORM_QC_NO},
+	{0xD126, UNICODE_NORM_QC_NO},
+	{0xD127, UNICODE_NORM_QC_NO},
+	{0xD128, UNICODE_NORM_QC_NO},
+	{0xD129, UNICODE_NORM_QC_NO},
+	{0xD12A, UNICODE_NORM_QC_NO},
+	{0xD12B, UNICODE_NORM_QC_NO},
+	{0xD12C, UNICODE_NORM_QC_NO},
+	{0xD12D, UNICODE_NORM_QC_NO},
+	{0xD12E, UNICODE_NORM_QC_NO},
+	{0xD12F, UNICODE_NORM_QC_NO},
+	{0xD130, UNICODE_NORM_QC_NO},
+	{0xD131, UNICODE_NORM_QC_NO},
+	{0xD132, UNICODE_NORM_QC_NO},
+	{0xD133, UNICODE_NORM_QC_NO},
+	{0xD134, UNICODE_NORM_QC_NO},
+	{0xD135, UNICODE_NORM_QC_NO},
+	{0xD136, UNICODE_NORM_QC_NO},
+	{0xD137, UNICODE_NORM_QC_NO},
+	{0xD138, UNICODE_NORM_QC_NO},
+	{0xD139, UNICODE_NORM_QC_NO},
+	{0xD13A, UNICODE_NORM_QC_NO},
+	{0xD13B, UNICODE_NORM_QC_NO},
+	{0xD13C, UNICODE_NORM_QC_NO},
+	{0xD13D, UNICODE_NORM_QC_NO},
+	{0xD13E, UNICODE_NORM_QC_NO},
+	{0xD13F, UNICODE_NORM_QC_NO},
+	{0xD140, UNICODE_NORM_QC_NO},
+	{0xD141, UNICODE_NORM_QC_NO},
+	{0xD142, UNICODE_NORM_QC_NO},
+	{0xD143, UNICODE_NORM_QC_NO},
+	{0xD144, UNICODE_NORM_QC_NO},
+	{0xD145, UNICODE_NORM_QC_NO},
+	{0xD146, UNICODE_NORM_QC_NO},
+	{0xD147, UNICODE_NORM_QC_NO},
+	{0xD148, UNICODE_NORM_QC_NO},
+	{0xD149, UNICODE_NORM_QC_NO},
+	{0xD14A, UNICODE_NORM_QC_NO},
+	{0xD14B, UNICODE_NORM_QC_NO},
+	{0xD14C, UNICODE_NORM_QC_NO},
+	{0xD14D, UNICODE_NORM_QC_NO},
+	{0xD14E, UNICODE_NORM_QC_NO},
+	{0xD14F, UNICODE_NORM_QC_NO},
+	{0xD150, UNICODE_NORM_QC_NO},
+	{0xD151, UNICODE_NORM_QC_NO},
+	{0xD152, UNICODE_NORM_QC_NO},
+	{0xD153, UNICODE_NORM_QC_NO},
+	{0xD154, UNICODE_NORM_QC_NO},
+	{0xD155, UNICODE_NORM_QC_NO},
+	{0xD156, UNICODE_NORM_QC_NO},
+	{0xD157, UNICODE_NORM_QC_NO},
+	{0xD158, UNICODE_NORM_QC_NO},
+	{0xD159, UNICODE_NORM_QC_NO},
+	{0xD15A, UNICODE_NORM_QC_NO},
+	{0xD15B, UNICODE_NORM_QC_NO},
+	{0xD15C, UNICODE_NORM_QC_NO},
+	{0xD15D, UNICODE_NORM_QC_NO},
+	{0xD15E, UNICODE_NORM_QC_NO},
+	{0xD15F, UNICODE_NORM_QC_NO},
+	{0xD160, UNICODE_NORM_QC_NO},
+	{0xD161, UNICODE_NORM_QC_NO},
+	{0xD162, UNICODE_NORM_QC_NO},
+	{0xD163, UNICODE_NORM_QC_NO},
+	{0xD164, UNICODE_NORM_QC_NO},
+	{0xD165, UNICODE_NORM_QC_NO},
+	{0xD166, UNICODE_NORM_QC_NO},
+	{0xD167, UNICODE_NORM_QC_NO},
+	{0xD168, UNICODE_NORM_QC_NO},
+	{0xD169, UNICODE_NORM_QC_NO},
+	{0xD16A, UNICODE_NORM_QC_NO},
+	{0xD16B, UNICODE_NORM_QC_NO},
+	{0xD16C, UNICODE_NORM_QC_NO},
+	{0xD16D, UNICODE_NORM_QC_NO},
+	{0xD16E, UNICODE_NORM_QC_NO},
+	{0xD16F, UNICODE_NORM_QC_NO},
+	{0xD170, UNICODE_NORM_QC_NO},
+	{0xD171, UNICODE_NORM_QC_NO},
+	{0xD172, UNICODE_NORM_QC_NO},
+	{0xD173, UNICODE_NORM_QC_NO},
+	{0xD174, UNICODE_NORM_QC_NO},
+	{0xD175, UNICODE_NORM_QC_NO},
+	{0xD176, UNICODE_NORM_QC_NO},
+	{0xD177, UNICODE_NORM_QC_NO},
+	{0xD178, UNICODE_NORM_QC_NO},
+	{0xD179, UNICODE_NORM_QC_NO},
+	{0xD17A, UNICODE_NORM_QC_NO},
+	{0xD17B, UNICODE_NORM_QC_NO},
+	{0xD17C, UNICODE_NORM_QC_NO},
+	{0xD17D, UNICODE_NORM_QC_NO},
+	{0xD17E, UNICODE_NORM_QC_NO},
+	{0xD17F, UNICODE_NORM_QC_NO},
+	{0xD180, UNICODE_NORM_QC_NO},
+	{0xD181, UNICODE_NORM_QC_NO},
+	{0xD182, UNICODE_NORM_QC_NO},
+	{0xD183, UNICODE_NORM_QC_NO},
+	{0xD184, UNICODE_NORM_QC_NO},
+	{0xD185, UNICODE_NORM_QC_NO},
+	{0xD186, UNICODE_NORM_QC_NO},
+	{0xD187, UNICODE_NORM_QC_NO},
+	{0xD188, UNICODE_NORM_QC_NO},
+	{0xD189, UNICODE_NORM_QC_NO},
+	{0xD18A, UNICODE_NORM_QC_NO},
+	{0xD18B, UNICODE_NORM_QC_NO},
+	{0xD18C, UNICODE_NORM_QC_NO},
+	{0xD18D, UNICODE_NORM_QC_NO},
+	{0xD18E, UNICODE_NORM_QC_NO},
+	{0xD18F, UNICODE_NORM_QC_NO},
+	{0xD190, UNICODE_NORM_QC_NO},
+	{0xD191, UNICODE_NORM_QC_NO},
+	{0xD192, UNICODE_NORM_QC_NO},
+	{0xD193, UNICODE_NORM_QC_NO},
+	{0xD194, UNICODE_NORM_QC_NO},
+	{0xD195, UNICODE_NORM_QC_NO},
+	{0xD196, UNICODE_NORM_QC_NO},
+	{0xD197, UNICODE_NORM_QC_NO},
+	{0xD198, UNICODE_NORM_QC_NO},
+	{0xD199, UNICODE_NORM_QC_NO},
+	{0xD19A, UNICODE_NORM_QC_NO},
+	{0xD19B, UNICODE_NORM_QC_NO},
+	{0xD19C, UNICODE_NORM_QC_NO},
+	{0xD19D, UNICODE_NORM_QC_NO},
+	{0xD19E, UNICODE_NORM_QC_NO},
+	{0xD19F, UNICODE_NORM_QC_NO},
+	{0xD1A0, UNICODE_NORM_QC_NO},
+	{0xD1A1, UNICODE_NORM_QC_NO},
+	{0xD1A2, UNICODE_NORM_QC_NO},
+	{0xD1A3, UNICODE_NORM_QC_NO},
+	{0xD1A4, UNICODE_NORM_QC_NO},
+	{0xD1A5, UNICODE_NORM_QC_NO},
+	{0xD1A6, UNICODE_NORM_QC_NO},
+	{0xD1A7, UNICODE_NORM_QC_NO},
+	{0xD1A8, UNICODE_NORM_QC_NO},
+	{0xD1A9, UNICODE_NORM_QC_NO},
+	{0xD1AA, UNICODE_NORM_QC_NO},
+	{0xD1AB, UNICODE_NORM_QC_NO},
+	{0xD1AC, UNICODE_NORM_QC_NO},
+	{0xD1AD, UNICODE_NORM_QC_NO},
+	{0xD1AE, UNICODE_NORM_QC_NO},
+	{0xD1AF, UNICODE_NORM_QC_NO},
+	{0xD1B0, UNICODE_NORM_QC_NO},
+	{0xD1B1, UNICODE_NORM_QC_NO},
+	{0xD1B2, UNICODE_NORM_QC_NO},
+	{0xD1B3, UNICODE_NORM_QC_NO},
+	{0xD1B4, UNICODE_NORM_QC_NO},
+	{0xD1B5, UNICODE_NORM_QC_NO},
+	{0xD1B6, UNICODE_NORM_QC_NO},
+	{0xD1B7, UNICODE_NORM_QC_NO},
+	{0xD1B8, UNICODE_NORM_QC_NO},
+	{0xD1B9, UNICODE_NORM_QC_NO},
+	{0xD1BA, UNICODE_NORM_QC_NO},
+	{0xD1BB, UNICODE_NORM_QC_NO},
+	{0xD1BC, UNICODE_NORM_QC_NO},
+	{0xD1BD, UNICODE_NORM_QC_NO},
+	{0xD1BE, UNICODE_NORM_QC_NO},
+	{0xD1BF, UNICODE_NORM_QC_NO},
+	{0xD1C0, UNICODE_NORM_QC_NO},
+	{0xD1C1, UNICODE_NORM_QC_NO},
+	{0xD1C2, UNICODE_NORM_QC_NO},
+	{0xD1C3, UNICODE_NORM_QC_NO},
+	{0xD1C4, UNICODE_NORM_QC_NO},
+	{0xD1C5, UNICODE_NORM_QC_NO},
+	{0xD1C6, UNICODE_NORM_QC_NO},
+	{0xD1C7, UNICODE_NORM_QC_NO},
+	{0xD1C8, UNICODE_NORM_QC_NO},
+	{0xD1C9, UNICODE_NORM_QC_NO},
+	{0xD1CA, UNICODE_NORM_QC_NO},
+	{0xD1CB, UNICODE_NORM_QC_NO},
+	{0xD1CC, UNICODE_NORM_QC_NO},
+	{0xD1CD, UNICODE_NORM_QC_NO},
+	{0xD1CE, UNICODE_NORM_QC_NO},
+	{0xD1CF, UNICODE_NORM_QC_NO},
+	{0xD1D0, UNICODE_NORM_QC_NO},
+	{0xD1D1, UNICODE_NORM_QC_NO},
+	{0xD1D2, UNICODE_NORM_QC_NO},
+	{0xD1D3, UNICODE_NORM_QC_NO},
+	{0xD1D4, UNICODE_NORM_QC_NO},
+	{0xD1D5, UNICODE_NORM_QC_NO},
+	{0xD1D6, UNICODE_NORM_QC_NO},
+	{0xD1D7, UNICODE_NORM_QC_NO},
+	{0xD1D8, UNICODE_NORM_QC_NO},
+	{0xD1D9, UNICODE_NORM_QC_NO},
+	{0xD1DA, UNICODE_NORM_QC_NO},
+	{0xD1DB, UNICODE_NORM_QC_NO},
+	{0xD1DC, UNICODE_NORM_QC_NO},
+	{0xD1DD, UNICODE_NORM_QC_NO},
+	{0xD1DE, UNICODE_NORM_QC_NO},
+	{0xD1DF, UNICODE_NORM_QC_NO},
+	{0xD1E0, UNICODE_NORM_QC_NO},
+	{0xD1E1, UNICODE_NORM_QC_NO},
+	{0xD1E2, UNICODE_NORM_QC_NO},
+	{0xD1E3, UNICODE_NORM_QC_NO},
+	{0xD1E4, UNICODE_NORM_QC_NO},
+	{0xD1E5, UNICODE_NORM_QC_NO},
+	{0xD1E6, UNICODE_NORM_QC_NO},
+	{0xD1E7, UNICODE_NORM_QC_NO},
+	{0xD1E8, UNICODE_NORM_QC_NO},
+	{0xD1E9, UNICODE_NORM_QC_NO},
+	{0xD1EA, UNICODE_NORM_QC_NO},
+	{0xD1EB, UNICODE_NORM_QC_NO},
+	{0xD1EC, UNICODE_NORM_QC_NO},
+	{0xD1ED, UNICODE_NORM_QC_NO},
+	{0xD1EE, UNICODE_NORM_QC_NO},
+	{0xD1EF, UNICODE_NORM_QC_NO},
+	{0xD1F0, UNICODE_NORM_QC_NO},
+	{0xD1F1, UNICODE_NORM_QC_NO},
+	{0xD1F2, UNICODE_NORM_QC_NO},
+	{0xD1F3, UNICODE_NORM_QC_NO},
+	{0xD1F4, UNICODE_NORM_QC_NO},
+	{0xD1F5, UNICODE_NORM_QC_NO},
+	{0xD1F6, UNICODE_NORM_QC_NO},
+	{0xD1F7, UNICODE_NORM_QC_NO},
+	{0xD1F8, UNICODE_NORM_QC_NO},
+	{0xD1F9, UNICODE_NORM_QC_NO},
+	{0xD1FA, UNICODE_NORM_QC_NO},
+	{0xD1FB, UNICODE_NORM_QC_NO},
+	{0xD1FC, UNICODE_NORM_QC_NO},
+	{0xD1FD, UNICODE_NORM_QC_NO},
+	{0xD1FE, UNICODE_NORM_QC_NO},
+	{0xD1FF, UNICODE_NORM_QC_NO},
+	{0xD200, UNICODE_NORM_QC_NO},
+	{0xD201, UNICODE_NORM_QC_NO},
+	{0xD202, UNICODE_NORM_QC_NO},
+	{0xD203, UNICODE_NORM_QC_NO},
+	{0xD204, UNICODE_NORM_QC_NO},
+	{0xD205, UNICODE_NORM_QC_NO},
+	{0xD206, UNICODE_NORM_QC_NO},
+	{0xD207, UNICODE_NORM_QC_NO},
+	{0xD208, UNICODE_NORM_QC_NO},
+	{0xD209, UNICODE_NORM_QC_NO},
+	{0xD20A, UNICODE_NORM_QC_NO},
+	{0xD20B, UNICODE_NORM_QC_NO},
+	{0xD20C, UNICODE_NORM_QC_NO},
+	{0xD20D, UNICODE_NORM_QC_NO},
+	{0xD20E, UNICODE_NORM_QC_NO},
+	{0xD20F, UNICODE_NORM_QC_NO},
+	{0xD210, UNICODE_NORM_QC_NO},
+	{0xD211, UNICODE_NORM_QC_NO},
+	{0xD212, UNICODE_NORM_QC_NO},
+	{0xD213, UNICODE_NORM_QC_NO},
+	{0xD214, UNICODE_NORM_QC_NO},
+	{0xD215, UNICODE_NORM_QC_NO},
+	{0xD216, UNICODE_NORM_QC_NO},
+	{0xD217, UNICODE_NORM_QC_NO},
+	{0xD218, UNICODE_NORM_QC_NO},
+	{0xD219, UNICODE_NORM_QC_NO},
+	{0xD21A, UNICODE_NORM_QC_NO},
+	{0xD21B, UNICODE_NORM_QC_NO},
+	{0xD21C, UNICODE_NORM_QC_NO},
+	{0xD21D, UNICODE_NORM_QC_NO},
+	{0xD21E, UNICODE_NORM_QC_NO},
+	{0xD21F, UNICODE_NORM_QC_NO},
+	{0xD220, UNICODE_NORM_QC_NO},
+	{0xD221, UNICODE_NORM_QC_NO},
+	{0xD222, UNICODE_NORM_QC_NO},
+	{0xD223, UNICODE_NORM_QC_NO},
+	{0xD224, UNICODE_NORM_QC_NO},
+	{0xD225, UNICODE_NORM_QC_NO},
+	{0xD226, UNICODE_NORM_QC_NO},
+	{0xD227, UNICODE_NORM_QC_NO},
+	{0xD228, UNICODE_NORM_QC_NO},
+	{0xD229, UNICODE_NORM_QC_NO},
+	{0xD22A, UNICODE_NORM_QC_NO},
+	{0xD22B, UNICODE_NORM_QC_NO},
+	{0xD22C, UNICODE_NORM_QC_NO},
+	{0xD22D, UNICODE_NORM_QC_NO},
+	{0xD22E, UNICODE_NORM_QC_NO},
+	{0xD22F, UNICODE_NORM_QC_NO},
+	{0xD230, UNICODE_NORM_QC_NO},
+	{0xD231, UNICODE_NORM_QC_NO},
+	{0xD232, UNICODE_NORM_QC_NO},
+	{0xD233, UNICODE_NORM_QC_NO},
+	{0xD234, UNICODE_NORM_QC_NO},
+	{0xD235, UNICODE_NORM_QC_NO},
+	{0xD236, UNICODE_NORM_QC_NO},
+	{0xD237, UNICODE_NORM_QC_NO},
+	{0xD238, UNICODE_NORM_QC_NO},
+	{0xD239, UNICODE_NORM_QC_NO},
+	{0xD23A, UNICODE_NORM_QC_NO},
+	{0xD23B, UNICODE_NORM_QC_NO},
+	{0xD23C, UNICODE_NORM_QC_NO},
+	{0xD23D, UNICODE_NORM_QC_NO},
+	{0xD23E, UNICODE_NORM_QC_NO},
+	{0xD23F, UNICODE_NORM_QC_NO},
+	{0xD240, UNICODE_NORM_QC_NO},
+	{0xD241, UNICODE_NORM_QC_NO},
+	{0xD242, UNICODE_NORM_QC_NO},
+	{0xD243, UNICODE_NORM_QC_NO},
+	{0xD244, UNICODE_NORM_QC_NO},
+	{0xD245, UNICODE_NORM_QC_NO},
+	{0xD246, UNICODE_NORM_QC_NO},
+	{0xD247, UNICODE_NORM_QC_NO},
+	{0xD248, UNICODE_NORM_QC_NO},
+	{0xD249, UNICODE_NORM_QC_NO},
+	{0xD24A, UNICODE_NORM_QC_NO},
+	{0xD24B, UNICODE_NORM_QC_NO},
+	{0xD24C, UNICODE_NORM_QC_NO},
+	{0xD24D, UNICODE_NORM_QC_NO},
+	{0xD24E, UNICODE_NORM_QC_NO},
+	{0xD24F, UNICODE_NORM_QC_NO},
+	{0xD250, UNICODE_NORM_QC_NO},
+	{0xD251, UNICODE_NORM_QC_NO},
+	{0xD252, UNICODE_NORM_QC_NO},
+	{0xD253, UNICODE_NORM_QC_NO},
+	{0xD254, UNICODE_NORM_QC_NO},
+	{0xD255, UNICODE_NORM_QC_NO},
+	{0xD256, UNICODE_NORM_QC_NO},
+	{0xD257, UNICODE_NORM_QC_NO},
+	{0xD258, UNICODE_NORM_QC_NO},
+	{0xD259, UNICODE_NORM_QC_NO},
+	{0xD25A, UNICODE_NORM_QC_NO},
+	{0xD25B, UNICODE_NORM_QC_NO},
+	{0xD25C, UNICODE_NORM_QC_NO},
+	{0xD25D, UNICODE_NORM_QC_NO},
+	{0xD25E, UNICODE_NORM_QC_NO},
+	{0xD25F, UNICODE_NORM_QC_NO},
+	{0xD260, UNICODE_NORM_QC_NO},
+	{0xD261, UNICODE_NORM_QC_NO},
+	{0xD262, UNICODE_NORM_QC_NO},
+	{0xD263, UNICODE_NORM_QC_NO},
+	{0xD264, UNICODE_NORM_QC_NO},
+	{0xD265, UNICODE_NORM_QC_NO},
+	{0xD266, UNICODE_NORM_QC_NO},
+	{0xD267, UNICODE_NORM_QC_NO},
+	{0xD268, UNICODE_NORM_QC_NO},
+	{0xD269, UNICODE_NORM_QC_NO},
+	{0xD26A, UNICODE_NORM_QC_NO},
+	{0xD26B, UNICODE_NORM_QC_NO},
+	{0xD26C, UNICODE_NORM_QC_NO},
+	{0xD26D, UNICODE_NORM_QC_NO},
+	{0xD26E, UNICODE_NORM_QC_NO},
+	{0xD26F, UNICODE_NORM_QC_NO},
+	{0xD270, UNICODE_NORM_QC_NO},
+	{0xD271, UNICODE_NORM_QC_NO},
+	{0xD272, UNICODE_NORM_QC_NO},
+	{0xD273, UNICODE_NORM_QC_NO},
+	{0xD274, UNICODE_NORM_QC_NO},
+	{0xD275, UNICODE_NORM_QC_NO},
+	{0xD276, UNICODE_NORM_QC_NO},
+	{0xD277, UNICODE_NORM_QC_NO},
+	{0xD278, UNICODE_NORM_QC_NO},
+	{0xD279, UNICODE_NORM_QC_NO},
+	{0xD27A, UNICODE_NORM_QC_NO},
+	{0xD27B, UNICODE_NORM_QC_NO},
+	{0xD27C, UNICODE_NORM_QC_NO},
+	{0xD27D, UNICODE_NORM_QC_NO},
+	{0xD27E, UNICODE_NORM_QC_NO},
+	{0xD27F, UNICODE_NORM_QC_NO},
+	{0xD280, UNICODE_NORM_QC_NO},
+	{0xD281, UNICODE_NORM_QC_NO},
+	{0xD282, UNICODE_NORM_QC_NO},
+	{0xD283, UNICODE_NORM_QC_NO},
+	{0xD284, UNICODE_NORM_QC_NO},
+	{0xD285, UNICODE_NORM_QC_NO},
+	{0xD286, UNICODE_NORM_QC_NO},
+	{0xD287, UNICODE_NORM_QC_NO},
+	{0xD288, UNICODE_NORM_QC_NO},
+	{0xD289, UNICODE_NORM_QC_NO},
+	{0xD28A, UNICODE_NORM_QC_NO},
+	{0xD28B, UNICODE_NORM_QC_NO},
+	{0xD28C, UNICODE_NORM_QC_NO},
+	{0xD28D, UNICODE_NORM_QC_NO},
+	{0xD28E, UNICODE_NORM_QC_NO},
+	{0xD28F, UNICODE_NORM_QC_NO},
+	{0xD290, UNICODE_NORM_QC_NO},
+	{0xD291, UNICODE_NORM_QC_NO},
+	{0xD292, UNICODE_NORM_QC_NO},
+	{0xD293, UNICODE_NORM_QC_NO},
+	{0xD294, UNICODE_NORM_QC_NO},
+	{0xD295, UNICODE_NORM_QC_NO},
+	{0xD296, UNICODE_NORM_QC_NO},
+	{0xD297, UNICODE_NORM_QC_NO},
+	{0xD298, UNICODE_NORM_QC_NO},
+	{0xD299, UNICODE_NORM_QC_NO},
+	{0xD29A, UNICODE_NORM_QC_NO},
+	{0xD29B, UNICODE_NORM_QC_NO},
+	{0xD29C, UNICODE_NORM_QC_NO},
+	{0xD29D, UNICODE_NORM_QC_NO},
+	{0xD29E, UNICODE_NORM_QC_NO},
+	{0xD29F, UNICODE_NORM_QC_NO},
+	{0xD2A0, UNICODE_NORM_QC_NO},
+	{0xD2A1, UNICODE_NORM_QC_NO},
+	{0xD2A2, UNICODE_NORM_QC_NO},
+	{0xD2A3, UNICODE_NORM_QC_NO},
+	{0xD2A4, UNICODE_NORM_QC_NO},
+	{0xD2A5, UNICODE_NORM_QC_NO},
+	{0xD2A6, UNICODE_NORM_QC_NO},
+	{0xD2A7, UNICODE_NORM_QC_NO},
+	{0xD2A8, UNICODE_NORM_QC_NO},
+	{0xD2A9, UNICODE_NORM_QC_NO},
+	{0xD2AA, UNICODE_NORM_QC_NO},
+	{0xD2AB, UNICODE_NORM_QC_NO},
+	{0xD2AC, UNICODE_NORM_QC_NO},
+	{0xD2AD, UNICODE_NORM_QC_NO},
+	{0xD2AE, UNICODE_NORM_QC_NO},
+	{0xD2AF, UNICODE_NORM_QC_NO},
+	{0xD2B0, UNICODE_NORM_QC_NO},
+	{0xD2B1, UNICODE_NORM_QC_NO},
+	{0xD2B2, UNICODE_NORM_QC_NO},
+	{0xD2B3, UNICODE_NORM_QC_NO},
+	{0xD2B4, UNICODE_NORM_QC_NO},
+	{0xD2B5, UNICODE_NORM_QC_NO},
+	{0xD2B6, UNICODE_NORM_QC_NO},
+	{0xD2B7, UNICODE_NORM_QC_NO},
+	{0xD2B8, UNICODE_NORM_QC_NO},
+	{0xD2B9, UNICODE_NORM_QC_NO},
+	{0xD2BA, UNICODE_NORM_QC_NO},
+	{0xD2BB, UNICODE_NORM_QC_NO},
+	{0xD2BC, UNICODE_NORM_QC_NO},
+	{0xD2BD, UNICODE_NORM_QC_NO},
+	{0xD2BE, UNICODE_NORM_QC_NO},
+	{0xD2BF, UNICODE_NORM_QC_NO},
+	{0xD2C0, UNICODE_NORM_QC_NO},
+	{0xD2C1, UNICODE_NORM_QC_NO},
+	{0xD2C2, UNICODE_NORM_QC_NO},
+	{0xD2C3, UNICODE_NORM_QC_NO},
+	{0xD2C4, UNICODE_NORM_QC_NO},
+	{0xD2C5, UNICODE_NORM_QC_NO},
+	{0xD2C6, UNICODE_NORM_QC_NO},
+	{0xD2C7, UNICODE_NORM_QC_NO},
+	{0xD2C8, UNICODE_NORM_QC_NO},
+	{0xD2C9, UNICODE_NORM_QC_NO},
+	{0xD2CA, UNICODE_NORM_QC_NO},
+	{0xD2CB, UNICODE_NORM_QC_NO},
+	{0xD2CC, UNICODE_NORM_QC_NO},
+	{0xD2CD, UNICODE_NORM_QC_NO},
+	{0xD2CE, UNICODE_NORM_QC_NO},
+	{0xD2CF, UNICODE_NORM_QC_NO},
+	{0xD2D0, UNICODE_NORM_QC_NO},
+	{0xD2D1, UNICODE_NORM_QC_NO},
+	{0xD2D2, UNICODE_NORM_QC_NO},
+	{0xD2D3, UNICODE_NORM_QC_NO},
+	{0xD2D4, UNICODE_NORM_QC_NO},
+	{0xD2D5, UNICODE_NORM_QC_NO},
+	{0xD2D6, UNICODE_NORM_QC_NO},
+	{0xD2D7, UNICODE_NORM_QC_NO},
+	{0xD2D8, UNICODE_NORM_QC_NO},
+	{0xD2D9, UNICODE_NORM_QC_NO},
+	{0xD2DA, UNICODE_NORM_QC_NO},
+	{0xD2DB, UNICODE_NORM_QC_NO},
+	{0xD2DC, UNICODE_NORM_QC_NO},
+	{0xD2DD, UNICODE_NORM_QC_NO},
+	{0xD2DE, UNICODE_NORM_QC_NO},
+	{0xD2DF, UNICODE_NORM_QC_NO},
+	{0xD2E0, UNICODE_NORM_QC_NO},
+	{0xD2E1, UNICODE_NORM_QC_NO},
+	{0xD2E2, UNICODE_NORM_QC_NO},
+	{0xD2E3, UNICODE_NORM_QC_NO},
+	{0xD2E4, UNICODE_NORM_QC_NO},
+	{0xD2E5, UNICODE_NORM_QC_NO},
+	{0xD2E6, UNICODE_NORM_QC_NO},
+	{0xD2E7, UNICODE_NORM_QC_NO},
+	{0xD2E8, UNICODE_NORM_QC_NO},
+	{0xD2E9, UNICODE_NORM_QC_NO},
+	{0xD2EA, UNICODE_NORM_QC_NO},
+	{0xD2EB, UNICODE_NORM_QC_NO},
+	{0xD2EC, UNICODE_NORM_QC_NO},
+	{0xD2ED, UNICODE_NORM_QC_NO},
+	{0xD2EE, UNICODE_NORM_QC_NO},
+	{0xD2EF, UNICODE_NORM_QC_NO},
+	{0xD2F0, UNICODE_NORM_QC_NO},
+	{0xD2F1, UNICODE_NORM_QC_NO},
+	{0xD2F2, UNICODE_NORM_QC_NO},
+	{0xD2F3, UNICODE_NORM_QC_NO},
+	{0xD2F4, UNICODE_NORM_QC_NO},
+	{0xD2F5, UNICODE_NORM_QC_NO},
+	{0xD2F6, UNICODE_NORM_QC_NO},
+	{0xD2F7, UNICODE_NORM_QC_NO},
+	{0xD2F8, UNICODE_NORM_QC_NO},
+	{0xD2F9, UNICODE_NORM_QC_NO},
+	{0xD2FA, UNICODE_NORM_QC_NO},
+	{0xD2FB, UNICODE_NORM_QC_NO},
+	{0xD2FC, UNICODE_NORM_QC_NO},
+	{0xD2FD, UNICODE_NORM_QC_NO},
+	{0xD2FE, UNICODE_NORM_QC_NO},
+	{0xD2FF, UNICODE_NORM_QC_NO},
+	{0xD300, UNICODE_NORM_QC_NO},
+	{0xD301, UNICODE_NORM_QC_NO},
+	{0xD302, UNICODE_NORM_QC_NO},
+	{0xD303, UNICODE_NORM_QC_NO},
+	{0xD304, UNICODE_NORM_QC_NO},
+	{0xD305, UNICODE_NORM_QC_NO},
+	{0xD306, UNICODE_NORM_QC_NO},
+	{0xD307, UNICODE_NORM_QC_NO},
+	{0xD308, UNICODE_NORM_QC_NO},
+	{0xD309, UNICODE_NORM_QC_NO},
+	{0xD30A, UNICODE_NORM_QC_NO},
+	{0xD30B, UNICODE_NORM_QC_NO},
+	{0xD30C, UNICODE_NORM_QC_NO},
+	{0xD30D, UNICODE_NORM_QC_NO},
+	{0xD30E, UNICODE_NORM_QC_NO},
+	{0xD30F, UNICODE_NORM_QC_NO},
+	{0xD310, UNICODE_NORM_QC_NO},
+	{0xD311, UNICODE_NORM_QC_NO},
+	{0xD312, UNICODE_NORM_QC_NO},
+	{0xD313, UNICODE_NORM_QC_NO},
+	{0xD314, UNICODE_NORM_QC_NO},
+	{0xD315, UNICODE_NORM_QC_NO},
+	{0xD316, UNICODE_NORM_QC_NO},
+	{0xD317, UNICODE_NORM_QC_NO},
+	{0xD318, UNICODE_NORM_QC_NO},
+	{0xD319, UNICODE_NORM_QC_NO},
+	{0xD31A, UNICODE_NORM_QC_NO},
+	{0xD31B, UNICODE_NORM_QC_NO},
+	{0xD31C, UNICODE_NORM_QC_NO},
+	{0xD31D, UNICODE_NORM_QC_NO},
+	{0xD31E, UNICODE_NORM_QC_NO},
+	{0xD31F, UNICODE_NORM_QC_NO},
+	{0xD320, UNICODE_NORM_QC_NO},
+	{0xD321, UNICODE_NORM_QC_NO},
+	{0xD322, UNICODE_NORM_QC_NO},
+	{0xD323, UNICODE_NORM_QC_NO},
+	{0xD324, UNICODE_NORM_QC_NO},
+	{0xD325, UNICODE_NORM_QC_NO},
+	{0xD326, UNICODE_NORM_QC_NO},
+	{0xD327, UNICODE_NORM_QC_NO},
+	{0xD328, UNICODE_NORM_QC_NO},
+	{0xD329, UNICODE_NORM_QC_NO},
+	{0xD32A, UNICODE_NORM_QC_NO},
+	{0xD32B, UNICODE_NORM_QC_NO},
+	{0xD32C, UNICODE_NORM_QC_NO},
+	{0xD32D, UNICODE_NORM_QC_NO},
+	{0xD32E, UNICODE_NORM_QC_NO},
+	{0xD32F, UNICODE_NORM_QC_NO},
+	{0xD330, UNICODE_NORM_QC_NO},
+	{0xD331, UNICODE_NORM_QC_NO},
+	{0xD332, UNICODE_NORM_QC_NO},
+	{0xD333, UNICODE_NORM_QC_NO},
+	{0xD334, UNICODE_NORM_QC_NO},
+	{0xD335, UNICODE_NORM_QC_NO},
+	{0xD336, UNICODE_NORM_QC_NO},
+	{0xD337, UNICODE_NORM_QC_NO},
+	{0xD338, UNICODE_NORM_QC_NO},
+	{0xD339, UNICODE_NORM_QC_NO},
+	{0xD33A, UNICODE_NORM_QC_NO},
+	{0xD33B, UNICODE_NORM_QC_NO},
+	{0xD33C, UNICODE_NORM_QC_NO},
+	{0xD33D, UNICODE_NORM_QC_NO},
+	{0xD33E, UNICODE_NORM_QC_NO},
+	{0xD33F, UNICODE_NORM_QC_NO},
+	{0xD340, UNICODE_NORM_QC_NO},
+	{0xD341, UNICODE_NORM_QC_NO},
+	{0xD342, UNICODE_NORM_QC_NO},
+	{0xD343, UNICODE_NORM_QC_NO},
+	{0xD344, UNICODE_NORM_QC_NO},
+	{0xD345, UNICODE_NORM_QC_NO},
+	{0xD346, UNICODE_NORM_QC_NO},
+	{0xD347, UNICODE_NORM_QC_NO},
+	{0xD348, UNICODE_NORM_QC_NO},
+	{0xD349, UNICODE_NORM_QC_NO},
+	{0xD34A, UNICODE_NORM_QC_NO},
+	{0xD34B, UNICODE_NORM_QC_NO},
+	{0xD34C, UNICODE_NORM_QC_NO},
+	{0xD34D, UNICODE_NORM_QC_NO},
+	{0xD34E, UNICODE_NORM_QC_NO},
+	{0xD34F, UNICODE_NORM_QC_NO},
+	{0xD350, UNICODE_NORM_QC_NO},
+	{0xD351, UNICODE_NORM_QC_NO},
+	{0xD352, UNICODE_NORM_QC_NO},
+	{0xD353, UNICODE_NORM_QC_NO},
+	{0xD354, UNICODE_NORM_QC_NO},
+	{0xD355, UNICODE_NORM_QC_NO},
+	{0xD356, UNICODE_NORM_QC_NO},
+	{0xD357, UNICODE_NORM_QC_NO},
+	{0xD358, UNICODE_NORM_QC_NO},
+	{0xD359, UNICODE_NORM_QC_NO},
+	{0xD35A, UNICODE_NORM_QC_NO},
+	{0xD35B, UNICODE_NORM_QC_NO},
+	{0xD35C, UNICODE_NORM_QC_NO},
+	{0xD35D, UNICODE_NORM_QC_NO},
+	{0xD35E, UNICODE_NORM_QC_NO},
+	{0xD35F, UNICODE_NORM_QC_NO},
+	{0xD360, UNICODE_NORM_QC_NO},
+	{0xD361, UNICODE_NORM_QC_NO},
+	{0xD362, UNICODE_NORM_QC_NO},
+	{0xD363, UNICODE_NORM_QC_NO},
+	{0xD364, UNICODE_NORM_QC_NO},
+	{0xD365, UNICODE_NORM_QC_NO},
+	{0xD366, UNICODE_NORM_QC_NO},
+	{0xD367, UNICODE_NORM_QC_NO},
+	{0xD368, UNICODE_NORM_QC_NO},
+	{0xD369, UNICODE_NORM_QC_NO},
+	{0xD36A, UNICODE_NORM_QC_NO},
+	{0xD36B, UNICODE_NORM_QC_NO},
+	{0xD36C, UNICODE_NORM_QC_NO},
+	{0xD36D, UNICODE_NORM_QC_NO},
+	{0xD36E, UNICODE_NORM_QC_NO},
+	{0xD36F, UNICODE_NORM_QC_NO},
+	{0xD370, UNICODE_NORM_QC_NO},
+	{0xD371, UNICODE_NORM_QC_NO},
+	{0xD372, UNICODE_NORM_QC_NO},
+	{0xD373, UNICODE_NORM_QC_NO},
+	{0xD374, UNICODE_NORM_QC_NO},
+	{0xD375, UNICODE_NORM_QC_NO},
+	{0xD376, UNICODE_NORM_QC_NO},
+	{0xD377, UNICODE_NORM_QC_NO},
+	{0xD378, UNICODE_NORM_QC_NO},
+	{0xD379, UNICODE_NORM_QC_NO},
+	{0xD37A, UNICODE_NORM_QC_NO},
+	{0xD37B, UNICODE_NORM_QC_NO},
+	{0xD37C, UNICODE_NORM_QC_NO},
+	{0xD37D, UNICODE_NORM_QC_NO},
+	{0xD37E, UNICODE_NORM_QC_NO},
+	{0xD37F, UNICODE_NORM_QC_NO},
+	{0xD380, UNICODE_NORM_QC_NO},
+	{0xD381, UNICODE_NORM_QC_NO},
+	{0xD382, UNICODE_NORM_QC_NO},
+	{0xD383, UNICODE_NORM_QC_NO},
+	{0xD384, UNICODE_NORM_QC_NO},
+	{0xD385, UNICODE_NORM_QC_NO},
+	{0xD386, UNICODE_NORM_QC_NO},
+	{0xD387, UNICODE_NORM_QC_NO},
+	{0xD388, UNICODE_NORM_QC_NO},
+	{0xD389, UNICODE_NORM_QC_NO},
+	{0xD38A, UNICODE_NORM_QC_NO},
+	{0xD38B, UNICODE_NORM_QC_NO},
+	{0xD38C, UNICODE_NORM_QC_NO},
+	{0xD38D, UNICODE_NORM_QC_NO},
+	{0xD38E, UNICODE_NORM_QC_NO},
+	{0xD38F, UNICODE_NORM_QC_NO},
+	{0xD390, UNICODE_NORM_QC_NO},
+	{0xD391, UNICODE_NORM_QC_NO},
+	{0xD392, UNICODE_NORM_QC_NO},
+	{0xD393, UNICODE_NORM_QC_NO},
+	{0xD394, UNICODE_NORM_QC_NO},
+	{0xD395, UNICODE_NORM_QC_NO},
+	{0xD396, UNICODE_NORM_QC_NO},
+	{0xD397, UNICODE_NORM_QC_NO},
+	{0xD398, UNICODE_NORM_QC_NO},
+	{0xD399, UNICODE_NORM_QC_NO},
+	{0xD39A, UNICODE_NORM_QC_NO},
+	{0xD39B, UNICODE_NORM_QC_NO},
+	{0xD39C, UNICODE_NORM_QC_NO},
+	{0xD39D, UNICODE_NORM_QC_NO},
+	{0xD39E, UNICODE_NORM_QC_NO},
+	{0xD39F, UNICODE_NORM_QC_NO},
+	{0xD3A0, UNICODE_NORM_QC_NO},
+	{0xD3A1, UNICODE_NORM_QC_NO},
+	{0xD3A2, UNICODE_NORM_QC_NO},
+	{0xD3A3, UNICODE_NORM_QC_NO},
+	{0xD3A4, UNICODE_NORM_QC_NO},
+	{0xD3A5, UNICODE_NORM_QC_NO},
+	{0xD3A6, UNICODE_NORM_QC_NO},
+	{0xD3A7, UNICODE_NORM_QC_NO},
+	{0xD3A8, UNICODE_NORM_QC_NO},
+	{0xD3A9, UNICODE_NORM_QC_NO},
+	{0xD3AA, UNICODE_NORM_QC_NO},
+	{0xD3AB, UNICODE_NORM_QC_NO},
+	{0xD3AC, UNICODE_NORM_QC_NO},
+	{0xD3AD, UNICODE_NORM_QC_NO},
+	{0xD3AE, UNICODE_NORM_QC_NO},
+	{0xD3AF, UNICODE_NORM_QC_NO},
+	{0xD3B0, UNICODE_NORM_QC_NO},
+	{0xD3B1, UNICODE_NORM_QC_NO},
+	{0xD3B2, UNICODE_NORM_QC_NO},
+	{0xD3B3, UNICODE_NORM_QC_NO},
+	{0xD3B4, UNICODE_NORM_QC_NO},
+	{0xD3B5, UNICODE_NORM_QC_NO},
+	{0xD3B6, UNICODE_NORM_QC_NO},
+	{0xD3B7, UNICODE_NORM_QC_NO},
+	{0xD3B8, UNICODE_NORM_QC_NO},
+	{0xD3B9, UNICODE_NORM_QC_NO},
+	{0xD3BA, UNICODE_NORM_QC_NO},
+	{0xD3BB, UNICODE_NORM_QC_NO},
+	{0xD3BC, UNICODE_NORM_QC_NO},
+	{0xD3BD, UNICODE_NORM_QC_NO},
+	{0xD3BE, UNICODE_NORM_QC_NO},
+	{0xD3BF, UNICODE_NORM_QC_NO},
+	{0xD3C0, UNICODE_NORM_QC_NO},
+	{0xD3C1, UNICODE_NORM_QC_NO},
+	{0xD3C2, UNICODE_NORM_QC_NO},
+	{0xD3C3, UNICODE_NORM_QC_NO},
+	{0xD3C4, UNICODE_NORM_QC_NO},
+	{0xD3C5, UNICODE_NORM_QC_NO},
+	{0xD3C6, UNICODE_NORM_QC_NO},
+	{0xD3C7, UNICODE_NORM_QC_NO},
+	{0xD3C8, UNICODE_NORM_QC_NO},
+	{0xD3C9, UNICODE_NORM_QC_NO},
+	{0xD3CA, UNICODE_NORM_QC_NO},
+	{0xD3CB, UNICODE_NORM_QC_NO},
+	{0xD3CC, UNICODE_NORM_QC_NO},
+	{0xD3CD, UNICODE_NORM_QC_NO},
+	{0xD3CE, UNICODE_NORM_QC_NO},
+	{0xD3CF, UNICODE_NORM_QC_NO},
+	{0xD3D0, UNICODE_NORM_QC_NO},
+	{0xD3D1, UNICODE_NORM_QC_NO},
+	{0xD3D2, UNICODE_NORM_QC_NO},
+	{0xD3D3, UNICODE_NORM_QC_NO},
+	{0xD3D4, UNICODE_NORM_QC_NO},
+	{0xD3D5, UNICODE_NORM_QC_NO},
+	{0xD3D6, UNICODE_NORM_QC_NO},
+	{0xD3D7, UNICODE_NORM_QC_NO},
+	{0xD3D8, UNICODE_NORM_QC_NO},
+	{0xD3D9, UNICODE_NORM_QC_NO},
+	{0xD3DA, UNICODE_NORM_QC_NO},
+	{0xD3DB, UNICODE_NORM_QC_NO},
+	{0xD3DC, UNICODE_NORM_QC_NO},
+	{0xD3DD, UNICODE_NORM_QC_NO},
+	{0xD3DE, UNICODE_NORM_QC_NO},
+	{0xD3DF, UNICODE_NORM_QC_NO},
+	{0xD3E0, UNICODE_NORM_QC_NO},
+	{0xD3E1, UNICODE_NORM_QC_NO},
+	{0xD3E2, UNICODE_NORM_QC_NO},
+	{0xD3E3, UNICODE_NORM_QC_NO},
+	{0xD3E4, UNICODE_NORM_QC_NO},
+	{0xD3E5, UNICODE_NORM_QC_NO},
+	{0xD3E6, UNICODE_NORM_QC_NO},
+	{0xD3E7, UNICODE_NORM_QC_NO},
+	{0xD3E8, UNICODE_NORM_QC_NO},
+	{0xD3E9, UNICODE_NORM_QC_NO},
+	{0xD3EA, UNICODE_NORM_QC_NO},
+	{0xD3EB, UNICODE_NORM_QC_NO},
+	{0xD3EC, UNICODE_NORM_QC_NO},
+	{0xD3ED, UNICODE_NORM_QC_NO},
+	{0xD3EE, UNICODE_NORM_QC_NO},
+	{0xD3EF, UNICODE_NORM_QC_NO},
+	{0xD3F0, UNICODE_NORM_QC_NO},
+	{0xD3F1, UNICODE_NORM_QC_NO},
+	{0xD3F2, UNICODE_NORM_QC_NO},
+	{0xD3F3, UNICODE_NORM_QC_NO},
+	{0xD3F4, UNICODE_NORM_QC_NO},
+	{0xD3F5, UNICODE_NORM_QC_NO},
+	{0xD3F6, UNICODE_NORM_QC_NO},
+	{0xD3F7, UNICODE_NORM_QC_NO},
+	{0xD3F8, UNICODE_NORM_QC_NO},
+	{0xD3F9, UNICODE_NORM_QC_NO},
+	{0xD3FA, UNICODE_NORM_QC_NO},
+	{0xD3FB, UNICODE_NORM_QC_NO},
+	{0xD3FC, UNICODE_NORM_QC_NO},
+	{0xD3FD, UNICODE_NORM_QC_NO},
+	{0xD3FE, UNICODE_NORM_QC_NO},
+	{0xD3FF, UNICODE_NORM_QC_NO},
+	{0xD400, UNICODE_NORM_QC_NO},
+	{0xD401, UNICODE_NORM_QC_NO},
+	{0xD402, UNICODE_NORM_QC_NO},
+	{0xD403, UNICODE_NORM_QC_NO},
+	{0xD404, UNICODE_NORM_QC_NO},
+	{0xD405, UNICODE_NORM_QC_NO},
+	{0xD406, UNICODE_NORM_QC_NO},
+	{0xD407, UNICODE_NORM_QC_NO},
+	{0xD408, UNICODE_NORM_QC_NO},
+	{0xD409, UNICODE_NORM_QC_NO},
+	{0xD40A, UNICODE_NORM_QC_NO},
+	{0xD40B, UNICODE_NORM_QC_NO},
+	{0xD40C, UNICODE_NORM_QC_NO},
+	{0xD40D, UNICODE_NORM_QC_NO},
+	{0xD40E, UNICODE_NORM_QC_NO},
+	{0xD40F, UNICODE_NORM_QC_NO},
+	{0xD410, UNICODE_NORM_QC_NO},
+	{0xD411, UNICODE_NORM_QC_NO},
+	{0xD412, UNICODE_NORM_QC_NO},
+	{0xD413, UNICODE_NORM_QC_NO},
+	{0xD414, UNICODE_NORM_QC_NO},
+	{0xD415, UNICODE_NORM_QC_NO},
+	{0xD416, UNICODE_NORM_QC_NO},
+	{0xD417, UNICODE_NORM_QC_NO},
+	{0xD418, UNICODE_NORM_QC_NO},
+	{0xD419, UNICODE_NORM_QC_NO},
+	{0xD41A, UNICODE_NORM_QC_NO},
+	{0xD41B, UNICODE_NORM_QC_NO},
+	{0xD41C, UNICODE_NORM_QC_NO},
+	{0xD41D, UNICODE_NORM_QC_NO},
+	{0xD41E, UNICODE_NORM_QC_NO},
+	{0xD41F, UNICODE_NORM_QC_NO},
+	{0xD420, UNICODE_NORM_QC_NO},
+	{0xD421, UNICODE_NORM_QC_NO},
+	{0xD422, UNICODE_NORM_QC_NO},
+	{0xD423, UNICODE_NORM_QC_NO},
+	{0xD424, UNICODE_NORM_QC_NO},
+	{0xD425, UNICODE_NORM_QC_NO},
+	{0xD426, UNICODE_NORM_QC_NO},
+	{0xD427, UNICODE_NORM_QC_NO},
+	{0xD428, UNICODE_NORM_QC_NO},
+	{0xD429, UNICODE_NORM_QC_NO},
+	{0xD42A, UNICODE_NORM_QC_NO},
+	{0xD42B, UNICODE_NORM_QC_NO},
+	{0xD42C, UNICODE_NORM_QC_NO},
+	{0xD42D, UNICODE_NORM_QC_NO},
+	{0xD42E, UNICODE_NORM_QC_NO},
+	{0xD42F, UNICODE_NORM_QC_NO},
+	{0xD430, UNICODE_NORM_QC_NO},
+	{0xD431, UNICODE_NORM_QC_NO},
+	{0xD432, UNICODE_NORM_QC_NO},
+	{0xD433, UNICODE_NORM_QC_NO},
+	{0xD434, UNICODE_NORM_QC_NO},
+	{0xD435, UNICODE_NORM_QC_NO},
+	{0xD436, UNICODE_NORM_QC_NO},
+	{0xD437, UNICODE_NORM_QC_NO},
+	{0xD438, UNICODE_NORM_QC_NO},
+	{0xD439, UNICODE_NORM_QC_NO},
+	{0xD43A, UNICODE_NORM_QC_NO},
+	{0xD43B, UNICODE_NORM_QC_NO},
+	{0xD43C, UNICODE_NORM_QC_NO},
+	{0xD43D, UNICODE_NORM_QC_NO},
+	{0xD43E, UNICODE_NORM_QC_NO},
+	{0xD43F, UNICODE_NORM_QC_NO},
+	{0xD440, UNICODE_NORM_QC_NO},
+	{0xD441, UNICODE_NORM_QC_NO},
+	{0xD442, UNICODE_NORM_QC_NO},
+	{0xD443, UNICODE_NORM_QC_NO},
+	{0xD444, UNICODE_NORM_QC_NO},
+	{0xD445, UNICODE_NORM_QC_NO},
+	{0xD446, UNICODE_NORM_QC_NO},
+	{0xD447, UNICODE_NORM_QC_NO},
+	{0xD448, UNICODE_NORM_QC_NO},
+	{0xD449, UNICODE_NORM_QC_NO},
+	{0xD44A, UNICODE_NORM_QC_NO},
+	{0xD44B, UNICODE_NORM_QC_NO},
+	{0xD44C, UNICODE_NORM_QC_NO},
+	{0xD44D, UNICODE_NORM_QC_NO},
+	{0xD44E, UNICODE_NORM_QC_NO},
+	{0xD44F, UNICODE_NORM_QC_NO},
+	{0xD450, UNICODE_NORM_QC_NO},
+	{0xD451, UNICODE_NORM_QC_NO},
+	{0xD452, UNICODE_NORM_QC_NO},
+	{0xD453, UNICODE_NORM_QC_NO},
+	{0xD454, UNICODE_NORM_QC_NO},
+	{0xD455, UNICODE_NORM_QC_NO},
+	{0xD456, UNICODE_NORM_QC_NO},
+	{0xD457, UNICODE_NORM_QC_NO},
+	{0xD458, UNICODE_NORM_QC_NO},
+	{0xD459, UNICODE_NORM_QC_NO},
+	{0xD45A, UNICODE_NORM_QC_NO},
+	{0xD45B, UNICODE_NORM_QC_NO},
+	{0xD45C, UNICODE_NORM_QC_NO},
+	{0xD45D, UNICODE_NORM_QC_NO},
+	{0xD45E, UNICODE_NORM_QC_NO},
+	{0xD45F, UNICODE_NORM_QC_NO},
+	{0xD460, UNICODE_NORM_QC_NO},
+	{0xD461, UNICODE_NORM_QC_NO},
+	{0xD462, UNICODE_NORM_QC_NO},
+	{0xD463, UNICODE_NORM_QC_NO},
+	{0xD464, UNICODE_NORM_QC_NO},
+	{0xD465, UNICODE_NORM_QC_NO},
+	{0xD466, UNICODE_NORM_QC_NO},
+	{0xD467, UNICODE_NORM_QC_NO},
+	{0xD468, UNICODE_NORM_QC_NO},
+	{0xD469, UNICODE_NORM_QC_NO},
+	{0xD46A, UNICODE_NORM_QC_NO},
+	{0xD46B, UNICODE_NORM_QC_NO},
+	{0xD46C, UNICODE_NORM_QC_NO},
+	{0xD46D, UNICODE_NORM_QC_NO},
+	{0xD46E, UNICODE_NORM_QC_NO},
+	{0xD46F, UNICODE_NORM_QC_NO},
+	{0xD470, UNICODE_NORM_QC_NO},
+	{0xD471, UNICODE_NORM_QC_NO},
+	{0xD472, UNICODE_NORM_QC_NO},
+	{0xD473, UNICODE_NORM_QC_NO},
+	{0xD474, UNICODE_NORM_QC_NO},
+	{0xD475, UNICODE_NORM_QC_NO},
+	{0xD476, UNICODE_NORM_QC_NO},
+	{0xD477, UNICODE_NORM_QC_NO},
+	{0xD478, UNICODE_NORM_QC_NO},
+	{0xD479, UNICODE_NORM_QC_NO},
+	{0xD47A, UNICODE_NORM_QC_NO},
+	{0xD47B, UNICODE_NORM_QC_NO},
+	{0xD47C, UNICODE_NORM_QC_NO},
+	{0xD47D, UNICODE_NORM_QC_NO},
+	{0xD47E, UNICODE_NORM_QC_NO},
+	{0xD47F, UNICODE_NORM_QC_NO},
+	{0xD480, UNICODE_NORM_QC_NO},
+	{0xD481, UNICODE_NORM_QC_NO},
+	{0xD482, UNICODE_NORM_QC_NO},
+	{0xD483, UNICODE_NORM_QC_NO},
+	{0xD484, UNICODE_NORM_QC_NO},
+	{0xD485, UNICODE_NORM_QC_NO},
+	{0xD486, UNICODE_NORM_QC_NO},
+	{0xD487, UNICODE_NORM_QC_NO},
+	{0xD488, UNICODE_NORM_QC_NO},
+	{0xD489, UNICODE_NORM_QC_NO},
+	{0xD48A, UNICODE_NORM_QC_NO},
+	{0xD48B, UNICODE_NORM_QC_NO},
+	{0xD48C, UNICODE_NORM_QC_NO},
+	{0xD48D, UNICODE_NORM_QC_NO},
+	{0xD48E, UNICODE_NORM_QC_NO},
+	{0xD48F, UNICODE_NORM_QC_NO},
+	{0xD490, UNICODE_NORM_QC_NO},
+	{0xD491, UNICODE_NORM_QC_NO},
+	{0xD492, UNICODE_NORM_QC_NO},
+	{0xD493, UNICODE_NORM_QC_NO},
+	{0xD494, UNICODE_NORM_QC_NO},
+	{0xD495, UNICODE_NORM_QC_NO},
+	{0xD496, UNICODE_NORM_QC_NO},
+	{0xD497, UNICODE_NORM_QC_NO},
+	{0xD498, UNICODE_NORM_QC_NO},
+	{0xD499, UNICODE_NORM_QC_NO},
+	{0xD49A, UNICODE_NORM_QC_NO},
+	{0xD49B, UNICODE_NORM_QC_NO},
+	{0xD49C, UNICODE_NORM_QC_NO},
+	{0xD49D, UNICODE_NORM_QC_NO},
+	{0xD49E, UNICODE_NORM_QC_NO},
+	{0xD49F, UNICODE_NORM_QC_NO},
+	{0xD4A0, UNICODE_NORM_QC_NO},
+	{0xD4A1, UNICODE_NORM_QC_NO},
+	{0xD4A2, UNICODE_NORM_QC_NO},
+	{0xD4A3, UNICODE_NORM_QC_NO},
+	{0xD4A4, UNICODE_NORM_QC_NO},
+	{0xD4A5, UNICODE_NORM_QC_NO},
+	{0xD4A6, UNICODE_NORM_QC_NO},
+	{0xD4A7, UNICODE_NORM_QC_NO},
+	{0xD4A8, UNICODE_NORM_QC_NO},
+	{0xD4A9, UNICODE_NORM_QC_NO},
+	{0xD4AA, UNICODE_NORM_QC_NO},
+	{0xD4AB, UNICODE_NORM_QC_NO},
+	{0xD4AC, UNICODE_NORM_QC_NO},
+	{0xD4AD, UNICODE_NORM_QC_NO},
+	{0xD4AE, UNICODE_NORM_QC_NO},
+	{0xD4AF, UNICODE_NORM_QC_NO},
+	{0xD4B0, UNICODE_NORM_QC_NO},
+	{0xD4B1, UNICODE_NORM_QC_NO},
+	{0xD4B2, UNICODE_NORM_QC_NO},
+	{0xD4B3, UNICODE_NORM_QC_NO},
+	{0xD4B4, UNICODE_NORM_QC_NO},
+	{0xD4B5, UNICODE_NORM_QC_NO},
+	{0xD4B6, UNICODE_NORM_QC_NO},
+	{0xD4B7, UNICODE_NORM_QC_NO},
+	{0xD4B8, UNICODE_NORM_QC_NO},
+	{0xD4B9, UNICODE_NORM_QC_NO},
+	{0xD4BA, UNICODE_NORM_QC_NO},
+	{0xD4BB, UNICODE_NORM_QC_NO},
+	{0xD4BC, UNICODE_NORM_QC_NO},
+	{0xD4BD, UNICODE_NORM_QC_NO},
+	{0xD4BE, UNICODE_NORM_QC_NO},
+	{0xD4BF, UNICODE_NORM_QC_NO},
+	{0xD4C0, UNICODE_NORM_QC_NO},
+	{0xD4C1, UNICODE_NORM_QC_NO},
+	{0xD4C2, UNICODE_NORM_QC_NO},
+	{0xD4C3, UNICODE_NORM_QC_NO},
+	{0xD4C4, UNICODE_NORM_QC_NO},
+	{0xD4C5, UNICODE_NORM_QC_NO},
+	{0xD4C6, UNICODE_NORM_QC_NO},
+	{0xD4C7, UNICODE_NORM_QC_NO},
+	{0xD4C8, UNICODE_NORM_QC_NO},
+	{0xD4C9, UNICODE_NORM_QC_NO},
+	{0xD4CA, UNICODE_NORM_QC_NO},
+	{0xD4CB, UNICODE_NORM_QC_NO},
+	{0xD4CC, UNICODE_NORM_QC_NO},
+	{0xD4CD, UNICODE_NORM_QC_NO},
+	{0xD4CE, UNICODE_NORM_QC_NO},
+	{0xD4CF, UNICODE_NORM_QC_NO},
+	{0xD4D0, UNICODE_NORM_QC_NO},
+	{0xD4D1, UNICODE_NORM_QC_NO},
+	{0xD4D2, UNICODE_NORM_QC_NO},
+	{0xD4D3, UNICODE_NORM_QC_NO},
+	{0xD4D4, UNICODE_NORM_QC_NO},
+	{0xD4D5, UNICODE_NORM_QC_NO},
+	{0xD4D6, UNICODE_NORM_QC_NO},
+	{0xD4D7, UNICODE_NORM_QC_NO},
+	{0xD4D8, UNICODE_NORM_QC_NO},
+	{0xD4D9, UNICODE_NORM_QC_NO},
+	{0xD4DA, UNICODE_NORM_QC_NO},
+	{0xD4DB, UNICODE_NORM_QC_NO},
+	{0xD4DC, UNICODE_NORM_QC_NO},
+	{0xD4DD, UNICODE_NORM_QC_NO},
+	{0xD4DE, UNICODE_NORM_QC_NO},
+	{0xD4DF, UNICODE_NORM_QC_NO},
+	{0xD4E0, UNICODE_NORM_QC_NO},
+	{0xD4E1, UNICODE_NORM_QC_NO},
+	{0xD4E2, UNICODE_NORM_QC_NO},
+	{0xD4E3, UNICODE_NORM_QC_NO},
+	{0xD4E4, UNICODE_NORM_QC_NO},
+	{0xD4E5, UNICODE_NORM_QC_NO},
+	{0xD4E6, UNICODE_NORM_QC_NO},
+	{0xD4E7, UNICODE_NORM_QC_NO},
+	{0xD4E8, UNICODE_NORM_QC_NO},
+	{0xD4E9, UNICODE_NORM_QC_NO},
+	{0xD4EA, UNICODE_NORM_QC_NO},
+	{0xD4EB, UNICODE_NORM_QC_NO},
+	{0xD4EC, UNICODE_NORM_QC_NO},
+	{0xD4ED, UNICODE_NORM_QC_NO},
+	{0xD4EE, UNICODE_NORM_QC_NO},
+	{0xD4EF, UNICODE_NORM_QC_NO},
+	{0xD4F0, UNICODE_NORM_QC_NO},
+	{0xD4F1, UNICODE_NORM_QC_NO},
+	{0xD4F2, UNICODE_NORM_QC_NO},
+	{0xD4F3, UNICODE_NORM_QC_NO},
+	{0xD4F4, UNICODE_NORM_QC_NO},
+	{0xD4F5, UNICODE_NORM_QC_NO},
+	{0xD4F6, UNICODE_NORM_QC_NO},
+	{0xD4F7, UNICODE_NORM_QC_NO},
+	{0xD4F8, UNICODE_NORM_QC_NO},
+	{0xD4F9, UNICODE_NORM_QC_NO},
+	{0xD4FA, UNICODE_NORM_QC_NO},
+	{0xD4FB, UNICODE_NORM_QC_NO},
+	{0xD4FC, UNICODE_NORM_QC_NO},
+	{0xD4FD, UNICODE_NORM_QC_NO},
+	{0xD4FE, UNICODE_NORM_QC_NO},
+	{0xD4FF, UNICODE_NORM_QC_NO},
+	{0xD500, UNICODE_NORM_QC_NO},
+	{0xD501, UNICODE_NORM_QC_NO},
+	{0xD502, UNICODE_NORM_QC_NO},
+	{0xD503, UNICODE_NORM_QC_NO},
+	{0xD504, UNICODE_NORM_QC_NO},
+	{0xD505, UNICODE_NORM_QC_NO},
+	{0xD506, UNICODE_NORM_QC_NO},
+	{0xD507, UNICODE_NORM_QC_NO},
+	{0xD508, UNICODE_NORM_QC_NO},
+	{0xD509, UNICODE_NORM_QC_NO},
+	{0xD50A, UNICODE_NORM_QC_NO},
+	{0xD50B, UNICODE_NORM_QC_NO},
+	{0xD50C, UNICODE_NORM_QC_NO},
+	{0xD50D, UNICODE_NORM_QC_NO},
+	{0xD50E, UNICODE_NORM_QC_NO},
+	{0xD50F, UNICODE_NORM_QC_NO},
+	{0xD510, UNICODE_NORM_QC_NO},
+	{0xD511, UNICODE_NORM_QC_NO},
+	{0xD512, UNICODE_NORM_QC_NO},
+	{0xD513, UNICODE_NORM_QC_NO},
+	{0xD514, UNICODE_NORM_QC_NO},
+	{0xD515, UNICODE_NORM_QC_NO},
+	{0xD516, UNICODE_NORM_QC_NO},
+	{0xD517, UNICODE_NORM_QC_NO},
+	{0xD518, UNICODE_NORM_QC_NO},
+	{0xD519, UNICODE_NORM_QC_NO},
+	{0xD51A, UNICODE_NORM_QC_NO},
+	{0xD51B, UNICODE_NORM_QC_NO},
+	{0xD51C, UNICODE_NORM_QC_NO},
+	{0xD51D, UNICODE_NORM_QC_NO},
+	{0xD51E, UNICODE_NORM_QC_NO},
+	{0xD51F, UNICODE_NORM_QC_NO},
+	{0xD520, UNICODE_NORM_QC_NO},
+	{0xD521, UNICODE_NORM_QC_NO},
+	{0xD522, UNICODE_NORM_QC_NO},
+	{0xD523, UNICODE_NORM_QC_NO},
+	{0xD524, UNICODE_NORM_QC_NO},
+	{0xD525, UNICODE_NORM_QC_NO},
+	{0xD526, UNICODE_NORM_QC_NO},
+	{0xD527, UNICODE_NORM_QC_NO},
+	{0xD528, UNICODE_NORM_QC_NO},
+	{0xD529, UNICODE_NORM_QC_NO},
+	{0xD52A, UNICODE_NORM_QC_NO},
+	{0xD52B, UNICODE_NORM_QC_NO},
+	{0xD52C, UNICODE_NORM_QC_NO},
+	{0xD52D, UNICODE_NORM_QC_NO},
+	{0xD52E, UNICODE_NORM_QC_NO},
+	{0xD52F, UNICODE_NORM_QC_NO},
+	{0xD530, UNICODE_NORM_QC_NO},
+	{0xD531, UNICODE_NORM_QC_NO},
+	{0xD532, UNICODE_NORM_QC_NO},
+	{0xD533, UNICODE_NORM_QC_NO},
+	{0xD534, UNICODE_NORM_QC_NO},
+	{0xD535, UNICODE_NORM_QC_NO},
+	{0xD536, UNICODE_NORM_QC_NO},
+	{0xD537, UNICODE_NORM_QC_NO},
+	{0xD538, UNICODE_NORM_QC_NO},
+	{0xD539, UNICODE_NORM_QC_NO},
+	{0xD53A, UNICODE_NORM_QC_NO},
+	{0xD53B, UNICODE_NORM_QC_NO},
+	{0xD53C, UNICODE_NORM_QC_NO},
+	{0xD53D, UNICODE_NORM_QC_NO},
+	{0xD53E, UNICODE_NORM_QC_NO},
+	{0xD53F, UNICODE_NORM_QC_NO},
+	{0xD540, UNICODE_NORM_QC_NO},
+	{0xD541, UNICODE_NORM_QC_NO},
+	{0xD542, UNICODE_NORM_QC_NO},
+	{0xD543, UNICODE_NORM_QC_NO},
+	{0xD544, UNICODE_NORM_QC_NO},
+	{0xD545, UNICODE_NORM_QC_NO},
+	{0xD546, UNICODE_NORM_QC_NO},
+	{0xD547, UNICODE_NORM_QC_NO},
+	{0xD548, UNICODE_NORM_QC_NO},
+	{0xD549, UNICODE_NORM_QC_NO},
+	{0xD54A, UNICODE_NORM_QC_NO},
+	{0xD54B, UNICODE_NORM_QC_NO},
+	{0xD54C, UNICODE_NORM_QC_NO},
+	{0xD54D, UNICODE_NORM_QC_NO},
+	{0xD54E, UNICODE_NORM_QC_NO},
+	{0xD54F, UNICODE_NORM_QC_NO},
+	{0xD550, UNICODE_NORM_QC_NO},
+	{0xD551, UNICODE_NORM_QC_NO},
+	{0xD552, UNICODE_NORM_QC_NO},
+	{0xD553, UNICODE_NORM_QC_NO},
+	{0xD554, UNICODE_NORM_QC_NO},
+	{0xD555, UNICODE_NORM_QC_NO},
+	{0xD556, UNICODE_NORM_QC_NO},
+	{0xD557, UNICODE_NORM_QC_NO},
+	{0xD558, UNICODE_NORM_QC_NO},
+	{0xD559, UNICODE_NORM_QC_NO},
+	{0xD55A, UNICODE_NORM_QC_NO},
+	{0xD55B, UNICODE_NORM_QC_NO},
+	{0xD55C, UNICODE_NORM_QC_NO},
+	{0xD55D, UNICODE_NORM_QC_NO},
+	{0xD55E, UNICODE_NORM_QC_NO},
+	{0xD55F, UNICODE_NORM_QC_NO},
+	{0xD560, UNICODE_NORM_QC_NO},
+	{0xD561, UNICODE_NORM_QC_NO},
+	{0xD562, UNICODE_NORM_QC_NO},
+	{0xD563, UNICODE_NORM_QC_NO},
+	{0xD564, UNICODE_NORM_QC_NO},
+	{0xD565, UNICODE_NORM_QC_NO},
+	{0xD566, UNICODE_NORM_QC_NO},
+	{0xD567, UNICODE_NORM_QC_NO},
+	{0xD568, UNICODE_NORM_QC_NO},
+	{0xD569, UNICODE_NORM_QC_NO},
+	{0xD56A, UNICODE_NORM_QC_NO},
+	{0xD56B, UNICODE_NORM_QC_NO},
+	{0xD56C, UNICODE_NORM_QC_NO},
+	{0xD56D, UNICODE_NORM_QC_NO},
+	{0xD56E, UNICODE_NORM_QC_NO},
+	{0xD56F, UNICODE_NORM_QC_NO},
+	{0xD570, UNICODE_NORM_QC_NO},
+	{0xD571, UNICODE_NORM_QC_NO},
+	{0xD572, UNICODE_NORM_QC_NO},
+	{0xD573, UNICODE_NORM_QC_NO},
+	{0xD574, UNICODE_NORM_QC_NO},
+	{0xD575, UNICODE_NORM_QC_NO},
+	{0xD576, UNICODE_NORM_QC_NO},
+	{0xD577, UNICODE_NORM_QC_NO},
+	{0xD578, UNICODE_NORM_QC_NO},
+	{0xD579, UNICODE_NORM_QC_NO},
+	{0xD57A, UNICODE_NORM_QC_NO},
+	{0xD57B, UNICODE_NORM_QC_NO},
+	{0xD57C, UNICODE_NORM_QC_NO},
+	{0xD57D, UNICODE_NORM_QC_NO},
+	{0xD57E, UNICODE_NORM_QC_NO},
+	{0xD57F, UNICODE_NORM_QC_NO},
+	{0xD580, UNICODE_NORM_QC_NO},
+	{0xD581, UNICODE_NORM_QC_NO},
+	{0xD582, UNICODE_NORM_QC_NO},
+	{0xD583, UNICODE_NORM_QC_NO},
+	{0xD584, UNICODE_NORM_QC_NO},
+	{0xD585, UNICODE_NORM_QC_NO},
+	{0xD586, UNICODE_NORM_QC_NO},
+	{0xD587, UNICODE_NORM_QC_NO},
+	{0xD588, UNICODE_NORM_QC_NO},
+	{0xD589, UNICODE_NORM_QC_NO},
+	{0xD58A, UNICODE_NORM_QC_NO},
+	{0xD58B, UNICODE_NORM_QC_NO},
+	{0xD58C, UNICODE_NORM_QC_NO},
+	{0xD58D, UNICODE_NORM_QC_NO},
+	{0xD58E, UNICODE_NORM_QC_NO},
+	{0xD58F, UNICODE_NORM_QC_NO},
+	{0xD590, UNICODE_NORM_QC_NO},
+	{0xD591, UNICODE_NORM_QC_NO},
+	{0xD592, UNICODE_NORM_QC_NO},
+	{0xD593, UNICODE_NORM_QC_NO},
+	{0xD594, UNICODE_NORM_QC_NO},
+	{0xD595, UNICODE_NORM_QC_NO},
+	{0xD596, UNICODE_NORM_QC_NO},
+	{0xD597, UNICODE_NORM_QC_NO},
+	{0xD598, UNICODE_NORM_QC_NO},
+	{0xD599, UNICODE_NORM_QC_NO},
+	{0xD59A, UNICODE_NORM_QC_NO},
+	{0xD59B, UNICODE_NORM_QC_NO},
+	{0xD59C, UNICODE_NORM_QC_NO},
+	{0xD59D, UNICODE_NORM_QC_NO},
+	{0xD59E, UNICODE_NORM_QC_NO},
+	{0xD59F, UNICODE_NORM_QC_NO},
+	{0xD5A0, UNICODE_NORM_QC_NO},
+	{0xD5A1, UNICODE_NORM_QC_NO},
+	{0xD5A2, UNICODE_NORM_QC_NO},
+	{0xD5A3, UNICODE_NORM_QC_NO},
+	{0xD5A4, UNICODE_NORM_QC_NO},
+	{0xD5A5, UNICODE_NORM_QC_NO},
+	{0xD5A6, UNICODE_NORM_QC_NO},
+	{0xD5A7, UNICODE_NORM_QC_NO},
+	{0xD5A8, UNICODE_NORM_QC_NO},
+	{0xD5A9, UNICODE_NORM_QC_NO},
+	{0xD5AA, UNICODE_NORM_QC_NO},
+	{0xD5AB, UNICODE_NORM_QC_NO},
+	{0xD5AC, UNICODE_NORM_QC_NO},
+	{0xD5AD, UNICODE_NORM_QC_NO},
+	{0xD5AE, UNICODE_NORM_QC_NO},
+	{0xD5AF, UNICODE_NORM_QC_NO},
+	{0xD5B0, UNICODE_NORM_QC_NO},
+	{0xD5B1, UNICODE_NORM_QC_NO},
+	{0xD5B2, UNICODE_NORM_QC_NO},
+	{0xD5B3, UNICODE_NORM_QC_NO},
+	{0xD5B4, UNICODE_NORM_QC_NO},
+	{0xD5B5, UNICODE_NORM_QC_NO},
+	{0xD5B6, UNICODE_NORM_QC_NO},
+	{0xD5B7, UNICODE_NORM_QC_NO},
+	{0xD5B8, UNICODE_NORM_QC_NO},
+	{0xD5B9, UNICODE_NORM_QC_NO},
+	{0xD5BA, UNICODE_NORM_QC_NO},
+	{0xD5BB, UNICODE_NORM_QC_NO},
+	{0xD5BC, UNICODE_NORM_QC_NO},
+	{0xD5BD, UNICODE_NORM_QC_NO},
+	{0xD5BE, UNICODE_NORM_QC_NO},
+	{0xD5BF, UNICODE_NORM_QC_NO},
+	{0xD5C0, UNICODE_NORM_QC_NO},
+	{0xD5C1, UNICODE_NORM_QC_NO},
+	{0xD5C2, UNICODE_NORM_QC_NO},
+	{0xD5C3, UNICODE_NORM_QC_NO},
+	{0xD5C4, UNICODE_NORM_QC_NO},
+	{0xD5C5, UNICODE_NORM_QC_NO},
+	{0xD5C6, UNICODE_NORM_QC_NO},
+	{0xD5C7, UNICODE_NORM_QC_NO},
+	{0xD5C8, UNICODE_NORM_QC_NO},
+	{0xD5C9, UNICODE_NORM_QC_NO},
+	{0xD5CA, UNICODE_NORM_QC_NO},
+	{0xD5CB, UNICODE_NORM_QC_NO},
+	{0xD5CC, UNICODE_NORM_QC_NO},
+	{0xD5CD, UNICODE_NORM_QC_NO},
+	{0xD5CE, UNICODE_NORM_QC_NO},
+	{0xD5CF, UNICODE_NORM_QC_NO},
+	{0xD5D0, UNICODE_NORM_QC_NO},
+	{0xD5D1, UNICODE_NORM_QC_NO},
+	{0xD5D2, UNICODE_NORM_QC_NO},
+	{0xD5D3, UNICODE_NORM_QC_NO},
+	{0xD5D4, UNICODE_NORM_QC_NO},
+	{0xD5D5, UNICODE_NORM_QC_NO},
+	{0xD5D6, UNICODE_NORM_QC_NO},
+	{0xD5D7, UNICODE_NORM_QC_NO},
+	{0xD5D8, UNICODE_NORM_QC_NO},
+	{0xD5D9, UNICODE_NORM_QC_NO},
+	{0xD5DA, UNICODE_NORM_QC_NO},
+	{0xD5DB, UNICODE_NORM_QC_NO},
+	{0xD5DC, UNICODE_NORM_QC_NO},
+	{0xD5DD, UNICODE_NORM_QC_NO},
+	{0xD5DE, UNICODE_NORM_QC_NO},
+	{0xD5DF, UNICODE_NORM_QC_NO},
+	{0xD5E0, UNICODE_NORM_QC_NO},
+	{0xD5E1, UNICODE_NORM_QC_NO},
+	{0xD5E2, UNICODE_NORM_QC_NO},
+	{0xD5E3, UNICODE_NORM_QC_NO},
+	{0xD5E4, UNICODE_NORM_QC_NO},
+	{0xD5E5, UNICODE_NORM_QC_NO},
+	{0xD5E6, UNICODE_NORM_QC_NO},
+	{0xD5E7, UNICODE_NORM_QC_NO},
+	{0xD5E8, UNICODE_NORM_QC_NO},
+	{0xD5E9, UNICODE_NORM_QC_NO},
+	{0xD5EA, UNICODE_NORM_QC_NO},
+	{0xD5EB, UNICODE_NORM_QC_NO},
+	{0xD5EC, UNICODE_NORM_QC_NO},
+	{0xD5ED, UNICODE_NORM_QC_NO},
+	{0xD5EE, UNICODE_NORM_QC_NO},
+	{0xD5EF, UNICODE_NORM_QC_NO},
+	{0xD5F0, UNICODE_NORM_QC_NO},
+	{0xD5F1, UNICODE_NORM_QC_NO},
+	{0xD5F2, UNICODE_NORM_QC_NO},
+	{0xD5F3, UNICODE_NORM_QC_NO},
+	{0xD5F4, UNICODE_NORM_QC_NO},
+	{0xD5F5, UNICODE_NORM_QC_NO},
+	{0xD5F6, UNICODE_NORM_QC_NO},
+	{0xD5F7, UNICODE_NORM_QC_NO},
+	{0xD5F8, UNICODE_NORM_QC_NO},
+	{0xD5F9, UNICODE_NORM_QC_NO},
+	{0xD5FA, UNICODE_NORM_QC_NO},
+	{0xD5FB, UNICODE_NORM_QC_NO},
+	{0xD5FC, UNICODE_NORM_QC_NO},
+	{0xD5FD, UNICODE_NORM_QC_NO},
+	{0xD5FE, UNICODE_NORM_QC_NO},
+	{0xD5FF, UNICODE_NORM_QC_NO},
+	{0xD600, UNICODE_NORM_QC_NO},
+	{0xD601, UNICODE_NORM_QC_NO},
+	{0xD602, UNICODE_NORM_QC_NO},
+	{0xD603, UNICODE_NORM_QC_NO},
+	{0xD604, UNICODE_NORM_QC_NO},
+	{0xD605, UNICODE_NORM_QC_NO},
+	{0xD606, UNICODE_NORM_QC_NO},
+	{0xD607, UNICODE_NORM_QC_NO},
+	{0xD608, UNICODE_NORM_QC_NO},
+	{0xD609, UNICODE_NORM_QC_NO},
+	{0xD60A, UNICODE_NORM_QC_NO},
+	{0xD60B, UNICODE_NORM_QC_NO},
+	{0xD60C, UNICODE_NORM_QC_NO},
+	{0xD60D, UNICODE_NORM_QC_NO},
+	{0xD60E, UNICODE_NORM_QC_NO},
+	{0xD60F, UNICODE_NORM_QC_NO},
+	{0xD610, UNICODE_NORM_QC_NO},
+	{0xD611, UNICODE_NORM_QC_NO},
+	{0xD612, UNICODE_NORM_QC_NO},
+	{0xD613, UNICODE_NORM_QC_NO},
+	{0xD614, UNICODE_NORM_QC_NO},
+	{0xD615, UNICODE_NORM_QC_NO},
+	{0xD616, UNICODE_NORM_QC_NO},
+	{0xD617, UNICODE_NORM_QC_NO},
+	{0xD618, UNICODE_NORM_QC_NO},
+	{0xD619, UNICODE_NORM_QC_NO},
+	{0xD61A, UNICODE_NORM_QC_NO},
+	{0xD61B, UNICODE_NORM_QC_NO},
+	{0xD61C, UNICODE_NORM_QC_NO},
+	{0xD61D, UNICODE_NORM_QC_NO},
+	{0xD61E, UNICODE_NORM_QC_NO},
+	{0xD61F, UNICODE_NORM_QC_NO},
+	{0xD620, UNICODE_NORM_QC_NO},
+	{0xD621, UNICODE_NORM_QC_NO},
+	{0xD622, UNICODE_NORM_QC_NO},
+	{0xD623, UNICODE_NORM_QC_NO},
+	{0xD624, UNICODE_NORM_QC_NO},
+	{0xD625, UNICODE_NORM_QC_NO},
+	{0xD626, UNICODE_NORM_QC_NO},
+	{0xD627, UNICODE_NORM_QC_NO},
+	{0xD628, UNICODE_NORM_QC_NO},
+	{0xD629, UNICODE_NORM_QC_NO},
+	{0xD62A, UNICODE_NORM_QC_NO},
+	{0xD62B, UNICODE_NORM_QC_NO},
+	{0xD62C, UNICODE_NORM_QC_NO},
+	{0xD62D, UNICODE_NORM_QC_NO},
+	{0xD62E, UNICODE_NORM_QC_NO},
+	{0xD62F, UNICODE_NORM_QC_NO},
+	{0xD630, UNICODE_NORM_QC_NO},
+	{0xD631, UNICODE_NORM_QC_NO},
+	{0xD632, UNICODE_NORM_QC_NO},
+	{0xD633, UNICODE_NORM_QC_NO},
+	{0xD634, UNICODE_NORM_QC_NO},
+	{0xD635, UNICODE_NORM_QC_NO},
+	{0xD636, UNICODE_NORM_QC_NO},
+	{0xD637, UNICODE_NORM_QC_NO},
+	{0xD638, UNICODE_NORM_QC_NO},
+	{0xD639, UNICODE_NORM_QC_NO},
+	{0xD63A, UNICODE_NORM_QC_NO},
+	{0xD63B, UNICODE_NORM_QC_NO},
+	{0xD63C, UNICODE_NORM_QC_NO},
+	{0xD63D, UNICODE_NORM_QC_NO},
+	{0xD63E, UNICODE_NORM_QC_NO},
+	{0xD63F, UNICODE_NORM_QC_NO},
+	{0xD640, UNICODE_NORM_QC_NO},
+	{0xD641, UNICODE_NORM_QC_NO},
+	{0xD642, UNICODE_NORM_QC_NO},
+	{0xD643, UNICODE_NORM_QC_NO},
+	{0xD644, UNICODE_NORM_QC_NO},
+	{0xD645, UNICODE_NORM_QC_NO},
+	{0xD646, UNICODE_NORM_QC_NO},
+	{0xD647, UNICODE_NORM_QC_NO},
+	{0xD648, UNICODE_NORM_QC_NO},
+	{0xD649, UNICODE_NORM_QC_NO},
+	{0xD64A, UNICODE_NORM_QC_NO},
+	{0xD64B, UNICODE_NORM_QC_NO},
+	{0xD64C, UNICODE_NORM_QC_NO},
+	{0xD64D, UNICODE_NORM_QC_NO},
+	{0xD64E, UNICODE_NORM_QC_NO},
+	{0xD64F, UNICODE_NORM_QC_NO},
+	{0xD650, UNICODE_NORM_QC_NO},
+	{0xD651, UNICODE_NORM_QC_NO},
+	{0xD652, UNICODE_NORM_QC_NO},
+	{0xD653, UNICODE_NORM_QC_NO},
+	{0xD654, UNICODE_NORM_QC_NO},
+	{0xD655, UNICODE_NORM_QC_NO},
+	{0xD656, UNICODE_NORM_QC_NO},
+	{0xD657, UNICODE_NORM_QC_NO},
+	{0xD658, UNICODE_NORM_QC_NO},
+	{0xD659, UNICODE_NORM_QC_NO},
+	{0xD65A, UNICODE_NORM_QC_NO},
+	{0xD65B, UNICODE_NORM_QC_NO},
+	{0xD65C, UNICODE_NORM_QC_NO},
+	{0xD65D, UNICODE_NORM_QC_NO},
+	{0xD65E, UNICODE_NORM_QC_NO},
+	{0xD65F, UNICODE_NORM_QC_NO},
+	{0xD660, UNICODE_NORM_QC_NO},
+	{0xD661, UNICODE_NORM_QC_NO},
+	{0xD662, UNICODE_NORM_QC_NO},
+	{0xD663, UNICODE_NORM_QC_NO},
+	{0xD664, UNICODE_NORM_QC_NO},
+	{0xD665, UNICODE_NORM_QC_NO},
+	{0xD666, UNICODE_NORM_QC_NO},
+	{0xD667, UNICODE_NORM_QC_NO},
+	{0xD668, UNICODE_NORM_QC_NO},
+	{0xD669, UNICODE_NORM_QC_NO},
+	{0xD66A, UNICODE_NORM_QC_NO},
+	{0xD66B, UNICODE_NORM_QC_NO},
+	{0xD66C, UNICODE_NORM_QC_NO},
+	{0xD66D, UNICODE_NORM_QC_NO},
+	{0xD66E, UNICODE_NORM_QC_NO},
+	{0xD66F, UNICODE_NORM_QC_NO},
+	{0xD670, UNICODE_NORM_QC_NO},
+	{0xD671, UNICODE_NORM_QC_NO},
+	{0xD672, UNICODE_NORM_QC_NO},
+	{0xD673, UNICODE_NORM_QC_NO},
+	{0xD674, UNICODE_NORM_QC_NO},
+	{0xD675, UNICODE_NORM_QC_NO},
+	{0xD676, UNICODE_NORM_QC_NO},
+	{0xD677, UNICODE_NORM_QC_NO},
+	{0xD678, UNICODE_NORM_QC_NO},
+	{0xD679, UNICODE_NORM_QC_NO},
+	{0xD67A, UNICODE_NORM_QC_NO},
+	{0xD67B, UNICODE_NORM_QC_NO},
+	{0xD67C, UNICODE_NORM_QC_NO},
+	{0xD67D, UNICODE_NORM_QC_NO},
+	{0xD67E, UNICODE_NORM_QC_NO},
+	{0xD67F, UNICODE_NORM_QC_NO},
+	{0xD680, UNICODE_NORM_QC_NO},
+	{0xD681, UNICODE_NORM_QC_NO},
+	{0xD682, UNICODE_NORM_QC_NO},
+	{0xD683, UNICODE_NORM_QC_NO},
+	{0xD684, UNICODE_NORM_QC_NO},
+	{0xD685, UNICODE_NORM_QC_NO},
+	{0xD686, UNICODE_NORM_QC_NO},
+	{0xD687, UNICODE_NORM_QC_NO},
+	{0xD688, UNICODE_NORM_QC_NO},
+	{0xD689, UNICODE_NORM_QC_NO},
+	{0xD68A, UNICODE_NORM_QC_NO},
+	{0xD68B, UNICODE_NORM_QC_NO},
+	{0xD68C, UNICODE_NORM_QC_NO},
+	{0xD68D, UNICODE_NORM_QC_NO},
+	{0xD68E, UNICODE_NORM_QC_NO},
+	{0xD68F, UNICODE_NORM_QC_NO},
+	{0xD690, UNICODE_NORM_QC_NO},
+	{0xD691, UNICODE_NORM_QC_NO},
+	{0xD692, UNICODE_NORM_QC_NO},
+	{0xD693, UNICODE_NORM_QC_NO},
+	{0xD694, UNICODE_NORM_QC_NO},
+	{0xD695, UNICODE_NORM_QC_NO},
+	{0xD696, UNICODE_NORM_QC_NO},
+	{0xD697, UNICODE_NORM_QC_NO},
+	{0xD698, UNICODE_NORM_QC_NO},
+	{0xD699, UNICODE_NORM_QC_NO},
+	{0xD69A, UNICODE_NORM_QC_NO},
+	{0xD69B, UNICODE_NORM_QC_NO},
+	{0xD69C, UNICODE_NORM_QC_NO},
+	{0xD69D, UNICODE_NORM_QC_NO},
+	{0xD69E, UNICODE_NORM_QC_NO},
+	{0xD69F, UNICODE_NORM_QC_NO},
+	{0xD6A0, UNICODE_NORM_QC_NO},
+	{0xD6A1, UNICODE_NORM_QC_NO},
+	{0xD6A2, UNICODE_NORM_QC_NO},
+	{0xD6A3, UNICODE_NORM_QC_NO},
+	{0xD6A4, UNICODE_NORM_QC_NO},
+	{0xD6A5, UNICODE_NORM_QC_NO},
+	{0xD6A6, UNICODE_NORM_QC_NO},
+	{0xD6A7, UNICODE_NORM_QC_NO},
+	{0xD6A8, UNICODE_NORM_QC_NO},
+	{0xD6A9, UNICODE_NORM_QC_NO},
+	{0xD6AA, UNICODE_NORM_QC_NO},
+	{0xD6AB, UNICODE_NORM_QC_NO},
+	{0xD6AC, UNICODE_NORM_QC_NO},
+	{0xD6AD, UNICODE_NORM_QC_NO},
+	{0xD6AE, UNICODE_NORM_QC_NO},
+	{0xD6AF, UNICODE_NORM_QC_NO},
+	{0xD6B0, UNICODE_NORM_QC_NO},
+	{0xD6B1, UNICODE_NORM_QC_NO},
+	{0xD6B2, UNICODE_NORM_QC_NO},
+	{0xD6B3, UNICODE_NORM_QC_NO},
+	{0xD6B4, UNICODE_NORM_QC_NO},
+	{0xD6B5, UNICODE_NORM_QC_NO},
+	{0xD6B6, UNICODE_NORM_QC_NO},
+	{0xD6B7, UNICODE_NORM_QC_NO},
+	{0xD6B8, UNICODE_NORM_QC_NO},
+	{0xD6B9, UNICODE_NORM_QC_NO},
+	{0xD6BA, UNICODE_NORM_QC_NO},
+	{0xD6BB, UNICODE_NORM_QC_NO},
+	{0xD6BC, UNICODE_NORM_QC_NO},
+	{0xD6BD, UNICODE_NORM_QC_NO},
+	{0xD6BE, UNICODE_NORM_QC_NO},
+	{0xD6BF, UNICODE_NORM_QC_NO},
+	{0xD6C0, UNICODE_NORM_QC_NO},
+	{0xD6C1, UNICODE_NORM_QC_NO},
+	{0xD6C2, UNICODE_NORM_QC_NO},
+	{0xD6C3, UNICODE_NORM_QC_NO},
+	{0xD6C4, UNICODE_NORM_QC_NO},
+	{0xD6C5, UNICODE_NORM_QC_NO},
+	{0xD6C6, UNICODE_NORM_QC_NO},
+	{0xD6C7, UNICODE_NORM_QC_NO},
+	{0xD6C8, UNICODE_NORM_QC_NO},
+	{0xD6C9, UNICODE_NORM_QC_NO},
+	{0xD6CA, UNICODE_NORM_QC_NO},
+	{0xD6CB, UNICODE_NORM_QC_NO},
+	{0xD6CC, UNICODE_NORM_QC_NO},
+	{0xD6CD, UNICODE_NORM_QC_NO},
+	{0xD6CE, UNICODE_NORM_QC_NO},
+	{0xD6CF, UNICODE_NORM_QC_NO},
+	{0xD6D0, UNICODE_NORM_QC_NO},
+	{0xD6D1, UNICODE_NORM_QC_NO},
+	{0xD6D2, UNICODE_NORM_QC_NO},
+	{0xD6D3, UNICODE_NORM_QC_NO},
+	{0xD6D4, UNICODE_NORM_QC_NO},
+	{0xD6D5, UNICODE_NORM_QC_NO},
+	{0xD6D6, UNICODE_NORM_QC_NO},
+	{0xD6D7, UNICODE_NORM_QC_NO},
+	{0xD6D8, UNICODE_NORM_QC_NO},
+	{0xD6D9, UNICODE_NORM_QC_NO},
+	{0xD6DA, UNICODE_NORM_QC_NO},
+	{0xD6DB, UNICODE_NORM_QC_NO},
+	{0xD6DC, UNICODE_NORM_QC_NO},
+	{0xD6DD, UNICODE_NORM_QC_NO},
+	{0xD6DE, UNICODE_NORM_QC_NO},
+	{0xD6DF, UNICODE_NORM_QC_NO},
+	{0xD6E0, UNICODE_NORM_QC_NO},
+	{0xD6E1, UNICODE_NORM_QC_NO},
+	{0xD6E2, UNICODE_NORM_QC_NO},
+	{0xD6E3, UNICODE_NORM_QC_NO},
+	{0xD6E4, UNICODE_NORM_QC_NO},
+	{0xD6E5, UNICODE_NORM_QC_NO},
+	{0xD6E6, UNICODE_NORM_QC_NO},
+	{0xD6E7, UNICODE_NORM_QC_NO},
+	{0xD6E8, UNICODE_NORM_QC_NO},
+	{0xD6E9, UNICODE_NORM_QC_NO},
+	{0xD6EA, UNICODE_NORM_QC_NO},
+	{0xD6EB, UNICODE_NORM_QC_NO},
+	{0xD6EC, UNICODE_NORM_QC_NO},
+	{0xD6ED, UNICODE_NORM_QC_NO},
+	{0xD6EE, UNICODE_NORM_QC_NO},
+	{0xD6EF, UNICODE_NORM_QC_NO},
+	{0xD6F0, UNICODE_NORM_QC_NO},
+	{0xD6F1, UNICODE_NORM_QC_NO},
+	{0xD6F2, UNICODE_NORM_QC_NO},
+	{0xD6F3, UNICODE_NORM_QC_NO},
+	{0xD6F4, UNICODE_NORM_QC_NO},
+	{0xD6F5, UNICODE_NORM_QC_NO},
+	{0xD6F6, UNICODE_NORM_QC_NO},
+	{0xD6F7, UNICODE_NORM_QC_NO},
+	{0xD6F8, UNICODE_NORM_QC_NO},
+	{0xD6F9, UNICODE_NORM_QC_NO},
+	{0xD6FA, UNICODE_NORM_QC_NO},
+	{0xD6FB, UNICODE_NORM_QC_NO},
+	{0xD6FC, UNICODE_NORM_QC_NO},
+	{0xD6FD, UNICODE_NORM_QC_NO},
+	{0xD6FE, UNICODE_NORM_QC_NO},
+	{0xD6FF, UNICODE_NORM_QC_NO},
+	{0xD700, UNICODE_NORM_QC_NO},
+	{0xD701, UNICODE_NORM_QC_NO},
+	{0xD702, UNICODE_NORM_QC_NO},
+	{0xD703, UNICODE_NORM_QC_NO},
+	{0xD704, UNICODE_NORM_QC_NO},
+	{0xD705, UNICODE_NORM_QC_NO},
+	{0xD706, UNICODE_NORM_QC_NO},
+	{0xD707, UNICODE_NORM_QC_NO},
+	{0xD708, UNICODE_NORM_QC_NO},
+	{0xD709, UNICODE_NORM_QC_NO},
+	{0xD70A, UNICODE_NORM_QC_NO},
+	{0xD70B, UNICODE_NORM_QC_NO},
+	{0xD70C, UNICODE_NORM_QC_NO},
+	{0xD70D, UNICODE_NORM_QC_NO},
+	{0xD70E, UNICODE_NORM_QC_NO},
+	{0xD70F, UNICODE_NORM_QC_NO},
+	{0xD710, UNICODE_NORM_QC_NO},
+	{0xD711, UNICODE_NORM_QC_NO},
+	{0xD712, UNICODE_NORM_QC_NO},
+	{0xD713, UNICODE_NORM_QC_NO},
+	{0xD714, UNICODE_NORM_QC_NO},
+	{0xD715, UNICODE_NORM_QC_NO},
+	{0xD716, UNICODE_NORM_QC_NO},
+	{0xD717, UNICODE_NORM_QC_NO},
+	{0xD718, UNICODE_NORM_QC_NO},
+	{0xD719, UNICODE_NORM_QC_NO},
+	{0xD71A, UNICODE_NORM_QC_NO},
+	{0xD71B, UNICODE_NORM_QC_NO},
+	{0xD71C, UNICODE_NORM_QC_NO},
+	{0xD71D, UNICODE_NORM_QC_NO},
+	{0xD71E, UNICODE_NORM_QC_NO},
+	{0xD71F, UNICODE_NORM_QC_NO},
+	{0xD720, UNICODE_NORM_QC_NO},
+	{0xD721, UNICODE_NORM_QC_NO},
+	{0xD722, UNICODE_NORM_QC_NO},
+	{0xD723, UNICODE_NORM_QC_NO},
+	{0xD724, UNICODE_NORM_QC_NO},
+	{0xD725, UNICODE_NORM_QC_NO},
+	{0xD726, UNICODE_NORM_QC_NO},
+	{0xD727, UNICODE_NORM_QC_NO},
+	{0xD728, UNICODE_NORM_QC_NO},
+	{0xD729, UNICODE_NORM_QC_NO},
+	{0xD72A, UNICODE_NORM_QC_NO},
+	{0xD72B, UNICODE_NORM_QC_NO},
+	{0xD72C, UNICODE_NORM_QC_NO},
+	{0xD72D, UNICODE_NORM_QC_NO},
+	{0xD72E, UNICODE_NORM_QC_NO},
+	{0xD72F, UNICODE_NORM_QC_NO},
+	{0xD730, UNICODE_NORM_QC_NO},
+	{0xD731, UNICODE_NORM_QC_NO},
+	{0xD732, UNICODE_NORM_QC_NO},
+	{0xD733, UNICODE_NORM_QC_NO},
+	{0xD734, UNICODE_NORM_QC_NO},
+	{0xD735, UNICODE_NORM_QC_NO},
+	{0xD736, UNICODE_NORM_QC_NO},
+	{0xD737, UNICODE_NORM_QC_NO},
+	{0xD738, UNICODE_NORM_QC_NO},
+	{0xD739, UNICODE_NORM_QC_NO},
+	{0xD73A, UNICODE_NORM_QC_NO},
+	{0xD73B, UNICODE_NORM_QC_NO},
+	{0xD73C, UNICODE_NORM_QC_NO},
+	{0xD73D, UNICODE_NORM_QC_NO},
+	{0xD73E, UNICODE_NORM_QC_NO},
+	{0xD73F, UNICODE_NORM_QC_NO},
+	{0xD740, UNICODE_NORM_QC_NO},
+	{0xD741, UNICODE_NORM_QC_NO},
+	{0xD742, UNICODE_NORM_QC_NO},
+	{0xD743, UNICODE_NORM_QC_NO},
+	{0xD744, UNICODE_NORM_QC_NO},
+	{0xD745, UNICODE_NORM_QC_NO},
+	{0xD746, UNICODE_NORM_QC_NO},
+	{0xD747, UNICODE_NORM_QC_NO},
+	{0xD748, UNICODE_NORM_QC_NO},
+	{0xD749, UNICODE_NORM_QC_NO},
+	{0xD74A, UNICODE_NORM_QC_NO},
+	{0xD74B, UNICODE_NORM_QC_NO},
+	{0xD74C, UNICODE_NORM_QC_NO},
+	{0xD74D, UNICODE_NORM_QC_NO},
+	{0xD74E, UNICODE_NORM_QC_NO},
+	{0xD74F, UNICODE_NORM_QC_NO},
+	{0xD750, UNICODE_NORM_QC_NO},
+	{0xD751, UNICODE_NORM_QC_NO},
+	{0xD752, UNICODE_NORM_QC_NO},
+	{0xD753, UNICODE_NORM_QC_NO},
+	{0xD754, UNICODE_NORM_QC_NO},
+	{0xD755, UNICODE_NORM_QC_NO},
+	{0xD756, UNICODE_NORM_QC_NO},
+	{0xD757, UNICODE_NORM_QC_NO},
+	{0xD758, UNICODE_NORM_QC_NO},
+	{0xD759, UNICODE_NORM_QC_NO},
+	{0xD75A, UNICODE_NORM_QC_NO},
+	{0xD75B, UNICODE_NORM_QC_NO},
+	{0xD75C, UNICODE_NORM_QC_NO},
+	{0xD75D, UNICODE_NORM_QC_NO},
+	{0xD75E, UNICODE_NORM_QC_NO},
+	{0xD75F, UNICODE_NORM_QC_NO},
+	{0xD760, UNICODE_NORM_QC_NO},
+	{0xD761, UNICODE_NORM_QC_NO},
+	{0xD762, UNICODE_NORM_QC_NO},
+	{0xD763, UNICODE_NORM_QC_NO},
+	{0xD764, UNICODE_NORM_QC_NO},
+	{0xD765, UNICODE_NORM_QC_NO},
+	{0xD766, UNICODE_NORM_QC_NO},
+	{0xD767, UNICODE_NORM_QC_NO},
+	{0xD768, UNICODE_NORM_QC_NO},
+	{0xD769, UNICODE_NORM_QC_NO},
+	{0xD76A, UNICODE_NORM_QC_NO},
+	{0xD76B, UNICODE_NORM_QC_NO},
+	{0xD76C, UNICODE_NORM_QC_NO},
+	{0xD76D, UNICODE_NORM_QC_NO},
+	{0xD76E, UNICODE_NORM_QC_NO},
+	{0xD76F, UNICODE_NORM_QC_NO},
+	{0xD770, UNICODE_NORM_QC_NO},
+	{0xD771, UNICODE_NORM_QC_NO},
+	{0xD772, UNICODE_NORM_QC_NO},
+	{0xD773, UNICODE_NORM_QC_NO},
+	{0xD774, UNICODE_NORM_QC_NO},
+	{0xD775, UNICODE_NORM_QC_NO},
+	{0xD776, UNICODE_NORM_QC_NO},
+	{0xD777, UNICODE_NORM_QC_NO},
+	{0xD778, UNICODE_NORM_QC_NO},
+	{0xD779, UNICODE_NORM_QC_NO},
+	{0xD77A, UNICODE_NORM_QC_NO},
+	{0xD77B, UNICODE_NORM_QC_NO},
+	{0xD77C, UNICODE_NORM_QC_NO},
+	{0xD77D, UNICODE_NORM_QC_NO},
+	{0xD77E, UNICODE_NORM_QC_NO},
+	{0xD77F, UNICODE_NORM_QC_NO},
+	{0xD780, UNICODE_NORM_QC_NO},
+	{0xD781, UNICODE_NORM_QC_NO},
+	{0xD782, UNICODE_NORM_QC_NO},
+	{0xD783, UNICODE_NORM_QC_NO},
+	{0xD784, UNICODE_NORM_QC_NO},
+	{0xD785, UNICODE_NORM_QC_NO},
+	{0xD786, UNICODE_NORM_QC_NO},
+	{0xD787, UNICODE_NORM_QC_NO},
+	{0xD788, UNICODE_NORM_QC_NO},
+	{0xD789, UNICODE_NORM_QC_NO},
+	{0xD78A, UNICODE_NORM_QC_NO},
+	{0xD78B, UNICODE_NORM_QC_NO},
+	{0xD78C, UNICODE_NORM_QC_NO},
+	{0xD78D, UNICODE_NORM_QC_NO},
+	{0xD78E, UNICODE_NORM_QC_NO},
+	{0xD78F, UNICODE_NORM_QC_NO},
+	{0xD790, UNICODE_NORM_QC_NO},
+	{0xD791, UNICODE_NORM_QC_NO},
+	{0xD792, UNICODE_NORM_QC_NO},
+	{0xD793, UNICODE_NORM_QC_NO},
+	{0xD794, UNICODE_NORM_QC_NO},
+	{0xD795, UNICODE_NORM_QC_NO},
+	{0xD796, UNICODE_NORM_QC_NO},
+	{0xD797, UNICODE_NORM_QC_NO},
+	{0xD798, UNICODE_NORM_QC_NO},
+	{0xD799, UNICODE_NORM_QC_NO},
+	{0xD79A, UNICODE_NORM_QC_NO},
+	{0xD79B, UNICODE_NORM_QC_NO},
+	{0xD79C, UNICODE_NORM_QC_NO},
+	{0xD79D, UNICODE_NORM_QC_NO},
+	{0xD79E, UNICODE_NORM_QC_NO},
+	{0xD79F, UNICODE_NORM_QC_NO},
+	{0xD7A0, UNICODE_NORM_QC_NO},
+	{0xD7A1, UNICODE_NORM_QC_NO},
+	{0xD7A2, UNICODE_NORM_QC_NO},
+	{0xD7A3, UNICODE_NORM_QC_NO},
+	{0xF900, UNICODE_NORM_QC_NO},
+	{0xF901, UNICODE_NORM_QC_NO},
+	{0xF902, UNICODE_NORM_QC_NO},
+	{0xF903, UNICODE_NORM_QC_NO},
+	{0xF904, UNICODE_NORM_QC_NO},
+	{0xF905, UNICODE_NORM_QC_NO},
+	{0xF906, UNICODE_NORM_QC_NO},
+	{0xF907, UNICODE_NORM_QC_NO},
+	{0xF908, UNICODE_NORM_QC_NO},
+	{0xF909, UNICODE_NORM_QC_NO},
+	{0xF90A, UNICODE_NORM_QC_NO},
+	{0xF90B, UNICODE_NORM_QC_NO},
+	{0xF90C, UNICODE_NORM_QC_NO},
+	{0xF90D, UNICODE_NORM_QC_NO},
+	{0xF90E, UNICODE_NORM_QC_NO},
+	{0xF90F, UNICODE_NORM_QC_NO},
+	{0xF910, UNICODE_NORM_QC_NO},
+	{0xF911, UNICODE_NORM_QC_NO},
+	{0xF912, UNICODE_NORM_QC_NO},
+	{0xF913, UNICODE_NORM_QC_NO},
+	{0xF914, UNICODE_NORM_QC_NO},
+	{0xF915, UNICODE_NORM_QC_NO},
+	{0xF916, UNICODE_NORM_QC_NO},
+	{0xF917, UNICODE_NORM_QC_NO},
+	{0xF918, UNICODE_NORM_QC_NO},
+	{0xF919, UNICODE_NORM_QC_NO},
+	{0xF91A, UNICODE_NORM_QC_NO},
+	{0xF91B, UNICODE_NORM_QC_NO},
+	{0xF91C, UNICODE_NORM_QC_NO},
+	{0xF91D, UNICODE_NORM_QC_NO},
+	{0xF91E, UNICODE_NORM_QC_NO},
+	{0xF91F, UNICODE_NORM_QC_NO},
+	{0xF920, UNICODE_NORM_QC_NO},
+	{0xF921, UNICODE_NORM_QC_NO},
+	{0xF922, UNICODE_NORM_QC_NO},
+	{0xF923, UNICODE_NORM_QC_NO},
+	{0xF924, UNICODE_NORM_QC_NO},
+	{0xF925, UNICODE_NORM_QC_NO},
+	{0xF926, UNICODE_NORM_QC_NO},
+	{0xF927, UNICODE_NORM_QC_NO},
+	{0xF928, UNICODE_NORM_QC_NO},
+	{0xF929, UNICODE_NORM_QC_NO},
+	{0xF92A, UNICODE_NORM_QC_NO},
+	{0xF92B, UNICODE_NORM_QC_NO},
+	{0xF92C, UNICODE_NORM_QC_NO},
+	{0xF92D, UNICODE_NORM_QC_NO},
+	{0xF92E, UNICODE_NORM_QC_NO},
+	{0xF92F, UNICODE_NORM_QC_NO},
+	{0xF930, UNICODE_NORM_QC_NO},
+	{0xF931, UNICODE_NORM_QC_NO},
+	{0xF932, UNICODE_NORM_QC_NO},
+	{0xF933, UNICODE_NORM_QC_NO},
+	{0xF934, UNICODE_NORM_QC_NO},
+	{0xF935, UNICODE_NORM_QC_NO},
+	{0xF936, UNICODE_NORM_QC_NO},
+	{0xF937, UNICODE_NORM_QC_NO},
+	{0xF938, UNICODE_NORM_QC_NO},
+	{0xF939, UNICODE_NORM_QC_NO},
+	{0xF93A, UNICODE_NORM_QC_NO},
+	{0xF93B, UNICODE_NORM_QC_NO},
+	{0xF93C, UNICODE_NORM_QC_NO},
+	{0xF93D, UNICODE_NORM_QC_NO},
+	{0xF93E, UNICODE_NORM_QC_NO},
+	{0xF93F, UNICODE_NORM_QC_NO},
+	{0xF940, UNICODE_NORM_QC_NO},
+	{0xF941, UNICODE_NORM_QC_NO},
+	{0xF942, UNICODE_NORM_QC_NO},
+	{0xF943, UNICODE_NORM_QC_NO},
+	{0xF944, UNICODE_NORM_QC_NO},
+	{0xF945, UNICODE_NORM_QC_NO},
+	{0xF946, UNICODE_NORM_QC_NO},
+	{0xF947, UNICODE_NORM_QC_NO},
+	{0xF948, UNICODE_NORM_QC_NO},
+	{0xF949, UNICODE_NORM_QC_NO},
+	{0xF94A, UNICODE_NORM_QC_NO},
+	{0xF94B, UNICODE_NORM_QC_NO},
+	{0xF94C, UNICODE_NORM_QC_NO},
+	{0xF94D, UNICODE_NORM_QC_NO},
+	{0xF94E, UNICODE_NORM_QC_NO},
+	{0xF94F, UNICODE_NORM_QC_NO},
+	{0xF950, UNICODE_NORM_QC_NO},
+	{0xF951, UNICODE_NORM_QC_NO},
+	{0xF952, UNICODE_NORM_QC_NO},
+	{0xF953, UNICODE_NORM_QC_NO},
+	{0xF954, UNICODE_NORM_QC_NO},
+	{0xF955, UNICODE_NORM_QC_NO},
+	{0xF956, UNICODE_NORM_QC_NO},
+	{0xF957, UNICODE_NORM_QC_NO},
+	{0xF958, UNICODE_NORM_QC_NO},
+	{0xF959, UNICODE_NORM_QC_NO},
+	{0xF95A, UNICODE_NORM_QC_NO},
+	{0xF95B, UNICODE_NORM_QC_NO},
+	{0xF95C, UNICODE_NORM_QC_NO},
+	{0xF95D, UNICODE_NORM_QC_NO},
+	{0xF95E, UNICODE_NORM_QC_NO},
+	{0xF95F, UNICODE_NORM_QC_NO},
+	{0xF960, UNICODE_NORM_QC_NO},
+	{0xF961, UNICODE_NORM_QC_NO},
+	{0xF962, UNICODE_NORM_QC_NO},
+	{0xF963, UNICODE_NORM_QC_NO},
+	{0xF964, UNICODE_NORM_QC_NO},
+	{0xF965, UNICODE_NORM_QC_NO},
+	{0xF966, UNICODE_NORM_QC_NO},
+	{0xF967, UNICODE_NORM_QC_NO},
+	{0xF968, UNICODE_NORM_QC_NO},
+	{0xF969, UNICODE_NORM_QC_NO},
+	{0xF96A, UNICODE_NORM_QC_NO},
+	{0xF96B, UNICODE_NORM_QC_NO},
+	{0xF96C, UNICODE_NORM_QC_NO},
+	{0xF96D, UNICODE_NORM_QC_NO},
+	{0xF96E, UNICODE_NORM_QC_NO},
+	{0xF96F, UNICODE_NORM_QC_NO},
+	{0xF970, UNICODE_NORM_QC_NO},
+	{0xF971, UNICODE_NORM_QC_NO},
+	{0xF972, UNICODE_NORM_QC_NO},
+	{0xF973, UNICODE_NORM_QC_NO},
+	{0xF974, UNICODE_NORM_QC_NO},
+	{0xF975, UNICODE_NORM_QC_NO},
+	{0xF976, UNICODE_NORM_QC_NO},
+	{0xF977, UNICODE_NORM_QC_NO},
+	{0xF978, UNICODE_NORM_QC_NO},
+	{0xF979, UNICODE_NORM_QC_NO},
+	{0xF97A, UNICODE_NORM_QC_NO},
+	{0xF97B, UNICODE_NORM_QC_NO},
+	{0xF97C, UNICODE_NORM_QC_NO},
+	{0xF97D, UNICODE_NORM_QC_NO},
+	{0xF97E, UNICODE_NORM_QC_NO},
+	{0xF97F, UNICODE_NORM_QC_NO},
+	{0xF980, UNICODE_NORM_QC_NO},
+	{0xF981, UNICODE_NORM_QC_NO},
+	{0xF982, UNICODE_NORM_QC_NO},
+	{0xF983, UNICODE_NORM_QC_NO},
+	{0xF984, UNICODE_NORM_QC_NO},
+	{0xF985, UNICODE_NORM_QC_NO},
+	{0xF986, UNICODE_NORM_QC_NO},
+	{0xF987, UNICODE_NORM_QC_NO},
+	{0xF988, UNICODE_NORM_QC_NO},
+	{0xF989, UNICODE_NORM_QC_NO},
+	{0xF98A, UNICODE_NORM_QC_NO},
+	{0xF98B, UNICODE_NORM_QC_NO},
+	{0xF98C, UNICODE_NORM_QC_NO},
+	{0xF98D, UNICODE_NORM_QC_NO},
+	{0xF98E, UNICODE_NORM_QC_NO},
+	{0xF98F, UNICODE_NORM_QC_NO},
+	{0xF990, UNICODE_NORM_QC_NO},
+	{0xF991, UNICODE_NORM_QC_NO},
+	{0xF992, UNICODE_NORM_QC_NO},
+	{0xF993, UNICODE_NORM_QC_NO},
+	{0xF994, UNICODE_NORM_QC_NO},
+	{0xF995, UNICODE_NORM_QC_NO},
+	{0xF996, UNICODE_NORM_QC_NO},
+	{0xF997, UNICODE_NORM_QC_NO},
+	{0xF998, UNICODE_NORM_QC_NO},
+	{0xF999, UNICODE_NORM_QC_NO},
+	{0xF99A, UNICODE_NORM_QC_NO},
+	{0xF99B, UNICODE_NORM_QC_NO},
+	{0xF99C, UNICODE_NORM_QC_NO},
+	{0xF99D, UNICODE_NORM_QC_NO},
+	{0xF99E, UNICODE_NORM_QC_NO},
+	{0xF99F, UNICODE_NORM_QC_NO},
+	{0xF9A0, UNICODE_NORM_QC_NO},
+	{0xF9A1, UNICODE_NORM_QC_NO},
+	{0xF9A2, UNICODE_NORM_QC_NO},
+	{0xF9A3, UNICODE_NORM_QC_NO},
+	{0xF9A4, UNICODE_NORM_QC_NO},
+	{0xF9A5, UNICODE_NORM_QC_NO},
+	{0xF9A6, UNICODE_NORM_QC_NO},
+	{0xF9A7, UNICODE_NORM_QC_NO},
+	{0xF9A8, UNICODE_NORM_QC_NO},
+	{0xF9A9, UNICODE_NORM_QC_NO},
+	{0xF9AA, UNICODE_NORM_QC_NO},
+	{0xF9AB, UNICODE_NORM_QC_NO},
+	{0xF9AC, UNICODE_NORM_QC_NO},
+	{0xF9AD, UNICODE_NORM_QC_NO},
+	{0xF9AE, UNICODE_NORM_QC_NO},
+	{0xF9AF, UNICODE_NORM_QC_NO},
+	{0xF9B0, UNICODE_NORM_QC_NO},
+	{0xF9B1, UNICODE_NORM_QC_NO},
+	{0xF9B2, UNICODE_NORM_QC_NO},
+	{0xF9B3, UNICODE_NORM_QC_NO},
+	{0xF9B4, UNICODE_NORM_QC_NO},
+	{0xF9B5, UNICODE_NORM_QC_NO},
+	{0xF9B6, UNICODE_NORM_QC_NO},
+	{0xF9B7, UNICODE_NORM_QC_NO},
+	{0xF9B8, UNICODE_NORM_QC_NO},
+	{0xF9B9, UNICODE_NORM_QC_NO},
+	{0xF9BA, UNICODE_NORM_QC_NO},
+	{0xF9BB, UNICODE_NORM_QC_NO},
+	{0xF9BC, UNICODE_NORM_QC_NO},
+	{0xF9BD, UNICODE_NORM_QC_NO},
+	{0xF9BE, UNICODE_NORM_QC_NO},
+	{0xF9BF, UNICODE_NORM_QC_NO},
+	{0xF9C0, UNICODE_NORM_QC_NO},
+	{0xF9C1, UNICODE_NORM_QC_NO},
+	{0xF9C2, UNICODE_NORM_QC_NO},
+	{0xF9C3, UNICODE_NORM_QC_NO},
+	{0xF9C4, UNICODE_NORM_QC_NO},
+	{0xF9C5, UNICODE_NORM_QC_NO},
+	{0xF9C6, UNICODE_NORM_QC_NO},
+	{0xF9C7, UNICODE_NORM_QC_NO},
+	{0xF9C8, UNICODE_NORM_QC_NO},
+	{0xF9C9, UNICODE_NORM_QC_NO},
+	{0xF9CA, UNICODE_NORM_QC_NO},
+	{0xF9CB, UNICODE_NORM_QC_NO},
+	{0xF9CC, UNICODE_NORM_QC_NO},
+	{0xF9CD, UNICODE_NORM_QC_NO},
+	{0xF9CE, UNICODE_NORM_QC_NO},
+	{0xF9CF, UNICODE_NORM_QC_NO},
+	{0xF9D0, UNICODE_NORM_QC_NO},
+	{0xF9D1, UNICODE_NORM_QC_NO},
+	{0xF9D2, UNICODE_NORM_QC_NO},
+	{0xF9D3, UNICODE_NORM_QC_NO},
+	{0xF9D4, UNICODE_NORM_QC_NO},
+	{0xF9D5, UNICODE_NORM_QC_NO},
+	{0xF9D6, UNICODE_NORM_QC_NO},
+	{0xF9D7, UNICODE_NORM_QC_NO},
+	{0xF9D8, UNICODE_NORM_QC_NO},
+	{0xF9D9, UNICODE_NORM_QC_NO},
+	{0xF9DA, UNICODE_NORM_QC_NO},
+	{0xF9DB, UNICODE_NORM_QC_NO},
+	{0xF9DC, UNICODE_NORM_QC_NO},
+	{0xF9DD, UNICODE_NORM_QC_NO},
+	{0xF9DE, UNICODE_NORM_QC_NO},
+	{0xF9DF, UNICODE_NORM_QC_NO},
+	{0xF9E0, UNICODE_NORM_QC_NO},
+	{0xF9E1, UNICODE_NORM_QC_NO},
+	{0xF9E2, UNICODE_NORM_QC_NO},
+	{0xF9E3, UNICODE_NORM_QC_NO},
+	{0xF9E4, UNICODE_NORM_QC_NO},
+	{0xF9E5, UNICODE_NORM_QC_NO},
+	{0xF9E6, UNICODE_NORM_QC_NO},
+	{0xF9E7, UNICODE_NORM_QC_NO},
+	{0xF9E8, UNICODE_NORM_QC_NO},
+	{0xF9E9, UNICODE_NORM_QC_NO},
+	{0xF9EA, UNICODE_NORM_QC_NO},
+	{0xF9EB, UNICODE_NORM_QC_NO},
+	{0xF9EC, UNICODE_NORM_QC_NO},
+	{0xF9ED, UNICODE_NORM_QC_NO},
+	{0xF9EE, UNICODE_NORM_QC_NO},
+	{0xF9EF, UNICODE_NORM_QC_NO},
+	{0xF9F0, UNICODE_NORM_QC_NO},
+	{0xF9F1, UNICODE_NORM_QC_NO},
+	{0xF9F2, UNICODE_NORM_QC_NO},
+	{0xF9F3, UNICODE_NORM_QC_NO},
+	{0xF9F4, UNICODE_NORM_QC_NO},
+	{0xF9F5, UNICODE_NORM_QC_NO},
+	{0xF9F6, UNICODE_NORM_QC_NO},
+	{0xF9F7, UNICODE_NORM_QC_NO},
+	{0xF9F8, UNICODE_NORM_QC_NO},
+	{0xF9F9, UNICODE_NORM_QC_NO},
+	{0xF9FA, UNICODE_NORM_QC_NO},
+	{0xF9FB, UNICODE_NORM_QC_NO},
+	{0xF9FC, UNICODE_NORM_QC_NO},
+	{0xF9FD, UNICODE_NORM_QC_NO},
+	{0xF9FE, UNICODE_NORM_QC_NO},
+	{0xF9FF, UNICODE_NORM_QC_NO},
+	{0xFA00, UNICODE_NORM_QC_NO},
+	{0xFA01, UNICODE_NORM_QC_NO},
+	{0xFA02, UNICODE_NORM_QC_NO},
+	{0xFA03, UNICODE_NORM_QC_NO},
+	{0xFA04, UNICODE_NORM_QC_NO},
+	{0xFA05, UNICODE_NORM_QC_NO},
+	{0xFA06, UNICODE_NORM_QC_NO},
+	{0xFA07, UNICODE_NORM_QC_NO},
+	{0xFA08, UNICODE_NORM_QC_NO},
+	{0xFA09, UNICODE_NORM_QC_NO},
+	{0xFA0A, UNICODE_NORM_QC_NO},
+	{0xFA0B, UNICODE_NORM_QC_NO},
+	{0xFA0C, UNICODE_NORM_QC_NO},
+	{0xFA0D, UNICODE_NORM_QC_NO},
+	{0xFA10, UNICODE_NORM_QC_NO},
+	{0xFA12, UNICODE_NORM_QC_NO},
+	{0xFA15, UNICODE_NORM_QC_NO},
+	{0xFA16, UNICODE_NORM_QC_NO},
+	{0xFA17, UNICODE_NORM_QC_NO},
+	{0xFA18, UNICODE_NORM_QC_NO},
+	{0xFA19, UNICODE_NORM_QC_NO},
+	{0xFA1A, UNICODE_NORM_QC_NO},
+	{0xFA1B, UNICODE_NORM_QC_NO},
+	{0xFA1C, UNICODE_NORM_QC_NO},
+	{0xFA1D, UNICODE_NORM_QC_NO},
+	{0xFA1E, UNICODE_NORM_QC_NO},
+	{0xFA20, UNICODE_NORM_QC_NO},
+	{0xFA22, UNICODE_NORM_QC_NO},
+	{0xFA25, UNICODE_NORM_QC_NO},
+	{0xFA26, UNICODE_NORM_QC_NO},
+	{0xFA2A, UNICODE_NORM_QC_NO},
+	{0xFA2B, UNICODE_NORM_QC_NO},
+	{0xFA2C, UNICODE_NORM_QC_NO},
+	{0xFA2D, UNICODE_NORM_QC_NO},
+	{0xFA2E, UNICODE_NORM_QC_NO},
+	{0xFA2F, UNICODE_NORM_QC_NO},
+	{0xFA30, UNICODE_NORM_QC_NO},
+	{0xFA31, UNICODE_NORM_QC_NO},
+	{0xFA32, UNICODE_NORM_QC_NO},
+	{0xFA33, UNICODE_NORM_QC_NO},
+	{0xFA34, UNICODE_NORM_QC_NO},
+	{0xFA35, UNICODE_NORM_QC_NO},
+	{0xFA36, UNICODE_NORM_QC_NO},
+	{0xFA37, UNICODE_NORM_QC_NO},
+	{0xFA38, UNICODE_NORM_QC_NO},
+	{0xFA39, UNICODE_NORM_QC_NO},
+	{0xFA3A, UNICODE_NORM_QC_NO},
+	{0xFA3B, UNICODE_NORM_QC_NO},
+	{0xFA3C, UNICODE_NORM_QC_NO},
+	{0xFA3D, UNICODE_NORM_QC_NO},
+	{0xFA3E, UNICODE_NORM_QC_NO},
+	{0xFA3F, UNICODE_NORM_QC_NO},
+	{0xFA40, UNICODE_NORM_QC_NO},
+	{0xFA41, UNICODE_NORM_QC_NO},
+	{0xFA42, UNICODE_NORM_QC_NO},
+	{0xFA43, UNICODE_NORM_QC_NO},
+	{0xFA44, UNICODE_NORM_QC_NO},
+	{0xFA45, UNICODE_NORM_QC_NO},
+	{0xFA46, UNICODE_NORM_QC_NO},
+	{0xFA47, UNICODE_NORM_QC_NO},
+	{0xFA48, UNICODE_NORM_QC_NO},
+	{0xFA49, UNICODE_NORM_QC_NO},
+	{0xFA4A, UNICODE_NORM_QC_NO},
+	{0xFA4B, UNICODE_NORM_QC_NO},
+	{0xFA4C, UNICODE_NORM_QC_NO},
+	{0xFA4D, UNICODE_NORM_QC_NO},
+	{0xFA4E, UNICODE_NORM_QC_NO},
+	{0xFA4F, UNICODE_NORM_QC_NO},
+	{0xFA50, UNICODE_NORM_QC_NO},
+	{0xFA51, UNICODE_NORM_QC_NO},
+	{0xFA52, UNICODE_NORM_QC_NO},
+	{0xFA53, UNICODE_NORM_QC_NO},
+	{0xFA54, UNICODE_NORM_QC_NO},
+	{0xFA55, UNICODE_NORM_QC_NO},
+	{0xFA56, UNICODE_NORM_QC_NO},
+	{0xFA57, UNICODE_NORM_QC_NO},
+	{0xFA58, UNICODE_NORM_QC_NO},
+	{0xFA59, UNICODE_NORM_QC_NO},
+	{0xFA5A, UNICODE_NORM_QC_NO},
+	{0xFA5B, UNICODE_NORM_QC_NO},
+	{0xFA5C, UNICODE_NORM_QC_NO},
+	{0xFA5D, UNICODE_NORM_QC_NO},
+	{0xFA5E, UNICODE_NORM_QC_NO},
+	{0xFA5F, UNICODE_NORM_QC_NO},
+	{0xFA60, UNICODE_NORM_QC_NO},
+	{0xFA61, UNICODE_NORM_QC_NO},
+	{0xFA62, UNICODE_NORM_QC_NO},
+	{0xFA63, UNICODE_NORM_QC_NO},
+	{0xFA64, UNICODE_NORM_QC_NO},
+	{0xFA65, UNICODE_NORM_QC_NO},
+	{0xFA66, UNICODE_NORM_QC_NO},
+	{0xFA67, UNICODE_NORM_QC_NO},
+	{0xFA68, UNICODE_NORM_QC_NO},
+	{0xFA69, UNICODE_NORM_QC_NO},
+	{0xFA6A, UNICODE_NORM_QC_NO},
+	{0xFA6B, UNICODE_NORM_QC_NO},
+	{0xFA6C, UNICODE_NORM_QC_NO},
+	{0xFA6D, UNICODE_NORM_QC_NO},
+	{0xFA70, UNICODE_NORM_QC_NO},
+	{0xFA71, UNICODE_NORM_QC_NO},
+	{0xFA72, UNICODE_NORM_QC_NO},
+	{0xFA73, UNICODE_NORM_QC_NO},
+	{0xFA74, UNICODE_NORM_QC_NO},
+	{0xFA75, UNICODE_NORM_QC_NO},
+	{0xFA76, UNICODE_NORM_QC_NO},
+	{0xFA77, UNICODE_NORM_QC_NO},
+	{0xFA78, UNICODE_NORM_QC_NO},
+	{0xFA79, UNICODE_NORM_QC_NO},
+	{0xFA7A, UNICODE_NORM_QC_NO},
+	{0xFA7B, UNICODE_NORM_QC_NO},
+	{0xFA7C, UNICODE_NORM_QC_NO},
+	{0xFA7D, UNICODE_NORM_QC_NO},
+	{0xFA7E, UNICODE_NORM_QC_NO},
+	{0xFA7F, UNICODE_NORM_QC_NO},
+	{0xFA80, UNICODE_NORM_QC_NO},
+	{0xFA81, UNICODE_NORM_QC_NO},
+	{0xFA82, UNICODE_NORM_QC_NO},
+	{0xFA83, UNICODE_NORM_QC_NO},
+	{0xFA84, UNICODE_NORM_QC_NO},
+	{0xFA85, UNICODE_NORM_QC_NO},
+	{0xFA86, UNICODE_NORM_QC_NO},
+	{0xFA87, UNICODE_NORM_QC_NO},
+	{0xFA88, UNICODE_NORM_QC_NO},
+	{0xFA89, UNICODE_NORM_QC_NO},
+	{0xFA8A, UNICODE_NORM_QC_NO},
+	{0xFA8B, UNICODE_NORM_QC_NO},
+	{0xFA8C, UNICODE_NORM_QC_NO},
+	{0xFA8D, UNICODE_NORM_QC_NO},
+	{0xFA8E, UNICODE_NORM_QC_NO},
+	{0xFA8F, UNICODE_NORM_QC_NO},
+	{0xFA90, UNICODE_NORM_QC_NO},
+	{0xFA91, UNICODE_NORM_QC_NO},
+	{0xFA92, UNICODE_NORM_QC_NO},
+	{0xFA93, UNICODE_NORM_QC_NO},
+	{0xFA94, UNICODE_NORM_QC_NO},
+	{0xFA95, UNICODE_NORM_QC_NO},
+	{0xFA96, UNICODE_NORM_QC_NO},
+	{0xFA97, UNICODE_NORM_QC_NO},
+	{0xFA98, UNICODE_NORM_QC_NO},
+	{0xFA99, UNICODE_NORM_QC_NO},
+	{0xFA9A, UNICODE_NORM_QC_NO},
+	{0xFA9B, UNICODE_NORM_QC_NO},
+	{0xFA9C, UNICODE_NORM_QC_NO},
+	{0xFA9D, UNICODE_NORM_QC_NO},
+	{0xFA9E, UNICODE_NORM_QC_NO},
+	{0xFA9F, UNICODE_NORM_QC_NO},
+	{0xFAA0, UNICODE_NORM_QC_NO},
+	{0xFAA1, UNICODE_NORM_QC_NO},
+	{0xFAA2, UNICODE_NORM_QC_NO},
+	{0xFAA3, UNICODE_NORM_QC_NO},
+	{0xFAA4, UNICODE_NORM_QC_NO},
+	{0xFAA5, UNICODE_NORM_QC_NO},
+	{0xFAA6, UNICODE_NORM_QC_NO},
+	{0xFAA7, UNICODE_NORM_QC_NO},
+	{0xFAA8, UNICODE_NORM_QC_NO},
+	{0xFAA9, UNICODE_NORM_QC_NO},
+	{0xFAAA, UNICODE_NORM_QC_NO},
+	{0xFAAB, UNICODE_NORM_QC_NO},
+	{0xFAAC, UNICODE_NORM_QC_NO},
+	{0xFAAD, UNICODE_NORM_QC_NO},
+	{0xFAAE, UNICODE_NORM_QC_NO},
+	{0xFAAF, UNICODE_NORM_QC_NO},
+	{0xFAB0, UNICODE_NORM_QC_NO},
+	{0xFAB1, UNICODE_NORM_QC_NO},
+	{0xFAB2, UNICODE_NORM_QC_NO},
+	{0xFAB3, UNICODE_NORM_QC_NO},
+	{0xFAB4, UNICODE_NORM_QC_NO},
+	{0xFAB5, UNICODE_NORM_QC_NO},
+	{0xFAB6, UNICODE_NORM_QC_NO},
+	{0xFAB7, UNICODE_NORM_QC_NO},
+	{0xFAB8, UNICODE_NORM_QC_NO},
+	{0xFAB9, UNICODE_NORM_QC_NO},
+	{0xFABA, UNICODE_NORM_QC_NO},
+	{0xFABB, UNICODE_NORM_QC_NO},
+	{0xFABC, UNICODE_NORM_QC_NO},
+	{0xFABD, UNICODE_NORM_QC_NO},
+	{0xFABE, UNICODE_NORM_QC_NO},
+	{0xFABF, UNICODE_NORM_QC_NO},
+	{0xFAC0, UNICODE_NORM_QC_NO},
+	{0xFAC1, UNICODE_NORM_QC_NO},
+	{0xFAC2, UNICODE_NORM_QC_NO},
+	{0xFAC3, UNICODE_NORM_QC_NO},
+	{0xFAC4, UNICODE_NORM_QC_NO},
+	{0xFAC5, UNICODE_NORM_QC_NO},
+	{0xFAC6, UNICODE_NORM_QC_NO},
+	{0xFAC7, UNICODE_NORM_QC_NO},
+	{0xFAC8, UNICODE_NORM_QC_NO},
+	{0xFAC9, UNICODE_NORM_QC_NO},
+	{0xFACA, UNICODE_NORM_QC_NO},
+	{0xFACB, UNICODE_NORM_QC_NO},
+	{0xFACC, UNICODE_NORM_QC_NO},
+	{0xFACD, UNICODE_NORM_QC_NO},
+	{0xFACE, UNICODE_NORM_QC_NO},
+	{0xFACF, UNICODE_NORM_QC_NO},
+	{0xFAD0, UNICODE_NORM_QC_NO},
+	{0xFAD1, UNICODE_NORM_QC_NO},
+	{0xFAD2, UNICODE_NORM_QC_NO},
+	{0xFAD3, UNICODE_NORM_QC_NO},
+	{0xFAD4, UNICODE_NORM_QC_NO},
+	{0xFAD5, UNICODE_NORM_QC_NO},
+	{0xFAD6, UNICODE_NORM_QC_NO},
+	{0xFAD7, UNICODE_NORM_QC_NO},
+	{0xFAD8, UNICODE_NORM_QC_NO},
+	{0xFAD9, UNICODE_NORM_QC_NO},
+	{0xFB1D, UNICODE_NORM_QC_NO},
+	{0xFB1F, UNICODE_NORM_QC_NO},
+	{0xFB2A, UNICODE_NORM_QC_NO},
+	{0xFB2B, UNICODE_NORM_QC_NO},
+	{0xFB2C, UNICODE_NORM_QC_NO},
+	{0xFB2D, UNICODE_NORM_QC_NO},
+	{0xFB2E, UNICODE_NORM_QC_NO},
+	{0xFB2F, UNICODE_NORM_QC_NO},
+	{0xFB30, UNICODE_NORM_QC_NO},
+	{0xFB31, UNICODE_NORM_QC_NO},
+	{0xFB32, UNICODE_NORM_QC_NO},
+	{0xFB33, UNICODE_NORM_QC_NO},
+	{0xFB34, UNICODE_NORM_QC_NO},
+	{0xFB35, UNICODE_NORM_QC_NO},
+	{0xFB36, UNICODE_NORM_QC_NO},
+	{0xFB38, UNICODE_NORM_QC_NO},
+	{0xFB39, UNICODE_NORM_QC_NO},
+	{0xFB3A, UNICODE_NORM_QC_NO},
+	{0xFB3B, UNICODE_NORM_QC_NO},
+	{0xFB3C, UNICODE_NORM_QC_NO},
+	{0xFB3E, UNICODE_NORM_QC_NO},
+	{0xFB40, UNICODE_NORM_QC_NO},
+	{0xFB41, UNICODE_NORM_QC_NO},
+	{0xFB43, UNICODE_NORM_QC_NO},
+	{0xFB44, UNICODE_NORM_QC_NO},
+	{0xFB46, UNICODE_NORM_QC_NO},
+	{0xFB47, UNICODE_NORM_QC_NO},
+	{0xFB48, UNICODE_NORM_QC_NO},
+	{0xFB49, UNICODE_NORM_QC_NO},
+	{0xFB4A, UNICODE_NORM_QC_NO},
+	{0xFB4B, UNICODE_NORM_QC_NO},
+	{0xFB4C, UNICODE_NORM_QC_NO},
+	{0xFB4D, UNICODE_NORM_QC_NO},
+	{0xFB4E, UNICODE_NORM_QC_NO},
+	{0x1109A, UNICODE_NORM_QC_NO},
+	{0x1109C, UNICODE_NORM_QC_NO},
+	{0x110AB, UNICODE_NORM_QC_NO},
+	{0x1112E, UNICODE_NORM_QC_NO},
+	{0x1112F, UNICODE_NORM_QC_NO},
+	{0x1134B, UNICODE_NORM_QC_NO},
+	{0x1134C, UNICODE_NORM_QC_NO},
+	{0x114BB, UNICODE_NORM_QC_NO},
+	{0x114BC, UNICODE_NORM_QC_NO},
+	{0x114BE, UNICODE_NORM_QC_NO},
+	{0x115BA, UNICODE_NORM_QC_NO},
+	{0x115BB, UNICODE_NORM_QC_NO},
+	{0x1D15E, UNICODE_NORM_QC_NO},
+	{0x1D15F, UNICODE_NORM_QC_NO},
+	{0x1D160, UNICODE_NORM_QC_NO},
+	{0x1D161, UNICODE_NORM_QC_NO},
+	{0x1D162, UNICODE_NORM_QC_NO},
+	{0x1D163, UNICODE_NORM_QC_NO},
+	{0x1D164, UNICODE_NORM_QC_NO},
+	{0x1D1BB, UNICODE_NORM_QC_NO},
+	{0x1D1BC, UNICODE_NORM_QC_NO},
+	{0x1D1BD, UNICODE_NORM_QC_NO},
+	{0x1D1BE, UNICODE_NORM_QC_NO},
+	{0x1D1BF, UNICODE_NORM_QC_NO},
+	{0x1D1C0, UNICODE_NORM_QC_NO},
+	{0x2F800, UNICODE_NORM_QC_NO},
+	{0x2F801, UNICODE_NORM_QC_NO},
+	{0x2F802, UNICODE_NORM_QC_NO},
+	{0x2F803, UNICODE_NORM_QC_NO},
+	{0x2F804, UNICODE_NORM_QC_NO},
+	{0x2F805, UNICODE_NORM_QC_NO},
+	{0x2F806, UNICODE_NORM_QC_NO},
+	{0x2F807, UNICODE_NORM_QC_NO},
+	{0x2F808, UNICODE_NORM_QC_NO},
+	{0x2F809, UNICODE_NORM_QC_NO},
+	{0x2F80A, UNICODE_NORM_QC_NO},
+	{0x2F80B, UNICODE_NORM_QC_NO},
+	{0x2F80C, UNICODE_NORM_QC_NO},
+	{0x2F80D, UNICODE_NORM_QC_NO},
+	{0x2F80E, UNICODE_NORM_QC_NO},
+	{0x2F80F, UNICODE_NORM_QC_NO},
+	{0x2F810, UNICODE_NORM_QC_NO},
+	{0x2F811, UNICODE_NORM_QC_NO},
+	{0x2F812, UNICODE_NORM_QC_NO},
+	{0x2F813, UNICODE_NORM_QC_NO},
+	{0x2F814, UNICODE_NORM_QC_NO},
+	{0x2F815, UNICODE_NORM_QC_NO},
+	{0x2F816, UNICODE_NORM_QC_NO},
+	{0x2F817, UNICODE_NORM_QC_NO},
+	{0x2F818, UNICODE_NORM_QC_NO},
+	{0x2F819, UNICODE_NORM_QC_NO},
+	{0x2F81A, UNICODE_NORM_QC_NO},
+	{0x2F81B, UNICODE_NORM_QC_NO},
+	{0x2F81C, UNICODE_NORM_QC_NO},
+	{0x2F81D, UNICODE_NORM_QC_NO},
+	{0x2F81E, UNICODE_NORM_QC_NO},
+	{0x2F81F, UNICODE_NORM_QC_NO},
+	{0x2F820, UNICODE_NORM_QC_NO},
+	{0x2F821, UNICODE_NORM_QC_NO},
+	{0x2F822, UNICODE_NORM_QC_NO},
+	{0x2F823, UNICODE_NORM_QC_NO},
+	{0x2F824, UNICODE_NORM_QC_NO},
+	{0x2F825, UNICODE_NORM_QC_NO},
+	{0x2F826, UNICODE_NORM_QC_NO},
+	{0x2F827, UNICODE_NORM_QC_NO},
+	{0x2F828, UNICODE_NORM_QC_NO},
+	{0x2F829, UNICODE_NORM_QC_NO},
+	{0x2F82A, UNICODE_NORM_QC_NO},
+	{0x2F82B, UNICODE_NORM_QC_NO},
+	{0x2F82C, UNICODE_NORM_QC_NO},
+	{0x2F82D, UNICODE_NORM_QC_NO},
+	{0x2F82E, UNICODE_NORM_QC_NO},
+	{0x2F82F, UNICODE_NORM_QC_NO},
+	{0x2F830, UNICODE_NORM_QC_NO},
+	{0x2F831, UNICODE_NORM_QC_NO},
+	{0x2F832, UNICODE_NORM_QC_NO},
+	{0x2F833, UNICODE_NORM_QC_NO},
+	{0x2F834, UNICODE_NORM_QC_NO},
+	{0x2F835, UNICODE_NORM_QC_NO},
+	{0x2F836, UNICODE_NORM_QC_NO},
+	{0x2F837, UNICODE_NORM_QC_NO},
+	{0x2F838, UNICODE_NORM_QC_NO},
+	{0x2F839, UNICODE_NORM_QC_NO},
+	{0x2F83A, UNICODE_NORM_QC_NO},
+	{0x2F83B, UNICODE_NORM_QC_NO},
+	{0x2F83C, UNICODE_NORM_QC_NO},
+	{0x2F83D, UNICODE_NORM_QC_NO},
+	{0x2F83E, UNICODE_NORM_QC_NO},
+	{0x2F83F, UNICODE_NORM_QC_NO},
+	{0x2F840, UNICODE_NORM_QC_NO},
+	{0x2F841, UNICODE_NORM_QC_NO},
+	{0x2F842, UNICODE_NORM_QC_NO},
+	{0x2F843, UNICODE_NORM_QC_NO},
+	{0x2F844, UNICODE_NORM_QC_NO},
+	{0x2F845, UNICODE_NORM_QC_NO},
+	{0x2F846, UNICODE_NORM_QC_NO},
+	{0x2F847, UNICODE_NORM_QC_NO},
+	{0x2F848, UNICODE_NORM_QC_NO},
+	{0x2F849, UNICODE_NORM_QC_NO},
+	{0x2F84A, UNICODE_NORM_QC_NO},
+	{0x2F84B, UNICODE_NORM_QC_NO},
+	{0x2F84C, UNICODE_NORM_QC_NO},
+	{0x2F84D, UNICODE_NORM_QC_NO},
+	{0x2F84E, UNICODE_NORM_QC_NO},
+	{0x2F84F, UNICODE_NORM_QC_NO},
+	{0x2F850, UNICODE_NORM_QC_NO},
+	{0x2F851, UNICODE_NORM_QC_NO},
+	{0x2F852, UNICODE_NORM_QC_NO},
+	{0x2F853, UNICODE_NORM_QC_NO},
+	{0x2F854, UNICODE_NORM_QC_NO},
+	{0x2F855, UNICODE_NORM_QC_NO},
+	{0x2F856, UNICODE_NORM_QC_NO},
+	{0x2F857, UNICODE_NORM_QC_NO},
+	{0x2F858, UNICODE_NORM_QC_NO},
+	{0x2F859, UNICODE_NORM_QC_NO},
+	{0x2F85A, UNICODE_NORM_QC_NO},
+	{0x2F85B, UNICODE_NORM_QC_NO},
+	{0x2F85C, UNICODE_NORM_QC_NO},
+	{0x2F85D, UNICODE_NORM_QC_NO},
+	{0x2F85E, UNICODE_NORM_QC_NO},
+	{0x2F85F, UNICODE_NORM_QC_NO},
+	{0x2F860, UNICODE_NORM_QC_NO},
+	{0x2F861, UNICODE_NORM_QC_NO},
+	{0x2F862, UNICODE_NORM_QC_NO},
+	{0x2F863, UNICODE_NORM_QC_NO},
+	{0x2F864, UNICODE_NORM_QC_NO},
+	{0x2F865, UNICODE_NORM_QC_NO},
+	{0x2F866, UNICODE_NORM_QC_NO},
+	{0x2F867, UNICODE_NORM_QC_NO},
+	{0x2F868, UNICODE_NORM_QC_NO},
+	{0x2F869, UNICODE_NORM_QC_NO},
+	{0x2F86A, UNICODE_NORM_QC_NO},
+	{0x2F86B, UNICODE_NORM_QC_NO},
+	{0x2F86C, UNICODE_NORM_QC_NO},
+	{0x2F86D, UNICODE_NORM_QC_NO},
+	{0x2F86E, UNICODE_NORM_QC_NO},
+	{0x2F86F, UNICODE_NORM_QC_NO},
+	{0x2F870, UNICODE_NORM_QC_NO},
+	{0x2F871, UNICODE_NORM_QC_NO},
+	{0x2F872, UNICODE_NORM_QC_NO},
+	{0x2F873, UNICODE_NORM_QC_NO},
+	{0x2F874, UNICODE_NORM_QC_NO},
+	{0x2F875, UNICODE_NORM_QC_NO},
+	{0x2F876, UNICODE_NORM_QC_NO},
+	{0x2F877, UNICODE_NORM_QC_NO},
+	{0x2F878, UNICODE_NORM_QC_NO},
+	{0x2F879, UNICODE_NORM_QC_NO},
+	{0x2F87A, UNICODE_NORM_QC_NO},
+	{0x2F87B, UNICODE_NORM_QC_NO},
+	{0x2F87C, UNICODE_NORM_QC_NO},
+	{0x2F87D, UNICODE_NORM_QC_NO},
+	{0x2F87E, UNICODE_NORM_QC_NO},
+	{0x2F87F, UNICODE_NORM_QC_NO},
+	{0x2F880, UNICODE_NORM_QC_NO},
+	{0x2F881, UNICODE_NORM_QC_NO},
+	{0x2F882, UNICODE_NORM_QC_NO},
+	{0x2F883, UNICODE_NORM_QC_NO},
+	{0x2F884, UNICODE_NORM_QC_NO},
+	{0x2F885, UNICODE_NORM_QC_NO},
+	{0x2F886, UNICODE_NORM_QC_NO},
+	{0x2F887, UNICODE_NORM_QC_NO},
+	{0x2F888, UNICODE_NORM_QC_NO},
+	{0x2F889, UNICODE_NORM_QC_NO},
+	{0x2F88A, UNICODE_NORM_QC_NO},
+	{0x2F88B, UNICODE_NORM_QC_NO},
+	{0x2F88C, UNICODE_NORM_QC_NO},
+	{0x2F88D, UNICODE_NORM_QC_NO},
+	{0x2F88E, UNICODE_NORM_QC_NO},
+	{0x2F88F, UNICODE_NORM_QC_NO},
+	{0x2F890, UNICODE_NORM_QC_NO},
+	{0x2F891, UNICODE_NORM_QC_NO},
+	{0x2F892, UNICODE_NORM_QC_NO},
+	{0x2F893, UNICODE_NORM_QC_NO},
+	{0x2F894, UNICODE_NORM_QC_NO},
+	{0x2F895, UNICODE_NORM_QC_NO},
+	{0x2F896, UNICODE_NORM_QC_NO},
+	{0x2F897, UNICODE_NORM_QC_NO},
+	{0x2F898, UNICODE_NORM_QC_NO},
+	{0x2F899, UNICODE_NORM_QC_NO},
+	{0x2F89A, UNICODE_NORM_QC_NO},
+	{0x2F89B, UNICODE_NORM_QC_NO},
+	{0x2F89C, UNICODE_NORM_QC_NO},
+	{0x2F89D, UNICODE_NORM_QC_NO},
+	{0x2F89E, UNICODE_NORM_QC_NO},
+	{0x2F89F, UNICODE_NORM_QC_NO},
+	{0x2F8A0, UNICODE_NORM_QC_NO},
+	{0x2F8A1, UNICODE_NORM_QC_NO},
+	{0x2F8A2, UNICODE_NORM_QC_NO},
+	{0x2F8A3, UNICODE_NORM_QC_NO},
+	{0x2F8A4, UNICODE_NORM_QC_NO},
+	{0x2F8A5, UNICODE_NORM_QC_NO},
+	{0x2F8A6, UNICODE_NORM_QC_NO},
+	{0x2F8A7, UNICODE_NORM_QC_NO},
+	{0x2F8A8, UNICODE_NORM_QC_NO},
+	{0x2F8A9, UNICODE_NORM_QC_NO},
+	{0x2F8AA, UNICODE_NORM_QC_NO},
+	{0x2F8AB, UNICODE_NORM_QC_NO},
+	{0x2F8AC, UNICODE_NORM_QC_NO},
+	{0x2F8AD, UNICODE_NORM_QC_NO},
+	{0x2F8AE, UNICODE_NORM_QC_NO},
+	{0x2F8AF, UNICODE_NORM_QC_NO},
+	{0x2F8B0, UNICODE_NORM_QC_NO},
+	{0x2F8B1, UNICODE_NORM_QC_NO},
+	{0x2F8B2, UNICODE_NORM_QC_NO},
+	{0x2F8B3, UNICODE_NORM_QC_NO},
+	{0x2F8B4, UNICODE_NORM_QC_NO},
+	{0x2F8B5, UNICODE_NORM_QC_NO},
+	{0x2F8B6, UNICODE_NORM_QC_NO},
+	{0x2F8B7, UNICODE_NORM_QC_NO},
+	{0x2F8B8, UNICODE_NORM_QC_NO},
+	{0x2F8B9, UNICODE_NORM_QC_NO},
+	{0x2F8BA, UNICODE_NORM_QC_NO},
+	{0x2F8BB, UNICODE_NORM_QC_NO},
+	{0x2F8BC, UNICODE_NORM_QC_NO},
+	{0x2F8BD, UNICODE_NORM_QC_NO},
+	{0x2F8BE, UNICODE_NORM_QC_NO},
+	{0x2F8BF, UNICODE_NORM_QC_NO},
+	{0x2F8C0, UNICODE_NORM_QC_NO},
+	{0x2F8C1, UNICODE_NORM_QC_NO},
+	{0x2F8C2, UNICODE_NORM_QC_NO},
+	{0x2F8C3, UNICODE_NORM_QC_NO},
+	{0x2F8C4, UNICODE_NORM_QC_NO},
+	{0x2F8C5, UNICODE_NORM_QC_NO},
+	{0x2F8C6, UNICODE_NORM_QC_NO},
+	{0x2F8C7, UNICODE_NORM_QC_NO},
+	{0x2F8C8, UNICODE_NORM_QC_NO},
+	{0x2F8C9, UNICODE_NORM_QC_NO},
+	{0x2F8CA, UNICODE_NORM_QC_NO},
+	{0x2F8CB, UNICODE_NORM_QC_NO},
+	{0x2F8CC, UNICODE_NORM_QC_NO},
+	{0x2F8CD, UNICODE_NORM_QC_NO},
+	{0x2F8CE, UNICODE_NORM_QC_NO},
+	{0x2F8CF, UNICODE_NORM_QC_NO},
+	{0x2F8D0, UNICODE_NORM_QC_NO},
+	{0x2F8D1, UNICODE_NORM_QC_NO},
+	{0x2F8D2, UNICODE_NORM_QC_NO},
+	{0x2F8D3, UNICODE_NORM_QC_NO},
+	{0x2F8D4, UNICODE_NORM_QC_NO},
+	{0x2F8D5, UNICODE_NORM_QC_NO},
+	{0x2F8D6, UNICODE_NORM_QC_NO},
+	{0x2F8D7, UNICODE_NORM_QC_NO},
+	{0x2F8D8, UNICODE_NORM_QC_NO},
+	{0x2F8D9, UNICODE_NORM_QC_NO},
+	{0x2F8DA, UNICODE_NORM_QC_NO},
+	{0x2F8DB, UNICODE_NORM_QC_NO},
+	{0x2F8DC, UNICODE_NORM_QC_NO},
+	{0x2F8DD, UNICODE_NORM_QC_NO},
+	{0x2F8DE, UNICODE_NORM_QC_NO},
+	{0x2F8DF, UNICODE_NORM_QC_NO},
+	{0x2F8E0, UNICODE_NORM_QC_NO},
+	{0x2F8E1, UNICODE_NORM_QC_NO},
+	{0x2F8E2, UNICODE_NORM_QC_NO},
+	{0x2F8E3, UNICODE_NORM_QC_NO},
+	{0x2F8E4, UNICODE_NORM_QC_NO},
+	{0x2F8E5, UNICODE_NORM_QC_NO},
+	{0x2F8E6, UNICODE_NORM_QC_NO},
+	{0x2F8E7, UNICODE_NORM_QC_NO},
+	{0x2F8E8, UNICODE_NORM_QC_NO},
+	{0x2F8E9, UNICODE_NORM_QC_NO},
+	{0x2F8EA, UNICODE_NORM_QC_NO},
+	{0x2F8EB, UNICODE_NORM_QC_NO},
+	{0x2F8EC, UNICODE_NORM_QC_NO},
+	{0x2F8ED, UNICODE_NORM_QC_NO},
+	{0x2F8EE, UNICODE_NORM_QC_NO},
+	{0x2F8EF, UNICODE_NORM_QC_NO},
+	{0x2F8F0, UNICODE_NORM_QC_NO},
+	{0x2F8F1, UNICODE_NORM_QC_NO},
+	{0x2F8F2, UNICODE_NORM_QC_NO},
+	{0x2F8F3, UNICODE_NORM_QC_NO},
+	{0x2F8F4, UNICODE_NORM_QC_NO},
+	{0x2F8F5, UNICODE_NORM_QC_NO},
+	{0x2F8F6, UNICODE_NORM_QC_NO},
+	{0x2F8F7, UNICODE_NORM_QC_NO},
+	{0x2F8F8, UNICODE_NORM_QC_NO},
+	{0x2F8F9, UNICODE_NORM_QC_NO},
+	{0x2F8FA, UNICODE_NORM_QC_NO},
+	{0x2F8FB, UNICODE_NORM_QC_NO},
+	{0x2F8FC, UNICODE_NORM_QC_NO},
+	{0x2F8FD, UNICODE_NORM_QC_NO},
+	{0x2F8FE, UNICODE_NORM_QC_NO},
+	{0x2F8FF, UNICODE_NORM_QC_NO},
+	{0x2F900, UNICODE_NORM_QC_NO},
+	{0x2F901, UNICODE_NORM_QC_NO},
+	{0x2F902, UNICODE_NORM_QC_NO},
+	{0x2F903, UNICODE_NORM_QC_NO},
+	{0x2F904, UNICODE_NORM_QC_NO},
+	{0x2F905, UNICODE_NORM_QC_NO},
+	{0x2F906, UNICODE_NORM_QC_NO},
+	{0x2F907, UNICODE_NORM_QC_NO},
+	{0x2F908, UNICODE_NORM_QC_NO},
+	{0x2F909, UNICODE_NORM_QC_NO},
+	{0x2F90A, UNICODE_NORM_QC_NO},
+	{0x2F90B, UNICODE_NORM_QC_NO},
+	{0x2F90C, UNICODE_NORM_QC_NO},
+	{0x2F90D, UNICODE_NORM_QC_NO},
+	{0x2F90E, UNICODE_NORM_QC_NO},
+	{0x2F90F, UNICODE_NORM_QC_NO},
+	{0x2F910, UNICODE_NORM_QC_NO},
+	{0x2F911, UNICODE_NORM_QC_NO},
+	{0x2F912, UNICODE_NORM_QC_NO},
+	{0x2F913, UNICODE_NORM_QC_NO},
+	{0x2F914, UNICODE_NORM_QC_NO},
+	{0x2F915, UNICODE_NORM_QC_NO},
+	{0x2F916, UNICODE_NORM_QC_NO},
+	{0x2F917, UNICODE_NORM_QC_NO},
+	{0x2F918, UNICODE_NORM_QC_NO},
+	{0x2F919, UNICODE_NORM_QC_NO},
+	{0x2F91A, UNICODE_NORM_QC_NO},
+	{0x2F91B, UNICODE_NORM_QC_NO},
+	{0x2F91C, UNICODE_NORM_QC_NO},
+	{0x2F91D, UNICODE_NORM_QC_NO},
+	{0x2F91E, UNICODE_NORM_QC_NO},
+	{0x2F91F, UNICODE_NORM_QC_NO},
+	{0x2F920, UNICODE_NORM_QC_NO},
+	{0x2F921, UNICODE_NORM_QC_NO},
+	{0x2F922, UNICODE_NORM_QC_NO},
+	{0x2F923, UNICODE_NORM_QC_NO},
+	{0x2F924, UNICODE_NORM_QC_NO},
+	{0x2F925, UNICODE_NORM_QC_NO},
+	{0x2F926, UNICODE_NORM_QC_NO},
+	{0x2F927, UNICODE_NORM_QC_NO},
+	{0x2F928, UNICODE_NORM_QC_NO},
+	{0x2F929, UNICODE_NORM_QC_NO},
+	{0x2F92A, UNICODE_NORM_QC_NO},
+	{0x2F92B, UNICODE_NORM_QC_NO},
+	{0x2F92C, UNICODE_NORM_QC_NO},
+	{0x2F92D, UNICODE_NORM_QC_NO},
+	{0x2F92E, UNICODE_NORM_QC_NO},
+	{0x2F92F, UNICODE_NORM_QC_NO},
+	{0x2F930, UNICODE_NORM_QC_NO},
+	{0x2F931, UNICODE_NORM_QC_NO},
+	{0x2F932, UNICODE_NORM_QC_NO},
+	{0x2F933, UNICODE_NORM_QC_NO},
+	{0x2F934, UNICODE_NORM_QC_NO},
+	{0x2F935, UNICODE_NORM_QC_NO},
+	{0x2F936, UNICODE_NORM_QC_NO},
+	{0x2F937, UNICODE_NORM_QC_NO},
+	{0x2F938, UNICODE_NORM_QC_NO},
+	{0x2F939, UNICODE_NORM_QC_NO},
+	{0x2F93A, UNICODE_NORM_QC_NO},
+	{0x2F93B, UNICODE_NORM_QC_NO},
+	{0x2F93C, UNICODE_NORM_QC_NO},
+	{0x2F93D, UNICODE_NORM_QC_NO},
+	{0x2F93E, UNICODE_NORM_QC_NO},
+	{0x2F93F, UNICODE_NORM_QC_NO},
+	{0x2F940, UNICODE_NORM_QC_NO},
+	{0x2F941, UNICODE_NORM_QC_NO},
+	{0x2F942, UNICODE_NORM_QC_NO},
+	{0x2F943, UNICODE_NORM_QC_NO},
+	{0x2F944, UNICODE_NORM_QC_NO},
+	{0x2F945, UNICODE_NORM_QC_NO},
+	{0x2F946, UNICODE_NORM_QC_NO},
+	{0x2F947, UNICODE_NORM_QC_NO},
+	{0x2F948, UNICODE_NORM_QC_NO},
+	{0x2F949, UNICODE_NORM_QC_NO},
+	{0x2F94A, UNICODE_NORM_QC_NO},
+	{0x2F94B, UNICODE_NORM_QC_NO},
+	{0x2F94C, UNICODE_NORM_QC_NO},
+	{0x2F94D, UNICODE_NORM_QC_NO},
+	{0x2F94E, UNICODE_NORM_QC_NO},
+	{0x2F94F, UNICODE_NORM_QC_NO},
+	{0x2F950, UNICODE_NORM_QC_NO},
+	{0x2F951, UNICODE_NORM_QC_NO},
+	{0x2F952, UNICODE_NORM_QC_NO},
+	{0x2F953, UNICODE_NORM_QC_NO},
+	{0x2F954, UNICODE_NORM_QC_NO},
+	{0x2F955, UNICODE_NORM_QC_NO},
+	{0x2F956, UNICODE_NORM_QC_NO},
+	{0x2F957, UNICODE_NORM_QC_NO},
+	{0x2F958, UNICODE_NORM_QC_NO},
+	{0x2F959, UNICODE_NORM_QC_NO},
+	{0x2F95A, UNICODE_NORM_QC_NO},
+	{0x2F95B, UNICODE_NORM_QC_NO},
+	{0x2F95C, UNICODE_NORM_QC_NO},
+	{0x2F95D, UNICODE_NORM_QC_NO},
+	{0x2F95E, UNICODE_NORM_QC_NO},
+	{0x2F95F, UNICODE_NORM_QC_NO},
+	{0x2F960, UNICODE_NORM_QC_NO},
+	{0x2F961, UNICODE_NORM_QC_NO},
+	{0x2F962, UNICODE_NORM_QC_NO},
+	{0x2F963, UNICODE_NORM_QC_NO},
+	{0x2F964, UNICODE_NORM_QC_NO},
+	{0x2F965, UNICODE_NORM_QC_NO},
+	{0x2F966, UNICODE_NORM_QC_NO},
+	{0x2F967, UNICODE_NORM_QC_NO},
+	{0x2F968, UNICODE_NORM_QC_NO},
+	{0x2F969, UNICODE_NORM_QC_NO},
+	{0x2F96A, UNICODE_NORM_QC_NO},
+	{0x2F96B, UNICODE_NORM_QC_NO},
+	{0x2F96C, UNICODE_NORM_QC_NO},
+	{0x2F96D, UNICODE_NORM_QC_NO},
+	{0x2F96E, UNICODE_NORM_QC_NO},
+	{0x2F96F, UNICODE_NORM_QC_NO},
+	{0x2F970, UNICODE_NORM_QC_NO},
+	{0x2F971, UNICODE_NORM_QC_NO},
+	{0x2F972, UNICODE_NORM_QC_NO},
+	{0x2F973, UNICODE_NORM_QC_NO},
+	{0x2F974, UNICODE_NORM_QC_NO},
+	{0x2F975, UNICODE_NORM_QC_NO},
+	{0x2F976, UNICODE_NORM_QC_NO},
+	{0x2F977, UNICODE_NORM_QC_NO},
+	{0x2F978, UNICODE_NORM_QC_NO},
+	{0x2F979, UNICODE_NORM_QC_NO},
+	{0x2F97A, UNICODE_NORM_QC_NO},
+	{0x2F97B, UNICODE_NORM_QC_NO},
+	{0x2F97C, UNICODE_NORM_QC_NO},
+	{0x2F97D, UNICODE_NORM_QC_NO},
+	{0x2F97E, UNICODE_NORM_QC_NO},
+	{0x2F97F, UNICODE_NORM_QC_NO},
+	{0x2F980, UNICODE_NORM_QC_NO},
+	{0x2F981, UNICODE_NORM_QC_NO},
+	{0x2F982, UNICODE_NORM_QC_NO},
+	{0x2F983, UNICODE_NORM_QC_NO},
+	{0x2F984, UNICODE_NORM_QC_NO},
+	{0x2F985, UNICODE_NORM_QC_NO},
+	{0x2F986, UNICODE_NORM_QC_NO},
+	{0x2F987, UNICODE_NORM_QC_NO},
+	{0x2F988, UNICODE_NORM_QC_NO},
+	{0x2F989, UNICODE_NORM_QC_NO},
+	{0x2F98A, UNICODE_NORM_QC_NO},
+	{0x2F98B, UNICODE_NORM_QC_NO},
+	{0x2F98C, UNICODE_NORM_QC_NO},
+	{0x2F98D, UNICODE_NORM_QC_NO},
+	{0x2F98E, UNICODE_NORM_QC_NO},
+	{0x2F98F, UNICODE_NORM_QC_NO},
+	{0x2F990, UNICODE_NORM_QC_NO},
+	{0x2F991, UNICODE_NORM_QC_NO},
+	{0x2F992, UNICODE_NORM_QC_NO},
+	{0x2F993, UNICODE_NORM_QC_NO},
+	{0x2F994, UNICODE_NORM_QC_NO},
+	{0x2F995, UNICODE_NORM_QC_NO},
+	{0x2F996, UNICODE_NORM_QC_NO},
+	{0x2F997, UNICODE_NORM_QC_NO},
+	{0x2F998, UNICODE_NORM_QC_NO},
+	{0x2F999, UNICODE_NORM_QC_NO},
+	{0x2F99A, UNICODE_NORM_QC_NO},
+	{0x2F99B, UNICODE_NORM_QC_NO},
+	{0x2F99C, UNICODE_NORM_QC_NO},
+	{0x2F99D, UNICODE_NORM_QC_NO},
+	{0x2F99E, UNICODE_NORM_QC_NO},
+	{0x2F99F, UNICODE_NORM_QC_NO},
+	{0x2F9A0, UNICODE_NORM_QC_NO},
+	{0x2F9A1, UNICODE_NORM_QC_NO},
+	{0x2F9A2, UNICODE_NORM_QC_NO},
+	{0x2F9A3, UNICODE_NORM_QC_NO},
+	{0x2F9A4, UNICODE_NORM_QC_NO},
+	{0x2F9A5, UNICODE_NORM_QC_NO},
+	{0x2F9A6, UNICODE_NORM_QC_NO},
+	{0x2F9A7, UNICODE_NORM_QC_NO},
+	{0x2F9A8, UNICODE_NORM_QC_NO},
+	{0x2F9A9, UNICODE_NORM_QC_NO},
+	{0x2F9AA, UNICODE_NORM_QC_NO},
+	{0x2F9AB, UNICODE_NORM_QC_NO},
+	{0x2F9AC, UNICODE_NORM_QC_NO},
+	{0x2F9AD, UNICODE_NORM_QC_NO},
+	{0x2F9AE, UNICODE_NORM_QC_NO},
+	{0x2F9AF, UNICODE_NORM_QC_NO},
+	{0x2F9B0, UNICODE_NORM_QC_NO},
+	{0x2F9B1, UNICODE_NORM_QC_NO},
+	{0x2F9B2, UNICODE_NORM_QC_NO},
+	{0x2F9B3, UNICODE_NORM_QC_NO},
+	{0x2F9B4, UNICODE_NORM_QC_NO},
+	{0x2F9B5, UNICODE_NORM_QC_NO},
+	{0x2F9B6, UNICODE_NORM_QC_NO},
+	{0x2F9B7, UNICODE_NORM_QC_NO},
+	{0x2F9B8, UNICODE_NORM_QC_NO},
+	{0x2F9B9, UNICODE_NORM_QC_NO},
+	{0x2F9BA, UNICODE_NORM_QC_NO},
+	{0x2F9BB, UNICODE_NORM_QC_NO},
+	{0x2F9BC, UNICODE_NORM_QC_NO},
+	{0x2F9BD, UNICODE_NORM_QC_NO},
+	{0x2F9BE, UNICODE_NORM_QC_NO},
+	{0x2F9BF, UNICODE_NORM_QC_NO},
+	{0x2F9C0, UNICODE_NORM_QC_NO},
+	{0x2F9C1, UNICODE_NORM_QC_NO},
+	{0x2F9C2, UNICODE_NORM_QC_NO},
+	{0x2F9C3, UNICODE_NORM_QC_NO},
+	{0x2F9C4, UNICODE_NORM_QC_NO},
+	{0x2F9C5, UNICODE_NORM_QC_NO},
+	{0x2F9C6, UNICODE_NORM_QC_NO},
+	{0x2F9C7, UNICODE_NORM_QC_NO},
+	{0x2F9C8, UNICODE_NORM_QC_NO},
+	{0x2F9C9, UNICODE_NORM_QC_NO},
+	{0x2F9CA, UNICODE_NORM_QC_NO},
+	{0x2F9CB, UNICODE_NORM_QC_NO},
+	{0x2F9CC, UNICODE_NORM_QC_NO},
+	{0x2F9CD, UNICODE_NORM_QC_NO},
+	{0x2F9CE, UNICODE_NORM_QC_NO},
+	{0x2F9CF, UNICODE_NORM_QC_NO},
+	{0x2F9D0, UNICODE_NORM_QC_NO},
+	{0x2F9D1, UNICODE_NORM_QC_NO},
+	{0x2F9D2, UNICODE_NORM_QC_NO},
+	{0x2F9D3, UNICODE_NORM_QC_NO},
+	{0x2F9D4, UNICODE_NORM_QC_NO},
+	{0x2F9D5, UNICODE_NORM_QC_NO},
+	{0x2F9D6, UNICODE_NORM_QC_NO},
+	{0x2F9D7, UNICODE_NORM_QC_NO},
+	{0x2F9D8, UNICODE_NORM_QC_NO},
+	{0x2F9D9, UNICODE_NORM_QC_NO},
+	{0x2F9DA, UNICODE_NORM_QC_NO},
+	{0x2F9DB, UNICODE_NORM_QC_NO},
+	{0x2F9DC, UNICODE_NORM_QC_NO},
+	{0x2F9DD, UNICODE_NORM_QC_NO},
+	{0x2F9DE, UNICODE_NORM_QC_NO},
+	{0x2F9DF, UNICODE_NORM_QC_NO},
+	{0x2F9E0, UNICODE_NORM_QC_NO},
+	{0x2F9E1, UNICODE_NORM_QC_NO},
+	{0x2F9E2, UNICODE_NORM_QC_NO},
+	{0x2F9E3, UNICODE_NORM_QC_NO},
+	{0x2F9E4, UNICODE_NORM_QC_NO},
+	{0x2F9E5, UNICODE_NORM_QC_NO},
+	{0x2F9E6, UNICODE_NORM_QC_NO},
+	{0x2F9E7, UNICODE_NORM_QC_NO},
+	{0x2F9E8, UNICODE_NORM_QC_NO},
+	{0x2F9E9, UNICODE_NORM_QC_NO},
+	{0x2F9EA, UNICODE_NORM_QC_NO},
+	{0x2F9EB, UNICODE_NORM_QC_NO},
+	{0x2F9EC, UNICODE_NORM_QC_NO},
+	{0x2F9ED, UNICODE_NORM_QC_NO},
+	{0x2F9EE, UNICODE_NORM_QC_NO},
+	{0x2F9EF, UNICODE_NORM_QC_NO},
+	{0x2F9F0, UNICODE_NORM_QC_NO},
+	{0x2F9F1, UNICODE_NORM_QC_NO},
+	{0x2F9F2, UNICODE_NORM_QC_NO},
+	{0x2F9F3, UNICODE_NORM_QC_NO},
+	{0x2F9F4, UNICODE_NORM_QC_NO},
+	{0x2F9F5, UNICODE_NORM_QC_NO},
+	{0x2F9F6, UNICODE_NORM_QC_NO},
+	{0x2F9F7, UNICODE_NORM_QC_NO},
+	{0x2F9F8, UNICODE_NORM_QC_NO},
+	{0x2F9F9, UNICODE_NORM_QC_NO},
+	{0x2F9FA, UNICODE_NORM_QC_NO},
+	{0x2F9FB, UNICODE_NORM_QC_NO},
+	{0x2F9FC, UNICODE_NORM_QC_NO},
+	{0x2F9FD, UNICODE_NORM_QC_NO},
+	{0x2F9FE, UNICODE_NORM_QC_NO},
+	{0x2F9FF, UNICODE_NORM_QC_NO},
+	{0x2FA00, UNICODE_NORM_QC_NO},
+	{0x2FA01, UNICODE_NORM_QC_NO},
+	{0x2FA02, UNICODE_NORM_QC_NO},
+	{0x2FA03, UNICODE_NORM_QC_NO},
+	{0x2FA04, UNICODE_NORM_QC_NO},
+	{0x2FA05, UNICODE_NORM_QC_NO},
+	{0x2FA06, UNICODE_NORM_QC_NO},
+	{0x2FA07, UNICODE_NORM_QC_NO},
+	{0x2FA08, UNICODE_NORM_QC_NO},
+	{0x2FA09, UNICODE_NORM_QC_NO},
+	{0x2FA0A, UNICODE_NORM_QC_NO},
+	{0x2FA0B, UNICODE_NORM_QC_NO},
+	{0x2FA0C, UNICODE_NORM_QC_NO},
+	{0x2FA0D, UNICODE_NORM_QC_NO},
+	{0x2FA0E, UNICODE_NORM_QC_NO},
+	{0x2FA0F, UNICODE_NORM_QC_NO},
+	{0x2FA10, UNICODE_NORM_QC_NO},
+	{0x2FA11, UNICODE_NORM_QC_NO},
+	{0x2FA12, UNICODE_NORM_QC_NO},
+	{0x2FA13, UNICODE_NORM_QC_NO},
+	{0x2FA14, UNICODE_NORM_QC_NO},
+	{0x2FA15, UNICODE_NORM_QC_NO},
+	{0x2FA16, UNICODE_NORM_QC_NO},
+	{0x2FA17, UNICODE_NORM_QC_NO},
+	{0x2FA18, UNICODE_NORM_QC_NO},
+	{0x2FA19, UNICODE_NORM_QC_NO},
+	{0x2FA1A, UNICODE_NORM_QC_NO},
+	{0x2FA1B, UNICODE_NORM_QC_NO},
+	{0x2FA1C, UNICODE_NORM_QC_NO},
+	{0x2FA1D, UNICODE_NORM_QC_NO},
+};
+
+static const pg_unicode_normprops UnicodeNormProps_NFKC_QC[] = {
+	{0x00A0, UNICODE_NORM_QC_NO},
+	{0x00A8, UNICODE_NORM_QC_NO},
+	{0x00AA, UNICODE_NORM_QC_NO},
+	{0x00AF, UNICODE_NORM_QC_NO},
+	{0x00B2, UNICODE_NORM_QC_NO},
+	{0x00B3, UNICODE_NORM_QC_NO},
+	{0x00B4, UNICODE_NORM_QC_NO},
+	{0x00B5, UNICODE_NORM_QC_NO},
+	{0x00B8, UNICODE_NORM_QC_NO},
+	{0x00B9, UNICODE_NORM_QC_NO},
+	{0x00BA, UNICODE_NORM_QC_NO},
+	{0x00BC, UNICODE_NORM_QC_NO},
+	{0x00BD, UNICODE_NORM_QC_NO},
+	{0x00BE, UNICODE_NORM_QC_NO},
+	{0x0132, UNICODE_NORM_QC_NO},
+	{0x0133, UNICODE_NORM_QC_NO},
+	{0x013F, UNICODE_NORM_QC_NO},
+	{0x0140, UNICODE_NORM_QC_NO},
+	{0x0149, UNICODE_NORM_QC_NO},
+	{0x017F, UNICODE_NORM_QC_NO},
+	{0x01C4, UNICODE_NORM_QC_NO},
+	{0x01C5, UNICODE_NORM_QC_NO},
+	{0x01C6, UNICODE_NORM_QC_NO},
+	{0x01C7, UNICODE_NORM_QC_NO},
+	{0x01C8, UNICODE_NORM_QC_NO},
+	{0x01C9, UNICODE_NORM_QC_NO},
+	{0x01CA, UNICODE_NORM_QC_NO},
+	{0x01CB, UNICODE_NORM_QC_NO},
+	{0x01CC, UNICODE_NORM_QC_NO},
+	{0x01F1, UNICODE_NORM_QC_NO},
+	{0x01F2, UNICODE_NORM_QC_NO},
+	{0x01F3, UNICODE_NORM_QC_NO},
+	{0x02B0, UNICODE_NORM_QC_NO},
+	{0x02B1, UNICODE_NORM_QC_NO},
+	{0x02B2, UNICODE_NORM_QC_NO},
+	{0x02B3, UNICODE_NORM_QC_NO},
+	{0x02B4, UNICODE_NORM_QC_NO},
+	{0x02B5, UNICODE_NORM_QC_NO},
+	{0x02B6, UNICODE_NORM_QC_NO},
+	{0x02B7, UNICODE_NORM_QC_NO},
+	{0x02B8, UNICODE_NORM_QC_NO},
+	{0x02D8, UNICODE_NORM_QC_NO},
+	{0x02D9, UNICODE_NORM_QC_NO},
+	{0x02DA, UNICODE_NORM_QC_NO},
+	{0x02DB, UNICODE_NORM_QC_NO},
+	{0x02DC, UNICODE_NORM_QC_NO},
+	{0x02DD, UNICODE_NORM_QC_NO},
+	{0x02E0, UNICODE_NORM_QC_NO},
+	{0x02E1, UNICODE_NORM_QC_NO},
+	{0x02E2, UNICODE_NORM_QC_NO},
+	{0x02E3, UNICODE_NORM_QC_NO},
+	{0x02E4, UNICODE_NORM_QC_NO},
+	{0x0300, UNICODE_NORM_QC_MAYBE},
+	{0x0301, UNICODE_NORM_QC_MAYBE},
+	{0x0302, UNICODE_NORM_QC_MAYBE},
+	{0x0303, UNICODE_NORM_QC_MAYBE},
+	{0x0304, UNICODE_NORM_QC_MAYBE},
+	{0x0306, UNICODE_NORM_QC_MAYBE},
+	{0x0307, UNICODE_NORM_QC_MAYBE},
+	{0x0308, UNICODE_NORM_QC_MAYBE},
+	{0x0309, UNICODE_NORM_QC_MAYBE},
+	{0x030A, UNICODE_NORM_QC_MAYBE},
+	{0x030B, UNICODE_NORM_QC_MAYBE},
+	{0x030C, UNICODE_NORM_QC_MAYBE},
+	{0x030F, UNICODE_NORM_QC_MAYBE},
+	{0x0311, UNICODE_NORM_QC_MAYBE},
+	{0x0313, UNICODE_NORM_QC_MAYBE},
+	{0x0314, UNICODE_NORM_QC_MAYBE},
+	{0x031B, UNICODE_NORM_QC_MAYBE},
+	{0x0323, UNICODE_NORM_QC_MAYBE},
+	{0x0324, UNICODE_NORM_QC_MAYBE},
+	{0x0325, UNICODE_NORM_QC_MAYBE},
+	{0x0326, UNICODE_NORM_QC_MAYBE},
+	{0x0327, UNICODE_NORM_QC_MAYBE},
+	{0x0328, UNICODE_NORM_QC_MAYBE},
+	{0x032D, UNICODE_NORM_QC_MAYBE},
+	{0x032E, UNICODE_NORM_QC_MAYBE},
+	{0x0330, UNICODE_NORM_QC_MAYBE},
+	{0x0331, UNICODE_NORM_QC_MAYBE},
+	{0x0338, UNICODE_NORM_QC_MAYBE},
+	{0x0340, UNICODE_NORM_QC_NO},
+	{0x0341, UNICODE_NORM_QC_NO},
+	{0x0342, UNICODE_NORM_QC_MAYBE},
+	{0x0343, UNICODE_NORM_QC_NO},
+	{0x0344, UNICODE_NORM_QC_NO},
+	{0x0345, UNICODE_NORM_QC_MAYBE},
+	{0x0374, UNICODE_NORM_QC_NO},
+	{0x037A, UNICODE_NORM_QC_NO},
+	{0x037E, UNICODE_NORM_QC_NO},
+	{0x0384, UNICODE_NORM_QC_NO},
+	{0x0385, UNICODE_NORM_QC_NO},
+	{0x0387, UNICODE_NORM_QC_NO},
+	{0x03D0, UNICODE_NORM_QC_NO},
+	{0x03D1, UNICODE_NORM_QC_NO},
+	{0x03D2, UNICODE_NORM_QC_NO},
+	{0x03D3, UNICODE_NORM_QC_NO},
+	{0x03D4, UNICODE_NORM_QC_NO},
+	{0x03D5, UNICODE_NORM_QC_NO},
+	{0x03D6, UNICODE_NORM_QC_NO},
+	{0x03F0, UNICODE_NORM_QC_NO},
+	{0x03F1, UNICODE_NORM_QC_NO},
+	{0x03F2, UNICODE_NORM_QC_NO},
+	{0x03F4, UNICODE_NORM_QC_NO},
+	{0x03F5, UNICODE_NORM_QC_NO},
+	{0x03F9, UNICODE_NORM_QC_NO},
+	{0x0587, UNICODE_NORM_QC_NO},
+	{0x0653, UNICODE_NORM_QC_MAYBE},
+	{0x0654, UNICODE_NORM_QC_MAYBE},
+	{0x0655, UNICODE_NORM_QC_MAYBE},
+	{0x0675, UNICODE_NORM_QC_NO},
+	{0x0676, UNICODE_NORM_QC_NO},
+	{0x0677, UNICODE_NORM_QC_NO},
+	{0x0678, UNICODE_NORM_QC_NO},
+	{0x093C, UNICODE_NORM_QC_MAYBE},
+	{0x0958, UNICODE_NORM_QC_NO},
+	{0x0959, UNICODE_NORM_QC_NO},
+	{0x095A, UNICODE_NORM_QC_NO},
+	{0x095B, UNICODE_NORM_QC_NO},
+	{0x095C, UNICODE_NORM_QC_NO},
+	{0x095D, UNICODE_NORM_QC_NO},
+	{0x095E, UNICODE_NORM_QC_NO},
+	{0x095F, UNICODE_NORM_QC_NO},
+	{0x09BE, UNICODE_NORM_QC_MAYBE},
+	{0x09D7, UNICODE_NORM_QC_MAYBE},
+	{0x09DC, UNICODE_NORM_QC_NO},
+	{0x09DD, UNICODE_NORM_QC_NO},
+	{0x09DF, UNICODE_NORM_QC_NO},
+	{0x0A33, UNICODE_NORM_QC_NO},
+	{0x0A36, UNICODE_NORM_QC_NO},
+	{0x0A59, UNICODE_NORM_QC_NO},
+	{0x0A5A, UNICODE_NORM_QC_NO},
+	{0x0A5B, UNICODE_NORM_QC_NO},
+	{0x0A5E, UNICODE_NORM_QC_NO},
+	{0x0B3E, UNICODE_NORM_QC_MAYBE},
+	{0x0B56, UNICODE_NORM_QC_MAYBE},
+	{0x0B57, UNICODE_NORM_QC_MAYBE},
+	{0x0B5C, UNICODE_NORM_QC_NO},
+	{0x0B5D, UNICODE_NORM_QC_NO},
+	{0x0BBE, UNICODE_NORM_QC_MAYBE},
+	{0x0BD7, UNICODE_NORM_QC_MAYBE},
+	{0x0C56, UNICODE_NORM_QC_MAYBE},
+	{0x0CC2, UNICODE_NORM_QC_MAYBE},
+	{0x0CD5, UNICODE_NORM_QC_MAYBE},
+	{0x0CD6, UNICODE_NORM_QC_MAYBE},
+	{0x0D3E, UNICODE_NORM_QC_MAYBE},
+	{0x0D57, UNICODE_NORM_QC_MAYBE},
+	{0x0DCA, UNICODE_NORM_QC_MAYBE},
+	{0x0DCF, UNICODE_NORM_QC_MAYBE},
+	{0x0DDF, UNICODE_NORM_QC_MAYBE},
+	{0x0E33, UNICODE_NORM_QC_NO},
+	{0x0EB3, UNICODE_NORM_QC_NO},
+	{0x0EDC, UNICODE_NORM_QC_NO},
+	{0x0EDD, UNICODE_NORM_QC_NO},
+	{0x0F0C, UNICODE_NORM_QC_NO},
+	{0x0F43, UNICODE_NORM_QC_NO},
+	{0x0F4D, UNICODE_NORM_QC_NO},
+	{0x0F52, UNICODE_NORM_QC_NO},
+	{0x0F57, UNICODE_NORM_QC_NO},
+	{0x0F5C, UNICODE_NORM_QC_NO},
+	{0x0F69, UNICODE_NORM_QC_NO},
+	{0x0F73, UNICODE_NORM_QC_NO},
+	{0x0F75, UNICODE_NORM_QC_NO},
+	{0x0F76, UNICODE_NORM_QC_NO},
+	{0x0F77, UNICODE_NORM_QC_NO},
+	{0x0F78, UNICODE_NORM_QC_NO},
+	{0x0F79, UNICODE_NORM_QC_NO},
+	{0x0F81, UNICODE_NORM_QC_NO},
+	{0x0F93, UNICODE_NORM_QC_NO},
+	{0x0F9D, UNICODE_NORM_QC_NO},
+	{0x0FA2, UNICODE_NORM_QC_NO},
+	{0x0FA7, UNICODE_NORM_QC_NO},
+	{0x0FAC, UNICODE_NORM_QC_NO},
+	{0x0FB9, UNICODE_NORM_QC_NO},
+	{0x102E, UNICODE_NORM_QC_MAYBE},
+	{0x10FC, UNICODE_NORM_QC_NO},
+	{0x1161, UNICODE_NORM_QC_MAYBE},
+	{0x1162, UNICODE_NORM_QC_MAYBE},
+	{0x1163, UNICODE_NORM_QC_MAYBE},
+	{0x1164, UNICODE_NORM_QC_MAYBE},
+	{0x1165, UNICODE_NORM_QC_MAYBE},
+	{0x1166, UNICODE_NORM_QC_MAYBE},
+	{0x1167, UNICODE_NORM_QC_MAYBE},
+	{0x1168, UNICODE_NORM_QC_MAYBE},
+	{0x1169, UNICODE_NORM_QC_MAYBE},
+	{0x116A, UNICODE_NORM_QC_MAYBE},
+	{0x116B, UNICODE_NORM_QC_MAYBE},
+	{0x116C, UNICODE_NORM_QC_MAYBE},
+	{0x116D, UNICODE_NORM_QC_MAYBE},
+	{0x116E, UNICODE_NORM_QC_MAYBE},
+	{0x116F, UNICODE_NORM_QC_MAYBE},
+	{0x1170, UNICODE_NORM_QC_MAYBE},
+	{0x1171, UNICODE_NORM_QC_MAYBE},
+	{0x1172, UNICODE_NORM_QC_MAYBE},
+	{0x1173, UNICODE_NORM_QC_MAYBE},
+	{0x1174, UNICODE_NORM_QC_MAYBE},
+	{0x1175, UNICODE_NORM_QC_MAYBE},
+	{0x11A8, UNICODE_NORM_QC_MAYBE},
+	{0x11A9, UNICODE_NORM_QC_MAYBE},
+	{0x11AA, UNICODE_NORM_QC_MAYBE},
+	{0x11AB, UNICODE_NORM_QC_MAYBE},
+	{0x11AC, UNICODE_NORM_QC_MAYBE},
+	{0x11AD, UNICODE_NORM_QC_MAYBE},
+	{0x11AE, UNICODE_NORM_QC_MAYBE},
+	{0x11AF, UNICODE_NORM_QC_MAYBE},
+	{0x11B0, UNICODE_NORM_QC_MAYBE},
+	{0x11B1, UNICODE_NORM_QC_MAYBE},
+	{0x11B2, UNICODE_NORM_QC_MAYBE},
+	{0x11B3, UNICODE_NORM_QC_MAYBE},
+	{0x11B4, UNICODE_NORM_QC_MAYBE},
+	{0x11B5, UNICODE_NORM_QC_MAYBE},
+	{0x11B6, UNICODE_NORM_QC_MAYBE},
+	{0x11B7, UNICODE_NORM_QC_MAYBE},
+	{0x11B8, UNICODE_NORM_QC_MAYBE},
+	{0x11B9, UNICODE_NORM_QC_MAYBE},
+	{0x11BA, UNICODE_NORM_QC_MAYBE},
+	{0x11BB, UNICODE_NORM_QC_MAYBE},
+	{0x11BC, UNICODE_NORM_QC_MAYBE},
+	{0x11BD, UNICODE_NORM_QC_MAYBE},
+	{0x11BE, UNICODE_NORM_QC_MAYBE},
+	{0x11BF, UNICODE_NORM_QC_MAYBE},
+	{0x11C0, UNICODE_NORM_QC_MAYBE},
+	{0x11C1, UNICODE_NORM_QC_MAYBE},
+	{0x11C2, UNICODE_NORM_QC_MAYBE},
+	{0x1B35, UNICODE_NORM_QC_MAYBE},
+	{0x1D2C, UNICODE_NORM_QC_NO},
+	{0x1D2D, UNICODE_NORM_QC_NO},
+	{0x1D2E, UNICODE_NORM_QC_NO},
+	{0x1D30, UNICODE_NORM_QC_NO},
+	{0x1D31, UNICODE_NORM_QC_NO},
+	{0x1D32, UNICODE_NORM_QC_NO},
+	{0x1D33, UNICODE_NORM_QC_NO},
+	{0x1D34, UNICODE_NORM_QC_NO},
+	{0x1D35, UNICODE_NORM_QC_NO},
+	{0x1D36, UNICODE_NORM_QC_NO},
+	{0x1D37, UNICODE_NORM_QC_NO},
+	{0x1D38, UNICODE_NORM_QC_NO},
+	{0x1D39, UNICODE_NORM_QC_NO},
+	{0x1D3A, UNICODE_NORM_QC_NO},
+	{0x1D3C, UNICODE_NORM_QC_NO},
+	{0x1D3D, UNICODE_NORM_QC_NO},
+	{0x1D3E, UNICODE_NORM_QC_NO},
+	{0x1D3F, UNICODE_NORM_QC_NO},
+	{0x1D40, UNICODE_NORM_QC_NO},
+	{0x1D41, UNICODE_NORM_QC_NO},
+	{0x1D42, UNICODE_NORM_QC_NO},
+	{0x1D43, UNICODE_NORM_QC_NO},
+	{0x1D44, UNICODE_NORM_QC_NO},
+	{0x1D45, UNICODE_NORM_QC_NO},
+	{0x1D46, UNICODE_NORM_QC_NO},
+	{0x1D47, UNICODE_NORM_QC_NO},
+	{0x1D48, UNICODE_NORM_QC_NO},
+	{0x1D49, UNICODE_NORM_QC_NO},
+	{0x1D4A, UNICODE_NORM_QC_NO},
+	{0x1D4B, UNICODE_NORM_QC_NO},
+	{0x1D4C, UNICODE_NORM_QC_NO},
+	{0x1D4D, UNICODE_NORM_QC_NO},
+	{0x1D4F, UNICODE_NORM_QC_NO},
+	{0x1D50, UNICODE_NORM_QC_NO},
+	{0x1D51, UNICODE_NORM_QC_NO},
+	{0x1D52, UNICODE_NORM_QC_NO},
+	{0x1D53, UNICODE_NORM_QC_NO},
+	{0x1D54, UNICODE_NORM_QC_NO},
+	{0x1D55, UNICODE_NORM_QC_NO},
+	{0x1D56, UNICODE_NORM_QC_NO},
+	{0x1D57, UNICODE_NORM_QC_NO},
+	{0x1D58, UNICODE_NORM_QC_NO},
+	{0x1D59, UNICODE_NORM_QC_NO},
+	{0x1D5A, UNICODE_NORM_QC_NO},
+	{0x1D5B, UNICODE_NORM_QC_NO},
+	{0x1D5C, UNICODE_NORM_QC_NO},
+	{0x1D5D, UNICODE_NORM_QC_NO},
+	{0x1D5E, UNICODE_NORM_QC_NO},
+	{0x1D5F, UNICODE_NORM_QC_NO},
+	{0x1D60, UNICODE_NORM_QC_NO},
+	{0x1D61, UNICODE_NORM_QC_NO},
+	{0x1D62, UNICODE_NORM_QC_NO},
+	{0x1D63, UNICODE_NORM_QC_NO},
+	{0x1D64, UNICODE_NORM_QC_NO},
+	{0x1D65, UNICODE_NORM_QC_NO},
+	{0x1D66, UNICODE_NORM_QC_NO},
+	{0x1D67, UNICODE_NORM_QC_NO},
+	{0x1D68, UNICODE_NORM_QC_NO},
+	{0x1D69, UNICODE_NORM_QC_NO},
+	{0x1D6A, UNICODE_NORM_QC_NO},
+	{0x1D78, UNICODE_NORM_QC_NO},
+	{0x1D9B, UNICODE_NORM_QC_NO},
+	{0x1D9C, UNICODE_NORM_QC_NO},
+	{0x1D9D, UNICODE_NORM_QC_NO},
+	{0x1D9E, UNICODE_NORM_QC_NO},
+	{0x1D9F, UNICODE_NORM_QC_NO},
+	{0x1DA0, UNICODE_NORM_QC_NO},
+	{0x1DA1, UNICODE_NORM_QC_NO},
+	{0x1DA2, UNICODE_NORM_QC_NO},
+	{0x1DA3, UNICODE_NORM_QC_NO},
+	{0x1DA4, UNICODE_NORM_QC_NO},
+	{0x1DA5, UNICODE_NORM_QC_NO},
+	{0x1DA6, UNICODE_NORM_QC_NO},
+	{0x1DA7, UNICODE_NORM_QC_NO},
+	{0x1DA8, UNICODE_NORM_QC_NO},
+	{0x1DA9, UNICODE_NORM_QC_NO},
+	{0x1DAA, UNICODE_NORM_QC_NO},
+	{0x1DAB, UNICODE_NORM_QC_NO},
+	{0x1DAC, UNICODE_NORM_QC_NO},
+	{0x1DAD, UNICODE_NORM_QC_NO},
+	{0x1DAE, UNICODE_NORM_QC_NO},
+	{0x1DAF, UNICODE_NORM_QC_NO},
+	{0x1DB0, UNICODE_NORM_QC_NO},
+	{0x1DB1, UNICODE_NORM_QC_NO},
+	{0x1DB2, UNICODE_NORM_QC_NO},
+	{0x1DB3, UNICODE_NORM_QC_NO},
+	{0x1DB4, UNICODE_NORM_QC_NO},
+	{0x1DB5, UNICODE_NORM_QC_NO},
+	{0x1DB6, UNICODE_NORM_QC_NO},
+	{0x1DB7, UNICODE_NORM_QC_NO},
+	{0x1DB8, UNICODE_NORM_QC_NO},
+	{0x1DB9, UNICODE_NORM_QC_NO},
+	{0x1DBA, UNICODE_NORM_QC_NO},
+	{0x1DBB, UNICODE_NORM_QC_NO},
+	{0x1DBC, UNICODE_NORM_QC_NO},
+	{0x1DBD, UNICODE_NORM_QC_NO},
+	{0x1DBE, UNICODE_NORM_QC_NO},
+	{0x1DBF, UNICODE_NORM_QC_NO},
+	{0x1E9A, UNICODE_NORM_QC_NO},
+	{0x1E9B, UNICODE_NORM_QC_NO},
+	{0x1F71, UNICODE_NORM_QC_NO},
+	{0x1F73, UNICODE_NORM_QC_NO},
+	{0x1F75, UNICODE_NORM_QC_NO},
+	{0x1F77, UNICODE_NORM_QC_NO},
+	{0x1F79, UNICODE_NORM_QC_NO},
+	{0x1F7B, UNICODE_NORM_QC_NO},
+	{0x1F7D, UNICODE_NORM_QC_NO},
+	{0x1FBB, UNICODE_NORM_QC_NO},
+	{0x1FBD, UNICODE_NORM_QC_NO},
+	{0x1FBE, UNICODE_NORM_QC_NO},
+	{0x1FBF, UNICODE_NORM_QC_NO},
+	{0x1FC0, UNICODE_NORM_QC_NO},
+	{0x1FC1, UNICODE_NORM_QC_NO},
+	{0x1FC9, UNICODE_NORM_QC_NO},
+	{0x1FCB, UNICODE_NORM_QC_NO},
+	{0x1FCD, UNICODE_NORM_QC_NO},
+	{0x1FCE, UNICODE_NORM_QC_NO},
+	{0x1FCF, UNICODE_NORM_QC_NO},
+	{0x1FD3, UNICODE_NORM_QC_NO},
+	{0x1FDB, UNICODE_NORM_QC_NO},
+	{0x1FDD, UNICODE_NORM_QC_NO},
+	{0x1FDE, UNICODE_NORM_QC_NO},
+	{0x1FDF, UNICODE_NORM_QC_NO},
+	{0x1FE3, UNICODE_NORM_QC_NO},
+	{0x1FEB, UNICODE_NORM_QC_NO},
+	{0x1FED, UNICODE_NORM_QC_NO},
+	{0x1FEE, UNICODE_NORM_QC_NO},
+	{0x1FEF, UNICODE_NORM_QC_NO},
+	{0x1FF9, UNICODE_NORM_QC_NO},
+	{0x1FFB, UNICODE_NORM_QC_NO},
+	{0x1FFD, UNICODE_NORM_QC_NO},
+	{0x1FFE, UNICODE_NORM_QC_NO},
+	{0x2000, UNICODE_NORM_QC_NO},
+	{0x2001, UNICODE_NORM_QC_NO},
+	{0x2002, UNICODE_NORM_QC_NO},
+	{0x2003, UNICODE_NORM_QC_NO},
+	{0x2004, UNICODE_NORM_QC_NO},
+	{0x2005, UNICODE_NORM_QC_NO},
+	{0x2006, UNICODE_NORM_QC_NO},
+	{0x2007, UNICODE_NORM_QC_NO},
+	{0x2008, UNICODE_NORM_QC_NO},
+	{0x2009, UNICODE_NORM_QC_NO},
+	{0x200A, UNICODE_NORM_QC_NO},
+	{0x2011, UNICODE_NORM_QC_NO},
+	{0x2017, UNICODE_NORM_QC_NO},
+	{0x2024, UNICODE_NORM_QC_NO},
+	{0x2025, UNICODE_NORM_QC_NO},
+	{0x2026, UNICODE_NORM_QC_NO},
+	{0x202F, UNICODE_NORM_QC_NO},
+	{0x2033, UNICODE_NORM_QC_NO},
+	{0x2034, UNICODE_NORM_QC_NO},
+	{0x2036, UNICODE_NORM_QC_NO},
+	{0x2037, UNICODE_NORM_QC_NO},
+	{0x203C, UNICODE_NORM_QC_NO},
+	{0x203E, UNICODE_NORM_QC_NO},
+	{0x2047, UNICODE_NORM_QC_NO},
+	{0x2048, UNICODE_NORM_QC_NO},
+	{0x2049, UNICODE_NORM_QC_NO},
+	{0x2057, UNICODE_NORM_QC_NO},
+	{0x205F, UNICODE_NORM_QC_NO},
+	{0x2070, UNICODE_NORM_QC_NO},
+	{0x2071, UNICODE_NORM_QC_NO},
+	{0x2074, UNICODE_NORM_QC_NO},
+	{0x2075, UNICODE_NORM_QC_NO},
+	{0x2076, UNICODE_NORM_QC_NO},
+	{0x2077, UNICODE_NORM_QC_NO},
+	{0x2078, UNICODE_NORM_QC_NO},
+	{0x2079, UNICODE_NORM_QC_NO},
+	{0x207A, UNICODE_NORM_QC_NO},
+	{0x207B, UNICODE_NORM_QC_NO},
+	{0x207C, UNICODE_NORM_QC_NO},
+	{0x207D, UNICODE_NORM_QC_NO},
+	{0x207E, UNICODE_NORM_QC_NO},
+	{0x207F, UNICODE_NORM_QC_NO},
+	{0x2080, UNICODE_NORM_QC_NO},
+	{0x2081, UNICODE_NORM_QC_NO},
+	{0x2082, UNICODE_NORM_QC_NO},
+	{0x2083, UNICODE_NORM_QC_NO},
+	{0x2084, UNICODE_NORM_QC_NO},
+	{0x2085, UNICODE_NORM_QC_NO},
+	{0x2086, UNICODE_NORM_QC_NO},
+	{0x2087, UNICODE_NORM_QC_NO},
+	{0x2088, UNICODE_NORM_QC_NO},
+	{0x2089, UNICODE_NORM_QC_NO},
+	{0x208A, UNICODE_NORM_QC_NO},
+	{0x208B, UNICODE_NORM_QC_NO},
+	{0x208C, UNICODE_NORM_QC_NO},
+	{0x208D, UNICODE_NORM_QC_NO},
+	{0x208E, UNICODE_NORM_QC_NO},
+	{0x2090, UNICODE_NORM_QC_NO},
+	{0x2091, UNICODE_NORM_QC_NO},
+	{0x2092, UNICODE_NORM_QC_NO},
+	{0x2093, UNICODE_NORM_QC_NO},
+	{0x2094, UNICODE_NORM_QC_NO},
+	{0x2095, UNICODE_NORM_QC_NO},
+	{0x2096, UNICODE_NORM_QC_NO},
+	{0x2097, UNICODE_NORM_QC_NO},
+	{0x2098, UNICODE_NORM_QC_NO},
+	{0x2099, UNICODE_NORM_QC_NO},
+	{0x209A, UNICODE_NORM_QC_NO},
+	{0x209B, UNICODE_NORM_QC_NO},
+	{0x209C, UNICODE_NORM_QC_NO},
+	{0x20A8, UNICODE_NORM_QC_NO},
+	{0x2100, UNICODE_NORM_QC_NO},
+	{0x2101, UNICODE_NORM_QC_NO},
+	{0x2102, UNICODE_NORM_QC_NO},
+	{0x2103, UNICODE_NORM_QC_NO},
+	{0x2105, UNICODE_NORM_QC_NO},
+	{0x2106, UNICODE_NORM_QC_NO},
+	{0x2107, UNICODE_NORM_QC_NO},
+	{0x2109, UNICODE_NORM_QC_NO},
+	{0x210A, UNICODE_NORM_QC_NO},
+	{0x210B, UNICODE_NORM_QC_NO},
+	{0x210C, UNICODE_NORM_QC_NO},
+	{0x210D, UNICODE_NORM_QC_NO},
+	{0x210E, UNICODE_NORM_QC_NO},
+	{0x210F, UNICODE_NORM_QC_NO},
+	{0x2110, UNICODE_NORM_QC_NO},
+	{0x2111, UNICODE_NORM_QC_NO},
+	{0x2112, UNICODE_NORM_QC_NO},
+	{0x2113, UNICODE_NORM_QC_NO},
+	{0x2115, UNICODE_NORM_QC_NO},
+	{0x2116, UNICODE_NORM_QC_NO},
+	{0x2119, UNICODE_NORM_QC_NO},
+	{0x211A, UNICODE_NORM_QC_NO},
+	{0x211B, UNICODE_NORM_QC_NO},
+	{0x211C, UNICODE_NORM_QC_NO},
+	{0x211D, UNICODE_NORM_QC_NO},
+	{0x2120, UNICODE_NORM_QC_NO},
+	{0x2121, UNICODE_NORM_QC_NO},
+	{0x2122, UNICODE_NORM_QC_NO},
+	{0x2124, UNICODE_NORM_QC_NO},
+	{0x2126, UNICODE_NORM_QC_NO},
+	{0x2128, UNICODE_NORM_QC_NO},
+	{0x212A, UNICODE_NORM_QC_NO},
+	{0x212B, UNICODE_NORM_QC_NO},
+	{0x212C, UNICODE_NORM_QC_NO},
+	{0x212D, UNICODE_NORM_QC_NO},
+	{0x212F, UNICODE_NORM_QC_NO},
+	{0x2130, UNICODE_NORM_QC_NO},
+	{0x2131, UNICODE_NORM_QC_NO},
+	{0x2133, UNICODE_NORM_QC_NO},
+	{0x2134, UNICODE_NORM_QC_NO},
+	{0x2135, UNICODE_NORM_QC_NO},
+	{0x2136, UNICODE_NORM_QC_NO},
+	{0x2137, UNICODE_NORM_QC_NO},
+	{0x2138, UNICODE_NORM_QC_NO},
+	{0x2139, UNICODE_NORM_QC_NO},
+	{0x213B, UNICODE_NORM_QC_NO},
+	{0x213C, UNICODE_NORM_QC_NO},
+	{0x213D, UNICODE_NORM_QC_NO},
+	{0x213E, UNICODE_NORM_QC_NO},
+	{0x213F, UNICODE_NORM_QC_NO},
+	{0x2140, UNICODE_NORM_QC_NO},
+	{0x2145, UNICODE_NORM_QC_NO},
+	{0x2146, UNICODE_NORM_QC_NO},
+	{0x2147, UNICODE_NORM_QC_NO},
+	{0x2148, UNICODE_NORM_QC_NO},
+	{0x2149, UNICODE_NORM_QC_NO},
+	{0x2150, UNICODE_NORM_QC_NO},
+	{0x2151, UNICODE_NORM_QC_NO},
+	{0x2152, UNICODE_NORM_QC_NO},
+	{0x2153, UNICODE_NORM_QC_NO},
+	{0x2154, UNICODE_NORM_QC_NO},
+	{0x2155, UNICODE_NORM_QC_NO},
+	{0x2156, UNICODE_NORM_QC_NO},
+	{0x2157, UNICODE_NORM_QC_NO},
+	{0x2158, UNICODE_NORM_QC_NO},
+	{0x2159, UNICODE_NORM_QC_NO},
+	{0x215A, UNICODE_NORM_QC_NO},
+	{0x215B, UNICODE_NORM_QC_NO},
+	{0x215C, UNICODE_NORM_QC_NO},
+	{0x215D, UNICODE_NORM_QC_NO},
+	{0x215E, UNICODE_NORM_QC_NO},
+	{0x215F, UNICODE_NORM_QC_NO},
+	{0x2160, UNICODE_NORM_QC_NO},
+	{0x2161, UNICODE_NORM_QC_NO},
+	{0x2162, UNICODE_NORM_QC_NO},
+	{0x2163, UNICODE_NORM_QC_NO},
+	{0x2164, UNICODE_NORM_QC_NO},
+	{0x2165, UNICODE_NORM_QC_NO},
+	{0x2166, UNICODE_NORM_QC_NO},
+	{0x2167, UNICODE_NORM_QC_NO},
+	{0x2168, UNICODE_NORM_QC_NO},
+	{0x2169, UNICODE_NORM_QC_NO},
+	{0x216A, UNICODE_NORM_QC_NO},
+	{0x216B, UNICODE_NORM_QC_NO},
+	{0x216C, UNICODE_NORM_QC_NO},
+	{0x216D, UNICODE_NORM_QC_NO},
+	{0x216E, UNICODE_NORM_QC_NO},
+	{0x216F, UNICODE_NORM_QC_NO},
+	{0x2170, UNICODE_NORM_QC_NO},
+	{0x2171, UNICODE_NORM_QC_NO},
+	{0x2172, UNICODE_NORM_QC_NO},
+	{0x2173, UNICODE_NORM_QC_NO},
+	{0x2174, UNICODE_NORM_QC_NO},
+	{0x2175, UNICODE_NORM_QC_NO},
+	{0x2176, UNICODE_NORM_QC_NO},
+	{0x2177, UNICODE_NORM_QC_NO},
+	{0x2178, UNICODE_NORM_QC_NO},
+	{0x2179, UNICODE_NORM_QC_NO},
+	{0x217A, UNICODE_NORM_QC_NO},
+	{0x217B, UNICODE_NORM_QC_NO},
+	{0x217C, UNICODE_NORM_QC_NO},
+	{0x217D, UNICODE_NORM_QC_NO},
+	{0x217E, UNICODE_NORM_QC_NO},
+	{0x217F, UNICODE_NORM_QC_NO},
+	{0x2189, UNICODE_NORM_QC_NO},
+	{0x222C, UNICODE_NORM_QC_NO},
+	{0x222D, UNICODE_NORM_QC_NO},
+	{0x222F, UNICODE_NORM_QC_NO},
+	{0x2230, UNICODE_NORM_QC_NO},
+	{0x2329, UNICODE_NORM_QC_NO},
+	{0x232A, UNICODE_NORM_QC_NO},
+	{0x2460, UNICODE_NORM_QC_NO},
+	{0x2461, UNICODE_NORM_QC_NO},
+	{0x2462, UNICODE_NORM_QC_NO},
+	{0x2463, UNICODE_NORM_QC_NO},
+	{0x2464, UNICODE_NORM_QC_NO},
+	{0x2465, UNICODE_NORM_QC_NO},
+	{0x2466, UNICODE_NORM_QC_NO},
+	{0x2467, UNICODE_NORM_QC_NO},
+	{0x2468, UNICODE_NORM_QC_NO},
+	{0x2469, UNICODE_NORM_QC_NO},
+	{0x246A, UNICODE_NORM_QC_NO},
+	{0x246B, UNICODE_NORM_QC_NO},
+	{0x246C, UNICODE_NORM_QC_NO},
+	{0x246D, UNICODE_NORM_QC_NO},
+	{0x246E, UNICODE_NORM_QC_NO},
+	{0x246F, UNICODE_NORM_QC_NO},
+	{0x2470, UNICODE_NORM_QC_NO},
+	{0x2471, UNICODE_NORM_QC_NO},
+	{0x2472, UNICODE_NORM_QC_NO},
+	{0x2473, UNICODE_NORM_QC_NO},
+	{0x2474, UNICODE_NORM_QC_NO},
+	{0x2475, UNICODE_NORM_QC_NO},
+	{0x2476, UNICODE_NORM_QC_NO},
+	{0x2477, UNICODE_NORM_QC_NO},
+	{0x2478, UNICODE_NORM_QC_NO},
+	{0x2479, UNICODE_NORM_QC_NO},
+	{0x247A, UNICODE_NORM_QC_NO},
+	{0x247B, UNICODE_NORM_QC_NO},
+	{0x247C, UNICODE_NORM_QC_NO},
+	{0x247D, UNICODE_NORM_QC_NO},
+	{0x247E, UNICODE_NORM_QC_NO},
+	{0x247F, UNICODE_NORM_QC_NO},
+	{0x2480, UNICODE_NORM_QC_NO},
+	{0x2481, UNICODE_NORM_QC_NO},
+	{0x2482, UNICODE_NORM_QC_NO},
+	{0x2483, UNICODE_NORM_QC_NO},
+	{0x2484, UNICODE_NORM_QC_NO},
+	{0x2485, UNICODE_NORM_QC_NO},
+	{0x2486, UNICODE_NORM_QC_NO},
+	{0x2487, UNICODE_NORM_QC_NO},
+	{0x2488, UNICODE_NORM_QC_NO},
+	{0x2489, UNICODE_NORM_QC_NO},
+	{0x248A, UNICODE_NORM_QC_NO},
+	{0x248B, UNICODE_NORM_QC_NO},
+	{0x248C, UNICODE_NORM_QC_NO},
+	{0x248D, UNICODE_NORM_QC_NO},
+	{0x248E, UNICODE_NORM_QC_NO},
+	{0x248F, UNICODE_NORM_QC_NO},
+	{0x2490, UNICODE_NORM_QC_NO},
+	{0x2491, UNICODE_NORM_QC_NO},
+	{0x2492, UNICODE_NORM_QC_NO},
+	{0x2493, UNICODE_NORM_QC_NO},
+	{0x2494, UNICODE_NORM_QC_NO},
+	{0x2495, UNICODE_NORM_QC_NO},
+	{0x2496, UNICODE_NORM_QC_NO},
+	{0x2497, UNICODE_NORM_QC_NO},
+	{0x2498, UNICODE_NORM_QC_NO},
+	{0x2499, UNICODE_NORM_QC_NO},
+	{0x249A, UNICODE_NORM_QC_NO},
+	{0x249B, UNICODE_NORM_QC_NO},
+	{0x249C, UNICODE_NORM_QC_NO},
+	{0x249D, UNICODE_NORM_QC_NO},
+	{0x249E, UNICODE_NORM_QC_NO},
+	{0x249F, UNICODE_NORM_QC_NO},
+	{0x24A0, UNICODE_NORM_QC_NO},
+	{0x24A1, UNICODE_NORM_QC_NO},
+	{0x24A2, UNICODE_NORM_QC_NO},
+	{0x24A3, UNICODE_NORM_QC_NO},
+	{0x24A4, UNICODE_NORM_QC_NO},
+	{0x24A5, UNICODE_NORM_QC_NO},
+	{0x24A6, UNICODE_NORM_QC_NO},
+	{0x24A7, UNICODE_NORM_QC_NO},
+	{0x24A8, UNICODE_NORM_QC_NO},
+	{0x24A9, UNICODE_NORM_QC_NO},
+	{0x24AA, UNICODE_NORM_QC_NO},
+	{0x24AB, UNICODE_NORM_QC_NO},
+	{0x24AC, UNICODE_NORM_QC_NO},
+	{0x24AD, UNICODE_NORM_QC_NO},
+	{0x24AE, UNICODE_NORM_QC_NO},
+	{0x24AF, UNICODE_NORM_QC_NO},
+	{0x24B0, UNICODE_NORM_QC_NO},
+	{0x24B1, UNICODE_NORM_QC_NO},
+	{0x24B2, UNICODE_NORM_QC_NO},
+	{0x24B3, UNICODE_NORM_QC_NO},
+	{0x24B4, UNICODE_NORM_QC_NO},
+	{0x24B5, UNICODE_NORM_QC_NO},
+	{0x24B6, UNICODE_NORM_QC_NO},
+	{0x24B7, UNICODE_NORM_QC_NO},
+	{0x24B8, UNICODE_NORM_QC_NO},
+	{0x24B9, UNICODE_NORM_QC_NO},
+	{0x24BA, UNICODE_NORM_QC_NO},
+	{0x24BB, UNICODE_NORM_QC_NO},
+	{0x24BC, UNICODE_NORM_QC_NO},
+	{0x24BD, UNICODE_NORM_QC_NO},
+	{0x24BE, UNICODE_NORM_QC_NO},
+	{0x24BF, UNICODE_NORM_QC_NO},
+	{0x24C0, UNICODE_NORM_QC_NO},
+	{0x24C1, UNICODE_NORM_QC_NO},
+	{0x24C2, UNICODE_NORM_QC_NO},
+	{0x24C3, UNICODE_NORM_QC_NO},
+	{0x24C4, UNICODE_NORM_QC_NO},
+	{0x24C5, UNICODE_NORM_QC_NO},
+	{0x24C6, UNICODE_NORM_QC_NO},
+	{0x24C7, UNICODE_NORM_QC_NO},
+	{0x24C8, UNICODE_NORM_QC_NO},
+	{0x24C9, UNICODE_NORM_QC_NO},
+	{0x24CA, UNICODE_NORM_QC_NO},
+	{0x24CB, UNICODE_NORM_QC_NO},
+	{0x24CC, UNICODE_NORM_QC_NO},
+	{0x24CD, UNICODE_NORM_QC_NO},
+	{0x24CE, UNICODE_NORM_QC_NO},
+	{0x24CF, UNICODE_NORM_QC_NO},
+	{0x24D0, UNICODE_NORM_QC_NO},
+	{0x24D1, UNICODE_NORM_QC_NO},
+	{0x24D2, UNICODE_NORM_QC_NO},
+	{0x24D3, UNICODE_NORM_QC_NO},
+	{0x24D4, UNICODE_NORM_QC_NO},
+	{0x24D5, UNICODE_NORM_QC_NO},
+	{0x24D6, UNICODE_NORM_QC_NO},
+	{0x24D7, UNICODE_NORM_QC_NO},
+	{0x24D8, UNICODE_NORM_QC_NO},
+	{0x24D9, UNICODE_NORM_QC_NO},
+	{0x24DA, UNICODE_NORM_QC_NO},
+	{0x24DB, UNICODE_NORM_QC_NO},
+	{0x24DC, UNICODE_NORM_QC_NO},
+	{0x24DD, UNICODE_NORM_QC_NO},
+	{0x24DE, UNICODE_NORM_QC_NO},
+	{0x24DF, UNICODE_NORM_QC_NO},
+	{0x24E0, UNICODE_NORM_QC_NO},
+	{0x24E1, UNICODE_NORM_QC_NO},
+	{0x24E2, UNICODE_NORM_QC_NO},
+	{0x24E3, UNICODE_NORM_QC_NO},
+	{0x24E4, UNICODE_NORM_QC_NO},
+	{0x24E5, UNICODE_NORM_QC_NO},
+	{0x24E6, UNICODE_NORM_QC_NO},
+	{0x24E7, UNICODE_NORM_QC_NO},
+	{0x24E8, UNICODE_NORM_QC_NO},
+	{0x24E9, UNICODE_NORM_QC_NO},
+	{0x24EA, UNICODE_NORM_QC_NO},
+	{0x2A0C, UNICODE_NORM_QC_NO},
+	{0x2A74, UNICODE_NORM_QC_NO},
+	{0x2A75, UNICODE_NORM_QC_NO},
+	{0x2A76, UNICODE_NORM_QC_NO},
+	{0x2ADC, UNICODE_NORM_QC_NO},
+	{0x2C7C, UNICODE_NORM_QC_NO},
+	{0x2C7D, UNICODE_NORM_QC_NO},
+	{0x2D6F, UNICODE_NORM_QC_NO},
+	{0x2E9F, UNICODE_NORM_QC_NO},
+	{0x2EF3, UNICODE_NORM_QC_NO},
+	{0x2F00, UNICODE_NORM_QC_NO},
+	{0x2F01, UNICODE_NORM_QC_NO},
+	{0x2F02, UNICODE_NORM_QC_NO},
+	{0x2F03, UNICODE_NORM_QC_NO},
+	{0x2F04, UNICODE_NORM_QC_NO},
+	{0x2F05, UNICODE_NORM_QC_NO},
+	{0x2F06, UNICODE_NORM_QC_NO},
+	{0x2F07, UNICODE_NORM_QC_NO},
+	{0x2F08, UNICODE_NORM_QC_NO},
+	{0x2F09, UNICODE_NORM_QC_NO},
+	{0x2F0A, UNICODE_NORM_QC_NO},
+	{0x2F0B, UNICODE_NORM_QC_NO},
+	{0x2F0C, UNICODE_NORM_QC_NO},
+	{0x2F0D, UNICODE_NORM_QC_NO},
+	{0x2F0E, UNICODE_NORM_QC_NO},
+	{0x2F0F, UNICODE_NORM_QC_NO},
+	{0x2F10, UNICODE_NORM_QC_NO},
+	{0x2F11, UNICODE_NORM_QC_NO},
+	{0x2F12, UNICODE_NORM_QC_NO},
+	{0x2F13, UNICODE_NORM_QC_NO},
+	{0x2F14, UNICODE_NORM_QC_NO},
+	{0x2F15, UNICODE_NORM_QC_NO},
+	{0x2F16, UNICODE_NORM_QC_NO},
+	{0x2F17, UNICODE_NORM_QC_NO},
+	{0x2F18, UNICODE_NORM_QC_NO},
+	{0x2F19, UNICODE_NORM_QC_NO},
+	{0x2F1A, UNICODE_NORM_QC_NO},
+	{0x2F1B, UNICODE_NORM_QC_NO},
+	{0x2F1C, UNICODE_NORM_QC_NO},
+	{0x2F1D, UNICODE_NORM_QC_NO},
+	{0x2F1E, UNICODE_NORM_QC_NO},
+	{0x2F1F, UNICODE_NORM_QC_NO},
+	{0x2F20, UNICODE_NORM_QC_NO},
+	{0x2F21, UNICODE_NORM_QC_NO},
+	{0x2F22, UNICODE_NORM_QC_NO},
+	{0x2F23, UNICODE_NORM_QC_NO},
+	{0x2F24, UNICODE_NORM_QC_NO},
+	{0x2F25, UNICODE_NORM_QC_NO},
+	{0x2F26, UNICODE_NORM_QC_NO},
+	{0x2F27, UNICODE_NORM_QC_NO},
+	{0x2F28, UNICODE_NORM_QC_NO},
+	{0x2F29, UNICODE_NORM_QC_NO},
+	{0x2F2A, UNICODE_NORM_QC_NO},
+	{0x2F2B, UNICODE_NORM_QC_NO},
+	{0x2F2C, UNICODE_NORM_QC_NO},
+	{0x2F2D, UNICODE_NORM_QC_NO},
+	{0x2F2E, UNICODE_NORM_QC_NO},
+	{0x2F2F, UNICODE_NORM_QC_NO},
+	{0x2F30, UNICODE_NORM_QC_NO},
+	{0x2F31, UNICODE_NORM_QC_NO},
+	{0x2F32, UNICODE_NORM_QC_NO},
+	{0x2F33, UNICODE_NORM_QC_NO},
+	{0x2F34, UNICODE_NORM_QC_NO},
+	{0x2F35, UNICODE_NORM_QC_NO},
+	{0x2F36, UNICODE_NORM_QC_NO},
+	{0x2F37, UNICODE_NORM_QC_NO},
+	{0x2F38, UNICODE_NORM_QC_NO},
+	{0x2F39, UNICODE_NORM_QC_NO},
+	{0x2F3A, UNICODE_NORM_QC_NO},
+	{0x2F3B, UNICODE_NORM_QC_NO},
+	{0x2F3C, UNICODE_NORM_QC_NO},
+	{0x2F3D, UNICODE_NORM_QC_NO},
+	{0x2F3E, UNICODE_NORM_QC_NO},
+	{0x2F3F, UNICODE_NORM_QC_NO},
+	{0x2F40, UNICODE_NORM_QC_NO},
+	{0x2F41, UNICODE_NORM_QC_NO},
+	{0x2F42, UNICODE_NORM_QC_NO},
+	{0x2F43, UNICODE_NORM_QC_NO},
+	{0x2F44, UNICODE_NORM_QC_NO},
+	{0x2F45, UNICODE_NORM_QC_NO},
+	{0x2F46, UNICODE_NORM_QC_NO},
+	{0x2F47, UNICODE_NORM_QC_NO},
+	{0x2F48, UNICODE_NORM_QC_NO},
+	{0x2F49, UNICODE_NORM_QC_NO},
+	{0x2F4A, UNICODE_NORM_QC_NO},
+	{0x2F4B, UNICODE_NORM_QC_NO},
+	{0x2F4C, UNICODE_NORM_QC_NO},
+	{0x2F4D, UNICODE_NORM_QC_NO},
+	{0x2F4E, UNICODE_NORM_QC_NO},
+	{0x2F4F, UNICODE_NORM_QC_NO},
+	{0x2F50, UNICODE_NORM_QC_NO},
+	{0x2F51, UNICODE_NORM_QC_NO},
+	{0x2F52, UNICODE_NORM_QC_NO},
+	{0x2F53, UNICODE_NORM_QC_NO},
+	{0x2F54, UNICODE_NORM_QC_NO},
+	{0x2F55, UNICODE_NORM_QC_NO},
+	{0x2F56, UNICODE_NORM_QC_NO},
+	{0x2F57, UNICODE_NORM_QC_NO},
+	{0x2F58, UNICODE_NORM_QC_NO},
+	{0x2F59, UNICODE_NORM_QC_NO},
+	{0x2F5A, UNICODE_NORM_QC_NO},
+	{0x2F5B, UNICODE_NORM_QC_NO},
+	{0x2F5C, UNICODE_NORM_QC_NO},
+	{0x2F5D, UNICODE_NORM_QC_NO},
+	{0x2F5E, UNICODE_NORM_QC_NO},
+	{0x2F5F, UNICODE_NORM_QC_NO},
+	{0x2F60, UNICODE_NORM_QC_NO},
+	{0x2F61, UNICODE_NORM_QC_NO},
+	{0x2F62, UNICODE_NORM_QC_NO},
+	{0x2F63, UNICODE_NORM_QC_NO},
+	{0x2F64, UNICODE_NORM_QC_NO},
+	{0x2F65, UNICODE_NORM_QC_NO},
+	{0x2F66, UNICODE_NORM_QC_NO},
+	{0x2F67, UNICODE_NORM_QC_NO},
+	{0x2F68, UNICODE_NORM_QC_NO},
+	{0x2F69, UNICODE_NORM_QC_NO},
+	{0x2F6A, UNICODE_NORM_QC_NO},
+	{0x2F6B, UNICODE_NORM_QC_NO},
+	{0x2F6C, UNICODE_NORM_QC_NO},
+	{0x2F6D, UNICODE_NORM_QC_NO},
+	{0x2F6E, UNICODE_NORM_QC_NO},
+	{0x2F6F, UNICODE_NORM_QC_NO},
+	{0x2F70, UNICODE_NORM_QC_NO},
+	{0x2F71, UNICODE_NORM_QC_NO},
+	{0x2F72, UNICODE_NORM_QC_NO},
+	{0x2F73, UNICODE_NORM_QC_NO},
+	{0x2F74, UNICODE_NORM_QC_NO},
+	{0x2F75, UNICODE_NORM_QC_NO},
+	{0x2F76, UNICODE_NORM_QC_NO},
+	{0x2F77, UNICODE_NORM_QC_NO},
+	{0x2F78, UNICODE_NORM_QC_NO},
+	{0x2F79, UNICODE_NORM_QC_NO},
+	{0x2F7A, UNICODE_NORM_QC_NO},
+	{0x2F7B, UNICODE_NORM_QC_NO},
+	{0x2F7C, UNICODE_NORM_QC_NO},
+	{0x2F7D, UNICODE_NORM_QC_NO},
+	{0x2F7E, UNICODE_NORM_QC_NO},
+	{0x2F7F, UNICODE_NORM_QC_NO},
+	{0x2F80, UNICODE_NORM_QC_NO},
+	{0x2F81, UNICODE_NORM_QC_NO},
+	{0x2F82, UNICODE_NORM_QC_NO},
+	{0x2F83, UNICODE_NORM_QC_NO},
+	{0x2F84, UNICODE_NORM_QC_NO},
+	{0x2F85, UNICODE_NORM_QC_NO},
+	{0x2F86, UNICODE_NORM_QC_NO},
+	{0x2F87, UNICODE_NORM_QC_NO},
+	{0x2F88, UNICODE_NORM_QC_NO},
+	{0x2F89, UNICODE_NORM_QC_NO},
+	{0x2F8A, UNICODE_NORM_QC_NO},
+	{0x2F8B, UNICODE_NORM_QC_NO},
+	{0x2F8C, UNICODE_NORM_QC_NO},
+	{0x2F8D, UNICODE_NORM_QC_NO},
+	{0x2F8E, UNICODE_NORM_QC_NO},
+	{0x2F8F, UNICODE_NORM_QC_NO},
+	{0x2F90, UNICODE_NORM_QC_NO},
+	{0x2F91, UNICODE_NORM_QC_NO},
+	{0x2F92, UNICODE_NORM_QC_NO},
+	{0x2F93, UNICODE_NORM_QC_NO},
+	{0x2F94, UNICODE_NORM_QC_NO},
+	{0x2F95, UNICODE_NORM_QC_NO},
+	{0x2F96, UNICODE_NORM_QC_NO},
+	{0x2F97, UNICODE_NORM_QC_NO},
+	{0x2F98, UNICODE_NORM_QC_NO},
+	{0x2F99, UNICODE_NORM_QC_NO},
+	{0x2F9A, UNICODE_NORM_QC_NO},
+	{0x2F9B, UNICODE_NORM_QC_NO},
+	{0x2F9C, UNICODE_NORM_QC_NO},
+	{0x2F9D, UNICODE_NORM_QC_NO},
+	{0x2F9E, UNICODE_NORM_QC_NO},
+	{0x2F9F, UNICODE_NORM_QC_NO},
+	{0x2FA0, UNICODE_NORM_QC_NO},
+	{0x2FA1, UNICODE_NORM_QC_NO},
+	{0x2FA2, UNICODE_NORM_QC_NO},
+	{0x2FA3, UNICODE_NORM_QC_NO},
+	{0x2FA4, UNICODE_NORM_QC_NO},
+	{0x2FA5, UNICODE_NORM_QC_NO},
+	{0x2FA6, UNICODE_NORM_QC_NO},
+	{0x2FA7, UNICODE_NORM_QC_NO},
+	{0x2FA8, UNICODE_NORM_QC_NO},
+	{0x2FA9, UNICODE_NORM_QC_NO},
+	{0x2FAA, UNICODE_NORM_QC_NO},
+	{0x2FAB, UNICODE_NORM_QC_NO},
+	{0x2FAC, UNICODE_NORM_QC_NO},
+	{0x2FAD, UNICODE_NORM_QC_NO},
+	{0x2FAE, UNICODE_NORM_QC_NO},
+	{0x2FAF, UNICODE_NORM_QC_NO},
+	{0x2FB0, UNICODE_NORM_QC_NO},
+	{0x2FB1, UNICODE_NORM_QC_NO},
+	{0x2FB2, UNICODE_NORM_QC_NO},
+	{0x2FB3, UNICODE_NORM_QC_NO},
+	{0x2FB4, UNICODE_NORM_QC_NO},
+	{0x2FB5, UNICODE_NORM_QC_NO},
+	{0x2FB6, UNICODE_NORM_QC_NO},
+	{0x2FB7, UNICODE_NORM_QC_NO},
+	{0x2FB8, UNICODE_NORM_QC_NO},
+	{0x2FB9, UNICODE_NORM_QC_NO},
+	{0x2FBA, UNICODE_NORM_QC_NO},
+	{0x2FBB, UNICODE_NORM_QC_NO},
+	{0x2FBC, UNICODE_NORM_QC_NO},
+	{0x2FBD, UNICODE_NORM_QC_NO},
+	{0x2FBE, UNICODE_NORM_QC_NO},
+	{0x2FBF, UNICODE_NORM_QC_NO},
+	{0x2FC0, UNICODE_NORM_QC_NO},
+	{0x2FC1, UNICODE_NORM_QC_NO},
+	{0x2FC2, UNICODE_NORM_QC_NO},
+	{0x2FC3, UNICODE_NORM_QC_NO},
+	{0x2FC4, UNICODE_NORM_QC_NO},
+	{0x2FC5, UNICODE_NORM_QC_NO},
+	{0x2FC6, UNICODE_NORM_QC_NO},
+	{0x2FC7, UNICODE_NORM_QC_NO},
+	{0x2FC8, UNICODE_NORM_QC_NO},
+	{0x2FC9, UNICODE_NORM_QC_NO},
+	{0x2FCA, UNICODE_NORM_QC_NO},
+	{0x2FCB, UNICODE_NORM_QC_NO},
+	{0x2FCC, UNICODE_NORM_QC_NO},
+	{0x2FCD, UNICODE_NORM_QC_NO},
+	{0x2FCE, UNICODE_NORM_QC_NO},
+	{0x2FCF, UNICODE_NORM_QC_NO},
+	{0x2FD0, UNICODE_NORM_QC_NO},
+	{0x2FD1, UNICODE_NORM_QC_NO},
+	{0x2FD2, UNICODE_NORM_QC_NO},
+	{0x2FD3, UNICODE_NORM_QC_NO},
+	{0x2FD4, UNICODE_NORM_QC_NO},
+	{0x2FD5, UNICODE_NORM_QC_NO},
+	{0x3000, UNICODE_NORM_QC_NO},
+	{0x3036, UNICODE_NORM_QC_NO},
+	{0x3038, UNICODE_NORM_QC_NO},
+	{0x3039, UNICODE_NORM_QC_NO},
+	{0x303A, UNICODE_NORM_QC_NO},
+	{0x3099, UNICODE_NORM_QC_MAYBE},
+	{0x309A, UNICODE_NORM_QC_MAYBE},
+	{0x309B, UNICODE_NORM_QC_NO},
+	{0x309C, UNICODE_NORM_QC_NO},
+	{0x309F, UNICODE_NORM_QC_NO},
+	{0x30FF, UNICODE_NORM_QC_NO},
+	{0x3131, UNICODE_NORM_QC_NO},
+	{0x3132, UNICODE_NORM_QC_NO},
+	{0x3133, UNICODE_NORM_QC_NO},
+	{0x3134, UNICODE_NORM_QC_NO},
+	{0x3135, UNICODE_NORM_QC_NO},
+	{0x3136, UNICODE_NORM_QC_NO},
+	{0x3137, UNICODE_NORM_QC_NO},
+	{0x3138, UNICODE_NORM_QC_NO},
+	{0x3139, UNICODE_NORM_QC_NO},
+	{0x313A, UNICODE_NORM_QC_NO},
+	{0x313B, UNICODE_NORM_QC_NO},
+	{0x313C, UNICODE_NORM_QC_NO},
+	{0x313D, UNICODE_NORM_QC_NO},
+	{0x313E, UNICODE_NORM_QC_NO},
+	{0x313F, UNICODE_NORM_QC_NO},
+	{0x3140, UNICODE_NORM_QC_NO},
+	{0x3141, UNICODE_NORM_QC_NO},
+	{0x3142, UNICODE_NORM_QC_NO},
+	{0x3143, UNICODE_NORM_QC_NO},
+	{0x3144, UNICODE_NORM_QC_NO},
+	{0x3145, UNICODE_NORM_QC_NO},
+	{0x3146, UNICODE_NORM_QC_NO},
+	{0x3147, UNICODE_NORM_QC_NO},
+	{0x3148, UNICODE_NORM_QC_NO},
+	{0x3149, UNICODE_NORM_QC_NO},
+	{0x314A, UNICODE_NORM_QC_NO},
+	{0x314B, UNICODE_NORM_QC_NO},
+	{0x314C, UNICODE_NORM_QC_NO},
+	{0x314D, UNICODE_NORM_QC_NO},
+	{0x314E, UNICODE_NORM_QC_NO},
+	{0x314F, UNICODE_NORM_QC_NO},
+	{0x3150, UNICODE_NORM_QC_NO},
+	{0x3151, UNICODE_NORM_QC_NO},
+	{0x3152, UNICODE_NORM_QC_NO},
+	{0x3153, UNICODE_NORM_QC_NO},
+	{0x3154, UNICODE_NORM_QC_NO},
+	{0x3155, UNICODE_NORM_QC_NO},
+	{0x3156, UNICODE_NORM_QC_NO},
+	{0x3157, UNICODE_NORM_QC_NO},
+	{0x3158, UNICODE_NORM_QC_NO},
+	{0x3159, UNICODE_NORM_QC_NO},
+	{0x315A, UNICODE_NORM_QC_NO},
+	{0x315B, UNICODE_NORM_QC_NO},
+	{0x315C, UNICODE_NORM_QC_NO},
+	{0x315D, UNICODE_NORM_QC_NO},
+	{0x315E, UNICODE_NORM_QC_NO},
+	{0x315F, UNICODE_NORM_QC_NO},
+	{0x3160, UNICODE_NORM_QC_NO},
+	{0x3161, UNICODE_NORM_QC_NO},
+	{0x3162, UNICODE_NORM_QC_NO},
+	{0x3163, UNICODE_NORM_QC_NO},
+	{0x3164, UNICODE_NORM_QC_NO},
+	{0x3165, UNICODE_NORM_QC_NO},
+	{0x3166, UNICODE_NORM_QC_NO},
+	{0x3167, UNICODE_NORM_QC_NO},
+	{0x3168, UNICODE_NORM_QC_NO},
+	{0x3169, UNICODE_NORM_QC_NO},
+	{0x316A, UNICODE_NORM_QC_NO},
+	{0x316B, UNICODE_NORM_QC_NO},
+	{0x316C, UNICODE_NORM_QC_NO},
+	{0x316D, UNICODE_NORM_QC_NO},
+	{0x316E, UNICODE_NORM_QC_NO},
+	{0x316F, UNICODE_NORM_QC_NO},
+	{0x3170, UNICODE_NORM_QC_NO},
+	{0x3171, UNICODE_NORM_QC_NO},
+	{0x3172, UNICODE_NORM_QC_NO},
+	{0x3173, UNICODE_NORM_QC_NO},
+	{0x3174, UNICODE_NORM_QC_NO},
+	{0x3175, UNICODE_NORM_QC_NO},
+	{0x3176, UNICODE_NORM_QC_NO},
+	{0x3177, UNICODE_NORM_QC_NO},
+	{0x3178, UNICODE_NORM_QC_NO},
+	{0x3179, UNICODE_NORM_QC_NO},
+	{0x317A, UNICODE_NORM_QC_NO},
+	{0x317B, UNICODE_NORM_QC_NO},
+	{0x317C, UNICODE_NORM_QC_NO},
+	{0x317D, UNICODE_NORM_QC_NO},
+	{0x317E, UNICODE_NORM_QC_NO},
+	{0x317F, UNICODE_NORM_QC_NO},
+	{0x3180, UNICODE_NORM_QC_NO},
+	{0x3181, UNICODE_NORM_QC_NO},
+	{0x3182, UNICODE_NORM_QC_NO},
+	{0x3183, UNICODE_NORM_QC_NO},
+	{0x3184, UNICODE_NORM_QC_NO},
+	{0x3185, UNICODE_NORM_QC_NO},
+	{0x3186, UNICODE_NORM_QC_NO},
+	{0x3187, UNICODE_NORM_QC_NO},
+	{0x3188, UNICODE_NORM_QC_NO},
+	{0x3189, UNICODE_NORM_QC_NO},
+	{0x318A, UNICODE_NORM_QC_NO},
+	{0x318B, UNICODE_NORM_QC_NO},
+	{0x318C, UNICODE_NORM_QC_NO},
+	{0x318D, UNICODE_NORM_QC_NO},
+	{0x318E, UNICODE_NORM_QC_NO},
+	{0x3192, UNICODE_NORM_QC_NO},
+	{0x3193, UNICODE_NORM_QC_NO},
+	{0x3194, UNICODE_NORM_QC_NO},
+	{0x3195, UNICODE_NORM_QC_NO},
+	{0x3196, UNICODE_NORM_QC_NO},
+	{0x3197, UNICODE_NORM_QC_NO},
+	{0x3198, UNICODE_NORM_QC_NO},
+	{0x3199, UNICODE_NORM_QC_NO},
+	{0x319A, UNICODE_NORM_QC_NO},
+	{0x319B, UNICODE_NORM_QC_NO},
+	{0x319C, UNICODE_NORM_QC_NO},
+	{0x319D, UNICODE_NORM_QC_NO},
+	{0x319E, UNICODE_NORM_QC_NO},
+	{0x319F, UNICODE_NORM_QC_NO},
+	{0x3200, UNICODE_NORM_QC_NO},
+	{0x3201, UNICODE_NORM_QC_NO},
+	{0x3202, UNICODE_NORM_QC_NO},
+	{0x3203, UNICODE_NORM_QC_NO},
+	{0x3204, UNICODE_NORM_QC_NO},
+	{0x3205, UNICODE_NORM_QC_NO},
+	{0x3206, UNICODE_NORM_QC_NO},
+	{0x3207, UNICODE_NORM_QC_NO},
+	{0x3208, UNICODE_NORM_QC_NO},
+	{0x3209, UNICODE_NORM_QC_NO},
+	{0x320A, UNICODE_NORM_QC_NO},
+	{0x320B, UNICODE_NORM_QC_NO},
+	{0x320C, UNICODE_NORM_QC_NO},
+	{0x320D, UNICODE_NORM_QC_NO},
+	{0x320E, UNICODE_NORM_QC_NO},
+	{0x320F, UNICODE_NORM_QC_NO},
+	{0x3210, UNICODE_NORM_QC_NO},
+	{0x3211, UNICODE_NORM_QC_NO},
+	{0x3212, UNICODE_NORM_QC_NO},
+	{0x3213, UNICODE_NORM_QC_NO},
+	{0x3214, UNICODE_NORM_QC_NO},
+	{0x3215, UNICODE_NORM_QC_NO},
+	{0x3216, UNICODE_NORM_QC_NO},
+	{0x3217, UNICODE_NORM_QC_NO},
+	{0x3218, UNICODE_NORM_QC_NO},
+	{0x3219, UNICODE_NORM_QC_NO},
+	{0x321A, UNICODE_NORM_QC_NO},
+	{0x321B, UNICODE_NORM_QC_NO},
+	{0x321C, UNICODE_NORM_QC_NO},
+	{0x321D, UNICODE_NORM_QC_NO},
+	{0x321E, UNICODE_NORM_QC_NO},
+	{0x3220, UNICODE_NORM_QC_NO},
+	{0x3221, UNICODE_NORM_QC_NO},
+	{0x3222, UNICODE_NORM_QC_NO},
+	{0x3223, UNICODE_NORM_QC_NO},
+	{0x3224, UNICODE_NORM_QC_NO},
+	{0x3225, UNICODE_NORM_QC_NO},
+	{0x3226, UNICODE_NORM_QC_NO},
+	{0x3227, UNICODE_NORM_QC_NO},
+	{0x3228, UNICODE_NORM_QC_NO},
+	{0x3229, UNICODE_NORM_QC_NO},
+	{0x322A, UNICODE_NORM_QC_NO},
+	{0x322B, UNICODE_NORM_QC_NO},
+	{0x322C, UNICODE_NORM_QC_NO},
+	{0x322D, UNICODE_NORM_QC_NO},
+	{0x322E, UNICODE_NORM_QC_NO},
+	{0x322F, UNICODE_NORM_QC_NO},
+	{0x3230, UNICODE_NORM_QC_NO},
+	{0x3231, UNICODE_NORM_QC_NO},
+	{0x3232, UNICODE_NORM_QC_NO},
+	{0x3233, UNICODE_NORM_QC_NO},
+	{0x3234, UNICODE_NORM_QC_NO},
+	{0x3235, UNICODE_NORM_QC_NO},
+	{0x3236, UNICODE_NORM_QC_NO},
+	{0x3237, UNICODE_NORM_QC_NO},
+	{0x3238, UNICODE_NORM_QC_NO},
+	{0x3239, UNICODE_NORM_QC_NO},
+	{0x323A, UNICODE_NORM_QC_NO},
+	{0x323B, UNICODE_NORM_QC_NO},
+	{0x323C, UNICODE_NORM_QC_NO},
+	{0x323D, UNICODE_NORM_QC_NO},
+	{0x323E, UNICODE_NORM_QC_NO},
+	{0x323F, UNICODE_NORM_QC_NO},
+	{0x3240, UNICODE_NORM_QC_NO},
+	{0x3241, UNICODE_NORM_QC_NO},
+	{0x3242, UNICODE_NORM_QC_NO},
+	{0x3243, UNICODE_NORM_QC_NO},
+	{0x3244, UNICODE_NORM_QC_NO},
+	{0x3245, UNICODE_NORM_QC_NO},
+	{0x3246, UNICODE_NORM_QC_NO},
+	{0x3247, UNICODE_NORM_QC_NO},
+	{0x3250, UNICODE_NORM_QC_NO},
+	{0x3251, UNICODE_NORM_QC_NO},
+	{0x3252, UNICODE_NORM_QC_NO},
+	{0x3253, UNICODE_NORM_QC_NO},
+	{0x3254, UNICODE_NORM_QC_NO},
+	{0x3255, UNICODE_NORM_QC_NO},
+	{0x3256, UNICODE_NORM_QC_NO},
+	{0x3257, UNICODE_NORM_QC_NO},
+	{0x3258, UNICODE_NORM_QC_NO},
+	{0x3259, UNICODE_NORM_QC_NO},
+	{0x325A, UNICODE_NORM_QC_NO},
+	{0x325B, UNICODE_NORM_QC_NO},
+	{0x325C, UNICODE_NORM_QC_NO},
+	{0x325D, UNICODE_NORM_QC_NO},
+	{0x325E, UNICODE_NORM_QC_NO},
+	{0x325F, UNICODE_NORM_QC_NO},
+	{0x3260, UNICODE_NORM_QC_NO},
+	{0x3261, UNICODE_NORM_QC_NO},
+	{0x3262, UNICODE_NORM_QC_NO},
+	{0x3263, UNICODE_NORM_QC_NO},
+	{0x3264, UNICODE_NORM_QC_NO},
+	{0x3265, UNICODE_NORM_QC_NO},
+	{0x3266, UNICODE_NORM_QC_NO},
+	{0x3267, UNICODE_NORM_QC_NO},
+	{0x3268, UNICODE_NORM_QC_NO},
+	{0x3269, UNICODE_NORM_QC_NO},
+	{0x326A, UNICODE_NORM_QC_NO},
+	{0x326B, UNICODE_NORM_QC_NO},
+	{0x326C, UNICODE_NORM_QC_NO},
+	{0x326D, UNICODE_NORM_QC_NO},
+	{0x326E, UNICODE_NORM_QC_NO},
+	{0x326F, UNICODE_NORM_QC_NO},
+	{0x3270, UNICODE_NORM_QC_NO},
+	{0x3271, UNICODE_NORM_QC_NO},
+	{0x3272, UNICODE_NORM_QC_NO},
+	{0x3273, UNICODE_NORM_QC_NO},
+	{0x3274, UNICODE_NORM_QC_NO},
+	{0x3275, UNICODE_NORM_QC_NO},
+	{0x3276, UNICODE_NORM_QC_NO},
+	{0x3277, UNICODE_NORM_QC_NO},
+	{0x3278, UNICODE_NORM_QC_NO},
+	{0x3279, UNICODE_NORM_QC_NO},
+	{0x327A, UNICODE_NORM_QC_NO},
+	{0x327B, UNICODE_NORM_QC_NO},
+	{0x327C, UNICODE_NORM_QC_NO},
+	{0x327D, UNICODE_NORM_QC_NO},
+	{0x327E, UNICODE_NORM_QC_NO},
+	{0x3280, UNICODE_NORM_QC_NO},
+	{0x3281, UNICODE_NORM_QC_NO},
+	{0x3282, UNICODE_NORM_QC_NO},
+	{0x3283, UNICODE_NORM_QC_NO},
+	{0x3284, UNICODE_NORM_QC_NO},
+	{0x3285, UNICODE_NORM_QC_NO},
+	{0x3286, UNICODE_NORM_QC_NO},
+	{0x3287, UNICODE_NORM_QC_NO},
+	{0x3288, UNICODE_NORM_QC_NO},
+	{0x3289, UNICODE_NORM_QC_NO},
+	{0x328A, UNICODE_NORM_QC_NO},
+	{0x328B, UNICODE_NORM_QC_NO},
+	{0x328C, UNICODE_NORM_QC_NO},
+	{0x328D, UNICODE_NORM_QC_NO},
+	{0x328E, UNICODE_NORM_QC_NO},
+	{0x328F, UNICODE_NORM_QC_NO},
+	{0x3290, UNICODE_NORM_QC_NO},
+	{0x3291, UNICODE_NORM_QC_NO},
+	{0x3292, UNICODE_NORM_QC_NO},
+	{0x3293, UNICODE_NORM_QC_NO},
+	{0x3294, UNICODE_NORM_QC_NO},
+	{0x3295, UNICODE_NORM_QC_NO},
+	{0x3296, UNICODE_NORM_QC_NO},
+	{0x3297, UNICODE_NORM_QC_NO},
+	{0x3298, UNICODE_NORM_QC_NO},
+	{0x3299, UNICODE_NORM_QC_NO},
+	{0x329A, UNICODE_NORM_QC_NO},
+	{0x329B, UNICODE_NORM_QC_NO},
+	{0x329C, UNICODE_NORM_QC_NO},
+	{0x329D, UNICODE_NORM_QC_NO},
+	{0x329E, UNICODE_NORM_QC_NO},
+	{0x329F, UNICODE_NORM_QC_NO},
+	{0x32A0, UNICODE_NORM_QC_NO},
+	{0x32A1, UNICODE_NORM_QC_NO},
+	{0x32A2, UNICODE_NORM_QC_NO},
+	{0x32A3, UNICODE_NORM_QC_NO},
+	{0x32A4, UNICODE_NORM_QC_NO},
+	{0x32A5, UNICODE_NORM_QC_NO},
+	{0x32A6, UNICODE_NORM_QC_NO},
+	{0x32A7, UNICODE_NORM_QC_NO},
+	{0x32A8, UNICODE_NORM_QC_NO},
+	{0x32A9, UNICODE_NORM_QC_NO},
+	{0x32AA, UNICODE_NORM_QC_NO},
+	{0x32AB, UNICODE_NORM_QC_NO},
+	{0x32AC, UNICODE_NORM_QC_NO},
+	{0x32AD, UNICODE_NORM_QC_NO},
+	{0x32AE, UNICODE_NORM_QC_NO},
+	{0x32AF, UNICODE_NORM_QC_NO},
+	{0x32B0, UNICODE_NORM_QC_NO},
+	{0x32B1, UNICODE_NORM_QC_NO},
+	{0x32B2, UNICODE_NORM_QC_NO},
+	{0x32B3, UNICODE_NORM_QC_NO},
+	{0x32B4, UNICODE_NORM_QC_NO},
+	{0x32B5, UNICODE_NORM_QC_NO},
+	{0x32B6, UNICODE_NORM_QC_NO},
+	{0x32B7, UNICODE_NORM_QC_NO},
+	{0x32B8, UNICODE_NORM_QC_NO},
+	{0x32B9, UNICODE_NORM_QC_NO},
+	{0x32BA, UNICODE_NORM_QC_NO},
+	{0x32BB, UNICODE_NORM_QC_NO},
+	{0x32BC, UNICODE_NORM_QC_NO},
+	{0x32BD, UNICODE_NORM_QC_NO},
+	{0x32BE, UNICODE_NORM_QC_NO},
+	{0x32BF, UNICODE_NORM_QC_NO},
+	{0x32C0, UNICODE_NORM_QC_NO},
+	{0x32C1, UNICODE_NORM_QC_NO},
+	{0x32C2, UNICODE_NORM_QC_NO},
+	{0x32C3, UNICODE_NORM_QC_NO},
+	{0x32C4, UNICODE_NORM_QC_NO},
+	{0x32C5, UNICODE_NORM_QC_NO},
+	{0x32C6, UNICODE_NORM_QC_NO},
+	{0x32C7, UNICODE_NORM_QC_NO},
+	{0x32C8, UNICODE_NORM_QC_NO},
+	{0x32C9, UNICODE_NORM_QC_NO},
+	{0x32CA, UNICODE_NORM_QC_NO},
+	{0x32CB, UNICODE_NORM_QC_NO},
+	{0x32CC, UNICODE_NORM_QC_NO},
+	{0x32CD, UNICODE_NORM_QC_NO},
+	{0x32CE, UNICODE_NORM_QC_NO},
+	{0x32CF, UNICODE_NORM_QC_NO},
+	{0x32D0, UNICODE_NORM_QC_NO},
+	{0x32D1, UNICODE_NORM_QC_NO},
+	{0x32D2, UNICODE_NORM_QC_NO},
+	{0x32D3, UNICODE_NORM_QC_NO},
+	{0x32D4, UNICODE_NORM_QC_NO},
+	{0x32D5, UNICODE_NORM_QC_NO},
+	{0x32D6, UNICODE_NORM_QC_NO},
+	{0x32D7, UNICODE_NORM_QC_NO},
+	{0x32D8, UNICODE_NORM_QC_NO},
+	{0x32D9, UNICODE_NORM_QC_NO},
+	{0x32DA, UNICODE_NORM_QC_NO},
+	{0x32DB, UNICODE_NORM_QC_NO},
+	{0x32DC, UNICODE_NORM_QC_NO},
+	{0x32DD, UNICODE_NORM_QC_NO},
+	{0x32DE, UNICODE_NORM_QC_NO},
+	{0x32DF, UNICODE_NORM_QC_NO},
+	{0x32E0, UNICODE_NORM_QC_NO},
+	{0x32E1, UNICODE_NORM_QC_NO},
+	{0x32E2, UNICODE_NORM_QC_NO},
+	{0x32E3, UNICODE_NORM_QC_NO},
+	{0x32E4, UNICODE_NORM_QC_NO},
+	{0x32E5, UNICODE_NORM_QC_NO},
+	{0x32E6, UNICODE_NORM_QC_NO},
+	{0x32E7, UNICODE_NORM_QC_NO},
+	{0x32E8, UNICODE_NORM_QC_NO},
+	{0x32E9, UNICODE_NORM_QC_NO},
+	{0x32EA, UNICODE_NORM_QC_NO},
+	{0x32EB, UNICODE_NORM_QC_NO},
+	{0x32EC, UNICODE_NORM_QC_NO},
+	{0x32ED, UNICODE_NORM_QC_NO},
+	{0x32EE, UNICODE_NORM_QC_NO},
+	{0x32EF, UNICODE_NORM_QC_NO},
+	{0x32F0, UNICODE_NORM_QC_NO},
+	{0x32F1, UNICODE_NORM_QC_NO},
+	{0x32F2, UNICODE_NORM_QC_NO},
+	{0x32F3, UNICODE_NORM_QC_NO},
+	{0x32F4, UNICODE_NORM_QC_NO},
+	{0x32F5, UNICODE_NORM_QC_NO},
+	{0x32F6, UNICODE_NORM_QC_NO},
+	{0x32F7, UNICODE_NORM_QC_NO},
+	{0x32F8, UNICODE_NORM_QC_NO},
+	{0x32F9, UNICODE_NORM_QC_NO},
+	{0x32FA, UNICODE_NORM_QC_NO},
+	{0x32FB, UNICODE_NORM_QC_NO},
+	{0x32FC, UNICODE_NORM_QC_NO},
+	{0x32FD, UNICODE_NORM_QC_NO},
+	{0x32FE, UNICODE_NORM_QC_NO},
+	{0x32FF, UNICODE_NORM_QC_NO},
+	{0x3300, UNICODE_NORM_QC_NO},
+	{0x3301, UNICODE_NORM_QC_NO},
+	{0x3302, UNICODE_NORM_QC_NO},
+	{0x3303, UNICODE_NORM_QC_NO},
+	{0x3304, UNICODE_NORM_QC_NO},
+	{0x3305, UNICODE_NORM_QC_NO},
+	{0x3306, UNICODE_NORM_QC_NO},
+	{0x3307, UNICODE_NORM_QC_NO},
+	{0x3308, UNICODE_NORM_QC_NO},
+	{0x3309, UNICODE_NORM_QC_NO},
+	{0x330A, UNICODE_NORM_QC_NO},
+	{0x330B, UNICODE_NORM_QC_NO},
+	{0x330C, UNICODE_NORM_QC_NO},
+	{0x330D, UNICODE_NORM_QC_NO},
+	{0x330E, UNICODE_NORM_QC_NO},
+	{0x330F, UNICODE_NORM_QC_NO},
+	{0x3310, UNICODE_NORM_QC_NO},
+	{0x3311, UNICODE_NORM_QC_NO},
+	{0x3312, UNICODE_NORM_QC_NO},
+	{0x3313, UNICODE_NORM_QC_NO},
+	{0x3314, UNICODE_NORM_QC_NO},
+	{0x3315, UNICODE_NORM_QC_NO},
+	{0x3316, UNICODE_NORM_QC_NO},
+	{0x3317, UNICODE_NORM_QC_NO},
+	{0x3318, UNICODE_NORM_QC_NO},
+	{0x3319, UNICODE_NORM_QC_NO},
+	{0x331A, UNICODE_NORM_QC_NO},
+	{0x331B, UNICODE_NORM_QC_NO},
+	{0x331C, UNICODE_NORM_QC_NO},
+	{0x331D, UNICODE_NORM_QC_NO},
+	{0x331E, UNICODE_NORM_QC_NO},
+	{0x331F, UNICODE_NORM_QC_NO},
+	{0x3320, UNICODE_NORM_QC_NO},
+	{0x3321, UNICODE_NORM_QC_NO},
+	{0x3322, UNICODE_NORM_QC_NO},
+	{0x3323, UNICODE_NORM_QC_NO},
+	{0x3324, UNICODE_NORM_QC_NO},
+	{0x3325, UNICODE_NORM_QC_NO},
+	{0x3326, UNICODE_NORM_QC_NO},
+	{0x3327, UNICODE_NORM_QC_NO},
+	{0x3328, UNICODE_NORM_QC_NO},
+	{0x3329, UNICODE_NORM_QC_NO},
+	{0x332A, UNICODE_NORM_QC_NO},
+	{0x332B, UNICODE_NORM_QC_NO},
+	{0x332C, UNICODE_NORM_QC_NO},
+	{0x332D, UNICODE_NORM_QC_NO},
+	{0x332E, UNICODE_NORM_QC_NO},
+	{0x332F, UNICODE_NORM_QC_NO},
+	{0x3330, UNICODE_NORM_QC_NO},
+	{0x3331, UNICODE_NORM_QC_NO},
+	{0x3332, UNICODE_NORM_QC_NO},
+	{0x3333, UNICODE_NORM_QC_NO},
+	{0x3334, UNICODE_NORM_QC_NO},
+	{0x3335, UNICODE_NORM_QC_NO},
+	{0x3336, UNICODE_NORM_QC_NO},
+	{0x3337, UNICODE_NORM_QC_NO},
+	{0x3338, UNICODE_NORM_QC_NO},
+	{0x3339, UNICODE_NORM_QC_NO},
+	{0x333A, UNICODE_NORM_QC_NO},
+	{0x333B, UNICODE_NORM_QC_NO},
+	{0x333C, UNICODE_NORM_QC_NO},
+	{0x333D, UNICODE_NORM_QC_NO},
+	{0x333E, UNICODE_NORM_QC_NO},
+	{0x333F, UNICODE_NORM_QC_NO},
+	{0x3340, UNICODE_NORM_QC_NO},
+	{0x3341, UNICODE_NORM_QC_NO},
+	{0x3342, UNICODE_NORM_QC_NO},
+	{0x3343, UNICODE_NORM_QC_NO},
+	{0x3344, UNICODE_NORM_QC_NO},
+	{0x3345, UNICODE_NORM_QC_NO},
+	{0x3346, UNICODE_NORM_QC_NO},
+	{0x3347, UNICODE_NORM_QC_NO},
+	{0x3348, UNICODE_NORM_QC_NO},
+	{0x3349, UNICODE_NORM_QC_NO},
+	{0x334A, UNICODE_NORM_QC_NO},
+	{0x334B, UNICODE_NORM_QC_NO},
+	{0x334C, UNICODE_NORM_QC_NO},
+	{0x334D, UNICODE_NORM_QC_NO},
+	{0x334E, UNICODE_NORM_QC_NO},
+	{0x334F, UNICODE_NORM_QC_NO},
+	{0x3350, UNICODE_NORM_QC_NO},
+	{0x3351, UNICODE_NORM_QC_NO},
+	{0x3352, UNICODE_NORM_QC_NO},
+	{0x3353, UNICODE_NORM_QC_NO},
+	{0x3354, UNICODE_NORM_QC_NO},
+	{0x3355, UNICODE_NORM_QC_NO},
+	{0x3356, UNICODE_NORM_QC_NO},
+	{0x3357, UNICODE_NORM_QC_NO},
+	{0x3358, UNICODE_NORM_QC_NO},
+	{0x3359, UNICODE_NORM_QC_NO},
+	{0x335A, UNICODE_NORM_QC_NO},
+	{0x335B, UNICODE_NORM_QC_NO},
+	{0x335C, UNICODE_NORM_QC_NO},
+	{0x335D, UNICODE_NORM_QC_NO},
+	{0x335E, UNICODE_NORM_QC_NO},
+	{0x335F, UNICODE_NORM_QC_NO},
+	{0x3360, UNICODE_NORM_QC_NO},
+	{0x3361, UNICODE_NORM_QC_NO},
+	{0x3362, UNICODE_NORM_QC_NO},
+	{0x3363, UNICODE_NORM_QC_NO},
+	{0x3364, UNICODE_NORM_QC_NO},
+	{0x3365, UNICODE_NORM_QC_NO},
+	{0x3366, UNICODE_NORM_QC_NO},
+	{0x3367, UNICODE_NORM_QC_NO},
+	{0x3368, UNICODE_NORM_QC_NO},
+	{0x3369, UNICODE_NORM_QC_NO},
+	{0x336A, UNICODE_NORM_QC_NO},
+	{0x336B, UNICODE_NORM_QC_NO},
+	{0x336C, UNICODE_NORM_QC_NO},
+	{0x336D, UNICODE_NORM_QC_NO},
+	{0x336E, UNICODE_NORM_QC_NO},
+	{0x336F, UNICODE_NORM_QC_NO},
+	{0x3370, UNICODE_NORM_QC_NO},
+	{0x3371, UNICODE_NORM_QC_NO},
+	{0x3372, UNICODE_NORM_QC_NO},
+	{0x3373, UNICODE_NORM_QC_NO},
+	{0x3374, UNICODE_NORM_QC_NO},
+	{0x3375, UNICODE_NORM_QC_NO},
+	{0x3376, UNICODE_NORM_QC_NO},
+	{0x3377, UNICODE_NORM_QC_NO},
+	{0x3378, UNICODE_NORM_QC_NO},
+	{0x3379, UNICODE_NORM_QC_NO},
+	{0x337A, UNICODE_NORM_QC_NO},
+	{0x337B, UNICODE_NORM_QC_NO},
+	{0x337C, UNICODE_NORM_QC_NO},
+	{0x337D, UNICODE_NORM_QC_NO},
+	{0x337E, UNICODE_NORM_QC_NO},
+	{0x337F, UNICODE_NORM_QC_NO},
+	{0x3380, UNICODE_NORM_QC_NO},
+	{0x3381, UNICODE_NORM_QC_NO},
+	{0x3382, UNICODE_NORM_QC_NO},
+	{0x3383, UNICODE_NORM_QC_NO},
+	{0x3384, UNICODE_NORM_QC_NO},
+	{0x3385, UNICODE_NORM_QC_NO},
+	{0x3386, UNICODE_NORM_QC_NO},
+	{0x3387, UNICODE_NORM_QC_NO},
+	{0x3388, UNICODE_NORM_QC_NO},
+	{0x3389, UNICODE_NORM_QC_NO},
+	{0x338A, UNICODE_NORM_QC_NO},
+	{0x338B, UNICODE_NORM_QC_NO},
+	{0x338C, UNICODE_NORM_QC_NO},
+	{0x338D, UNICODE_NORM_QC_NO},
+	{0x338E, UNICODE_NORM_QC_NO},
+	{0x338F, UNICODE_NORM_QC_NO},
+	{0x3390, UNICODE_NORM_QC_NO},
+	{0x3391, UNICODE_NORM_QC_NO},
+	{0x3392, UNICODE_NORM_QC_NO},
+	{0x3393, UNICODE_NORM_QC_NO},
+	{0x3394, UNICODE_NORM_QC_NO},
+	{0x3395, UNICODE_NORM_QC_NO},
+	{0x3396, UNICODE_NORM_QC_NO},
+	{0x3397, UNICODE_NORM_QC_NO},
+	{0x3398, UNICODE_NORM_QC_NO},
+	{0x3399, UNICODE_NORM_QC_NO},
+	{0x339A, UNICODE_NORM_QC_NO},
+	{0x339B, UNICODE_NORM_QC_NO},
+	{0x339C, UNICODE_NORM_QC_NO},
+	{0x339D, UNICODE_NORM_QC_NO},
+	{0x339E, UNICODE_NORM_QC_NO},
+	{0x339F, UNICODE_NORM_QC_NO},
+	{0x33A0, UNICODE_NORM_QC_NO},
+	{0x33A1, UNICODE_NORM_QC_NO},
+	{0x33A2, UNICODE_NORM_QC_NO},
+	{0x33A3, UNICODE_NORM_QC_NO},
+	{0x33A4, UNICODE_NORM_QC_NO},
+	{0x33A5, UNICODE_NORM_QC_NO},
+	{0x33A6, UNICODE_NORM_QC_NO},
+	{0x33A7, UNICODE_NORM_QC_NO},
+	{0x33A8, UNICODE_NORM_QC_NO},
+	{0x33A9, UNICODE_NORM_QC_NO},
+	{0x33AA, UNICODE_NORM_QC_NO},
+	{0x33AB, UNICODE_NORM_QC_NO},
+	{0x33AC, UNICODE_NORM_QC_NO},
+	{0x33AD, UNICODE_NORM_QC_NO},
+	{0x33AE, UNICODE_NORM_QC_NO},
+	{0x33AF, UNICODE_NORM_QC_NO},
+	{0x33B0, UNICODE_NORM_QC_NO},
+	{0x33B1, UNICODE_NORM_QC_NO},
+	{0x33B2, UNICODE_NORM_QC_NO},
+	{0x33B3, UNICODE_NORM_QC_NO},
+	{0x33B4, UNICODE_NORM_QC_NO},
+	{0x33B5, UNICODE_NORM_QC_NO},
+	{0x33B6, UNICODE_NORM_QC_NO},
+	{0x33B7, UNICODE_NORM_QC_NO},
+	{0x33B8, UNICODE_NORM_QC_NO},
+	{0x33B9, UNICODE_NORM_QC_NO},
+	{0x33BA, UNICODE_NORM_QC_NO},
+	{0x33BB, UNICODE_NORM_QC_NO},
+	{0x33BC, UNICODE_NORM_QC_NO},
+	{0x33BD, UNICODE_NORM_QC_NO},
+	{0x33BE, UNICODE_NORM_QC_NO},
+	{0x33BF, UNICODE_NORM_QC_NO},
+	{0x33C0, UNICODE_NORM_QC_NO},
+	{0x33C1, UNICODE_NORM_QC_NO},
+	{0x33C2, UNICODE_NORM_QC_NO},
+	{0x33C3, UNICODE_NORM_QC_NO},
+	{0x33C4, UNICODE_NORM_QC_NO},
+	{0x33C5, UNICODE_NORM_QC_NO},
+	{0x33C6, UNICODE_NORM_QC_NO},
+	{0x33C7, UNICODE_NORM_QC_NO},
+	{0x33C8, UNICODE_NORM_QC_NO},
+	{0x33C9, UNICODE_NORM_QC_NO},
+	{0x33CA, UNICODE_NORM_QC_NO},
+	{0x33CB, UNICODE_NORM_QC_NO},
+	{0x33CC, UNICODE_NORM_QC_NO},
+	{0x33CD, UNICODE_NORM_QC_NO},
+	{0x33CE, UNICODE_NORM_QC_NO},
+	{0x33CF, UNICODE_NORM_QC_NO},
+	{0x33D0, UNICODE_NORM_QC_NO},
+	{0x33D1, UNICODE_NORM_QC_NO},
+	{0x33D2, UNICODE_NORM_QC_NO},
+	{0x33D3, UNICODE_NORM_QC_NO},
+	{0x33D4, UNICODE_NORM_QC_NO},
+	{0x33D5, UNICODE_NORM_QC_NO},
+	{0x33D6, UNICODE_NORM_QC_NO},
+	{0x33D7, UNICODE_NORM_QC_NO},
+	{0x33D8, UNICODE_NORM_QC_NO},
+	{0x33D9, UNICODE_NORM_QC_NO},
+	{0x33DA, UNICODE_NORM_QC_NO},
+	{0x33DB, UNICODE_NORM_QC_NO},
+	{0x33DC, UNICODE_NORM_QC_NO},
+	{0x33DD, UNICODE_NORM_QC_NO},
+	{0x33DE, UNICODE_NORM_QC_NO},
+	{0x33DF, UNICODE_NORM_QC_NO},
+	{0x33E0, UNICODE_NORM_QC_NO},
+	{0x33E1, UNICODE_NORM_QC_NO},
+	{0x33E2, UNICODE_NORM_QC_NO},
+	{0x33E3, UNICODE_NORM_QC_NO},
+	{0x33E4, UNICODE_NORM_QC_NO},
+	{0x33E5, UNICODE_NORM_QC_NO},
+	{0x33E6, UNICODE_NORM_QC_NO},
+	{0x33E7, UNICODE_NORM_QC_NO},
+	{0x33E8, UNICODE_NORM_QC_NO},
+	{0x33E9, UNICODE_NORM_QC_NO},
+	{0x33EA, UNICODE_NORM_QC_NO},
+	{0x33EB, UNICODE_NORM_QC_NO},
+	{0x33EC, UNICODE_NORM_QC_NO},
+	{0x33ED, UNICODE_NORM_QC_NO},
+	{0x33EE, UNICODE_NORM_QC_NO},
+	{0x33EF, UNICODE_NORM_QC_NO},
+	{0x33F0, UNICODE_NORM_QC_NO},
+	{0x33F1, UNICODE_NORM_QC_NO},
+	{0x33F2, UNICODE_NORM_QC_NO},
+	{0x33F3, UNICODE_NORM_QC_NO},
+	{0x33F4, UNICODE_NORM_QC_NO},
+	{0x33F5, UNICODE_NORM_QC_NO},
+	{0x33F6, UNICODE_NORM_QC_NO},
+	{0x33F7, UNICODE_NORM_QC_NO},
+	{0x33F8, UNICODE_NORM_QC_NO},
+	{0x33F9, UNICODE_NORM_QC_NO},
+	{0x33FA, UNICODE_NORM_QC_NO},
+	{0x33FB, UNICODE_NORM_QC_NO},
+	{0x33FC, UNICODE_NORM_QC_NO},
+	{0x33FD, UNICODE_NORM_QC_NO},
+	{0x33FE, UNICODE_NORM_QC_NO},
+	{0x33FF, UNICODE_NORM_QC_NO},
+	{0xA69C, UNICODE_NORM_QC_NO},
+	{0xA69D, UNICODE_NORM_QC_NO},
+	{0xA770, UNICODE_NORM_QC_NO},
+	{0xA7F8, UNICODE_NORM_QC_NO},
+	{0xA7F9, UNICODE_NORM_QC_NO},
+	{0xAB5C, UNICODE_NORM_QC_NO},
+	{0xAB5D, UNICODE_NORM_QC_NO},
+	{0xAB5E, UNICODE_NORM_QC_NO},
+	{0xAB5F, UNICODE_NORM_QC_NO},
+	{0xF900, UNICODE_NORM_QC_NO},
+	{0xF901, UNICODE_NORM_QC_NO},
+	{0xF902, UNICODE_NORM_QC_NO},
+	{0xF903, UNICODE_NORM_QC_NO},
+	{0xF904, UNICODE_NORM_QC_NO},
+	{0xF905, UNICODE_NORM_QC_NO},
+	{0xF906, UNICODE_NORM_QC_NO},
+	{0xF907, UNICODE_NORM_QC_NO},
+	{0xF908, UNICODE_NORM_QC_NO},
+	{0xF909, UNICODE_NORM_QC_NO},
+	{0xF90A, UNICODE_NORM_QC_NO},
+	{0xF90B, UNICODE_NORM_QC_NO},
+	{0xF90C, UNICODE_NORM_QC_NO},
+	{0xF90D, UNICODE_NORM_QC_NO},
+	{0xF90E, UNICODE_NORM_QC_NO},
+	{0xF90F, UNICODE_NORM_QC_NO},
+	{0xF910, UNICODE_NORM_QC_NO},
+	{0xF911, UNICODE_NORM_QC_NO},
+	{0xF912, UNICODE_NORM_QC_NO},
+	{0xF913, UNICODE_NORM_QC_NO},
+	{0xF914, UNICODE_NORM_QC_NO},
+	{0xF915, UNICODE_NORM_QC_NO},
+	{0xF916, UNICODE_NORM_QC_NO},
+	{0xF917, UNICODE_NORM_QC_NO},
+	{0xF918, UNICODE_NORM_QC_NO},
+	{0xF919, UNICODE_NORM_QC_NO},
+	{0xF91A, UNICODE_NORM_QC_NO},
+	{0xF91B, UNICODE_NORM_QC_NO},
+	{0xF91C, UNICODE_NORM_QC_NO},
+	{0xF91D, UNICODE_NORM_QC_NO},
+	{0xF91E, UNICODE_NORM_QC_NO},
+	{0xF91F, UNICODE_NORM_QC_NO},
+	{0xF920, UNICODE_NORM_QC_NO},
+	{0xF921, UNICODE_NORM_QC_NO},
+	{0xF922, UNICODE_NORM_QC_NO},
+	{0xF923, UNICODE_NORM_QC_NO},
+	{0xF924, UNICODE_NORM_QC_NO},
+	{0xF925, UNICODE_NORM_QC_NO},
+	{0xF926, UNICODE_NORM_QC_NO},
+	{0xF927, UNICODE_NORM_QC_NO},
+	{0xF928, UNICODE_NORM_QC_NO},
+	{0xF929, UNICODE_NORM_QC_NO},
+	{0xF92A, UNICODE_NORM_QC_NO},
+	{0xF92B, UNICODE_NORM_QC_NO},
+	{0xF92C, UNICODE_NORM_QC_NO},
+	{0xF92D, UNICODE_NORM_QC_NO},
+	{0xF92E, UNICODE_NORM_QC_NO},
+	{0xF92F, UNICODE_NORM_QC_NO},
+	{0xF930, UNICODE_NORM_QC_NO},
+	{0xF931, UNICODE_NORM_QC_NO},
+	{0xF932, UNICODE_NORM_QC_NO},
+	{0xF933, UNICODE_NORM_QC_NO},
+	{0xF934, UNICODE_NORM_QC_NO},
+	{0xF935, UNICODE_NORM_QC_NO},
+	{0xF936, UNICODE_NORM_QC_NO},
+	{0xF937, UNICODE_NORM_QC_NO},
+	{0xF938, UNICODE_NORM_QC_NO},
+	{0xF939, UNICODE_NORM_QC_NO},
+	{0xF93A, UNICODE_NORM_QC_NO},
+	{0xF93B, UNICODE_NORM_QC_NO},
+	{0xF93C, UNICODE_NORM_QC_NO},
+	{0xF93D, UNICODE_NORM_QC_NO},
+	{0xF93E, UNICODE_NORM_QC_NO},
+	{0xF93F, UNICODE_NORM_QC_NO},
+	{0xF940, UNICODE_NORM_QC_NO},
+	{0xF941, UNICODE_NORM_QC_NO},
+	{0xF942, UNICODE_NORM_QC_NO},
+	{0xF943, UNICODE_NORM_QC_NO},
+	{0xF944, UNICODE_NORM_QC_NO},
+	{0xF945, UNICODE_NORM_QC_NO},
+	{0xF946, UNICODE_NORM_QC_NO},
+	{0xF947, UNICODE_NORM_QC_NO},
+	{0xF948, UNICODE_NORM_QC_NO},
+	{0xF949, UNICODE_NORM_QC_NO},
+	{0xF94A, UNICODE_NORM_QC_NO},
+	{0xF94B, UNICODE_NORM_QC_NO},
+	{0xF94C, UNICODE_NORM_QC_NO},
+	{0xF94D, UNICODE_NORM_QC_NO},
+	{0xF94E, UNICODE_NORM_QC_NO},
+	{0xF94F, UNICODE_NORM_QC_NO},
+	{0xF950, UNICODE_NORM_QC_NO},
+	{0xF951, UNICODE_NORM_QC_NO},
+	{0xF952, UNICODE_NORM_QC_NO},
+	{0xF953, UNICODE_NORM_QC_NO},
+	{0xF954, UNICODE_NORM_QC_NO},
+	{0xF955, UNICODE_NORM_QC_NO},
+	{0xF956, UNICODE_NORM_QC_NO},
+	{0xF957, UNICODE_NORM_QC_NO},
+	{0xF958, UNICODE_NORM_QC_NO},
+	{0xF959, UNICODE_NORM_QC_NO},
+	{0xF95A, UNICODE_NORM_QC_NO},
+	{0xF95B, UNICODE_NORM_QC_NO},
+	{0xF95C, UNICODE_NORM_QC_NO},
+	{0xF95D, UNICODE_NORM_QC_NO},
+	{0xF95E, UNICODE_NORM_QC_NO},
+	{0xF95F, UNICODE_NORM_QC_NO},
+	{0xF960, UNICODE_NORM_QC_NO},
+	{0xF961, UNICODE_NORM_QC_NO},
+	{0xF962, UNICODE_NORM_QC_NO},
+	{0xF963, UNICODE_NORM_QC_NO},
+	{0xF964, UNICODE_NORM_QC_NO},
+	{0xF965, UNICODE_NORM_QC_NO},
+	{0xF966, UNICODE_NORM_QC_NO},
+	{0xF967, UNICODE_NORM_QC_NO},
+	{0xF968, UNICODE_NORM_QC_NO},
+	{0xF969, UNICODE_NORM_QC_NO},
+	{0xF96A, UNICODE_NORM_QC_NO},
+	{0xF96B, UNICODE_NORM_QC_NO},
+	{0xF96C, UNICODE_NORM_QC_NO},
+	{0xF96D, UNICODE_NORM_QC_NO},
+	{0xF96E, UNICODE_NORM_QC_NO},
+	{0xF96F, UNICODE_NORM_QC_NO},
+	{0xF970, UNICODE_NORM_QC_NO},
+	{0xF971, UNICODE_NORM_QC_NO},
+	{0xF972, UNICODE_NORM_QC_NO},
+	{0xF973, UNICODE_NORM_QC_NO},
+	{0xF974, UNICODE_NORM_QC_NO},
+	{0xF975, UNICODE_NORM_QC_NO},
+	{0xF976, UNICODE_NORM_QC_NO},
+	{0xF977, UNICODE_NORM_QC_NO},
+	{0xF978, UNICODE_NORM_QC_NO},
+	{0xF979, UNICODE_NORM_QC_NO},
+	{0xF97A, UNICODE_NORM_QC_NO},
+	{0xF97B, UNICODE_NORM_QC_NO},
+	{0xF97C, UNICODE_NORM_QC_NO},
+	{0xF97D, UNICODE_NORM_QC_NO},
+	{0xF97E, UNICODE_NORM_QC_NO},
+	{0xF97F, UNICODE_NORM_QC_NO},
+	{0xF980, UNICODE_NORM_QC_NO},
+	{0xF981, UNICODE_NORM_QC_NO},
+	{0xF982, UNICODE_NORM_QC_NO},
+	{0xF983, UNICODE_NORM_QC_NO},
+	{0xF984, UNICODE_NORM_QC_NO},
+	{0xF985, UNICODE_NORM_QC_NO},
+	{0xF986, UNICODE_NORM_QC_NO},
+	{0xF987, UNICODE_NORM_QC_NO},
+	{0xF988, UNICODE_NORM_QC_NO},
+	{0xF989, UNICODE_NORM_QC_NO},
+	{0xF98A, UNICODE_NORM_QC_NO},
+	{0xF98B, UNICODE_NORM_QC_NO},
+	{0xF98C, UNICODE_NORM_QC_NO},
+	{0xF98D, UNICODE_NORM_QC_NO},
+	{0xF98E, UNICODE_NORM_QC_NO},
+	{0xF98F, UNICODE_NORM_QC_NO},
+	{0xF990, UNICODE_NORM_QC_NO},
+	{0xF991, UNICODE_NORM_QC_NO},
+	{0xF992, UNICODE_NORM_QC_NO},
+	{0xF993, UNICODE_NORM_QC_NO},
+	{0xF994, UNICODE_NORM_QC_NO},
+	{0xF995, UNICODE_NORM_QC_NO},
+	{0xF996, UNICODE_NORM_QC_NO},
+	{0xF997, UNICODE_NORM_QC_NO},
+	{0xF998, UNICODE_NORM_QC_NO},
+	{0xF999, UNICODE_NORM_QC_NO},
+	{0xF99A, UNICODE_NORM_QC_NO},
+	{0xF99B, UNICODE_NORM_QC_NO},
+	{0xF99C, UNICODE_NORM_QC_NO},
+	{0xF99D, UNICODE_NORM_QC_NO},
+	{0xF99E, UNICODE_NORM_QC_NO},
+	{0xF99F, UNICODE_NORM_QC_NO},
+	{0xF9A0, UNICODE_NORM_QC_NO},
+	{0xF9A1, UNICODE_NORM_QC_NO},
+	{0xF9A2, UNICODE_NORM_QC_NO},
+	{0xF9A3, UNICODE_NORM_QC_NO},
+	{0xF9A4, UNICODE_NORM_QC_NO},
+	{0xF9A5, UNICODE_NORM_QC_NO},
+	{0xF9A6, UNICODE_NORM_QC_NO},
+	{0xF9A7, UNICODE_NORM_QC_NO},
+	{0xF9A8, UNICODE_NORM_QC_NO},
+	{0xF9A9, UNICODE_NORM_QC_NO},
+	{0xF9AA, UNICODE_NORM_QC_NO},
+	{0xF9AB, UNICODE_NORM_QC_NO},
+	{0xF9AC, UNICODE_NORM_QC_NO},
+	{0xF9AD, UNICODE_NORM_QC_NO},
+	{0xF9AE, UNICODE_NORM_QC_NO},
+	{0xF9AF, UNICODE_NORM_QC_NO},
+	{0xF9B0, UNICODE_NORM_QC_NO},
+	{0xF9B1, UNICODE_NORM_QC_NO},
+	{0xF9B2, UNICODE_NORM_QC_NO},
+	{0xF9B3, UNICODE_NORM_QC_NO},
+	{0xF9B4, UNICODE_NORM_QC_NO},
+	{0xF9B5, UNICODE_NORM_QC_NO},
+	{0xF9B6, UNICODE_NORM_QC_NO},
+	{0xF9B7, UNICODE_NORM_QC_NO},
+	{0xF9B8, UNICODE_NORM_QC_NO},
+	{0xF9B9, UNICODE_NORM_QC_NO},
+	{0xF9BA, UNICODE_NORM_QC_NO},
+	{0xF9BB, UNICODE_NORM_QC_NO},
+	{0xF9BC, UNICODE_NORM_QC_NO},
+	{0xF9BD, UNICODE_NORM_QC_NO},
+	{0xF9BE, UNICODE_NORM_QC_NO},
+	{0xF9BF, UNICODE_NORM_QC_NO},
+	{0xF9C0, UNICODE_NORM_QC_NO},
+	{0xF9C1, UNICODE_NORM_QC_NO},
+	{0xF9C2, UNICODE_NORM_QC_NO},
+	{0xF9C3, UNICODE_NORM_QC_NO},
+	{0xF9C4, UNICODE_NORM_QC_NO},
+	{0xF9C5, UNICODE_NORM_QC_NO},
+	{0xF9C6, UNICODE_NORM_QC_NO},
+	{0xF9C7, UNICODE_NORM_QC_NO},
+	{0xF9C8, UNICODE_NORM_QC_NO},
+	{0xF9C9, UNICODE_NORM_QC_NO},
+	{0xF9CA, UNICODE_NORM_QC_NO},
+	{0xF9CB, UNICODE_NORM_QC_NO},
+	{0xF9CC, UNICODE_NORM_QC_NO},
+	{0xF9CD, UNICODE_NORM_QC_NO},
+	{0xF9CE, UNICODE_NORM_QC_NO},
+	{0xF9CF, UNICODE_NORM_QC_NO},
+	{0xF9D0, UNICODE_NORM_QC_NO},
+	{0xF9D1, UNICODE_NORM_QC_NO},
+	{0xF9D2, UNICODE_NORM_QC_NO},
+	{0xF9D3, UNICODE_NORM_QC_NO},
+	{0xF9D4, UNICODE_NORM_QC_NO},
+	{0xF9D5, UNICODE_NORM_QC_NO},
+	{0xF9D6, UNICODE_NORM_QC_NO},
+	{0xF9D7, UNICODE_NORM_QC_NO},
+	{0xF9D8, UNICODE_NORM_QC_NO},
+	{0xF9D9, UNICODE_NORM_QC_NO},
+	{0xF9DA, UNICODE_NORM_QC_NO},
+	{0xF9DB, UNICODE_NORM_QC_NO},
+	{0xF9DC, UNICODE_NORM_QC_NO},
+	{0xF9DD, UNICODE_NORM_QC_NO},
+	{0xF9DE, UNICODE_NORM_QC_NO},
+	{0xF9DF, UNICODE_NORM_QC_NO},
+	{0xF9E0, UNICODE_NORM_QC_NO},
+	{0xF9E1, UNICODE_NORM_QC_NO},
+	{0xF9E2, UNICODE_NORM_QC_NO},
+	{0xF9E3, UNICODE_NORM_QC_NO},
+	{0xF9E4, UNICODE_NORM_QC_NO},
+	{0xF9E5, UNICODE_NORM_QC_NO},
+	{0xF9E6, UNICODE_NORM_QC_NO},
+	{0xF9E7, UNICODE_NORM_QC_NO},
+	{0xF9E8, UNICODE_NORM_QC_NO},
+	{0xF9E9, UNICODE_NORM_QC_NO},
+	{0xF9EA, UNICODE_NORM_QC_NO},
+	{0xF9EB, UNICODE_NORM_QC_NO},
+	{0xF9EC, UNICODE_NORM_QC_NO},
+	{0xF9ED, UNICODE_NORM_QC_NO},
+	{0xF9EE, UNICODE_NORM_QC_NO},
+	{0xF9EF, UNICODE_NORM_QC_NO},
+	{0xF9F0, UNICODE_NORM_QC_NO},
+	{0xF9F1, UNICODE_NORM_QC_NO},
+	{0xF9F2, UNICODE_NORM_QC_NO},
+	{0xF9F3, UNICODE_NORM_QC_NO},
+	{0xF9F4, UNICODE_NORM_QC_NO},
+	{0xF9F5, UNICODE_NORM_QC_NO},
+	{0xF9F6, UNICODE_NORM_QC_NO},
+	{0xF9F7, UNICODE_NORM_QC_NO},
+	{0xF9F8, UNICODE_NORM_QC_NO},
+	{0xF9F9, UNICODE_NORM_QC_NO},
+	{0xF9FA, UNICODE_NORM_QC_NO},
+	{0xF9FB, UNICODE_NORM_QC_NO},
+	{0xF9FC, UNICODE_NORM_QC_NO},
+	{0xF9FD, UNICODE_NORM_QC_NO},
+	{0xF9FE, UNICODE_NORM_QC_NO},
+	{0xF9FF, UNICODE_NORM_QC_NO},
+	{0xFA00, UNICODE_NORM_QC_NO},
+	{0xFA01, UNICODE_NORM_QC_NO},
+	{0xFA02, UNICODE_NORM_QC_NO},
+	{0xFA03, UNICODE_NORM_QC_NO},
+	{0xFA04, UNICODE_NORM_QC_NO},
+	{0xFA05, UNICODE_NORM_QC_NO},
+	{0xFA06, UNICODE_NORM_QC_NO},
+	{0xFA07, UNICODE_NORM_QC_NO},
+	{0xFA08, UNICODE_NORM_QC_NO},
+	{0xFA09, UNICODE_NORM_QC_NO},
+	{0xFA0A, UNICODE_NORM_QC_NO},
+	{0xFA0B, UNICODE_NORM_QC_NO},
+	{0xFA0C, UNICODE_NORM_QC_NO},
+	{0xFA0D, UNICODE_NORM_QC_NO},
+	{0xFA10, UNICODE_NORM_QC_NO},
+	{0xFA12, UNICODE_NORM_QC_NO},
+	{0xFA15, UNICODE_NORM_QC_NO},
+	{0xFA16, UNICODE_NORM_QC_NO},
+	{0xFA17, UNICODE_NORM_QC_NO},
+	{0xFA18, UNICODE_NORM_QC_NO},
+	{0xFA19, UNICODE_NORM_QC_NO},
+	{0xFA1A, UNICODE_NORM_QC_NO},
+	{0xFA1B, UNICODE_NORM_QC_NO},
+	{0xFA1C, UNICODE_NORM_QC_NO},
+	{0xFA1D, UNICODE_NORM_QC_NO},
+	{0xFA1E, UNICODE_NORM_QC_NO},
+	{0xFA20, UNICODE_NORM_QC_NO},
+	{0xFA22, UNICODE_NORM_QC_NO},
+	{0xFA25, UNICODE_NORM_QC_NO},
+	{0xFA26, UNICODE_NORM_QC_NO},
+	{0xFA2A, UNICODE_NORM_QC_NO},
+	{0xFA2B, UNICODE_NORM_QC_NO},
+	{0xFA2C, UNICODE_NORM_QC_NO},
+	{0xFA2D, UNICODE_NORM_QC_NO},
+	{0xFA2E, UNICODE_NORM_QC_NO},
+	{0xFA2F, UNICODE_NORM_QC_NO},
+	{0xFA30, UNICODE_NORM_QC_NO},
+	{0xFA31, UNICODE_NORM_QC_NO},
+	{0xFA32, UNICODE_NORM_QC_NO},
+	{0xFA33, UNICODE_NORM_QC_NO},
+	{0xFA34, UNICODE_NORM_QC_NO},
+	{0xFA35, UNICODE_NORM_QC_NO},
+	{0xFA36, UNICODE_NORM_QC_NO},
+	{0xFA37, UNICODE_NORM_QC_NO},
+	{0xFA38, UNICODE_NORM_QC_NO},
+	{0xFA39, UNICODE_NORM_QC_NO},
+	{0xFA3A, UNICODE_NORM_QC_NO},
+	{0xFA3B, UNICODE_NORM_QC_NO},
+	{0xFA3C, UNICODE_NORM_QC_NO},
+	{0xFA3D, UNICODE_NORM_QC_NO},
+	{0xFA3E, UNICODE_NORM_QC_NO},
+	{0xFA3F, UNICODE_NORM_QC_NO},
+	{0xFA40, UNICODE_NORM_QC_NO},
+	{0xFA41, UNICODE_NORM_QC_NO},
+	{0xFA42, UNICODE_NORM_QC_NO},
+	{0xFA43, UNICODE_NORM_QC_NO},
+	{0xFA44, UNICODE_NORM_QC_NO},
+	{0xFA45, UNICODE_NORM_QC_NO},
+	{0xFA46, UNICODE_NORM_QC_NO},
+	{0xFA47, UNICODE_NORM_QC_NO},
+	{0xFA48, UNICODE_NORM_QC_NO},
+	{0xFA49, UNICODE_NORM_QC_NO},
+	{0xFA4A, UNICODE_NORM_QC_NO},
+	{0xFA4B, UNICODE_NORM_QC_NO},
+	{0xFA4C, UNICODE_NORM_QC_NO},
+	{0xFA4D, UNICODE_NORM_QC_NO},
+	{0xFA4E, UNICODE_NORM_QC_NO},
+	{0xFA4F, UNICODE_NORM_QC_NO},
+	{0xFA50, UNICODE_NORM_QC_NO},
+	{0xFA51, UNICODE_NORM_QC_NO},
+	{0xFA52, UNICODE_NORM_QC_NO},
+	{0xFA53, UNICODE_NORM_QC_NO},
+	{0xFA54, UNICODE_NORM_QC_NO},
+	{0xFA55, UNICODE_NORM_QC_NO},
+	{0xFA56, UNICODE_NORM_QC_NO},
+	{0xFA57, UNICODE_NORM_QC_NO},
+	{0xFA58, UNICODE_NORM_QC_NO},
+	{0xFA59, UNICODE_NORM_QC_NO},
+	{0xFA5A, UNICODE_NORM_QC_NO},
+	{0xFA5B, UNICODE_NORM_QC_NO},
+	{0xFA5C, UNICODE_NORM_QC_NO},
+	{0xFA5D, UNICODE_NORM_QC_NO},
+	{0xFA5E, UNICODE_NORM_QC_NO},
+	{0xFA5F, UNICODE_NORM_QC_NO},
+	{0xFA60, UNICODE_NORM_QC_NO},
+	{0xFA61, UNICODE_NORM_QC_NO},
+	{0xFA62, UNICODE_NORM_QC_NO},
+	{0xFA63, UNICODE_NORM_QC_NO},
+	{0xFA64, UNICODE_NORM_QC_NO},
+	{0xFA65, UNICODE_NORM_QC_NO},
+	{0xFA66, UNICODE_NORM_QC_NO},
+	{0xFA67, UNICODE_NORM_QC_NO},
+	{0xFA68, UNICODE_NORM_QC_NO},
+	{0xFA69, UNICODE_NORM_QC_NO},
+	{0xFA6A, UNICODE_NORM_QC_NO},
+	{0xFA6B, UNICODE_NORM_QC_NO},
+	{0xFA6C, UNICODE_NORM_QC_NO},
+	{0xFA6D, UNICODE_NORM_QC_NO},
+	{0xFA70, UNICODE_NORM_QC_NO},
+	{0xFA71, UNICODE_NORM_QC_NO},
+	{0xFA72, UNICODE_NORM_QC_NO},
+	{0xFA73, UNICODE_NORM_QC_NO},
+	{0xFA74, UNICODE_NORM_QC_NO},
+	{0xFA75, UNICODE_NORM_QC_NO},
+	{0xFA76, UNICODE_NORM_QC_NO},
+	{0xFA77, UNICODE_NORM_QC_NO},
+	{0xFA78, UNICODE_NORM_QC_NO},
+	{0xFA79, UNICODE_NORM_QC_NO},
+	{0xFA7A, UNICODE_NORM_QC_NO},
+	{0xFA7B, UNICODE_NORM_QC_NO},
+	{0xFA7C, UNICODE_NORM_QC_NO},
+	{0xFA7D, UNICODE_NORM_QC_NO},
+	{0xFA7E, UNICODE_NORM_QC_NO},
+	{0xFA7F, UNICODE_NORM_QC_NO},
+	{0xFA80, UNICODE_NORM_QC_NO},
+	{0xFA81, UNICODE_NORM_QC_NO},
+	{0xFA82, UNICODE_NORM_QC_NO},
+	{0xFA83, UNICODE_NORM_QC_NO},
+	{0xFA84, UNICODE_NORM_QC_NO},
+	{0xFA85, UNICODE_NORM_QC_NO},
+	{0xFA86, UNICODE_NORM_QC_NO},
+	{0xFA87, UNICODE_NORM_QC_NO},
+	{0xFA88, UNICODE_NORM_QC_NO},
+	{0xFA89, UNICODE_NORM_QC_NO},
+	{0xFA8A, UNICODE_NORM_QC_NO},
+	{0xFA8B, UNICODE_NORM_QC_NO},
+	{0xFA8C, UNICODE_NORM_QC_NO},
+	{0xFA8D, UNICODE_NORM_QC_NO},
+	{0xFA8E, UNICODE_NORM_QC_NO},
+	{0xFA8F, UNICODE_NORM_QC_NO},
+	{0xFA90, UNICODE_NORM_QC_NO},
+	{0xFA91, UNICODE_NORM_QC_NO},
+	{0xFA92, UNICODE_NORM_QC_NO},
+	{0xFA93, UNICODE_NORM_QC_NO},
+	{0xFA94, UNICODE_NORM_QC_NO},
+	{0xFA95, UNICODE_NORM_QC_NO},
+	{0xFA96, UNICODE_NORM_QC_NO},
+	{0xFA97, UNICODE_NORM_QC_NO},
+	{0xFA98, UNICODE_NORM_QC_NO},
+	{0xFA99, UNICODE_NORM_QC_NO},
+	{0xFA9A, UNICODE_NORM_QC_NO},
+	{0xFA9B, UNICODE_NORM_QC_NO},
+	{0xFA9C, UNICODE_NORM_QC_NO},
+	{0xFA9D, UNICODE_NORM_QC_NO},
+	{0xFA9E, UNICODE_NORM_QC_NO},
+	{0xFA9F, UNICODE_NORM_QC_NO},
+	{0xFAA0, UNICODE_NORM_QC_NO},
+	{0xFAA1, UNICODE_NORM_QC_NO},
+	{0xFAA2, UNICODE_NORM_QC_NO},
+	{0xFAA3, UNICODE_NORM_QC_NO},
+	{0xFAA4, UNICODE_NORM_QC_NO},
+	{0xFAA5, UNICODE_NORM_QC_NO},
+	{0xFAA6, UNICODE_NORM_QC_NO},
+	{0xFAA7, UNICODE_NORM_QC_NO},
+	{0xFAA8, UNICODE_NORM_QC_NO},
+	{0xFAA9, UNICODE_NORM_QC_NO},
+	{0xFAAA, UNICODE_NORM_QC_NO},
+	{0xFAAB, UNICODE_NORM_QC_NO},
+	{0xFAAC, UNICODE_NORM_QC_NO},
+	{0xFAAD, UNICODE_NORM_QC_NO},
+	{0xFAAE, UNICODE_NORM_QC_NO},
+	{0xFAAF, UNICODE_NORM_QC_NO},
+	{0xFAB0, UNICODE_NORM_QC_NO},
+	{0xFAB1, UNICODE_NORM_QC_NO},
+	{0xFAB2, UNICODE_NORM_QC_NO},
+	{0xFAB3, UNICODE_NORM_QC_NO},
+	{0xFAB4, UNICODE_NORM_QC_NO},
+	{0xFAB5, UNICODE_NORM_QC_NO},
+	{0xFAB6, UNICODE_NORM_QC_NO},
+	{0xFAB7, UNICODE_NORM_QC_NO},
+	{0xFAB8, UNICODE_NORM_QC_NO},
+	{0xFAB9, UNICODE_NORM_QC_NO},
+	{0xFABA, UNICODE_NORM_QC_NO},
+	{0xFABB, UNICODE_NORM_QC_NO},
+	{0xFABC, UNICODE_NORM_QC_NO},
+	{0xFABD, UNICODE_NORM_QC_NO},
+	{0xFABE, UNICODE_NORM_QC_NO},
+	{0xFABF, UNICODE_NORM_QC_NO},
+	{0xFAC0, UNICODE_NORM_QC_NO},
+	{0xFAC1, UNICODE_NORM_QC_NO},
+	{0xFAC2, UNICODE_NORM_QC_NO},
+	{0xFAC3, UNICODE_NORM_QC_NO},
+	{0xFAC4, UNICODE_NORM_QC_NO},
+	{0xFAC5, UNICODE_NORM_QC_NO},
+	{0xFAC6, UNICODE_NORM_QC_NO},
+	{0xFAC7, UNICODE_NORM_QC_NO},
+	{0xFAC8, UNICODE_NORM_QC_NO},
+	{0xFAC9, UNICODE_NORM_QC_NO},
+	{0xFACA, UNICODE_NORM_QC_NO},
+	{0xFACB, UNICODE_NORM_QC_NO},
+	{0xFACC, UNICODE_NORM_QC_NO},
+	{0xFACD, UNICODE_NORM_QC_NO},
+	{0xFACE, UNICODE_NORM_QC_NO},
+	{0xFACF, UNICODE_NORM_QC_NO},
+	{0xFAD0, UNICODE_NORM_QC_NO},
+	{0xFAD1, UNICODE_NORM_QC_NO},
+	{0xFAD2, UNICODE_NORM_QC_NO},
+	{0xFAD3, UNICODE_NORM_QC_NO},
+	{0xFAD4, UNICODE_NORM_QC_NO},
+	{0xFAD5, UNICODE_NORM_QC_NO},
+	{0xFAD6, UNICODE_NORM_QC_NO},
+	{0xFAD7, UNICODE_NORM_QC_NO},
+	{0xFAD8, UNICODE_NORM_QC_NO},
+	{0xFAD9, UNICODE_NORM_QC_NO},
+	{0xFB00, UNICODE_NORM_QC_NO},
+	{0xFB01, UNICODE_NORM_QC_NO},
+	{0xFB02, UNICODE_NORM_QC_NO},
+	{0xFB03, UNICODE_NORM_QC_NO},
+	{0xFB04, UNICODE_NORM_QC_NO},
+	{0xFB05, UNICODE_NORM_QC_NO},
+	{0xFB06, UNICODE_NORM_QC_NO},
+	{0xFB13, UNICODE_NORM_QC_NO},
+	{0xFB14, UNICODE_NORM_QC_NO},
+	{0xFB15, UNICODE_NORM_QC_NO},
+	{0xFB16, UNICODE_NORM_QC_NO},
+	{0xFB17, UNICODE_NORM_QC_NO},
+	{0xFB1D, UNICODE_NORM_QC_NO},
+	{0xFB1F, UNICODE_NORM_QC_NO},
+	{0xFB20, UNICODE_NORM_QC_NO},
+	{0xFB21, UNICODE_NORM_QC_NO},
+	{0xFB22, UNICODE_NORM_QC_NO},
+	{0xFB23, UNICODE_NORM_QC_NO},
+	{0xFB24, UNICODE_NORM_QC_NO},
+	{0xFB25, UNICODE_NORM_QC_NO},
+	{0xFB26, UNICODE_NORM_QC_NO},
+	{0xFB27, UNICODE_NORM_QC_NO},
+	{0xFB28, UNICODE_NORM_QC_NO},
+	{0xFB29, UNICODE_NORM_QC_NO},
+	{0xFB2A, UNICODE_NORM_QC_NO},
+	{0xFB2B, UNICODE_NORM_QC_NO},
+	{0xFB2C, UNICODE_NORM_QC_NO},
+	{0xFB2D, UNICODE_NORM_QC_NO},
+	{0xFB2E, UNICODE_NORM_QC_NO},
+	{0xFB2F, UNICODE_NORM_QC_NO},
+	{0xFB30, UNICODE_NORM_QC_NO},
+	{0xFB31, UNICODE_NORM_QC_NO},
+	{0xFB32, UNICODE_NORM_QC_NO},
+	{0xFB33, UNICODE_NORM_QC_NO},
+	{0xFB34, UNICODE_NORM_QC_NO},
+	{0xFB35, UNICODE_NORM_QC_NO},
+	{0xFB36, UNICODE_NORM_QC_NO},
+	{0xFB38, UNICODE_NORM_QC_NO},
+	{0xFB39, UNICODE_NORM_QC_NO},
+	{0xFB3A, UNICODE_NORM_QC_NO},
+	{0xFB3B, UNICODE_NORM_QC_NO},
+	{0xFB3C, UNICODE_NORM_QC_NO},
+	{0xFB3E, UNICODE_NORM_QC_NO},
+	{0xFB40, UNICODE_NORM_QC_NO},
+	{0xFB41, UNICODE_NORM_QC_NO},
+	{0xFB43, UNICODE_NORM_QC_NO},
+	{0xFB44, UNICODE_NORM_QC_NO},
+	{0xFB46, UNICODE_NORM_QC_NO},
+	{0xFB47, UNICODE_NORM_QC_NO},
+	{0xFB48, UNICODE_NORM_QC_NO},
+	{0xFB49, UNICODE_NORM_QC_NO},
+	{0xFB4A, UNICODE_NORM_QC_NO},
+	{0xFB4B, UNICODE_NORM_QC_NO},
+	{0xFB4C, UNICODE_NORM_QC_NO},
+	{0xFB4D, UNICODE_NORM_QC_NO},
+	{0xFB4E, UNICODE_NORM_QC_NO},
+	{0xFB4F, UNICODE_NORM_QC_NO},
+	{0xFB50, UNICODE_NORM_QC_NO},
+	{0xFB51, UNICODE_NORM_QC_NO},
+	{0xFB52, UNICODE_NORM_QC_NO},
+	{0xFB53, UNICODE_NORM_QC_NO},
+	{0xFB54, UNICODE_NORM_QC_NO},
+	{0xFB55, UNICODE_NORM_QC_NO},
+	{0xFB56, UNICODE_NORM_QC_NO},
+	{0xFB57, UNICODE_NORM_QC_NO},
+	{0xFB58, UNICODE_NORM_QC_NO},
+	{0xFB59, UNICODE_NORM_QC_NO},
+	{0xFB5A, UNICODE_NORM_QC_NO},
+	{0xFB5B, UNICODE_NORM_QC_NO},
+	{0xFB5C, UNICODE_NORM_QC_NO},
+	{0xFB5D, UNICODE_NORM_QC_NO},
+	{0xFB5E, UNICODE_NORM_QC_NO},
+	{0xFB5F, UNICODE_NORM_QC_NO},
+	{0xFB60, UNICODE_NORM_QC_NO},
+	{0xFB61, UNICODE_NORM_QC_NO},
+	{0xFB62, UNICODE_NORM_QC_NO},
+	{0xFB63, UNICODE_NORM_QC_NO},
+	{0xFB64, UNICODE_NORM_QC_NO},
+	{0xFB65, UNICODE_NORM_QC_NO},
+	{0xFB66, UNICODE_NORM_QC_NO},
+	{0xFB67, UNICODE_NORM_QC_NO},
+	{0xFB68, UNICODE_NORM_QC_NO},
+	{0xFB69, UNICODE_NORM_QC_NO},
+	{0xFB6A, UNICODE_NORM_QC_NO},
+	{0xFB6B, UNICODE_NORM_QC_NO},
+	{0xFB6C, UNICODE_NORM_QC_NO},
+	{0xFB6D, UNICODE_NORM_QC_NO},
+	{0xFB6E, UNICODE_NORM_QC_NO},
+	{0xFB6F, UNICODE_NORM_QC_NO},
+	{0xFB70, UNICODE_NORM_QC_NO},
+	{0xFB71, UNICODE_NORM_QC_NO},
+	{0xFB72, UNICODE_NORM_QC_NO},
+	{0xFB73, UNICODE_NORM_QC_NO},
+	{0xFB74, UNICODE_NORM_QC_NO},
+	{0xFB75, UNICODE_NORM_QC_NO},
+	{0xFB76, UNICODE_NORM_QC_NO},
+	{0xFB77, UNICODE_NORM_QC_NO},
+	{0xFB78, UNICODE_NORM_QC_NO},
+	{0xFB79, UNICODE_NORM_QC_NO},
+	{0xFB7A, UNICODE_NORM_QC_NO},
+	{0xFB7B, UNICODE_NORM_QC_NO},
+	{0xFB7C, UNICODE_NORM_QC_NO},
+	{0xFB7D, UNICODE_NORM_QC_NO},
+	{0xFB7E, UNICODE_NORM_QC_NO},
+	{0xFB7F, UNICODE_NORM_QC_NO},
+	{0xFB80, UNICODE_NORM_QC_NO},
+	{0xFB81, UNICODE_NORM_QC_NO},
+	{0xFB82, UNICODE_NORM_QC_NO},
+	{0xFB83, UNICODE_NORM_QC_NO},
+	{0xFB84, UNICODE_NORM_QC_NO},
+	{0xFB85, UNICODE_NORM_QC_NO},
+	{0xFB86, UNICODE_NORM_QC_NO},
+	{0xFB87, UNICODE_NORM_QC_NO},
+	{0xFB88, UNICODE_NORM_QC_NO},
+	{0xFB89, UNICODE_NORM_QC_NO},
+	{0xFB8A, UNICODE_NORM_QC_NO},
+	{0xFB8B, UNICODE_NORM_QC_NO},
+	{0xFB8C, UNICODE_NORM_QC_NO},
+	{0xFB8D, UNICODE_NORM_QC_NO},
+	{0xFB8E, UNICODE_NORM_QC_NO},
+	{0xFB8F, UNICODE_NORM_QC_NO},
+	{0xFB90, UNICODE_NORM_QC_NO},
+	{0xFB91, UNICODE_NORM_QC_NO},
+	{0xFB92, UNICODE_NORM_QC_NO},
+	{0xFB93, UNICODE_NORM_QC_NO},
+	{0xFB94, UNICODE_NORM_QC_NO},
+	{0xFB95, UNICODE_NORM_QC_NO},
+	{0xFB96, UNICODE_NORM_QC_NO},
+	{0xFB97, UNICODE_NORM_QC_NO},
+	{0xFB98, UNICODE_NORM_QC_NO},
+	{0xFB99, UNICODE_NORM_QC_NO},
+	{0xFB9A, UNICODE_NORM_QC_NO},
+	{0xFB9B, UNICODE_NORM_QC_NO},
+	{0xFB9C, UNICODE_NORM_QC_NO},
+	{0xFB9D, UNICODE_NORM_QC_NO},
+	{0xFB9E, UNICODE_NORM_QC_NO},
+	{0xFB9F, UNICODE_NORM_QC_NO},
+	{0xFBA0, UNICODE_NORM_QC_NO},
+	{0xFBA1, UNICODE_NORM_QC_NO},
+	{0xFBA2, UNICODE_NORM_QC_NO},
+	{0xFBA3, UNICODE_NORM_QC_NO},
+	{0xFBA4, UNICODE_NORM_QC_NO},
+	{0xFBA5, UNICODE_NORM_QC_NO},
+	{0xFBA6, UNICODE_NORM_QC_NO},
+	{0xFBA7, UNICODE_NORM_QC_NO},
+	{0xFBA8, UNICODE_NORM_QC_NO},
+	{0xFBA9, UNICODE_NORM_QC_NO},
+	{0xFBAA, UNICODE_NORM_QC_NO},
+	{0xFBAB, UNICODE_NORM_QC_NO},
+	{0xFBAC, UNICODE_NORM_QC_NO},
+	{0xFBAD, UNICODE_NORM_QC_NO},
+	{0xFBAE, UNICODE_NORM_QC_NO},
+	{0xFBAF, UNICODE_NORM_QC_NO},
+	{0xFBB0, UNICODE_NORM_QC_NO},
+	{0xFBB1, UNICODE_NORM_QC_NO},
+	{0xFBD3, UNICODE_NORM_QC_NO},
+	{0xFBD4, UNICODE_NORM_QC_NO},
+	{0xFBD5, UNICODE_NORM_QC_NO},
+	{0xFBD6, UNICODE_NORM_QC_NO},
+	{0xFBD7, UNICODE_NORM_QC_NO},
+	{0xFBD8, UNICODE_NORM_QC_NO},
+	{0xFBD9, UNICODE_NORM_QC_NO},
+	{0xFBDA, UNICODE_NORM_QC_NO},
+	{0xFBDB, UNICODE_NORM_QC_NO},
+	{0xFBDC, UNICODE_NORM_QC_NO},
+	{0xFBDD, UNICODE_NORM_QC_NO},
+	{0xFBDE, UNICODE_NORM_QC_NO},
+	{0xFBDF, UNICODE_NORM_QC_NO},
+	{0xFBE0, UNICODE_NORM_QC_NO},
+	{0xFBE1, UNICODE_NORM_QC_NO},
+	{0xFBE2, UNICODE_NORM_QC_NO},
+	{0xFBE3, UNICODE_NORM_QC_NO},
+	{0xFBE4, UNICODE_NORM_QC_NO},
+	{0xFBE5, UNICODE_NORM_QC_NO},
+	{0xFBE6, UNICODE_NORM_QC_NO},
+	{0xFBE7, UNICODE_NORM_QC_NO},
+	{0xFBE8, UNICODE_NORM_QC_NO},
+	{0xFBE9, UNICODE_NORM_QC_NO},
+	{0xFBEA, UNICODE_NORM_QC_NO},
+	{0xFBEB, UNICODE_NORM_QC_NO},
+	{0xFBEC, UNICODE_NORM_QC_NO},
+	{0xFBED, UNICODE_NORM_QC_NO},
+	{0xFBEE, UNICODE_NORM_QC_NO},
+	{0xFBEF, UNICODE_NORM_QC_NO},
+	{0xFBF0, UNICODE_NORM_QC_NO},
+	{0xFBF1, UNICODE_NORM_QC_NO},
+	{0xFBF2, UNICODE_NORM_QC_NO},
+	{0xFBF3, UNICODE_NORM_QC_NO},
+	{0xFBF4, UNICODE_NORM_QC_NO},
+	{0xFBF5, UNICODE_NORM_QC_NO},
+	{0xFBF6, UNICODE_NORM_QC_NO},
+	{0xFBF7, UNICODE_NORM_QC_NO},
+	{0xFBF8, UNICODE_NORM_QC_NO},
+	{0xFBF9, UNICODE_NORM_QC_NO},
+	{0xFBFA, UNICODE_NORM_QC_NO},
+	{0xFBFB, UNICODE_NORM_QC_NO},
+	{0xFBFC, UNICODE_NORM_QC_NO},
+	{0xFBFD, UNICODE_NORM_QC_NO},
+	{0xFBFE, UNICODE_NORM_QC_NO},
+	{0xFBFF, UNICODE_NORM_QC_NO},
+	{0xFC00, UNICODE_NORM_QC_NO},
+	{0xFC01, UNICODE_NORM_QC_NO},
+	{0xFC02, UNICODE_NORM_QC_NO},
+	{0xFC03, UNICODE_NORM_QC_NO},
+	{0xFC04, UNICODE_NORM_QC_NO},
+	{0xFC05, UNICODE_NORM_QC_NO},
+	{0xFC06, UNICODE_NORM_QC_NO},
+	{0xFC07, UNICODE_NORM_QC_NO},
+	{0xFC08, UNICODE_NORM_QC_NO},
+	{0xFC09, UNICODE_NORM_QC_NO},
+	{0xFC0A, UNICODE_NORM_QC_NO},
+	{0xFC0B, UNICODE_NORM_QC_NO},
+	{0xFC0C, UNICODE_NORM_QC_NO},
+	{0xFC0D, UNICODE_NORM_QC_NO},
+	{0xFC0E, UNICODE_NORM_QC_NO},
+	{0xFC0F, UNICODE_NORM_QC_NO},
+	{0xFC10, UNICODE_NORM_QC_NO},
+	{0xFC11, UNICODE_NORM_QC_NO},
+	{0xFC12, UNICODE_NORM_QC_NO},
+	{0xFC13, UNICODE_NORM_QC_NO},
+	{0xFC14, UNICODE_NORM_QC_NO},
+	{0xFC15, UNICODE_NORM_QC_NO},
+	{0xFC16, UNICODE_NORM_QC_NO},
+	{0xFC17, UNICODE_NORM_QC_NO},
+	{0xFC18, UNICODE_NORM_QC_NO},
+	{0xFC19, UNICODE_NORM_QC_NO},
+	{0xFC1A, UNICODE_NORM_QC_NO},
+	{0xFC1B, UNICODE_NORM_QC_NO},
+	{0xFC1C, UNICODE_NORM_QC_NO},
+	{0xFC1D, UNICODE_NORM_QC_NO},
+	{0xFC1E, UNICODE_NORM_QC_NO},
+	{0xFC1F, UNICODE_NORM_QC_NO},
+	{0xFC20, UNICODE_NORM_QC_NO},
+	{0xFC21, UNICODE_NORM_QC_NO},
+	{0xFC22, UNICODE_NORM_QC_NO},
+	{0xFC23, UNICODE_NORM_QC_NO},
+	{0xFC24, UNICODE_NORM_QC_NO},
+	{0xFC25, UNICODE_NORM_QC_NO},
+	{0xFC26, UNICODE_NORM_QC_NO},
+	{0xFC27, UNICODE_NORM_QC_NO},
+	{0xFC28, UNICODE_NORM_QC_NO},
+	{0xFC29, UNICODE_NORM_QC_NO},
+	{0xFC2A, UNICODE_NORM_QC_NO},
+	{0xFC2B, UNICODE_NORM_QC_NO},
+	{0xFC2C, UNICODE_NORM_QC_NO},
+	{0xFC2D, UNICODE_NORM_QC_NO},
+	{0xFC2E, UNICODE_NORM_QC_NO},
+	{0xFC2F, UNICODE_NORM_QC_NO},
+	{0xFC30, UNICODE_NORM_QC_NO},
+	{0xFC31, UNICODE_NORM_QC_NO},
+	{0xFC32, UNICODE_NORM_QC_NO},
+	{0xFC33, UNICODE_NORM_QC_NO},
+	{0xFC34, UNICODE_NORM_QC_NO},
+	{0xFC35, UNICODE_NORM_QC_NO},
+	{0xFC36, UNICODE_NORM_QC_NO},
+	{0xFC37, UNICODE_NORM_QC_NO},
+	{0xFC38, UNICODE_NORM_QC_NO},
+	{0xFC39, UNICODE_NORM_QC_NO},
+	{0xFC3A, UNICODE_NORM_QC_NO},
+	{0xFC3B, UNICODE_NORM_QC_NO},
+	{0xFC3C, UNICODE_NORM_QC_NO},
+	{0xFC3D, UNICODE_NORM_QC_NO},
+	{0xFC3E, UNICODE_NORM_QC_NO},
+	{0xFC3F, UNICODE_NORM_QC_NO},
+	{0xFC40, UNICODE_NORM_QC_NO},
+	{0xFC41, UNICODE_NORM_QC_NO},
+	{0xFC42, UNICODE_NORM_QC_NO},
+	{0xFC43, UNICODE_NORM_QC_NO},
+	{0xFC44, UNICODE_NORM_QC_NO},
+	{0xFC45, UNICODE_NORM_QC_NO},
+	{0xFC46, UNICODE_NORM_QC_NO},
+	{0xFC47, UNICODE_NORM_QC_NO},
+	{0xFC48, UNICODE_NORM_QC_NO},
+	{0xFC49, UNICODE_NORM_QC_NO},
+	{0xFC4A, UNICODE_NORM_QC_NO},
+	{0xFC4B, UNICODE_NORM_QC_NO},
+	{0xFC4C, UNICODE_NORM_QC_NO},
+	{0xFC4D, UNICODE_NORM_QC_NO},
+	{0xFC4E, UNICODE_NORM_QC_NO},
+	{0xFC4F, UNICODE_NORM_QC_NO},
+	{0xFC50, UNICODE_NORM_QC_NO},
+	{0xFC51, UNICODE_NORM_QC_NO},
+	{0xFC52, UNICODE_NORM_QC_NO},
+	{0xFC53, UNICODE_NORM_QC_NO},
+	{0xFC54, UNICODE_NORM_QC_NO},
+	{0xFC55, UNICODE_NORM_QC_NO},
+	{0xFC56, UNICODE_NORM_QC_NO},
+	{0xFC57, UNICODE_NORM_QC_NO},
+	{0xFC58, UNICODE_NORM_QC_NO},
+	{0xFC59, UNICODE_NORM_QC_NO},
+	{0xFC5A, UNICODE_NORM_QC_NO},
+	{0xFC5B, UNICODE_NORM_QC_NO},
+	{0xFC5C, UNICODE_NORM_QC_NO},
+	{0xFC5D, UNICODE_NORM_QC_NO},
+	{0xFC5E, UNICODE_NORM_QC_NO},
+	{0xFC5F, UNICODE_NORM_QC_NO},
+	{0xFC60, UNICODE_NORM_QC_NO},
+	{0xFC61, UNICODE_NORM_QC_NO},
+	{0xFC62, UNICODE_NORM_QC_NO},
+	{0xFC63, UNICODE_NORM_QC_NO},
+	{0xFC64, UNICODE_NORM_QC_NO},
+	{0xFC65, UNICODE_NORM_QC_NO},
+	{0xFC66, UNICODE_NORM_QC_NO},
+	{0xFC67, UNICODE_NORM_QC_NO},
+	{0xFC68, UNICODE_NORM_QC_NO},
+	{0xFC69, UNICODE_NORM_QC_NO},
+	{0xFC6A, UNICODE_NORM_QC_NO},
+	{0xFC6B, UNICODE_NORM_QC_NO},
+	{0xFC6C, UNICODE_NORM_QC_NO},
+	{0xFC6D, UNICODE_NORM_QC_NO},
+	{0xFC6E, UNICODE_NORM_QC_NO},
+	{0xFC6F, UNICODE_NORM_QC_NO},
+	{0xFC70, UNICODE_NORM_QC_NO},
+	{0xFC71, UNICODE_NORM_QC_NO},
+	{0xFC72, UNICODE_NORM_QC_NO},
+	{0xFC73, UNICODE_NORM_QC_NO},
+	{0xFC74, UNICODE_NORM_QC_NO},
+	{0xFC75, UNICODE_NORM_QC_NO},
+	{0xFC76, UNICODE_NORM_QC_NO},
+	{0xFC77, UNICODE_NORM_QC_NO},
+	{0xFC78, UNICODE_NORM_QC_NO},
+	{0xFC79, UNICODE_NORM_QC_NO},
+	{0xFC7A, UNICODE_NORM_QC_NO},
+	{0xFC7B, UNICODE_NORM_QC_NO},
+	{0xFC7C, UNICODE_NORM_QC_NO},
+	{0xFC7D, UNICODE_NORM_QC_NO},
+	{0xFC7E, UNICODE_NORM_QC_NO},
+	{0xFC7F, UNICODE_NORM_QC_NO},
+	{0xFC80, UNICODE_NORM_QC_NO},
+	{0xFC81, UNICODE_NORM_QC_NO},
+	{0xFC82, UNICODE_NORM_QC_NO},
+	{0xFC83, UNICODE_NORM_QC_NO},
+	{0xFC84, UNICODE_NORM_QC_NO},
+	{0xFC85, UNICODE_NORM_QC_NO},
+	{0xFC86, UNICODE_NORM_QC_NO},
+	{0xFC87, UNICODE_NORM_QC_NO},
+	{0xFC88, UNICODE_NORM_QC_NO},
+	{0xFC89, UNICODE_NORM_QC_NO},
+	{0xFC8A, UNICODE_NORM_QC_NO},
+	{0xFC8B, UNICODE_NORM_QC_NO},
+	{0xFC8C, UNICODE_NORM_QC_NO},
+	{0xFC8D, UNICODE_NORM_QC_NO},
+	{0xFC8E, UNICODE_NORM_QC_NO},
+	{0xFC8F, UNICODE_NORM_QC_NO},
+	{0xFC90, UNICODE_NORM_QC_NO},
+	{0xFC91, UNICODE_NORM_QC_NO},
+	{0xFC92, UNICODE_NORM_QC_NO},
+	{0xFC93, UNICODE_NORM_QC_NO},
+	{0xFC94, UNICODE_NORM_QC_NO},
+	{0xFC95, UNICODE_NORM_QC_NO},
+	{0xFC96, UNICODE_NORM_QC_NO},
+	{0xFC97, UNICODE_NORM_QC_NO},
+	{0xFC98, UNICODE_NORM_QC_NO},
+	{0xFC99, UNICODE_NORM_QC_NO},
+	{0xFC9A, UNICODE_NORM_QC_NO},
+	{0xFC9B, UNICODE_NORM_QC_NO},
+	{0xFC9C, UNICODE_NORM_QC_NO},
+	{0xFC9D, UNICODE_NORM_QC_NO},
+	{0xFC9E, UNICODE_NORM_QC_NO},
+	{0xFC9F, UNICODE_NORM_QC_NO},
+	{0xFCA0, UNICODE_NORM_QC_NO},
+	{0xFCA1, UNICODE_NORM_QC_NO},
+	{0xFCA2, UNICODE_NORM_QC_NO},
+	{0xFCA3, UNICODE_NORM_QC_NO},
+	{0xFCA4, UNICODE_NORM_QC_NO},
+	{0xFCA5, UNICODE_NORM_QC_NO},
+	{0xFCA6, UNICODE_NORM_QC_NO},
+	{0xFCA7, UNICODE_NORM_QC_NO},
+	{0xFCA8, UNICODE_NORM_QC_NO},
+	{0xFCA9, UNICODE_NORM_QC_NO},
+	{0xFCAA, UNICODE_NORM_QC_NO},
+	{0xFCAB, UNICODE_NORM_QC_NO},
+	{0xFCAC, UNICODE_NORM_QC_NO},
+	{0xFCAD, UNICODE_NORM_QC_NO},
+	{0xFCAE, UNICODE_NORM_QC_NO},
+	{0xFCAF, UNICODE_NORM_QC_NO},
+	{0xFCB0, UNICODE_NORM_QC_NO},
+	{0xFCB1, UNICODE_NORM_QC_NO},
+	{0xFCB2, UNICODE_NORM_QC_NO},
+	{0xFCB3, UNICODE_NORM_QC_NO},
+	{0xFCB4, UNICODE_NORM_QC_NO},
+	{0xFCB5, UNICODE_NORM_QC_NO},
+	{0xFCB6, UNICODE_NORM_QC_NO},
+	{0xFCB7, UNICODE_NORM_QC_NO},
+	{0xFCB8, UNICODE_NORM_QC_NO},
+	{0xFCB9, UNICODE_NORM_QC_NO},
+	{0xFCBA, UNICODE_NORM_QC_NO},
+	{0xFCBB, UNICODE_NORM_QC_NO},
+	{0xFCBC, UNICODE_NORM_QC_NO},
+	{0xFCBD, UNICODE_NORM_QC_NO},
+	{0xFCBE, UNICODE_NORM_QC_NO},
+	{0xFCBF, UNICODE_NORM_QC_NO},
+	{0xFCC0, UNICODE_NORM_QC_NO},
+	{0xFCC1, UNICODE_NORM_QC_NO},
+	{0xFCC2, UNICODE_NORM_QC_NO},
+	{0xFCC3, UNICODE_NORM_QC_NO},
+	{0xFCC4, UNICODE_NORM_QC_NO},
+	{0xFCC5, UNICODE_NORM_QC_NO},
+	{0xFCC6, UNICODE_NORM_QC_NO},
+	{0xFCC7, UNICODE_NORM_QC_NO},
+	{0xFCC8, UNICODE_NORM_QC_NO},
+	{0xFCC9, UNICODE_NORM_QC_NO},
+	{0xFCCA, UNICODE_NORM_QC_NO},
+	{0xFCCB, UNICODE_NORM_QC_NO},
+	{0xFCCC, UNICODE_NORM_QC_NO},
+	{0xFCCD, UNICODE_NORM_QC_NO},
+	{0xFCCE, UNICODE_NORM_QC_NO},
+	{0xFCCF, UNICODE_NORM_QC_NO},
+	{0xFCD0, UNICODE_NORM_QC_NO},
+	{0xFCD1, UNICODE_NORM_QC_NO},
+	{0xFCD2, UNICODE_NORM_QC_NO},
+	{0xFCD3, UNICODE_NORM_QC_NO},
+	{0xFCD4, UNICODE_NORM_QC_NO},
+	{0xFCD5, UNICODE_NORM_QC_NO},
+	{0xFCD6, UNICODE_NORM_QC_NO},
+	{0xFCD7, UNICODE_NORM_QC_NO},
+	{0xFCD8, UNICODE_NORM_QC_NO},
+	{0xFCD9, UNICODE_NORM_QC_NO},
+	{0xFCDA, UNICODE_NORM_QC_NO},
+	{0xFCDB, UNICODE_NORM_QC_NO},
+	{0xFCDC, UNICODE_NORM_QC_NO},
+	{0xFCDD, UNICODE_NORM_QC_NO},
+	{0xFCDE, UNICODE_NORM_QC_NO},
+	{0xFCDF, UNICODE_NORM_QC_NO},
+	{0xFCE0, UNICODE_NORM_QC_NO},
+	{0xFCE1, UNICODE_NORM_QC_NO},
+	{0xFCE2, UNICODE_NORM_QC_NO},
+	{0xFCE3, UNICODE_NORM_QC_NO},
+	{0xFCE4, UNICODE_NORM_QC_NO},
+	{0xFCE5, UNICODE_NORM_QC_NO},
+	{0xFCE6, UNICODE_NORM_QC_NO},
+	{0xFCE7, UNICODE_NORM_QC_NO},
+	{0xFCE8, UNICODE_NORM_QC_NO},
+	{0xFCE9, UNICODE_NORM_QC_NO},
+	{0xFCEA, UNICODE_NORM_QC_NO},
+	{0xFCEB, UNICODE_NORM_QC_NO},
+	{0xFCEC, UNICODE_NORM_QC_NO},
+	{0xFCED, UNICODE_NORM_QC_NO},
+	{0xFCEE, UNICODE_NORM_QC_NO},
+	{0xFCEF, UNICODE_NORM_QC_NO},
+	{0xFCF0, UNICODE_NORM_QC_NO},
+	{0xFCF1, UNICODE_NORM_QC_NO},
+	{0xFCF2, UNICODE_NORM_QC_NO},
+	{0xFCF3, UNICODE_NORM_QC_NO},
+	{0xFCF4, UNICODE_NORM_QC_NO},
+	{0xFCF5, UNICODE_NORM_QC_NO},
+	{0xFCF6, UNICODE_NORM_QC_NO},
+	{0xFCF7, UNICODE_NORM_QC_NO},
+	{0xFCF8, UNICODE_NORM_QC_NO},
+	{0xFCF9, UNICODE_NORM_QC_NO},
+	{0xFCFA, UNICODE_NORM_QC_NO},
+	{0xFCFB, UNICODE_NORM_QC_NO},
+	{0xFCFC, UNICODE_NORM_QC_NO},
+	{0xFCFD, UNICODE_NORM_QC_NO},
+	{0xFCFE, UNICODE_NORM_QC_NO},
+	{0xFCFF, UNICODE_NORM_QC_NO},
+	{0xFD00, UNICODE_NORM_QC_NO},
+	{0xFD01, UNICODE_NORM_QC_NO},
+	{0xFD02, UNICODE_NORM_QC_NO},
+	{0xFD03, UNICODE_NORM_QC_NO},
+	{0xFD04, UNICODE_NORM_QC_NO},
+	{0xFD05, UNICODE_NORM_QC_NO},
+	{0xFD06, UNICODE_NORM_QC_NO},
+	{0xFD07, UNICODE_NORM_QC_NO},
+	{0xFD08, UNICODE_NORM_QC_NO},
+	{0xFD09, UNICODE_NORM_QC_NO},
+	{0xFD0A, UNICODE_NORM_QC_NO},
+	{0xFD0B, UNICODE_NORM_QC_NO},
+	{0xFD0C, UNICODE_NORM_QC_NO},
+	{0xFD0D, UNICODE_NORM_QC_NO},
+	{0xFD0E, UNICODE_NORM_QC_NO},
+	{0xFD0F, UNICODE_NORM_QC_NO},
+	{0xFD10, UNICODE_NORM_QC_NO},
+	{0xFD11, UNICODE_NORM_QC_NO},
+	{0xFD12, UNICODE_NORM_QC_NO},
+	{0xFD13, UNICODE_NORM_QC_NO},
+	{0xFD14, UNICODE_NORM_QC_NO},
+	{0xFD15, UNICODE_NORM_QC_NO},
+	{0xFD16, UNICODE_NORM_QC_NO},
+	{0xFD17, UNICODE_NORM_QC_NO},
+	{0xFD18, UNICODE_NORM_QC_NO},
+	{0xFD19, UNICODE_NORM_QC_NO},
+	{0xFD1A, UNICODE_NORM_QC_NO},
+	{0xFD1B, UNICODE_NORM_QC_NO},
+	{0xFD1C, UNICODE_NORM_QC_NO},
+	{0xFD1D, UNICODE_NORM_QC_NO},
+	{0xFD1E, UNICODE_NORM_QC_NO},
+	{0xFD1F, UNICODE_NORM_QC_NO},
+	{0xFD20, UNICODE_NORM_QC_NO},
+	{0xFD21, UNICODE_NORM_QC_NO},
+	{0xFD22, UNICODE_NORM_QC_NO},
+	{0xFD23, UNICODE_NORM_QC_NO},
+	{0xFD24, UNICODE_NORM_QC_NO},
+	{0xFD25, UNICODE_NORM_QC_NO},
+	{0xFD26, UNICODE_NORM_QC_NO},
+	{0xFD27, UNICODE_NORM_QC_NO},
+	{0xFD28, UNICODE_NORM_QC_NO},
+	{0xFD29, UNICODE_NORM_QC_NO},
+	{0xFD2A, UNICODE_NORM_QC_NO},
+	{0xFD2B, UNICODE_NORM_QC_NO},
+	{0xFD2C, UNICODE_NORM_QC_NO},
+	{0xFD2D, UNICODE_NORM_QC_NO},
+	{0xFD2E, UNICODE_NORM_QC_NO},
+	{0xFD2F, UNICODE_NORM_QC_NO},
+	{0xFD30, UNICODE_NORM_QC_NO},
+	{0xFD31, UNICODE_NORM_QC_NO},
+	{0xFD32, UNICODE_NORM_QC_NO},
+	{0xFD33, UNICODE_NORM_QC_NO},
+	{0xFD34, UNICODE_NORM_QC_NO},
+	{0xFD35, UNICODE_NORM_QC_NO},
+	{0xFD36, UNICODE_NORM_QC_NO},
+	{0xFD37, UNICODE_NORM_QC_NO},
+	{0xFD38, UNICODE_NORM_QC_NO},
+	{0xFD39, UNICODE_NORM_QC_NO},
+	{0xFD3A, UNICODE_NORM_QC_NO},
+	{0xFD3B, UNICODE_NORM_QC_NO},
+	{0xFD3C, UNICODE_NORM_QC_NO},
+	{0xFD3D, UNICODE_NORM_QC_NO},
+	{0xFD50, UNICODE_NORM_QC_NO},
+	{0xFD51, UNICODE_NORM_QC_NO},
+	{0xFD52, UNICODE_NORM_QC_NO},
+	{0xFD53, UNICODE_NORM_QC_NO},
+	{0xFD54, UNICODE_NORM_QC_NO},
+	{0xFD55, UNICODE_NORM_QC_NO},
+	{0xFD56, UNICODE_NORM_QC_NO},
+	{0xFD57, UNICODE_NORM_QC_NO},
+	{0xFD58, UNICODE_NORM_QC_NO},
+	{0xFD59, UNICODE_NORM_QC_NO},
+	{0xFD5A, UNICODE_NORM_QC_NO},
+	{0xFD5B, UNICODE_NORM_QC_NO},
+	{0xFD5C, UNICODE_NORM_QC_NO},
+	{0xFD5D, UNICODE_NORM_QC_NO},
+	{0xFD5E, UNICODE_NORM_QC_NO},
+	{0xFD5F, UNICODE_NORM_QC_NO},
+	{0xFD60, UNICODE_NORM_QC_NO},
+	{0xFD61, UNICODE_NORM_QC_NO},
+	{0xFD62, UNICODE_NORM_QC_NO},
+	{0xFD63, UNICODE_NORM_QC_NO},
+	{0xFD64, UNICODE_NORM_QC_NO},
+	{0xFD65, UNICODE_NORM_QC_NO},
+	{0xFD66, UNICODE_NORM_QC_NO},
+	{0xFD67, UNICODE_NORM_QC_NO},
+	{0xFD68, UNICODE_NORM_QC_NO},
+	{0xFD69, UNICODE_NORM_QC_NO},
+	{0xFD6A, UNICODE_NORM_QC_NO},
+	{0xFD6B, UNICODE_NORM_QC_NO},
+	{0xFD6C, UNICODE_NORM_QC_NO},
+	{0xFD6D, UNICODE_NORM_QC_NO},
+	{0xFD6E, UNICODE_NORM_QC_NO},
+	{0xFD6F, UNICODE_NORM_QC_NO},
+	{0xFD70, UNICODE_NORM_QC_NO},
+	{0xFD71, UNICODE_NORM_QC_NO},
+	{0xFD72, UNICODE_NORM_QC_NO},
+	{0xFD73, UNICODE_NORM_QC_NO},
+	{0xFD74, UNICODE_NORM_QC_NO},
+	{0xFD75, UNICODE_NORM_QC_NO},
+	{0xFD76, UNICODE_NORM_QC_NO},
+	{0xFD77, UNICODE_NORM_QC_NO},
+	{0xFD78, UNICODE_NORM_QC_NO},
+	{0xFD79, UNICODE_NORM_QC_NO},
+	{0xFD7A, UNICODE_NORM_QC_NO},
+	{0xFD7B, UNICODE_NORM_QC_NO},
+	{0xFD7C, UNICODE_NORM_QC_NO},
+	{0xFD7D, UNICODE_NORM_QC_NO},
+	{0xFD7E, UNICODE_NORM_QC_NO},
+	{0xFD7F, UNICODE_NORM_QC_NO},
+	{0xFD80, UNICODE_NORM_QC_NO},
+	{0xFD81, UNICODE_NORM_QC_NO},
+	{0xFD82, UNICODE_NORM_QC_NO},
+	{0xFD83, UNICODE_NORM_QC_NO},
+	{0xFD84, UNICODE_NORM_QC_NO},
+	{0xFD85, UNICODE_NORM_QC_NO},
+	{0xFD86, UNICODE_NORM_QC_NO},
+	{0xFD87, UNICODE_NORM_QC_NO},
+	{0xFD88, UNICODE_NORM_QC_NO},
+	{0xFD89, UNICODE_NORM_QC_NO},
+	{0xFD8A, UNICODE_NORM_QC_NO},
+	{0xFD8B, UNICODE_NORM_QC_NO},
+	{0xFD8C, UNICODE_NORM_QC_NO},
+	{0xFD8D, UNICODE_NORM_QC_NO},
+	{0xFD8E, UNICODE_NORM_QC_NO},
+	{0xFD8F, UNICODE_NORM_QC_NO},
+	{0xFD92, UNICODE_NORM_QC_NO},
+	{0xFD93, UNICODE_NORM_QC_NO},
+	{0xFD94, UNICODE_NORM_QC_NO},
+	{0xFD95, UNICODE_NORM_QC_NO},
+	{0xFD96, UNICODE_NORM_QC_NO},
+	{0xFD97, UNICODE_NORM_QC_NO},
+	{0xFD98, UNICODE_NORM_QC_NO},
+	{0xFD99, UNICODE_NORM_QC_NO},
+	{0xFD9A, UNICODE_NORM_QC_NO},
+	{0xFD9B, UNICODE_NORM_QC_NO},
+	{0xFD9C, UNICODE_NORM_QC_NO},
+	{0xFD9D, UNICODE_NORM_QC_NO},
+	{0xFD9E, UNICODE_NORM_QC_NO},
+	{0xFD9F, UNICODE_NORM_QC_NO},
+	{0xFDA0, UNICODE_NORM_QC_NO},
+	{0xFDA1, UNICODE_NORM_QC_NO},
+	{0xFDA2, UNICODE_NORM_QC_NO},
+	{0xFDA3, UNICODE_NORM_QC_NO},
+	{0xFDA4, UNICODE_NORM_QC_NO},
+	{0xFDA5, UNICODE_NORM_QC_NO},
+	{0xFDA6, UNICODE_NORM_QC_NO},
+	{0xFDA7, UNICODE_NORM_QC_NO},
+	{0xFDA8, UNICODE_NORM_QC_NO},
+	{0xFDA9, UNICODE_NORM_QC_NO},
+	{0xFDAA, UNICODE_NORM_QC_NO},
+	{0xFDAB, UNICODE_NORM_QC_NO},
+	{0xFDAC, UNICODE_NORM_QC_NO},
+	{0xFDAD, UNICODE_NORM_QC_NO},
+	{0xFDAE, UNICODE_NORM_QC_NO},
+	{0xFDAF, UNICODE_NORM_QC_NO},
+	{0xFDB0, UNICODE_NORM_QC_NO},
+	{0xFDB1, UNICODE_NORM_QC_NO},
+	{0xFDB2, UNICODE_NORM_QC_NO},
+	{0xFDB3, UNICODE_NORM_QC_NO},
+	{0xFDB4, UNICODE_NORM_QC_NO},
+	{0xFDB5, UNICODE_NORM_QC_NO},
+	{0xFDB6, UNICODE_NORM_QC_NO},
+	{0xFDB7, UNICODE_NORM_QC_NO},
+	{0xFDB8, UNICODE_NORM_QC_NO},
+	{0xFDB9, UNICODE_NORM_QC_NO},
+	{0xFDBA, UNICODE_NORM_QC_NO},
+	{0xFDBB, UNICODE_NORM_QC_NO},
+	{0xFDBC, UNICODE_NORM_QC_NO},
+	{0xFDBD, UNICODE_NORM_QC_NO},
+	{0xFDBE, UNICODE_NORM_QC_NO},
+	{0xFDBF, UNICODE_NORM_QC_NO},
+	{0xFDC0, UNICODE_NORM_QC_NO},
+	{0xFDC1, UNICODE_NORM_QC_NO},
+	{0xFDC2, UNICODE_NORM_QC_NO},
+	{0xFDC3, UNICODE_NORM_QC_NO},
+	{0xFDC4, UNICODE_NORM_QC_NO},
+	{0xFDC5, UNICODE_NORM_QC_NO},
+	{0xFDC6, UNICODE_NORM_QC_NO},
+	{0xFDC7, UNICODE_NORM_QC_NO},
+	{0xFDF0, UNICODE_NORM_QC_NO},
+	{0xFDF1, UNICODE_NORM_QC_NO},
+	{0xFDF2, UNICODE_NORM_QC_NO},
+	{0xFDF3, UNICODE_NORM_QC_NO},
+	{0xFDF4, UNICODE_NORM_QC_NO},
+	{0xFDF5, UNICODE_NORM_QC_NO},
+	{0xFDF6, UNICODE_NORM_QC_NO},
+	{0xFDF7, UNICODE_NORM_QC_NO},
+	{0xFDF8, UNICODE_NORM_QC_NO},
+	{0xFDF9, UNICODE_NORM_QC_NO},
+	{0xFDFA, UNICODE_NORM_QC_NO},
+	{0xFDFB, UNICODE_NORM_QC_NO},
+	{0xFDFC, UNICODE_NORM_QC_NO},
+	{0xFE10, UNICODE_NORM_QC_NO},
+	{0xFE11, UNICODE_NORM_QC_NO},
+	{0xFE12, UNICODE_NORM_QC_NO},
+	{0xFE13, UNICODE_NORM_QC_NO},
+	{0xFE14, UNICODE_NORM_QC_NO},
+	{0xFE15, UNICODE_NORM_QC_NO},
+	{0xFE16, UNICODE_NORM_QC_NO},
+	{0xFE17, UNICODE_NORM_QC_NO},
+	{0xFE18, UNICODE_NORM_QC_NO},
+	{0xFE19, UNICODE_NORM_QC_NO},
+	{0xFE30, UNICODE_NORM_QC_NO},
+	{0xFE31, UNICODE_NORM_QC_NO},
+	{0xFE32, UNICODE_NORM_QC_NO},
+	{0xFE33, UNICODE_NORM_QC_NO},
+	{0xFE34, UNICODE_NORM_QC_NO},
+	{0xFE35, UNICODE_NORM_QC_NO},
+	{0xFE36, UNICODE_NORM_QC_NO},
+	{0xFE37, UNICODE_NORM_QC_NO},
+	{0xFE38, UNICODE_NORM_QC_NO},
+	{0xFE39, UNICODE_NORM_QC_NO},
+	{0xFE3A, UNICODE_NORM_QC_NO},
+	{0xFE3B, UNICODE_NORM_QC_NO},
+	{0xFE3C, UNICODE_NORM_QC_NO},
+	{0xFE3D, UNICODE_NORM_QC_NO},
+	{0xFE3E, UNICODE_NORM_QC_NO},
+	{0xFE3F, UNICODE_NORM_QC_NO},
+	{0xFE40, UNICODE_NORM_QC_NO},
+	{0xFE41, UNICODE_NORM_QC_NO},
+	{0xFE42, UNICODE_NORM_QC_NO},
+	{0xFE43, UNICODE_NORM_QC_NO},
+	{0xFE44, UNICODE_NORM_QC_NO},
+	{0xFE47, UNICODE_NORM_QC_NO},
+	{0xFE48, UNICODE_NORM_QC_NO},
+	{0xFE49, UNICODE_NORM_QC_NO},
+	{0xFE4A, UNICODE_NORM_QC_NO},
+	{0xFE4B, UNICODE_NORM_QC_NO},
+	{0xFE4C, UNICODE_NORM_QC_NO},
+	{0xFE4D, UNICODE_NORM_QC_NO},
+	{0xFE4E, UNICODE_NORM_QC_NO},
+	{0xFE4F, UNICODE_NORM_QC_NO},
+	{0xFE50, UNICODE_NORM_QC_NO},
+	{0xFE51, UNICODE_NORM_QC_NO},
+	{0xFE52, UNICODE_NORM_QC_NO},
+	{0xFE54, UNICODE_NORM_QC_NO},
+	{0xFE55, UNICODE_NORM_QC_NO},
+	{0xFE56, UNICODE_NORM_QC_NO},
+	{0xFE57, UNICODE_NORM_QC_NO},
+	{0xFE58, UNICODE_NORM_QC_NO},
+	{0xFE59, UNICODE_NORM_QC_NO},
+	{0xFE5A, UNICODE_NORM_QC_NO},
+	{0xFE5B, UNICODE_NORM_QC_NO},
+	{0xFE5C, UNICODE_NORM_QC_NO},
+	{0xFE5D, UNICODE_NORM_QC_NO},
+	{0xFE5E, UNICODE_NORM_QC_NO},
+	{0xFE5F, UNICODE_NORM_QC_NO},
+	{0xFE60, UNICODE_NORM_QC_NO},
+	{0xFE61, UNICODE_NORM_QC_NO},
+	{0xFE62, UNICODE_NORM_QC_NO},
+	{0xFE63, UNICODE_NORM_QC_NO},
+	{0xFE64, UNICODE_NORM_QC_NO},
+	{0xFE65, UNICODE_NORM_QC_NO},
+	{0xFE66, UNICODE_NORM_QC_NO},
+	{0xFE68, UNICODE_NORM_QC_NO},
+	{0xFE69, UNICODE_NORM_QC_NO},
+	{0xFE6A, UNICODE_NORM_QC_NO},
+	{0xFE6B, UNICODE_NORM_QC_NO},
+	{0xFE70, UNICODE_NORM_QC_NO},
+	{0xFE71, UNICODE_NORM_QC_NO},
+	{0xFE72, UNICODE_NORM_QC_NO},
+	{0xFE74, UNICODE_NORM_QC_NO},
+	{0xFE76, UNICODE_NORM_QC_NO},
+	{0xFE77, UNICODE_NORM_QC_NO},
+	{0xFE78, UNICODE_NORM_QC_NO},
+	{0xFE79, UNICODE_NORM_QC_NO},
+	{0xFE7A, UNICODE_NORM_QC_NO},
+	{0xFE7B, UNICODE_NORM_QC_NO},
+	{0xFE7C, UNICODE_NORM_QC_NO},
+	{0xFE7D, UNICODE_NORM_QC_NO},
+	{0xFE7E, UNICODE_NORM_QC_NO},
+	{0xFE7F, UNICODE_NORM_QC_NO},
+	{0xFE80, UNICODE_NORM_QC_NO},
+	{0xFE81, UNICODE_NORM_QC_NO},
+	{0xFE82, UNICODE_NORM_QC_NO},
+	{0xFE83, UNICODE_NORM_QC_NO},
+	{0xFE84, UNICODE_NORM_QC_NO},
+	{0xFE85, UNICODE_NORM_QC_NO},
+	{0xFE86, UNICODE_NORM_QC_NO},
+	{0xFE87, UNICODE_NORM_QC_NO},
+	{0xFE88, UNICODE_NORM_QC_NO},
+	{0xFE89, UNICODE_NORM_QC_NO},
+	{0xFE8A, UNICODE_NORM_QC_NO},
+	{0xFE8B, UNICODE_NORM_QC_NO},
+	{0xFE8C, UNICODE_NORM_QC_NO},
+	{0xFE8D, UNICODE_NORM_QC_NO},
+	{0xFE8E, UNICODE_NORM_QC_NO},
+	{0xFE8F, UNICODE_NORM_QC_NO},
+	{0xFE90, UNICODE_NORM_QC_NO},
+	{0xFE91, UNICODE_NORM_QC_NO},
+	{0xFE92, UNICODE_NORM_QC_NO},
+	{0xFE93, UNICODE_NORM_QC_NO},
+	{0xFE94, UNICODE_NORM_QC_NO},
+	{0xFE95, UNICODE_NORM_QC_NO},
+	{0xFE96, UNICODE_NORM_QC_NO},
+	{0xFE97, UNICODE_NORM_QC_NO},
+	{0xFE98, UNICODE_NORM_QC_NO},
+	{0xFE99, UNICODE_NORM_QC_NO},
+	{0xFE9A, UNICODE_NORM_QC_NO},
+	{0xFE9B, UNICODE_NORM_QC_NO},
+	{0xFE9C, UNICODE_NORM_QC_NO},
+	{0xFE9D, UNICODE_NORM_QC_NO},
+	{0xFE9E, UNICODE_NORM_QC_NO},
+	{0xFE9F, UNICODE_NORM_QC_NO},
+	{0xFEA0, UNICODE_NORM_QC_NO},
+	{0xFEA1, UNICODE_NORM_QC_NO},
+	{0xFEA2, UNICODE_NORM_QC_NO},
+	{0xFEA3, UNICODE_NORM_QC_NO},
+	{0xFEA4, UNICODE_NORM_QC_NO},
+	{0xFEA5, UNICODE_NORM_QC_NO},
+	{0xFEA6, UNICODE_NORM_QC_NO},
+	{0xFEA7, UNICODE_NORM_QC_NO},
+	{0xFEA8, UNICODE_NORM_QC_NO},
+	{0xFEA9, UNICODE_NORM_QC_NO},
+	{0xFEAA, UNICODE_NORM_QC_NO},
+	{0xFEAB, UNICODE_NORM_QC_NO},
+	{0xFEAC, UNICODE_NORM_QC_NO},
+	{0xFEAD, UNICODE_NORM_QC_NO},
+	{0xFEAE, UNICODE_NORM_QC_NO},
+	{0xFEAF, UNICODE_NORM_QC_NO},
+	{0xFEB0, UNICODE_NORM_QC_NO},
+	{0xFEB1, UNICODE_NORM_QC_NO},
+	{0xFEB2, UNICODE_NORM_QC_NO},
+	{0xFEB3, UNICODE_NORM_QC_NO},
+	{0xFEB4, UNICODE_NORM_QC_NO},
+	{0xFEB5, UNICODE_NORM_QC_NO},
+	{0xFEB6, UNICODE_NORM_QC_NO},
+	{0xFEB7, UNICODE_NORM_QC_NO},
+	{0xFEB8, UNICODE_NORM_QC_NO},
+	{0xFEB9, UNICODE_NORM_QC_NO},
+	{0xFEBA, UNICODE_NORM_QC_NO},
+	{0xFEBB, UNICODE_NORM_QC_NO},
+	{0xFEBC, UNICODE_NORM_QC_NO},
+	{0xFEBD, UNICODE_NORM_QC_NO},
+	{0xFEBE, UNICODE_NORM_QC_NO},
+	{0xFEBF, UNICODE_NORM_QC_NO},
+	{0xFEC0, UNICODE_NORM_QC_NO},
+	{0xFEC1, UNICODE_NORM_QC_NO},
+	{0xFEC2, UNICODE_NORM_QC_NO},
+	{0xFEC3, UNICODE_NORM_QC_NO},
+	{0xFEC4, UNICODE_NORM_QC_NO},
+	{0xFEC5, UNICODE_NORM_QC_NO},
+	{0xFEC6, UNICODE_NORM_QC_NO},
+	{0xFEC7, UNICODE_NORM_QC_NO},
+	{0xFEC8, UNICODE_NORM_QC_NO},
+	{0xFEC9, UNICODE_NORM_QC_NO},
+	{0xFECA, UNICODE_NORM_QC_NO},
+	{0xFECB, UNICODE_NORM_QC_NO},
+	{0xFECC, UNICODE_NORM_QC_NO},
+	{0xFECD, UNICODE_NORM_QC_NO},
+	{0xFECE, UNICODE_NORM_QC_NO},
+	{0xFECF, UNICODE_NORM_QC_NO},
+	{0xFED0, UNICODE_NORM_QC_NO},
+	{0xFED1, UNICODE_NORM_QC_NO},
+	{0xFED2, UNICODE_NORM_QC_NO},
+	{0xFED3, UNICODE_NORM_QC_NO},
+	{0xFED4, UNICODE_NORM_QC_NO},
+	{0xFED5, UNICODE_NORM_QC_NO},
+	{0xFED6, UNICODE_NORM_QC_NO},
+	{0xFED7, UNICODE_NORM_QC_NO},
+	{0xFED8, UNICODE_NORM_QC_NO},
+	{0xFED9, UNICODE_NORM_QC_NO},
+	{0xFEDA, UNICODE_NORM_QC_NO},
+	{0xFEDB, UNICODE_NORM_QC_NO},
+	{0xFEDC, UNICODE_NORM_QC_NO},
+	{0xFEDD, UNICODE_NORM_QC_NO},
+	{0xFEDE, UNICODE_NORM_QC_NO},
+	{0xFEDF, UNICODE_NORM_QC_NO},
+	{0xFEE0, UNICODE_NORM_QC_NO},
+	{0xFEE1, UNICODE_NORM_QC_NO},
+	{0xFEE2, UNICODE_NORM_QC_NO},
+	{0xFEE3, UNICODE_NORM_QC_NO},
+	{0xFEE4, UNICODE_NORM_QC_NO},
+	{0xFEE5, UNICODE_NORM_QC_NO},
+	{0xFEE6, UNICODE_NORM_QC_NO},
+	{0xFEE7, UNICODE_NORM_QC_NO},
+	{0xFEE8, UNICODE_NORM_QC_NO},
+	{0xFEE9, UNICODE_NORM_QC_NO},
+	{0xFEEA, UNICODE_NORM_QC_NO},
+	{0xFEEB, UNICODE_NORM_QC_NO},
+	{0xFEEC, UNICODE_NORM_QC_NO},
+	{0xFEED, UNICODE_NORM_QC_NO},
+	{0xFEEE, UNICODE_NORM_QC_NO},
+	{0xFEEF, UNICODE_NORM_QC_NO},
+	{0xFEF0, UNICODE_NORM_QC_NO},
+	{0xFEF1, UNICODE_NORM_QC_NO},
+	{0xFEF2, UNICODE_NORM_QC_NO},
+	{0xFEF3, UNICODE_NORM_QC_NO},
+	{0xFEF4, UNICODE_NORM_QC_NO},
+	{0xFEF5, UNICODE_NORM_QC_NO},
+	{0xFEF6, UNICODE_NORM_QC_NO},
+	{0xFEF7, UNICODE_NORM_QC_NO},
+	{0xFEF8, UNICODE_NORM_QC_NO},
+	{0xFEF9, UNICODE_NORM_QC_NO},
+	{0xFEFA, UNICODE_NORM_QC_NO},
+	{0xFEFB, UNICODE_NORM_QC_NO},
+	{0xFEFC, UNICODE_NORM_QC_NO},
+	{0xFF01, UNICODE_NORM_QC_NO},
+	{0xFF02, UNICODE_NORM_QC_NO},
+	{0xFF03, UNICODE_NORM_QC_NO},
+	{0xFF04, UNICODE_NORM_QC_NO},
+	{0xFF05, UNICODE_NORM_QC_NO},
+	{0xFF06, UNICODE_NORM_QC_NO},
+	{0xFF07, UNICODE_NORM_QC_NO},
+	{0xFF08, UNICODE_NORM_QC_NO},
+	{0xFF09, UNICODE_NORM_QC_NO},
+	{0xFF0A, UNICODE_NORM_QC_NO},
+	{0xFF0B, UNICODE_NORM_QC_NO},
+	{0xFF0C, UNICODE_NORM_QC_NO},
+	{0xFF0D, UNICODE_NORM_QC_NO},
+	{0xFF0E, UNICODE_NORM_QC_NO},
+	{0xFF0F, UNICODE_NORM_QC_NO},
+	{0xFF10, UNICODE_NORM_QC_NO},
+	{0xFF11, UNICODE_NORM_QC_NO},
+	{0xFF12, UNICODE_NORM_QC_NO},
+	{0xFF13, UNICODE_NORM_QC_NO},
+	{0xFF14, UNICODE_NORM_QC_NO},
+	{0xFF15, UNICODE_NORM_QC_NO},
+	{0xFF16, UNICODE_NORM_QC_NO},
+	{0xFF17, UNICODE_NORM_QC_NO},
+	{0xFF18, UNICODE_NORM_QC_NO},
+	{0xFF19, UNICODE_NORM_QC_NO},
+	{0xFF1A, UNICODE_NORM_QC_NO},
+	{0xFF1B, UNICODE_NORM_QC_NO},
+	{0xFF1C, UNICODE_NORM_QC_NO},
+	{0xFF1D, UNICODE_NORM_QC_NO},
+	{0xFF1E, UNICODE_NORM_QC_NO},
+	{0xFF1F, UNICODE_NORM_QC_NO},
+	{0xFF20, UNICODE_NORM_QC_NO},
+	{0xFF21, UNICODE_NORM_QC_NO},
+	{0xFF22, UNICODE_NORM_QC_NO},
+	{0xFF23, UNICODE_NORM_QC_NO},
+	{0xFF24, UNICODE_NORM_QC_NO},
+	{0xFF25, UNICODE_NORM_QC_NO},
+	{0xFF26, UNICODE_NORM_QC_NO},
+	{0xFF27, UNICODE_NORM_QC_NO},
+	{0xFF28, UNICODE_NORM_QC_NO},
+	{0xFF29, UNICODE_NORM_QC_NO},
+	{0xFF2A, UNICODE_NORM_QC_NO},
+	{0xFF2B, UNICODE_NORM_QC_NO},
+	{0xFF2C, UNICODE_NORM_QC_NO},
+	{0xFF2D, UNICODE_NORM_QC_NO},
+	{0xFF2E, UNICODE_NORM_QC_NO},
+	{0xFF2F, UNICODE_NORM_QC_NO},
+	{0xFF30, UNICODE_NORM_QC_NO},
+	{0xFF31, UNICODE_NORM_QC_NO},
+	{0xFF32, UNICODE_NORM_QC_NO},
+	{0xFF33, UNICODE_NORM_QC_NO},
+	{0xFF34, UNICODE_NORM_QC_NO},
+	{0xFF35, UNICODE_NORM_QC_NO},
+	{0xFF36, UNICODE_NORM_QC_NO},
+	{0xFF37, UNICODE_NORM_QC_NO},
+	{0xFF38, UNICODE_NORM_QC_NO},
+	{0xFF39, UNICODE_NORM_QC_NO},
+	{0xFF3A, UNICODE_NORM_QC_NO},
+	{0xFF3B, UNICODE_NORM_QC_NO},
+	{0xFF3C, UNICODE_NORM_QC_NO},
+	{0xFF3D, UNICODE_NORM_QC_NO},
+	{0xFF3E, UNICODE_NORM_QC_NO},
+	{0xFF3F, UNICODE_NORM_QC_NO},
+	{0xFF40, UNICODE_NORM_QC_NO},
+	{0xFF41, UNICODE_NORM_QC_NO},
+	{0xFF42, UNICODE_NORM_QC_NO},
+	{0xFF43, UNICODE_NORM_QC_NO},
+	{0xFF44, UNICODE_NORM_QC_NO},
+	{0xFF45, UNICODE_NORM_QC_NO},
+	{0xFF46, UNICODE_NORM_QC_NO},
+	{0xFF47, UNICODE_NORM_QC_NO},
+	{0xFF48, UNICODE_NORM_QC_NO},
+	{0xFF49, UNICODE_NORM_QC_NO},
+	{0xFF4A, UNICODE_NORM_QC_NO},
+	{0xFF4B, UNICODE_NORM_QC_NO},
+	{0xFF4C, UNICODE_NORM_QC_NO},
+	{0xFF4D, UNICODE_NORM_QC_NO},
+	{0xFF4E, UNICODE_NORM_QC_NO},
+	{0xFF4F, UNICODE_NORM_QC_NO},
+	{0xFF50, UNICODE_NORM_QC_NO},
+	{0xFF51, UNICODE_NORM_QC_NO},
+	{0xFF52, UNICODE_NORM_QC_NO},
+	{0xFF53, UNICODE_NORM_QC_NO},
+	{0xFF54, UNICODE_NORM_QC_NO},
+	{0xFF55, UNICODE_NORM_QC_NO},
+	{0xFF56, UNICODE_NORM_QC_NO},
+	{0xFF57, UNICODE_NORM_QC_NO},
+	{0xFF58, UNICODE_NORM_QC_NO},
+	{0xFF59, UNICODE_NORM_QC_NO},
+	{0xFF5A, UNICODE_NORM_QC_NO},
+	{0xFF5B, UNICODE_NORM_QC_NO},
+	{0xFF5C, UNICODE_NORM_QC_NO},
+	{0xFF5D, UNICODE_NORM_QC_NO},
+	{0xFF5E, UNICODE_NORM_QC_NO},
+	{0xFF5F, UNICODE_NORM_QC_NO},
+	{0xFF60, UNICODE_NORM_QC_NO},
+	{0xFF61, UNICODE_NORM_QC_NO},
+	{0xFF62, UNICODE_NORM_QC_NO},
+	{0xFF63, UNICODE_NORM_QC_NO},
+	{0xFF64, UNICODE_NORM_QC_NO},
+	{0xFF65, UNICODE_NORM_QC_NO},
+	{0xFF66, UNICODE_NORM_QC_NO},
+	{0xFF67, UNICODE_NORM_QC_NO},
+	{0xFF68, UNICODE_NORM_QC_NO},
+	{0xFF69, UNICODE_NORM_QC_NO},
+	{0xFF6A, UNICODE_NORM_QC_NO},
+	{0xFF6B, UNICODE_NORM_QC_NO},
+	{0xFF6C, UNICODE_NORM_QC_NO},
+	{0xFF6D, UNICODE_NORM_QC_NO},
+	{0xFF6E, UNICODE_NORM_QC_NO},
+	{0xFF6F, UNICODE_NORM_QC_NO},
+	{0xFF70, UNICODE_NORM_QC_NO},
+	{0xFF71, UNICODE_NORM_QC_NO},
+	{0xFF72, UNICODE_NORM_QC_NO},
+	{0xFF73, UNICODE_NORM_QC_NO},
+	{0xFF74, UNICODE_NORM_QC_NO},
+	{0xFF75, UNICODE_NORM_QC_NO},
+	{0xFF76, UNICODE_NORM_QC_NO},
+	{0xFF77, UNICODE_NORM_QC_NO},
+	{0xFF78, UNICODE_NORM_QC_NO},
+	{0xFF79, UNICODE_NORM_QC_NO},
+	{0xFF7A, UNICODE_NORM_QC_NO},
+	{0xFF7B, UNICODE_NORM_QC_NO},
+	{0xFF7C, UNICODE_NORM_QC_NO},
+	{0xFF7D, UNICODE_NORM_QC_NO},
+	{0xFF7E, UNICODE_NORM_QC_NO},
+	{0xFF7F, UNICODE_NORM_QC_NO},
+	{0xFF80, UNICODE_NORM_QC_NO},
+	{0xFF81, UNICODE_NORM_QC_NO},
+	{0xFF82, UNICODE_NORM_QC_NO},
+	{0xFF83, UNICODE_NORM_QC_NO},
+	{0xFF84, UNICODE_NORM_QC_NO},
+	{0xFF85, UNICODE_NORM_QC_NO},
+	{0xFF86, UNICODE_NORM_QC_NO},
+	{0xFF87, UNICODE_NORM_QC_NO},
+	{0xFF88, UNICODE_NORM_QC_NO},
+	{0xFF89, UNICODE_NORM_QC_NO},
+	{0xFF8A, UNICODE_NORM_QC_NO},
+	{0xFF8B, UNICODE_NORM_QC_NO},
+	{0xFF8C, UNICODE_NORM_QC_NO},
+	{0xFF8D, UNICODE_NORM_QC_NO},
+	{0xFF8E, UNICODE_NORM_QC_NO},
+	{0xFF8F, UNICODE_NORM_QC_NO},
+	{0xFF90, UNICODE_NORM_QC_NO},
+	{0xFF91, UNICODE_NORM_QC_NO},
+	{0xFF92, UNICODE_NORM_QC_NO},
+	{0xFF93, UNICODE_NORM_QC_NO},
+	{0xFF94, UNICODE_NORM_QC_NO},
+	{0xFF95, UNICODE_NORM_QC_NO},
+	{0xFF96, UNICODE_NORM_QC_NO},
+	{0xFF97, UNICODE_NORM_QC_NO},
+	{0xFF98, UNICODE_NORM_QC_NO},
+	{0xFF99, UNICODE_NORM_QC_NO},
+	{0xFF9A, UNICODE_NORM_QC_NO},
+	{0xFF9B, UNICODE_NORM_QC_NO},
+	{0xFF9C, UNICODE_NORM_QC_NO},
+	{0xFF9D, UNICODE_NORM_QC_NO},
+	{0xFF9E, UNICODE_NORM_QC_NO},
+	{0xFF9F, UNICODE_NORM_QC_NO},
+	{0xFFA0, UNICODE_NORM_QC_NO},
+	{0xFFA1, UNICODE_NORM_QC_NO},
+	{0xFFA2, UNICODE_NORM_QC_NO},
+	{0xFFA3, UNICODE_NORM_QC_NO},
+	{0xFFA4, UNICODE_NORM_QC_NO},
+	{0xFFA5, UNICODE_NORM_QC_NO},
+	{0xFFA6, UNICODE_NORM_QC_NO},
+	{0xFFA7, UNICODE_NORM_QC_NO},
+	{0xFFA8, UNICODE_NORM_QC_NO},
+	{0xFFA9, UNICODE_NORM_QC_NO},
+	{0xFFAA, UNICODE_NORM_QC_NO},
+	{0xFFAB, UNICODE_NORM_QC_NO},
+	{0xFFAC, UNICODE_NORM_QC_NO},
+	{0xFFAD, UNICODE_NORM_QC_NO},
+	{0xFFAE, UNICODE_NORM_QC_NO},
+	{0xFFAF, UNICODE_NORM_QC_NO},
+	{0xFFB0, UNICODE_NORM_QC_NO},
+	{0xFFB1, UNICODE_NORM_QC_NO},
+	{0xFFB2, UNICODE_NORM_QC_NO},
+	{0xFFB3, UNICODE_NORM_QC_NO},
+	{0xFFB4, UNICODE_NORM_QC_NO},
+	{0xFFB5, UNICODE_NORM_QC_NO},
+	{0xFFB6, UNICODE_NORM_QC_NO},
+	{0xFFB7, UNICODE_NORM_QC_NO},
+	{0xFFB8, UNICODE_NORM_QC_NO},
+	{0xFFB9, UNICODE_NORM_QC_NO},
+	{0xFFBA, UNICODE_NORM_QC_NO},
+	{0xFFBB, UNICODE_NORM_QC_NO},
+	{0xFFBC, UNICODE_NORM_QC_NO},
+	{0xFFBD, UNICODE_NORM_QC_NO},
+	{0xFFBE, UNICODE_NORM_QC_NO},
+	{0xFFC2, UNICODE_NORM_QC_NO},
+	{0xFFC3, UNICODE_NORM_QC_NO},
+	{0xFFC4, UNICODE_NORM_QC_NO},
+	{0xFFC5, UNICODE_NORM_QC_NO},
+	{0xFFC6, UNICODE_NORM_QC_NO},
+	{0xFFC7, UNICODE_NORM_QC_NO},
+	{0xFFCA, UNICODE_NORM_QC_NO},
+	{0xFFCB, UNICODE_NORM_QC_NO},
+	{0xFFCC, UNICODE_NORM_QC_NO},
+	{0xFFCD, UNICODE_NORM_QC_NO},
+	{0xFFCE, UNICODE_NORM_QC_NO},
+	{0xFFCF, UNICODE_NORM_QC_NO},
+	{0xFFD2, UNICODE_NORM_QC_NO},
+	{0xFFD3, UNICODE_NORM_QC_NO},
+	{0xFFD4, UNICODE_NORM_QC_NO},
+	{0xFFD5, UNICODE_NORM_QC_NO},
+	{0xFFD6, UNICODE_NORM_QC_NO},
+	{0xFFD7, UNICODE_NORM_QC_NO},
+	{0xFFDA, UNICODE_NORM_QC_NO},
+	{0xFFDB, UNICODE_NORM_QC_NO},
+	{0xFFDC, UNICODE_NORM_QC_NO},
+	{0xFFE0, UNICODE_NORM_QC_NO},
+	{0xFFE1, UNICODE_NORM_QC_NO},
+	{0xFFE2, UNICODE_NORM_QC_NO},
+	{0xFFE3, UNICODE_NORM_QC_NO},
+	{0xFFE4, UNICODE_NORM_QC_NO},
+	{0xFFE5, UNICODE_NORM_QC_NO},
+	{0xFFE6, UNICODE_NORM_QC_NO},
+	{0xFFE8, UNICODE_NORM_QC_NO},
+	{0xFFE9, UNICODE_NORM_QC_NO},
+	{0xFFEA, UNICODE_NORM_QC_NO},
+	{0xFFEB, UNICODE_NORM_QC_NO},
+	{0xFFEC, UNICODE_NORM_QC_NO},
+	{0xFFED, UNICODE_NORM_QC_NO},
+	{0xFFEE, UNICODE_NORM_QC_NO},
+	{0x110BA, UNICODE_NORM_QC_MAYBE},
+	{0x11127, UNICODE_NORM_QC_MAYBE},
+	{0x1133E, UNICODE_NORM_QC_MAYBE},
+	{0x11357, UNICODE_NORM_QC_MAYBE},
+	{0x114B0, UNICODE_NORM_QC_MAYBE},
+	{0x114BA, UNICODE_NORM_QC_MAYBE},
+	{0x114BD, UNICODE_NORM_QC_MAYBE},
+	{0x115AF, UNICODE_NORM_QC_MAYBE},
+	{0x1D15E, UNICODE_NORM_QC_NO},
+	{0x1D15F, UNICODE_NORM_QC_NO},
+	{0x1D160, UNICODE_NORM_QC_NO},
+	{0x1D161, UNICODE_NORM_QC_NO},
+	{0x1D162, UNICODE_NORM_QC_NO},
+	{0x1D163, UNICODE_NORM_QC_NO},
+	{0x1D164, UNICODE_NORM_QC_NO},
+	{0x1D1BB, UNICODE_NORM_QC_NO},
+	{0x1D1BC, UNICODE_NORM_QC_NO},
+	{0x1D1BD, UNICODE_NORM_QC_NO},
+	{0x1D1BE, UNICODE_NORM_QC_NO},
+	{0x1D1BF, UNICODE_NORM_QC_NO},
+	{0x1D1C0, UNICODE_NORM_QC_NO},
+	{0x1D400, UNICODE_NORM_QC_NO},
+	{0x1D401, UNICODE_NORM_QC_NO},
+	{0x1D402, UNICODE_NORM_QC_NO},
+	{0x1D403, UNICODE_NORM_QC_NO},
+	{0x1D404, UNICODE_NORM_QC_NO},
+	{0x1D405, UNICODE_NORM_QC_NO},
+	{0x1D406, UNICODE_NORM_QC_NO},
+	{0x1D407, UNICODE_NORM_QC_NO},
+	{0x1D408, UNICODE_NORM_QC_NO},
+	{0x1D409, UNICODE_NORM_QC_NO},
+	{0x1D40A, UNICODE_NORM_QC_NO},
+	{0x1D40B, UNICODE_NORM_QC_NO},
+	{0x1D40C, UNICODE_NORM_QC_NO},
+	{0x1D40D, UNICODE_NORM_QC_NO},
+	{0x1D40E, UNICODE_NORM_QC_NO},
+	{0x1D40F, UNICODE_NORM_QC_NO},
+	{0x1D410, UNICODE_NORM_QC_NO},
+	{0x1D411, UNICODE_NORM_QC_NO},
+	{0x1D412, UNICODE_NORM_QC_NO},
+	{0x1D413, UNICODE_NORM_QC_NO},
+	{0x1D414, UNICODE_NORM_QC_NO},
+	{0x1D415, UNICODE_NORM_QC_NO},
+	{0x1D416, UNICODE_NORM_QC_NO},
+	{0x1D417, UNICODE_NORM_QC_NO},
+	{0x1D418, UNICODE_NORM_QC_NO},
+	{0x1D419, UNICODE_NORM_QC_NO},
+	{0x1D41A, UNICODE_NORM_QC_NO},
+	{0x1D41B, UNICODE_NORM_QC_NO},
+	{0x1D41C, UNICODE_NORM_QC_NO},
+	{0x1D41D, UNICODE_NORM_QC_NO},
+	{0x1D41E, UNICODE_NORM_QC_NO},
+	{0x1D41F, UNICODE_NORM_QC_NO},
+	{0x1D420, UNICODE_NORM_QC_NO},
+	{0x1D421, UNICODE_NORM_QC_NO},
+	{0x1D422, UNICODE_NORM_QC_NO},
+	{0x1D423, UNICODE_NORM_QC_NO},
+	{0x1D424, UNICODE_NORM_QC_NO},
+	{0x1D425, UNICODE_NORM_QC_NO},
+	{0x1D426, UNICODE_NORM_QC_NO},
+	{0x1D427, UNICODE_NORM_QC_NO},
+	{0x1D428, UNICODE_NORM_QC_NO},
+	{0x1D429, UNICODE_NORM_QC_NO},
+	{0x1D42A, UNICODE_NORM_QC_NO},
+	{0x1D42B, UNICODE_NORM_QC_NO},
+	{0x1D42C, UNICODE_NORM_QC_NO},
+	{0x1D42D, UNICODE_NORM_QC_NO},
+	{0x1D42E, UNICODE_NORM_QC_NO},
+	{0x1D42F, UNICODE_NORM_QC_NO},
+	{0x1D430, UNICODE_NORM_QC_NO},
+	{0x1D431, UNICODE_NORM_QC_NO},
+	{0x1D432, UNICODE_NORM_QC_NO},
+	{0x1D433, UNICODE_NORM_QC_NO},
+	{0x1D434, UNICODE_NORM_QC_NO},
+	{0x1D435, UNICODE_NORM_QC_NO},
+	{0x1D436, UNICODE_NORM_QC_NO},
+	{0x1D437, UNICODE_NORM_QC_NO},
+	{0x1D438, UNICODE_NORM_QC_NO},
+	{0x1D439, UNICODE_NORM_QC_NO},
+	{0x1D43A, UNICODE_NORM_QC_NO},
+	{0x1D43B, UNICODE_NORM_QC_NO},
+	{0x1D43C, UNICODE_NORM_QC_NO},
+	{0x1D43D, UNICODE_NORM_QC_NO},
+	{0x1D43E, UNICODE_NORM_QC_NO},
+	{0x1D43F, UNICODE_NORM_QC_NO},
+	{0x1D440, UNICODE_NORM_QC_NO},
+	{0x1D441, UNICODE_NORM_QC_NO},
+	{0x1D442, UNICODE_NORM_QC_NO},
+	{0x1D443, UNICODE_NORM_QC_NO},
+	{0x1D444, UNICODE_NORM_QC_NO},
+	{0x1D445, UNICODE_NORM_QC_NO},
+	{0x1D446, UNICODE_NORM_QC_NO},
+	{0x1D447, UNICODE_NORM_QC_NO},
+	{0x1D448, UNICODE_NORM_QC_NO},
+	{0x1D449, UNICODE_NORM_QC_NO},
+	{0x1D44A, UNICODE_NORM_QC_NO},
+	{0x1D44B, UNICODE_NORM_QC_NO},
+	{0x1D44C, UNICODE_NORM_QC_NO},
+	{0x1D44D, UNICODE_NORM_QC_NO},
+	{0x1D44E, UNICODE_NORM_QC_NO},
+	{0x1D44F, UNICODE_NORM_QC_NO},
+	{0x1D450, UNICODE_NORM_QC_NO},
+	{0x1D451, UNICODE_NORM_QC_NO},
+	{0x1D452, UNICODE_NORM_QC_NO},
+	{0x1D453, UNICODE_NORM_QC_NO},
+	{0x1D454, UNICODE_NORM_QC_NO},
+	{0x1D456, UNICODE_NORM_QC_NO},
+	{0x1D457, UNICODE_NORM_QC_NO},
+	{0x1D458, UNICODE_NORM_QC_NO},
+	{0x1D459, UNICODE_NORM_QC_NO},
+	{0x1D45A, UNICODE_NORM_QC_NO},
+	{0x1D45B, UNICODE_NORM_QC_NO},
+	{0x1D45C, UNICODE_NORM_QC_NO},
+	{0x1D45D, UNICODE_NORM_QC_NO},
+	{0x1D45E, UNICODE_NORM_QC_NO},
+	{0x1D45F, UNICODE_NORM_QC_NO},
+	{0x1D460, UNICODE_NORM_QC_NO},
+	{0x1D461, UNICODE_NORM_QC_NO},
+	{0x1D462, UNICODE_NORM_QC_NO},
+	{0x1D463, UNICODE_NORM_QC_NO},
+	{0x1D464, UNICODE_NORM_QC_NO},
+	{0x1D465, UNICODE_NORM_QC_NO},
+	{0x1D466, UNICODE_NORM_QC_NO},
+	{0x1D467, UNICODE_NORM_QC_NO},
+	{0x1D468, UNICODE_NORM_QC_NO},
+	{0x1D469, UNICODE_NORM_QC_NO},
+	{0x1D46A, UNICODE_NORM_QC_NO},
+	{0x1D46B, UNICODE_NORM_QC_NO},
+	{0x1D46C, UNICODE_NORM_QC_NO},
+	{0x1D46D, UNICODE_NORM_QC_NO},
+	{0x1D46E, UNICODE_NORM_QC_NO},
+	{0x1D46F, UNICODE_NORM_QC_NO},
+	{0x1D470, UNICODE_NORM_QC_NO},
+	{0x1D471, UNICODE_NORM_QC_NO},
+	{0x1D472, UNICODE_NORM_QC_NO},
+	{0x1D473, UNICODE_NORM_QC_NO},
+	{0x1D474, UNICODE_NORM_QC_NO},
+	{0x1D475, UNICODE_NORM_QC_NO},
+	{0x1D476, UNICODE_NORM_QC_NO},
+	{0x1D477, UNICODE_NORM_QC_NO},
+	{0x1D478, UNICODE_NORM_QC_NO},
+	{0x1D479, UNICODE_NORM_QC_NO},
+	{0x1D47A, UNICODE_NORM_QC_NO},
+	{0x1D47B, UNICODE_NORM_QC_NO},
+	{0x1D47C, UNICODE_NORM_QC_NO},
+	{0x1D47D, UNICODE_NORM_QC_NO},
+	{0x1D47E, UNICODE_NORM_QC_NO},
+	{0x1D47F, UNICODE_NORM_QC_NO},
+	{0x1D480, UNICODE_NORM_QC_NO},
+	{0x1D481, UNICODE_NORM_QC_NO},
+	{0x1D482, UNICODE_NORM_QC_NO},
+	{0x1D483, UNICODE_NORM_QC_NO},
+	{0x1D484, UNICODE_NORM_QC_NO},
+	{0x1D485, UNICODE_NORM_QC_NO},
+	{0x1D486, UNICODE_NORM_QC_NO},
+	{0x1D487, UNICODE_NORM_QC_NO},
+	{0x1D488, UNICODE_NORM_QC_NO},
+	{0x1D489, UNICODE_NORM_QC_NO},
+	{0x1D48A, UNICODE_NORM_QC_NO},
+	{0x1D48B, UNICODE_NORM_QC_NO},
+	{0x1D48C, UNICODE_NORM_QC_NO},
+	{0x1D48D, UNICODE_NORM_QC_NO},
+	{0x1D48E, UNICODE_NORM_QC_NO},
+	{0x1D48F, UNICODE_NORM_QC_NO},
+	{0x1D490, UNICODE_NORM_QC_NO},
+	{0x1D491, UNICODE_NORM_QC_NO},
+	{0x1D492, UNICODE_NORM_QC_NO},
+	{0x1D493, UNICODE_NORM_QC_NO},
+	{0x1D494, UNICODE_NORM_QC_NO},
+	{0x1D495, UNICODE_NORM_QC_NO},
+	{0x1D496, UNICODE_NORM_QC_NO},
+	{0x1D497, UNICODE_NORM_QC_NO},
+	{0x1D498, UNICODE_NORM_QC_NO},
+	{0x1D499, UNICODE_NORM_QC_NO},
+	{0x1D49A, UNICODE_NORM_QC_NO},
+	{0x1D49B, UNICODE_NORM_QC_NO},
+	{0x1D49C, UNICODE_NORM_QC_NO},
+	{0x1D49E, UNICODE_NORM_QC_NO},
+	{0x1D49F, UNICODE_NORM_QC_NO},
+	{0x1D4A2, UNICODE_NORM_QC_NO},
+	{0x1D4A5, UNICODE_NORM_QC_NO},
+	{0x1D4A6, UNICODE_NORM_QC_NO},
+	{0x1D4A9, UNICODE_NORM_QC_NO},
+	{0x1D4AA, UNICODE_NORM_QC_NO},
+	{0x1D4AB, UNICODE_NORM_QC_NO},
+	{0x1D4AC, UNICODE_NORM_QC_NO},
+	{0x1D4AE, UNICODE_NORM_QC_NO},
+	{0x1D4AF, UNICODE_NORM_QC_NO},
+	{0x1D4B0, UNICODE_NORM_QC_NO},
+	{0x1D4B1, UNICODE_NORM_QC_NO},
+	{0x1D4B2, UNICODE_NORM_QC_NO},
+	{0x1D4B3, UNICODE_NORM_QC_NO},
+	{0x1D4B4, UNICODE_NORM_QC_NO},
+	{0x1D4B5, UNICODE_NORM_QC_NO},
+	{0x1D4B6, UNICODE_NORM_QC_NO},
+	{0x1D4B7, UNICODE_NORM_QC_NO},
+	{0x1D4B8, UNICODE_NORM_QC_NO},
+	{0x1D4B9, UNICODE_NORM_QC_NO},
+	{0x1D4BB, UNICODE_NORM_QC_NO},
+	{0x1D4BD, UNICODE_NORM_QC_NO},
+	{0x1D4BE, UNICODE_NORM_QC_NO},
+	{0x1D4BF, UNICODE_NORM_QC_NO},
+	{0x1D4C0, UNICODE_NORM_QC_NO},
+	{0x1D4C1, UNICODE_NORM_QC_NO},
+	{0x1D4C2, UNICODE_NORM_QC_NO},
+	{0x1D4C3, UNICODE_NORM_QC_NO},
+	{0x1D4C5, UNICODE_NORM_QC_NO},
+	{0x1D4C6, UNICODE_NORM_QC_NO},
+	{0x1D4C7, UNICODE_NORM_QC_NO},
+	{0x1D4C8, UNICODE_NORM_QC_NO},
+	{0x1D4C9, UNICODE_NORM_QC_NO},
+	{0x1D4CA, UNICODE_NORM_QC_NO},
+	{0x1D4CB, UNICODE_NORM_QC_NO},
+	{0x1D4CC, UNICODE_NORM_QC_NO},
+	{0x1D4CD, UNICODE_NORM_QC_NO},
+	{0x1D4CE, UNICODE_NORM_QC_NO},
+	{0x1D4CF, UNICODE_NORM_QC_NO},
+	{0x1D4D0, UNICODE_NORM_QC_NO},
+	{0x1D4D1, UNICODE_NORM_QC_NO},
+	{0x1D4D2, UNICODE_NORM_QC_NO},
+	{0x1D4D3, UNICODE_NORM_QC_NO},
+	{0x1D4D4, UNICODE_NORM_QC_NO},
+	{0x1D4D5, UNICODE_NORM_QC_NO},
+	{0x1D4D6, UNICODE_NORM_QC_NO},
+	{0x1D4D7, UNICODE_NORM_QC_NO},
+	{0x1D4D8, UNICODE_NORM_QC_NO},
+	{0x1D4D9, UNICODE_NORM_QC_NO},
+	{0x1D4DA, UNICODE_NORM_QC_NO},
+	{0x1D4DB, UNICODE_NORM_QC_NO},
+	{0x1D4DC, UNICODE_NORM_QC_NO},
+	{0x1D4DD, UNICODE_NORM_QC_NO},
+	{0x1D4DE, UNICODE_NORM_QC_NO},
+	{0x1D4DF, UNICODE_NORM_QC_NO},
+	{0x1D4E0, UNICODE_NORM_QC_NO},
+	{0x1D4E1, UNICODE_NORM_QC_NO},
+	{0x1D4E2, UNICODE_NORM_QC_NO},
+	{0x1D4E3, UNICODE_NORM_QC_NO},
+	{0x1D4E4, UNICODE_NORM_QC_NO},
+	{0x1D4E5, UNICODE_NORM_QC_NO},
+	{0x1D4E6, UNICODE_NORM_QC_NO},
+	{0x1D4E7, UNICODE_NORM_QC_NO},
+	{0x1D4E8, UNICODE_NORM_QC_NO},
+	{0x1D4E9, UNICODE_NORM_QC_NO},
+	{0x1D4EA, UNICODE_NORM_QC_NO},
+	{0x1D4EB, UNICODE_NORM_QC_NO},
+	{0x1D4EC, UNICODE_NORM_QC_NO},
+	{0x1D4ED, UNICODE_NORM_QC_NO},
+	{0x1D4EE, UNICODE_NORM_QC_NO},
+	{0x1D4EF, UNICODE_NORM_QC_NO},
+	{0x1D4F0, UNICODE_NORM_QC_NO},
+	{0x1D4F1, UNICODE_NORM_QC_NO},
+	{0x1D4F2, UNICODE_NORM_QC_NO},
+	{0x1D4F3, UNICODE_NORM_QC_NO},
+	{0x1D4F4, UNICODE_NORM_QC_NO},
+	{0x1D4F5, UNICODE_NORM_QC_NO},
+	{0x1D4F6, UNICODE_NORM_QC_NO},
+	{0x1D4F7, UNICODE_NORM_QC_NO},
+	{0x1D4F8, UNICODE_NORM_QC_NO},
+	{0x1D4F9, UNICODE_NORM_QC_NO},
+	{0x1D4FA, UNICODE_NORM_QC_NO},
+	{0x1D4FB, UNICODE_NORM_QC_NO},
+	{0x1D4FC, UNICODE_NORM_QC_NO},
+	{0x1D4FD, UNICODE_NORM_QC_NO},
+	{0x1D4FE, UNICODE_NORM_QC_NO},
+	{0x1D4FF, UNICODE_NORM_QC_NO},
+	{0x1D500, UNICODE_NORM_QC_NO},
+	{0x1D501, UNICODE_NORM_QC_NO},
+	{0x1D502, UNICODE_NORM_QC_NO},
+	{0x1D503, UNICODE_NORM_QC_NO},
+	{0x1D504, UNICODE_NORM_QC_NO},
+	{0x1D505, UNICODE_NORM_QC_NO},
+	{0x1D507, UNICODE_NORM_QC_NO},
+	{0x1D508, UNICODE_NORM_QC_NO},
+	{0x1D509, UNICODE_NORM_QC_NO},
+	{0x1D50A, UNICODE_NORM_QC_NO},
+	{0x1D50D, UNICODE_NORM_QC_NO},
+	{0x1D50E, UNICODE_NORM_QC_NO},
+	{0x1D50F, UNICODE_NORM_QC_NO},
+	{0x1D510, UNICODE_NORM_QC_NO},
+	{0x1D511, UNICODE_NORM_QC_NO},
+	{0x1D512, UNICODE_NORM_QC_NO},
+	{0x1D513, UNICODE_NORM_QC_NO},
+	{0x1D514, UNICODE_NORM_QC_NO},
+	{0x1D516, UNICODE_NORM_QC_NO},
+	{0x1D517, UNICODE_NORM_QC_NO},
+	{0x1D518, UNICODE_NORM_QC_NO},
+	{0x1D519, UNICODE_NORM_QC_NO},
+	{0x1D51A, UNICODE_NORM_QC_NO},
+	{0x1D51B, UNICODE_NORM_QC_NO},
+	{0x1D51C, UNICODE_NORM_QC_NO},
+	{0x1D51E, UNICODE_NORM_QC_NO},
+	{0x1D51F, UNICODE_NORM_QC_NO},
+	{0x1D520, UNICODE_NORM_QC_NO},
+	{0x1D521, UNICODE_NORM_QC_NO},
+	{0x1D522, UNICODE_NORM_QC_NO},
+	{0x1D523, UNICODE_NORM_QC_NO},
+	{0x1D524, UNICODE_NORM_QC_NO},
+	{0x1D525, UNICODE_NORM_QC_NO},
+	{0x1D526, UNICODE_NORM_QC_NO},
+	{0x1D527, UNICODE_NORM_QC_NO},
+	{0x1D528, UNICODE_NORM_QC_NO},
+	{0x1D529, UNICODE_NORM_QC_NO},
+	{0x1D52A, UNICODE_NORM_QC_NO},
+	{0x1D52B, UNICODE_NORM_QC_NO},
+	{0x1D52C, UNICODE_NORM_QC_NO},
+	{0x1D52D, UNICODE_NORM_QC_NO},
+	{0x1D52E, UNICODE_NORM_QC_NO},
+	{0x1D52F, UNICODE_NORM_QC_NO},
+	{0x1D530, UNICODE_NORM_QC_NO},
+	{0x1D531, UNICODE_NORM_QC_NO},
+	{0x1D532, UNICODE_NORM_QC_NO},
+	{0x1D533, UNICODE_NORM_QC_NO},
+	{0x1D534, UNICODE_NORM_QC_NO},
+	{0x1D535, UNICODE_NORM_QC_NO},
+	{0x1D536, UNICODE_NORM_QC_NO},
+	{0x1D537, UNICODE_NORM_QC_NO},
+	{0x1D538, UNICODE_NORM_QC_NO},
+	{0x1D539, UNICODE_NORM_QC_NO},
+	{0x1D53B, UNICODE_NORM_QC_NO},
+	{0x1D53C, UNICODE_NORM_QC_NO},
+	{0x1D53D, UNICODE_NORM_QC_NO},
+	{0x1D53E, UNICODE_NORM_QC_NO},
+	{0x1D540, UNICODE_NORM_QC_NO},
+	{0x1D541, UNICODE_NORM_QC_NO},
+	{0x1D542, UNICODE_NORM_QC_NO},
+	{0x1D543, UNICODE_NORM_QC_NO},
+	{0x1D544, UNICODE_NORM_QC_NO},
+	{0x1D546, UNICODE_NORM_QC_NO},
+	{0x1D54A, UNICODE_NORM_QC_NO},
+	{0x1D54B, UNICODE_NORM_QC_NO},
+	{0x1D54C, UNICODE_NORM_QC_NO},
+	{0x1D54D, UNICODE_NORM_QC_NO},
+	{0x1D54E, UNICODE_NORM_QC_NO},
+	{0x1D54F, UNICODE_NORM_QC_NO},
+	{0x1D550, UNICODE_NORM_QC_NO},
+	{0x1D552, UNICODE_NORM_QC_NO},
+	{0x1D553, UNICODE_NORM_QC_NO},
+	{0x1D554, UNICODE_NORM_QC_NO},
+	{0x1D555, UNICODE_NORM_QC_NO},
+	{0x1D556, UNICODE_NORM_QC_NO},
+	{0x1D557, UNICODE_NORM_QC_NO},
+	{0x1D558, UNICODE_NORM_QC_NO},
+	{0x1D559, UNICODE_NORM_QC_NO},
+	{0x1D55A, UNICODE_NORM_QC_NO},
+	{0x1D55B, UNICODE_NORM_QC_NO},
+	{0x1D55C, UNICODE_NORM_QC_NO},
+	{0x1D55D, UNICODE_NORM_QC_NO},
+	{0x1D55E, UNICODE_NORM_QC_NO},
+	{0x1D55F, UNICODE_NORM_QC_NO},
+	{0x1D560, UNICODE_NORM_QC_NO},
+	{0x1D561, UNICODE_NORM_QC_NO},
+	{0x1D562, UNICODE_NORM_QC_NO},
+	{0x1D563, UNICODE_NORM_QC_NO},
+	{0x1D564, UNICODE_NORM_QC_NO},
+	{0x1D565, UNICODE_NORM_QC_NO},
+	{0x1D566, UNICODE_NORM_QC_NO},
+	{0x1D567, UNICODE_NORM_QC_NO},
+	{0x1D568, UNICODE_NORM_QC_NO},
+	{0x1D569, UNICODE_NORM_QC_NO},
+	{0x1D56A, UNICODE_NORM_QC_NO},
+	{0x1D56B, UNICODE_NORM_QC_NO},
+	{0x1D56C, UNICODE_NORM_QC_NO},
+	{0x1D56D, UNICODE_NORM_QC_NO},
+	{0x1D56E, UNICODE_NORM_QC_NO},
+	{0x1D56F, UNICODE_NORM_QC_NO},
+	{0x1D570, UNICODE_NORM_QC_NO},
+	{0x1D571, UNICODE_NORM_QC_NO},
+	{0x1D572, UNICODE_NORM_QC_NO},
+	{0x1D573, UNICODE_NORM_QC_NO},
+	{0x1D574, UNICODE_NORM_QC_NO},
+	{0x1D575, UNICODE_NORM_QC_NO},
+	{0x1D576, UNICODE_NORM_QC_NO},
+	{0x1D577, UNICODE_NORM_QC_NO},
+	{0x1D578, UNICODE_NORM_QC_NO},
+	{0x1D579, UNICODE_NORM_QC_NO},
+	{0x1D57A, UNICODE_NORM_QC_NO},
+	{0x1D57B, UNICODE_NORM_QC_NO},
+	{0x1D57C, UNICODE_NORM_QC_NO},
+	{0x1D57D, UNICODE_NORM_QC_NO},
+	{0x1D57E, UNICODE_NORM_QC_NO},
+	{0x1D57F, UNICODE_NORM_QC_NO},
+	{0x1D580, UNICODE_NORM_QC_NO},
+	{0x1D581, UNICODE_NORM_QC_NO},
+	{0x1D582, UNICODE_NORM_QC_NO},
+	{0x1D583, UNICODE_NORM_QC_NO},
+	{0x1D584, UNICODE_NORM_QC_NO},
+	{0x1D585, UNICODE_NORM_QC_NO},
+	{0x1D586, UNICODE_NORM_QC_NO},
+	{0x1D587, UNICODE_NORM_QC_NO},
+	{0x1D588, UNICODE_NORM_QC_NO},
+	{0x1D589, UNICODE_NORM_QC_NO},
+	{0x1D58A, UNICODE_NORM_QC_NO},
+	{0x1D58B, UNICODE_NORM_QC_NO},
+	{0x1D58C, UNICODE_NORM_QC_NO},
+	{0x1D58D, UNICODE_NORM_QC_NO},
+	{0x1D58E, UNICODE_NORM_QC_NO},
+	{0x1D58F, UNICODE_NORM_QC_NO},
+	{0x1D590, UNICODE_NORM_QC_NO},
+	{0x1D591, UNICODE_NORM_QC_NO},
+	{0x1D592, UNICODE_NORM_QC_NO},
+	{0x1D593, UNICODE_NORM_QC_NO},
+	{0x1D594, UNICODE_NORM_QC_NO},
+	{0x1D595, UNICODE_NORM_QC_NO},
+	{0x1D596, UNICODE_NORM_QC_NO},
+	{0x1D597, UNICODE_NORM_QC_NO},
+	{0x1D598, UNICODE_NORM_QC_NO},
+	{0x1D599, UNICODE_NORM_QC_NO},
+	{0x1D59A, UNICODE_NORM_QC_NO},
+	{0x1D59B, UNICODE_NORM_QC_NO},
+	{0x1D59C, UNICODE_NORM_QC_NO},
+	{0x1D59D, UNICODE_NORM_QC_NO},
+	{0x1D59E, UNICODE_NORM_QC_NO},
+	{0x1D59F, UNICODE_NORM_QC_NO},
+	{0x1D5A0, UNICODE_NORM_QC_NO},
+	{0x1D5A1, UNICODE_NORM_QC_NO},
+	{0x1D5A2, UNICODE_NORM_QC_NO},
+	{0x1D5A3, UNICODE_NORM_QC_NO},
+	{0x1D5A4, UNICODE_NORM_QC_NO},
+	{0x1D5A5, UNICODE_NORM_QC_NO},
+	{0x1D5A6, UNICODE_NORM_QC_NO},
+	{0x1D5A7, UNICODE_NORM_QC_NO},
+	{0x1D5A8, UNICODE_NORM_QC_NO},
+	{0x1D5A9, UNICODE_NORM_QC_NO},
+	{0x1D5AA, UNICODE_NORM_QC_NO},
+	{0x1D5AB, UNICODE_NORM_QC_NO},
+	{0x1D5AC, UNICODE_NORM_QC_NO},
+	{0x1D5AD, UNICODE_NORM_QC_NO},
+	{0x1D5AE, UNICODE_NORM_QC_NO},
+	{0x1D5AF, UNICODE_NORM_QC_NO},
+	{0x1D5B0, UNICODE_NORM_QC_NO},
+	{0x1D5B1, UNICODE_NORM_QC_NO},
+	{0x1D5B2, UNICODE_NORM_QC_NO},
+	{0x1D5B3, UNICODE_NORM_QC_NO},
+	{0x1D5B4, UNICODE_NORM_QC_NO},
+	{0x1D5B5, UNICODE_NORM_QC_NO},
+	{0x1D5B6, UNICODE_NORM_QC_NO},
+	{0x1D5B7, UNICODE_NORM_QC_NO},
+	{0x1D5B8, UNICODE_NORM_QC_NO},
+	{0x1D5B9, UNICODE_NORM_QC_NO},
+	{0x1D5BA, UNICODE_NORM_QC_NO},
+	{0x1D5BB, UNICODE_NORM_QC_NO},
+	{0x1D5BC, UNICODE_NORM_QC_NO},
+	{0x1D5BD, UNICODE_NORM_QC_NO},
+	{0x1D5BE, UNICODE_NORM_QC_NO},
+	{0x1D5BF, UNICODE_NORM_QC_NO},
+	{0x1D5C0, UNICODE_NORM_QC_NO},
+	{0x1D5C1, UNICODE_NORM_QC_NO},
+	{0x1D5C2, UNICODE_NORM_QC_NO},
+	{0x1D5C3, UNICODE_NORM_QC_NO},
+	{0x1D5C4, UNICODE_NORM_QC_NO},
+	{0x1D5C5, UNICODE_NORM_QC_NO},
+	{0x1D5C6, UNICODE_NORM_QC_NO},
+	{0x1D5C7, UNICODE_NORM_QC_NO},
+	{0x1D5C8, UNICODE_NORM_QC_NO},
+	{0x1D5C9, UNICODE_NORM_QC_NO},
+	{0x1D5CA, UNICODE_NORM_QC_NO},
+	{0x1D5CB, UNICODE_NORM_QC_NO},
+	{0x1D5CC, UNICODE_NORM_QC_NO},
+	{0x1D5CD, UNICODE_NORM_QC_NO},
+	{0x1D5CE, UNICODE_NORM_QC_NO},
+	{0x1D5CF, UNICODE_NORM_QC_NO},
+	{0x1D5D0, UNICODE_NORM_QC_NO},
+	{0x1D5D1, UNICODE_NORM_QC_NO},
+	{0x1D5D2, UNICODE_NORM_QC_NO},
+	{0x1D5D3, UNICODE_NORM_QC_NO},
+	{0x1D5D4, UNICODE_NORM_QC_NO},
+	{0x1D5D5, UNICODE_NORM_QC_NO},
+	{0x1D5D6, UNICODE_NORM_QC_NO},
+	{0x1D5D7, UNICODE_NORM_QC_NO},
+	{0x1D5D8, UNICODE_NORM_QC_NO},
+	{0x1D5D9, UNICODE_NORM_QC_NO},
+	{0x1D5DA, UNICODE_NORM_QC_NO},
+	{0x1D5DB, UNICODE_NORM_QC_NO},
+	{0x1D5DC, UNICODE_NORM_QC_NO},
+	{0x1D5DD, UNICODE_NORM_QC_NO},
+	{0x1D5DE, UNICODE_NORM_QC_NO},
+	{0x1D5DF, UNICODE_NORM_QC_NO},
+	{0x1D5E0, UNICODE_NORM_QC_NO},
+	{0x1D5E1, UNICODE_NORM_QC_NO},
+	{0x1D5E2, UNICODE_NORM_QC_NO},
+	{0x1D5E3, UNICODE_NORM_QC_NO},
+	{0x1D5E4, UNICODE_NORM_QC_NO},
+	{0x1D5E5, UNICODE_NORM_QC_NO},
+	{0x1D5E6, UNICODE_NORM_QC_NO},
+	{0x1D5E7, UNICODE_NORM_QC_NO},
+	{0x1D5E8, UNICODE_NORM_QC_NO},
+	{0x1D5E9, UNICODE_NORM_QC_NO},
+	{0x1D5EA, UNICODE_NORM_QC_NO},
+	{0x1D5EB, UNICODE_NORM_QC_NO},
+	{0x1D5EC, UNICODE_NORM_QC_NO},
+	{0x1D5ED, UNICODE_NORM_QC_NO},
+	{0x1D5EE, UNICODE_NORM_QC_NO},
+	{0x1D5EF, UNICODE_NORM_QC_NO},
+	{0x1D5F0, UNICODE_NORM_QC_NO},
+	{0x1D5F1, UNICODE_NORM_QC_NO},
+	{0x1D5F2, UNICODE_NORM_QC_NO},
+	{0x1D5F3, UNICODE_NORM_QC_NO},
+	{0x1D5F4, UNICODE_NORM_QC_NO},
+	{0x1D5F5, UNICODE_NORM_QC_NO},
+	{0x1D5F6, UNICODE_NORM_QC_NO},
+	{0x1D5F7, UNICODE_NORM_QC_NO},
+	{0x1D5F8, UNICODE_NORM_QC_NO},
+	{0x1D5F9, UNICODE_NORM_QC_NO},
+	{0x1D5FA, UNICODE_NORM_QC_NO},
+	{0x1D5FB, UNICODE_NORM_QC_NO},
+	{0x1D5FC, UNICODE_NORM_QC_NO},
+	{0x1D5FD, UNICODE_NORM_QC_NO},
+	{0x1D5FE, UNICODE_NORM_QC_NO},
+	{0x1D5FF, UNICODE_NORM_QC_NO},
+	{0x1D600, UNICODE_NORM_QC_NO},
+	{0x1D601, UNICODE_NORM_QC_NO},
+	{0x1D602, UNICODE_NORM_QC_NO},
+	{0x1D603, UNICODE_NORM_QC_NO},
+	{0x1D604, UNICODE_NORM_QC_NO},
+	{0x1D605, UNICODE_NORM_QC_NO},
+	{0x1D606, UNICODE_NORM_QC_NO},
+	{0x1D607, UNICODE_NORM_QC_NO},
+	{0x1D608, UNICODE_NORM_QC_NO},
+	{0x1D609, UNICODE_NORM_QC_NO},
+	{0x1D60A, UNICODE_NORM_QC_NO},
+	{0x1D60B, UNICODE_NORM_QC_NO},
+	{0x1D60C, UNICODE_NORM_QC_NO},
+	{0x1D60D, UNICODE_NORM_QC_NO},
+	{0x1D60E, UNICODE_NORM_QC_NO},
+	{0x1D60F, UNICODE_NORM_QC_NO},
+	{0x1D610, UNICODE_NORM_QC_NO},
+	{0x1D611, UNICODE_NORM_QC_NO},
+	{0x1D612, UNICODE_NORM_QC_NO},
+	{0x1D613, UNICODE_NORM_QC_NO},
+	{0x1D614, UNICODE_NORM_QC_NO},
+	{0x1D615, UNICODE_NORM_QC_NO},
+	{0x1D616, UNICODE_NORM_QC_NO},
+	{0x1D617, UNICODE_NORM_QC_NO},
+	{0x1D618, UNICODE_NORM_QC_NO},
+	{0x1D619, UNICODE_NORM_QC_NO},
+	{0x1D61A, UNICODE_NORM_QC_NO},
+	{0x1D61B, UNICODE_NORM_QC_NO},
+	{0x1D61C, UNICODE_NORM_QC_NO},
+	{0x1D61D, UNICODE_NORM_QC_NO},
+	{0x1D61E, UNICODE_NORM_QC_NO},
+	{0x1D61F, UNICODE_NORM_QC_NO},
+	{0x1D620, UNICODE_NORM_QC_NO},
+	{0x1D621, UNICODE_NORM_QC_NO},
+	{0x1D622, UNICODE_NORM_QC_NO},
+	{0x1D623, UNICODE_NORM_QC_NO},
+	{0x1D624, UNICODE_NORM_QC_NO},
+	{0x1D625, UNICODE_NORM_QC_NO},
+	{0x1D626, UNICODE_NORM_QC_NO},
+	{0x1D627, UNICODE_NORM_QC_NO},
+	{0x1D628, UNICODE_NORM_QC_NO},
+	{0x1D629, UNICODE_NORM_QC_NO},
+	{0x1D62A, UNICODE_NORM_QC_NO},
+	{0x1D62B, UNICODE_NORM_QC_NO},
+	{0x1D62C, UNICODE_NORM_QC_NO},
+	{0x1D62D, UNICODE_NORM_QC_NO},
+	{0x1D62E, UNICODE_NORM_QC_NO},
+	{0x1D62F, UNICODE_NORM_QC_NO},
+	{0x1D630, UNICODE_NORM_QC_NO},
+	{0x1D631, UNICODE_NORM_QC_NO},
+	{0x1D632, UNICODE_NORM_QC_NO},
+	{0x1D633, UNICODE_NORM_QC_NO},
+	{0x1D634, UNICODE_NORM_QC_NO},
+	{0x1D635, UNICODE_NORM_QC_NO},
+	{0x1D636, UNICODE_NORM_QC_NO},
+	{0x1D637, UNICODE_NORM_QC_NO},
+	{0x1D638, UNICODE_NORM_QC_NO},
+	{0x1D639, UNICODE_NORM_QC_NO},
+	{0x1D63A, UNICODE_NORM_QC_NO},
+	{0x1D63B, UNICODE_NORM_QC_NO},
+	{0x1D63C, UNICODE_NORM_QC_NO},
+	{0x1D63D, UNICODE_NORM_QC_NO},
+	{0x1D63E, UNICODE_NORM_QC_NO},
+	{0x1D63F, UNICODE_NORM_QC_NO},
+	{0x1D640, UNICODE_NORM_QC_NO},
+	{0x1D641, UNICODE_NORM_QC_NO},
+	{0x1D642, UNICODE_NORM_QC_NO},
+	{0x1D643, UNICODE_NORM_QC_NO},
+	{0x1D644, UNICODE_NORM_QC_NO},
+	{0x1D645, UNICODE_NORM_QC_NO},
+	{0x1D646, UNICODE_NORM_QC_NO},
+	{0x1D647, UNICODE_NORM_QC_NO},
+	{0x1D648, UNICODE_NORM_QC_NO},
+	{0x1D649, UNICODE_NORM_QC_NO},
+	{0x1D64A, UNICODE_NORM_QC_NO},
+	{0x1D64B, UNICODE_NORM_QC_NO},
+	{0x1D64C, UNICODE_NORM_QC_NO},
+	{0x1D64D, UNICODE_NORM_QC_NO},
+	{0x1D64E, UNICODE_NORM_QC_NO},
+	{0x1D64F, UNICODE_NORM_QC_NO},
+	{0x1D650, UNICODE_NORM_QC_NO},
+	{0x1D651, UNICODE_NORM_QC_NO},
+	{0x1D652, UNICODE_NORM_QC_NO},
+	{0x1D653, UNICODE_NORM_QC_NO},
+	{0x1D654, UNICODE_NORM_QC_NO},
+	{0x1D655, UNICODE_NORM_QC_NO},
+	{0x1D656, UNICODE_NORM_QC_NO},
+	{0x1D657, UNICODE_NORM_QC_NO},
+	{0x1D658, UNICODE_NORM_QC_NO},
+	{0x1D659, UNICODE_NORM_QC_NO},
+	{0x1D65A, UNICODE_NORM_QC_NO},
+	{0x1D65B, UNICODE_NORM_QC_NO},
+	{0x1D65C, UNICODE_NORM_QC_NO},
+	{0x1D65D, UNICODE_NORM_QC_NO},
+	{0x1D65E, UNICODE_NORM_QC_NO},
+	{0x1D65F, UNICODE_NORM_QC_NO},
+	{0x1D660, UNICODE_NORM_QC_NO},
+	{0x1D661, UNICODE_NORM_QC_NO},
+	{0x1D662, UNICODE_NORM_QC_NO},
+	{0x1D663, UNICODE_NORM_QC_NO},
+	{0x1D664, UNICODE_NORM_QC_NO},
+	{0x1D665, UNICODE_NORM_QC_NO},
+	{0x1D666, UNICODE_NORM_QC_NO},
+	{0x1D667, UNICODE_NORM_QC_NO},
+	{0x1D668, UNICODE_NORM_QC_NO},
+	{0x1D669, UNICODE_NORM_QC_NO},
+	{0x1D66A, UNICODE_NORM_QC_NO},
+	{0x1D66B, UNICODE_NORM_QC_NO},
+	{0x1D66C, UNICODE_NORM_QC_NO},
+	{0x1D66D, UNICODE_NORM_QC_NO},
+	{0x1D66E, UNICODE_NORM_QC_NO},
+	{0x1D66F, UNICODE_NORM_QC_NO},
+	{0x1D670, UNICODE_NORM_QC_NO},
+	{0x1D671, UNICODE_NORM_QC_NO},
+	{0x1D672, UNICODE_NORM_QC_NO},
+	{0x1D673, UNICODE_NORM_QC_NO},
+	{0x1D674, UNICODE_NORM_QC_NO},
+	{0x1D675, UNICODE_NORM_QC_NO},
+	{0x1D676, UNICODE_NORM_QC_NO},
+	{0x1D677, UNICODE_NORM_QC_NO},
+	{0x1D678, UNICODE_NORM_QC_NO},
+	{0x1D679, UNICODE_NORM_QC_NO},
+	{0x1D67A, UNICODE_NORM_QC_NO},
+	{0x1D67B, UNICODE_NORM_QC_NO},
+	{0x1D67C, UNICODE_NORM_QC_NO},
+	{0x1D67D, UNICODE_NORM_QC_NO},
+	{0x1D67E, UNICODE_NORM_QC_NO},
+	{0x1D67F, UNICODE_NORM_QC_NO},
+	{0x1D680, UNICODE_NORM_QC_NO},
+	{0x1D681, UNICODE_NORM_QC_NO},
+	{0x1D682, UNICODE_NORM_QC_NO},
+	{0x1D683, UNICODE_NORM_QC_NO},
+	{0x1D684, UNICODE_NORM_QC_NO},
+	{0x1D685, UNICODE_NORM_QC_NO},
+	{0x1D686, UNICODE_NORM_QC_NO},
+	{0x1D687, UNICODE_NORM_QC_NO},
+	{0x1D688, UNICODE_NORM_QC_NO},
+	{0x1D689, UNICODE_NORM_QC_NO},
+	{0x1D68A, UNICODE_NORM_QC_NO},
+	{0x1D68B, UNICODE_NORM_QC_NO},
+	{0x1D68C, UNICODE_NORM_QC_NO},
+	{0x1D68D, UNICODE_NORM_QC_NO},
+	{0x1D68E, UNICODE_NORM_QC_NO},
+	{0x1D68F, UNICODE_NORM_QC_NO},
+	{0x1D690, UNICODE_NORM_QC_NO},
+	{0x1D691, UNICODE_NORM_QC_NO},
+	{0x1D692, UNICODE_NORM_QC_NO},
+	{0x1D693, UNICODE_NORM_QC_NO},
+	{0x1D694, UNICODE_NORM_QC_NO},
+	{0x1D695, UNICODE_NORM_QC_NO},
+	{0x1D696, UNICODE_NORM_QC_NO},
+	{0x1D697, UNICODE_NORM_QC_NO},
+	{0x1D698, UNICODE_NORM_QC_NO},
+	{0x1D699, UNICODE_NORM_QC_NO},
+	{0x1D69A, UNICODE_NORM_QC_NO},
+	{0x1D69B, UNICODE_NORM_QC_NO},
+	{0x1D69C, UNICODE_NORM_QC_NO},
+	{0x1D69D, UNICODE_NORM_QC_NO},
+	{0x1D69E, UNICODE_NORM_QC_NO},
+	{0x1D69F, UNICODE_NORM_QC_NO},
+	{0x1D6A0, UNICODE_NORM_QC_NO},
+	{0x1D6A1, UNICODE_NORM_QC_NO},
+	{0x1D6A2, UNICODE_NORM_QC_NO},
+	{0x1D6A3, UNICODE_NORM_QC_NO},
+	{0x1D6A4, UNICODE_NORM_QC_NO},
+	{0x1D6A5, UNICODE_NORM_QC_NO},
+	{0x1D6A8, UNICODE_NORM_QC_NO},
+	{0x1D6A9, UNICODE_NORM_QC_NO},
+	{0x1D6AA, UNICODE_NORM_QC_NO},
+	{0x1D6AB, UNICODE_NORM_QC_NO},
+	{0x1D6AC, UNICODE_NORM_QC_NO},
+	{0x1D6AD, UNICODE_NORM_QC_NO},
+	{0x1D6AE, UNICODE_NORM_QC_NO},
+	{0x1D6AF, UNICODE_NORM_QC_NO},
+	{0x1D6B0, UNICODE_NORM_QC_NO},
+	{0x1D6B1, UNICODE_NORM_QC_NO},
+	{0x1D6B2, UNICODE_NORM_QC_NO},
+	{0x1D6B3, UNICODE_NORM_QC_NO},
+	{0x1D6B4, UNICODE_NORM_QC_NO},
+	{0x1D6B5, UNICODE_NORM_QC_NO},
+	{0x1D6B6, UNICODE_NORM_QC_NO},
+	{0x1D6B7, UNICODE_NORM_QC_NO},
+	{0x1D6B8, UNICODE_NORM_QC_NO},
+	{0x1D6B9, UNICODE_NORM_QC_NO},
+	{0x1D6BA, UNICODE_NORM_QC_NO},
+	{0x1D6BB, UNICODE_NORM_QC_NO},
+	{0x1D6BC, UNICODE_NORM_QC_NO},
+	{0x1D6BD, UNICODE_NORM_QC_NO},
+	{0x1D6BE, UNICODE_NORM_QC_NO},
+	{0x1D6BF, UNICODE_NORM_QC_NO},
+	{0x1D6C0, UNICODE_NORM_QC_NO},
+	{0x1D6C1, UNICODE_NORM_QC_NO},
+	{0x1D6C2, UNICODE_NORM_QC_NO},
+	{0x1D6C3, UNICODE_NORM_QC_NO},
+	{0x1D6C4, UNICODE_NORM_QC_NO},
+	{0x1D6C5, UNICODE_NORM_QC_NO},
+	{0x1D6C6, UNICODE_NORM_QC_NO},
+	{0x1D6C7, UNICODE_NORM_QC_NO},
+	{0x1D6C8, UNICODE_NORM_QC_NO},
+	{0x1D6C9, UNICODE_NORM_QC_NO},
+	{0x1D6CA, UNICODE_NORM_QC_NO},
+	{0x1D6CB, UNICODE_NORM_QC_NO},
+	{0x1D6CC, UNICODE_NORM_QC_NO},
+	{0x1D6CD, UNICODE_NORM_QC_NO},
+	{0x1D6CE, UNICODE_NORM_QC_NO},
+	{0x1D6CF, UNICODE_NORM_QC_NO},
+	{0x1D6D0, UNICODE_NORM_QC_NO},
+	{0x1D6D1, UNICODE_NORM_QC_NO},
+	{0x1D6D2, UNICODE_NORM_QC_NO},
+	{0x1D6D3, UNICODE_NORM_QC_NO},
+	{0x1D6D4, UNICODE_NORM_QC_NO},
+	{0x1D6D5, UNICODE_NORM_QC_NO},
+	{0x1D6D6, UNICODE_NORM_QC_NO},
+	{0x1D6D7, UNICODE_NORM_QC_NO},
+	{0x1D6D8, UNICODE_NORM_QC_NO},
+	{0x1D6D9, UNICODE_NORM_QC_NO},
+	{0x1D6DA, UNICODE_NORM_QC_NO},
+	{0x1D6DB, UNICODE_NORM_QC_NO},
+	{0x1D6DC, UNICODE_NORM_QC_NO},
+	{0x1D6DD, UNICODE_NORM_QC_NO},
+	{0x1D6DE, UNICODE_NORM_QC_NO},
+	{0x1D6DF, UNICODE_NORM_QC_NO},
+	{0x1D6E0, UNICODE_NORM_QC_NO},
+	{0x1D6E1, UNICODE_NORM_QC_NO},
+	{0x1D6E2, UNICODE_NORM_QC_NO},
+	{0x1D6E3, UNICODE_NORM_QC_NO},
+	{0x1D6E4, UNICODE_NORM_QC_NO},
+	{0x1D6E5, UNICODE_NORM_QC_NO},
+	{0x1D6E6, UNICODE_NORM_QC_NO},
+	{0x1D6E7, UNICODE_NORM_QC_NO},
+	{0x1D6E8, UNICODE_NORM_QC_NO},
+	{0x1D6E9, UNICODE_NORM_QC_NO},
+	{0x1D6EA, UNICODE_NORM_QC_NO},
+	{0x1D6EB, UNICODE_NORM_QC_NO},
+	{0x1D6EC, UNICODE_NORM_QC_NO},
+	{0x1D6ED, UNICODE_NORM_QC_NO},
+	{0x1D6EE, UNICODE_NORM_QC_NO},
+	{0x1D6EF, UNICODE_NORM_QC_NO},
+	{0x1D6F0, UNICODE_NORM_QC_NO},
+	{0x1D6F1, UNICODE_NORM_QC_NO},
+	{0x1D6F2, UNICODE_NORM_QC_NO},
+	{0x1D6F3, UNICODE_NORM_QC_NO},
+	{0x1D6F4, UNICODE_NORM_QC_NO},
+	{0x1D6F5, UNICODE_NORM_QC_NO},
+	{0x1D6F6, UNICODE_NORM_QC_NO},
+	{0x1D6F7, UNICODE_NORM_QC_NO},
+	{0x1D6F8, UNICODE_NORM_QC_NO},
+	{0x1D6F9, UNICODE_NORM_QC_NO},
+	{0x1D6FA, UNICODE_NORM_QC_NO},
+	{0x1D6FB, UNICODE_NORM_QC_NO},
+	{0x1D6FC, UNICODE_NORM_QC_NO},
+	{0x1D6FD, UNICODE_NORM_QC_NO},
+	{0x1D6FE, UNICODE_NORM_QC_NO},
+	{0x1D6FF, UNICODE_NORM_QC_NO},
+	{0x1D700, UNICODE_NORM_QC_NO},
+	{0x1D701, UNICODE_NORM_QC_NO},
+	{0x1D702, UNICODE_NORM_QC_NO},
+	{0x1D703, UNICODE_NORM_QC_NO},
+	{0x1D704, UNICODE_NORM_QC_NO},
+	{0x1D705, UNICODE_NORM_QC_NO},
+	{0x1D706, UNICODE_NORM_QC_NO},
+	{0x1D707, UNICODE_NORM_QC_NO},
+	{0x1D708, UNICODE_NORM_QC_NO},
+	{0x1D709, UNICODE_NORM_QC_NO},
+	{0x1D70A, UNICODE_NORM_QC_NO},
+	{0x1D70B, UNICODE_NORM_QC_NO},
+	{0x1D70C, UNICODE_NORM_QC_NO},
+	{0x1D70D, UNICODE_NORM_QC_NO},
+	{0x1D70E, UNICODE_NORM_QC_NO},
+	{0x1D70F, UNICODE_NORM_QC_NO},
+	{0x1D710, UNICODE_NORM_QC_NO},
+	{0x1D711, UNICODE_NORM_QC_NO},
+	{0x1D712, UNICODE_NORM_QC_NO},
+	{0x1D713, UNICODE_NORM_QC_NO},
+	{0x1D714, UNICODE_NORM_QC_NO},
+	{0x1D715, UNICODE_NORM_QC_NO},
+	{0x1D716, UNICODE_NORM_QC_NO},
+	{0x1D717, UNICODE_NORM_QC_NO},
+	{0x1D718, UNICODE_NORM_QC_NO},
+	{0x1D719, UNICODE_NORM_QC_NO},
+	{0x1D71A, UNICODE_NORM_QC_NO},
+	{0x1D71B, UNICODE_NORM_QC_NO},
+	{0x1D71C, UNICODE_NORM_QC_NO},
+	{0x1D71D, UNICODE_NORM_QC_NO},
+	{0x1D71E, UNICODE_NORM_QC_NO},
+	{0x1D71F, UNICODE_NORM_QC_NO},
+	{0x1D720, UNICODE_NORM_QC_NO},
+	{0x1D721, UNICODE_NORM_QC_NO},
+	{0x1D722, UNICODE_NORM_QC_NO},
+	{0x1D723, UNICODE_NORM_QC_NO},
+	{0x1D724, UNICODE_NORM_QC_NO},
+	{0x1D725, UNICODE_NORM_QC_NO},
+	{0x1D726, UNICODE_NORM_QC_NO},
+	{0x1D727, UNICODE_NORM_QC_NO},
+	{0x1D728, UNICODE_NORM_QC_NO},
+	{0x1D729, UNICODE_NORM_QC_NO},
+	{0x1D72A, UNICODE_NORM_QC_NO},
+	{0x1D72B, UNICODE_NORM_QC_NO},
+	{0x1D72C, UNICODE_NORM_QC_NO},
+	{0x1D72D, UNICODE_NORM_QC_NO},
+	{0x1D72E, UNICODE_NORM_QC_NO},
+	{0x1D72F, UNICODE_NORM_QC_NO},
+	{0x1D730, UNICODE_NORM_QC_NO},
+	{0x1D731, UNICODE_NORM_QC_NO},
+	{0x1D732, UNICODE_NORM_QC_NO},
+	{0x1D733, UNICODE_NORM_QC_NO},
+	{0x1D734, UNICODE_NORM_QC_NO},
+	{0x1D735, UNICODE_NORM_QC_NO},
+	{0x1D736, UNICODE_NORM_QC_NO},
+	{0x1D737, UNICODE_NORM_QC_NO},
+	{0x1D738, UNICODE_NORM_QC_NO},
+	{0x1D739, UNICODE_NORM_QC_NO},
+	{0x1D73A, UNICODE_NORM_QC_NO},
+	{0x1D73B, UNICODE_NORM_QC_NO},
+	{0x1D73C, UNICODE_NORM_QC_NO},
+	{0x1D73D, UNICODE_NORM_QC_NO},
+	{0x1D73E, UNICODE_NORM_QC_NO},
+	{0x1D73F, UNICODE_NORM_QC_NO},
+	{0x1D740, UNICODE_NORM_QC_NO},
+	{0x1D741, UNICODE_NORM_QC_NO},
+	{0x1D742, UNICODE_NORM_QC_NO},
+	{0x1D743, UNICODE_NORM_QC_NO},
+	{0x1D744, UNICODE_NORM_QC_NO},
+	{0x1D745, UNICODE_NORM_QC_NO},
+	{0x1D746, UNICODE_NORM_QC_NO},
+	{0x1D747, UNICODE_NORM_QC_NO},
+	{0x1D748, UNICODE_NORM_QC_NO},
+	{0x1D749, UNICODE_NORM_QC_NO},
+	{0x1D74A, UNICODE_NORM_QC_NO},
+	{0x1D74B, UNICODE_NORM_QC_NO},
+	{0x1D74C, UNICODE_NORM_QC_NO},
+	{0x1D74D, UNICODE_NORM_QC_NO},
+	{0x1D74E, UNICODE_NORM_QC_NO},
+	{0x1D74F, UNICODE_NORM_QC_NO},
+	{0x1D750, UNICODE_NORM_QC_NO},
+	{0x1D751, UNICODE_NORM_QC_NO},
+	{0x1D752, UNICODE_NORM_QC_NO},
+	{0x1D753, UNICODE_NORM_QC_NO},
+	{0x1D754, UNICODE_NORM_QC_NO},
+	{0x1D755, UNICODE_NORM_QC_NO},
+	{0x1D756, UNICODE_NORM_QC_NO},
+	{0x1D757, UNICODE_NORM_QC_NO},
+	{0x1D758, UNICODE_NORM_QC_NO},
+	{0x1D759, UNICODE_NORM_QC_NO},
+	{0x1D75A, UNICODE_NORM_QC_NO},
+	{0x1D75B, UNICODE_NORM_QC_NO},
+	{0x1D75C, UNICODE_NORM_QC_NO},
+	{0x1D75D, UNICODE_NORM_QC_NO},
+	{0x1D75E, UNICODE_NORM_QC_NO},
+	{0x1D75F, UNICODE_NORM_QC_NO},
+	{0x1D760, UNICODE_NORM_QC_NO},
+	{0x1D761, UNICODE_NORM_QC_NO},
+	{0x1D762, UNICODE_NORM_QC_NO},
+	{0x1D763, UNICODE_NORM_QC_NO},
+	{0x1D764, UNICODE_NORM_QC_NO},
+	{0x1D765, UNICODE_NORM_QC_NO},
+	{0x1D766, UNICODE_NORM_QC_NO},
+	{0x1D767, UNICODE_NORM_QC_NO},
+	{0x1D768, UNICODE_NORM_QC_NO},
+	{0x1D769, UNICODE_NORM_QC_NO},
+	{0x1D76A, UNICODE_NORM_QC_NO},
+	{0x1D76B, UNICODE_NORM_QC_NO},
+	{0x1D76C, UNICODE_NORM_QC_NO},
+	{0x1D76D, UNICODE_NORM_QC_NO},
+	{0x1D76E, UNICODE_NORM_QC_NO},
+	{0x1D76F, UNICODE_NORM_QC_NO},
+	{0x1D770, UNICODE_NORM_QC_NO},
+	{0x1D771, UNICODE_NORM_QC_NO},
+	{0x1D772, UNICODE_NORM_QC_NO},
+	{0x1D773, UNICODE_NORM_QC_NO},
+	{0x1D774, UNICODE_NORM_QC_NO},
+	{0x1D775, UNICODE_NORM_QC_NO},
+	{0x1D776, UNICODE_NORM_QC_NO},
+	{0x1D777, UNICODE_NORM_QC_NO},
+	{0x1D778, UNICODE_NORM_QC_NO},
+	{0x1D779, UNICODE_NORM_QC_NO},
+	{0x1D77A, UNICODE_NORM_QC_NO},
+	{0x1D77B, UNICODE_NORM_QC_NO},
+	{0x1D77C, UNICODE_NORM_QC_NO},
+	{0x1D77D, UNICODE_NORM_QC_NO},
+	{0x1D77E, UNICODE_NORM_QC_NO},
+	{0x1D77F, UNICODE_NORM_QC_NO},
+	{0x1D780, UNICODE_NORM_QC_NO},
+	{0x1D781, UNICODE_NORM_QC_NO},
+	{0x1D782, UNICODE_NORM_QC_NO},
+	{0x1D783, UNICODE_NORM_QC_NO},
+	{0x1D784, UNICODE_NORM_QC_NO},
+	{0x1D785, UNICODE_NORM_QC_NO},
+	{0x1D786, UNICODE_NORM_QC_NO},
+	{0x1D787, UNICODE_NORM_QC_NO},
+	{0x1D788, UNICODE_NORM_QC_NO},
+	{0x1D789, UNICODE_NORM_QC_NO},
+	{0x1D78A, UNICODE_NORM_QC_NO},
+	{0x1D78B, UNICODE_NORM_QC_NO},
+	{0x1D78C, UNICODE_NORM_QC_NO},
+	{0x1D78D, UNICODE_NORM_QC_NO},
+	{0x1D78E, UNICODE_NORM_QC_NO},
+	{0x1D78F, UNICODE_NORM_QC_NO},
+	{0x1D790, UNICODE_NORM_QC_NO},
+	{0x1D791, UNICODE_NORM_QC_NO},
+	{0x1D792, UNICODE_NORM_QC_NO},
+	{0x1D793, UNICODE_NORM_QC_NO},
+	{0x1D794, UNICODE_NORM_QC_NO},
+	{0x1D795, UNICODE_NORM_QC_NO},
+	{0x1D796, UNICODE_NORM_QC_NO},
+	{0x1D797, UNICODE_NORM_QC_NO},
+	{0x1D798, UNICODE_NORM_QC_NO},
+	{0x1D799, UNICODE_NORM_QC_NO},
+	{0x1D79A, UNICODE_NORM_QC_NO},
+	{0x1D79B, UNICODE_NORM_QC_NO},
+	{0x1D79C, UNICODE_NORM_QC_NO},
+	{0x1D79D, UNICODE_NORM_QC_NO},
+	{0x1D79E, UNICODE_NORM_QC_NO},
+	{0x1D79F, UNICODE_NORM_QC_NO},
+	{0x1D7A0, UNICODE_NORM_QC_NO},
+	{0x1D7A1, UNICODE_NORM_QC_NO},
+	{0x1D7A2, UNICODE_NORM_QC_NO},
+	{0x1D7A3, UNICODE_NORM_QC_NO},
+	{0x1D7A4, UNICODE_NORM_QC_NO},
+	{0x1D7A5, UNICODE_NORM_QC_NO},
+	{0x1D7A6, UNICODE_NORM_QC_NO},
+	{0x1D7A7, UNICODE_NORM_QC_NO},
+	{0x1D7A8, UNICODE_NORM_QC_NO},
+	{0x1D7A9, UNICODE_NORM_QC_NO},
+	{0x1D7AA, UNICODE_NORM_QC_NO},
+	{0x1D7AB, UNICODE_NORM_QC_NO},
+	{0x1D7AC, UNICODE_NORM_QC_NO},
+	{0x1D7AD, UNICODE_NORM_QC_NO},
+	{0x1D7AE, UNICODE_NORM_QC_NO},
+	{0x1D7AF, UNICODE_NORM_QC_NO},
+	{0x1D7B0, UNICODE_NORM_QC_NO},
+	{0x1D7B1, UNICODE_NORM_QC_NO},
+	{0x1D7B2, UNICODE_NORM_QC_NO},
+	{0x1D7B3, UNICODE_NORM_QC_NO},
+	{0x1D7B4, UNICODE_NORM_QC_NO},
+	{0x1D7B5, UNICODE_NORM_QC_NO},
+	{0x1D7B6, UNICODE_NORM_QC_NO},
+	{0x1D7B7, UNICODE_NORM_QC_NO},
+	{0x1D7B8, UNICODE_NORM_QC_NO},
+	{0x1D7B9, UNICODE_NORM_QC_NO},
+	{0x1D7BA, UNICODE_NORM_QC_NO},
+	{0x1D7BB, UNICODE_NORM_QC_NO},
+	{0x1D7BC, UNICODE_NORM_QC_NO},
+	{0x1D7BD, UNICODE_NORM_QC_NO},
+	{0x1D7BE, UNICODE_NORM_QC_NO},
+	{0x1D7BF, UNICODE_NORM_QC_NO},
+	{0x1D7C0, UNICODE_NORM_QC_NO},
+	{0x1D7C1, UNICODE_NORM_QC_NO},
+	{0x1D7C2, UNICODE_NORM_QC_NO},
+	{0x1D7C3, UNICODE_NORM_QC_NO},
+	{0x1D7C4, UNICODE_NORM_QC_NO},
+	{0x1D7C5, UNICODE_NORM_QC_NO},
+	{0x1D7C6, UNICODE_NORM_QC_NO},
+	{0x1D7C7, UNICODE_NORM_QC_NO},
+	{0x1D7C8, UNICODE_NORM_QC_NO},
+	{0x1D7C9, UNICODE_NORM_QC_NO},
+	{0x1D7CA, UNICODE_NORM_QC_NO},
+	{0x1D7CB, UNICODE_NORM_QC_NO},
+	{0x1D7CE, UNICODE_NORM_QC_NO},
+	{0x1D7CF, UNICODE_NORM_QC_NO},
+	{0x1D7D0, UNICODE_NORM_QC_NO},
+	{0x1D7D1, UNICODE_NORM_QC_NO},
+	{0x1D7D2, UNICODE_NORM_QC_NO},
+	{0x1D7D3, UNICODE_NORM_QC_NO},
+	{0x1D7D4, UNICODE_NORM_QC_NO},
+	{0x1D7D5, UNICODE_NORM_QC_NO},
+	{0x1D7D6, UNICODE_NORM_QC_NO},
+	{0x1D7D7, UNICODE_NORM_QC_NO},
+	{0x1D7D8, UNICODE_NORM_QC_NO},
+	{0x1D7D9, UNICODE_NORM_QC_NO},
+	{0x1D7DA, UNICODE_NORM_QC_NO},
+	{0x1D7DB, UNICODE_NORM_QC_NO},
+	{0x1D7DC, UNICODE_NORM_QC_NO},
+	{0x1D7DD, UNICODE_NORM_QC_NO},
+	{0x1D7DE, UNICODE_NORM_QC_NO},
+	{0x1D7DF, UNICODE_NORM_QC_NO},
+	{0x1D7E0, UNICODE_NORM_QC_NO},
+	{0x1D7E1, UNICODE_NORM_QC_NO},
+	{0x1D7E2, UNICODE_NORM_QC_NO},
+	{0x1D7E3, UNICODE_NORM_QC_NO},
+	{0x1D7E4, UNICODE_NORM_QC_NO},
+	{0x1D7E5, UNICODE_NORM_QC_NO},
+	{0x1D7E6, UNICODE_NORM_QC_NO},
+	{0x1D7E7, UNICODE_NORM_QC_NO},
+	{0x1D7E8, UNICODE_NORM_QC_NO},
+	{0x1D7E9, UNICODE_NORM_QC_NO},
+	{0x1D7EA, UNICODE_NORM_QC_NO},
+	{0x1D7EB, UNICODE_NORM_QC_NO},
+	{0x1D7EC, UNICODE_NORM_QC_NO},
+	{0x1D7ED, UNICODE_NORM_QC_NO},
+	{0x1D7EE, UNICODE_NORM_QC_NO},
+	{0x1D7EF, UNICODE_NORM_QC_NO},
+	{0x1D7F0, UNICODE_NORM_QC_NO},
+	{0x1D7F1, UNICODE_NORM_QC_NO},
+	{0x1D7F2, UNICODE_NORM_QC_NO},
+	{0x1D7F3, UNICODE_NORM_QC_NO},
+	{0x1D7F4, UNICODE_NORM_QC_NO},
+	{0x1D7F5, UNICODE_NORM_QC_NO},
+	{0x1D7F6, UNICODE_NORM_QC_NO},
+	{0x1D7F7, UNICODE_NORM_QC_NO},
+	{0x1D7F8, UNICODE_NORM_QC_NO},
+	{0x1D7F9, UNICODE_NORM_QC_NO},
+	{0x1D7FA, UNICODE_NORM_QC_NO},
+	{0x1D7FB, UNICODE_NORM_QC_NO},
+	{0x1D7FC, UNICODE_NORM_QC_NO},
+	{0x1D7FD, UNICODE_NORM_QC_NO},
+	{0x1D7FE, UNICODE_NORM_QC_NO},
+	{0x1D7FF, UNICODE_NORM_QC_NO},
+	{0x1EE00, UNICODE_NORM_QC_NO},
+	{0x1EE01, UNICODE_NORM_QC_NO},
+	{0x1EE02, UNICODE_NORM_QC_NO},
+	{0x1EE03, UNICODE_NORM_QC_NO},
+	{0x1EE05, UNICODE_NORM_QC_NO},
+	{0x1EE06, UNICODE_NORM_QC_NO},
+	{0x1EE07, UNICODE_NORM_QC_NO},
+	{0x1EE08, UNICODE_NORM_QC_NO},
+	{0x1EE09, UNICODE_NORM_QC_NO},
+	{0x1EE0A, UNICODE_NORM_QC_NO},
+	{0x1EE0B, UNICODE_NORM_QC_NO},
+	{0x1EE0C, UNICODE_NORM_QC_NO},
+	{0x1EE0D, UNICODE_NORM_QC_NO},
+	{0x1EE0E, UNICODE_NORM_QC_NO},
+	{0x1EE0F, UNICODE_NORM_QC_NO},
+	{0x1EE10, UNICODE_NORM_QC_NO},
+	{0x1EE11, UNICODE_NORM_QC_NO},
+	{0x1EE12, UNICODE_NORM_QC_NO},
+	{0x1EE13, UNICODE_NORM_QC_NO},
+	{0x1EE14, UNICODE_NORM_QC_NO},
+	{0x1EE15, UNICODE_NORM_QC_NO},
+	{0x1EE16, UNICODE_NORM_QC_NO},
+	{0x1EE17, UNICODE_NORM_QC_NO},
+	{0x1EE18, UNICODE_NORM_QC_NO},
+	{0x1EE19, UNICODE_NORM_QC_NO},
+	{0x1EE1A, UNICODE_NORM_QC_NO},
+	{0x1EE1B, UNICODE_NORM_QC_NO},
+	{0x1EE1C, UNICODE_NORM_QC_NO},
+	{0x1EE1D, UNICODE_NORM_QC_NO},
+	{0x1EE1E, UNICODE_NORM_QC_NO},
+	{0x1EE1F, UNICODE_NORM_QC_NO},
+	{0x1EE21, UNICODE_NORM_QC_NO},
+	{0x1EE22, UNICODE_NORM_QC_NO},
+	{0x1EE24, UNICODE_NORM_QC_NO},
+	{0x1EE27, UNICODE_NORM_QC_NO},
+	{0x1EE29, UNICODE_NORM_QC_NO},
+	{0x1EE2A, UNICODE_NORM_QC_NO},
+	{0x1EE2B, UNICODE_NORM_QC_NO},
+	{0x1EE2C, UNICODE_NORM_QC_NO},
+	{0x1EE2D, UNICODE_NORM_QC_NO},
+	{0x1EE2E, UNICODE_NORM_QC_NO},
+	{0x1EE2F, UNICODE_NORM_QC_NO},
+	{0x1EE30, UNICODE_NORM_QC_NO},
+	{0x1EE31, UNICODE_NORM_QC_NO},
+	{0x1EE32, UNICODE_NORM_QC_NO},
+	{0x1EE34, UNICODE_NORM_QC_NO},
+	{0x1EE35, UNICODE_NORM_QC_NO},
+	{0x1EE36, UNICODE_NORM_QC_NO},
+	{0x1EE37, UNICODE_NORM_QC_NO},
+	{0x1EE39, UNICODE_NORM_QC_NO},
+	{0x1EE3B, UNICODE_NORM_QC_NO},
+	{0x1EE42, UNICODE_NORM_QC_NO},
+	{0x1EE47, UNICODE_NORM_QC_NO},
+	{0x1EE49, UNICODE_NORM_QC_NO},
+	{0x1EE4B, UNICODE_NORM_QC_NO},
+	{0x1EE4D, UNICODE_NORM_QC_NO},
+	{0x1EE4E, UNICODE_NORM_QC_NO},
+	{0x1EE4F, UNICODE_NORM_QC_NO},
+	{0x1EE51, UNICODE_NORM_QC_NO},
+	{0x1EE52, UNICODE_NORM_QC_NO},
+	{0x1EE54, UNICODE_NORM_QC_NO},
+	{0x1EE57, UNICODE_NORM_QC_NO},
+	{0x1EE59, UNICODE_NORM_QC_NO},
+	{0x1EE5B, UNICODE_NORM_QC_NO},
+	{0x1EE5D, UNICODE_NORM_QC_NO},
+	{0x1EE5F, UNICODE_NORM_QC_NO},
+	{0x1EE61, UNICODE_NORM_QC_NO},
+	{0x1EE62, UNICODE_NORM_QC_NO},
+	{0x1EE64, UNICODE_NORM_QC_NO},
+	{0x1EE67, UNICODE_NORM_QC_NO},
+	{0x1EE68, UNICODE_NORM_QC_NO},
+	{0x1EE69, UNICODE_NORM_QC_NO},
+	{0x1EE6A, UNICODE_NORM_QC_NO},
+	{0x1EE6C, UNICODE_NORM_QC_NO},
+	{0x1EE6D, UNICODE_NORM_QC_NO},
+	{0x1EE6E, UNICODE_NORM_QC_NO},
+	{0x1EE6F, UNICODE_NORM_QC_NO},
+	{0x1EE70, UNICODE_NORM_QC_NO},
+	{0x1EE71, UNICODE_NORM_QC_NO},
+	{0x1EE72, UNICODE_NORM_QC_NO},
+	{0x1EE74, UNICODE_NORM_QC_NO},
+	{0x1EE75, UNICODE_NORM_QC_NO},
+	{0x1EE76, UNICODE_NORM_QC_NO},
+	{0x1EE77, UNICODE_NORM_QC_NO},
+	{0x1EE79, UNICODE_NORM_QC_NO},
+	{0x1EE7A, UNICODE_NORM_QC_NO},
+	{0x1EE7B, UNICODE_NORM_QC_NO},
+	{0x1EE7C, UNICODE_NORM_QC_NO},
+	{0x1EE7E, UNICODE_NORM_QC_NO},
+	{0x1EE80, UNICODE_NORM_QC_NO},
+	{0x1EE81, UNICODE_NORM_QC_NO},
+	{0x1EE82, UNICODE_NORM_QC_NO},
+	{0x1EE83, UNICODE_NORM_QC_NO},
+	{0x1EE84, UNICODE_NORM_QC_NO},
+	{0x1EE85, UNICODE_NORM_QC_NO},
+	{0x1EE86, UNICODE_NORM_QC_NO},
+	{0x1EE87, UNICODE_NORM_QC_NO},
+	{0x1EE88, UNICODE_NORM_QC_NO},
+	{0x1EE89, UNICODE_NORM_QC_NO},
+	{0x1EE8B, UNICODE_NORM_QC_NO},
+	{0x1EE8C, UNICODE_NORM_QC_NO},
+	{0x1EE8D, UNICODE_NORM_QC_NO},
+	{0x1EE8E, UNICODE_NORM_QC_NO},
+	{0x1EE8F, UNICODE_NORM_QC_NO},
+	{0x1EE90, UNICODE_NORM_QC_NO},
+	{0x1EE91, UNICODE_NORM_QC_NO},
+	{0x1EE92, UNICODE_NORM_QC_NO},
+	{0x1EE93, UNICODE_NORM_QC_NO},
+	{0x1EE94, UNICODE_NORM_QC_NO},
+	{0x1EE95, UNICODE_NORM_QC_NO},
+	{0x1EE96, UNICODE_NORM_QC_NO},
+	{0x1EE97, UNICODE_NORM_QC_NO},
+	{0x1EE98, UNICODE_NORM_QC_NO},
+	{0x1EE99, UNICODE_NORM_QC_NO},
+	{0x1EE9A, UNICODE_NORM_QC_NO},
+	{0x1EE9B, UNICODE_NORM_QC_NO},
+	{0x1EEA1, UNICODE_NORM_QC_NO},
+	{0x1EEA2, UNICODE_NORM_QC_NO},
+	{0x1EEA3, UNICODE_NORM_QC_NO},
+	{0x1EEA5, UNICODE_NORM_QC_NO},
+	{0x1EEA6, UNICODE_NORM_QC_NO},
+	{0x1EEA7, UNICODE_NORM_QC_NO},
+	{0x1EEA8, UNICODE_NORM_QC_NO},
+	{0x1EEA9, UNICODE_NORM_QC_NO},
+	{0x1EEAB, UNICODE_NORM_QC_NO},
+	{0x1EEAC, UNICODE_NORM_QC_NO},
+	{0x1EEAD, UNICODE_NORM_QC_NO},
+	{0x1EEAE, UNICODE_NORM_QC_NO},
+	{0x1EEAF, UNICODE_NORM_QC_NO},
+	{0x1EEB0, UNICODE_NORM_QC_NO},
+	{0x1EEB1, UNICODE_NORM_QC_NO},
+	{0x1EEB2, UNICODE_NORM_QC_NO},
+	{0x1EEB3, UNICODE_NORM_QC_NO},
+	{0x1EEB4, UNICODE_NORM_QC_NO},
+	{0x1EEB5, UNICODE_NORM_QC_NO},
+	{0x1EEB6, UNICODE_NORM_QC_NO},
+	{0x1EEB7, UNICODE_NORM_QC_NO},
+	{0x1EEB8, UNICODE_NORM_QC_NO},
+	{0x1EEB9, UNICODE_NORM_QC_NO},
+	{0x1EEBA, UNICODE_NORM_QC_NO},
+	{0x1EEBB, UNICODE_NORM_QC_NO},
+	{0x1F100, UNICODE_NORM_QC_NO},
+	{0x1F101, UNICODE_NORM_QC_NO},
+	{0x1F102, UNICODE_NORM_QC_NO},
+	{0x1F103, UNICODE_NORM_QC_NO},
+	{0x1F104, UNICODE_NORM_QC_NO},
+	{0x1F105, UNICODE_NORM_QC_NO},
+	{0x1F106, UNICODE_NORM_QC_NO},
+	{0x1F107, UNICODE_NORM_QC_NO},
+	{0x1F108, UNICODE_NORM_QC_NO},
+	{0x1F109, UNICODE_NORM_QC_NO},
+	{0x1F10A, UNICODE_NORM_QC_NO},
+	{0x1F110, UNICODE_NORM_QC_NO},
+	{0x1F111, UNICODE_NORM_QC_NO},
+	{0x1F112, UNICODE_NORM_QC_NO},
+	{0x1F113, UNICODE_NORM_QC_NO},
+	{0x1F114, UNICODE_NORM_QC_NO},
+	{0x1F115, UNICODE_NORM_QC_NO},
+	{0x1F116, UNICODE_NORM_QC_NO},
+	{0x1F117, UNICODE_NORM_QC_NO},
+	{0x1F118, UNICODE_NORM_QC_NO},
+	{0x1F119, UNICODE_NORM_QC_NO},
+	{0x1F11A, UNICODE_NORM_QC_NO},
+	{0x1F11B, UNICODE_NORM_QC_NO},
+	{0x1F11C, UNICODE_NORM_QC_NO},
+	{0x1F11D, UNICODE_NORM_QC_NO},
+	{0x1F11E, UNICODE_NORM_QC_NO},
+	{0x1F11F, UNICODE_NORM_QC_NO},
+	{0x1F120, UNICODE_NORM_QC_NO},
+	{0x1F121, UNICODE_NORM_QC_NO},
+	{0x1F122, UNICODE_NORM_QC_NO},
+	{0x1F123, UNICODE_NORM_QC_NO},
+	{0x1F124, UNICODE_NORM_QC_NO},
+	{0x1F125, UNICODE_NORM_QC_NO},
+	{0x1F126, UNICODE_NORM_QC_NO},
+	{0x1F127, UNICODE_NORM_QC_NO},
+	{0x1F128, UNICODE_NORM_QC_NO},
+	{0x1F129, UNICODE_NORM_QC_NO},
+	{0x1F12A, UNICODE_NORM_QC_NO},
+	{0x1F12B, UNICODE_NORM_QC_NO},
+	{0x1F12C, UNICODE_NORM_QC_NO},
+	{0x1F12D, UNICODE_NORM_QC_NO},
+	{0x1F12E, UNICODE_NORM_QC_NO},
+	{0x1F130, UNICODE_NORM_QC_NO},
+	{0x1F131, UNICODE_NORM_QC_NO},
+	{0x1F132, UNICODE_NORM_QC_NO},
+	{0x1F133, UNICODE_NORM_QC_NO},
+	{0x1F134, UNICODE_NORM_QC_NO},
+	{0x1F135, UNICODE_NORM_QC_NO},
+	{0x1F136, UNICODE_NORM_QC_NO},
+	{0x1F137, UNICODE_NORM_QC_NO},
+	{0x1F138, UNICODE_NORM_QC_NO},
+	{0x1F139, UNICODE_NORM_QC_NO},
+	{0x1F13A, UNICODE_NORM_QC_NO},
+	{0x1F13B, UNICODE_NORM_QC_NO},
+	{0x1F13C, UNICODE_NORM_QC_NO},
+	{0x1F13D, UNICODE_NORM_QC_NO},
+	{0x1F13E, UNICODE_NORM_QC_NO},
+	{0x1F13F, UNICODE_NORM_QC_NO},
+	{0x1F140, UNICODE_NORM_QC_NO},
+	{0x1F141, UNICODE_NORM_QC_NO},
+	{0x1F142, UNICODE_NORM_QC_NO},
+	{0x1F143, UNICODE_NORM_QC_NO},
+	{0x1F144, UNICODE_NORM_QC_NO},
+	{0x1F145, UNICODE_NORM_QC_NO},
+	{0x1F146, UNICODE_NORM_QC_NO},
+	{0x1F147, UNICODE_NORM_QC_NO},
+	{0x1F148, UNICODE_NORM_QC_NO},
+	{0x1F149, UNICODE_NORM_QC_NO},
+	{0x1F14A, UNICODE_NORM_QC_NO},
+	{0x1F14B, UNICODE_NORM_QC_NO},
+	{0x1F14C, UNICODE_NORM_QC_NO},
+	{0x1F14D, UNICODE_NORM_QC_NO},
+	{0x1F14E, UNICODE_NORM_QC_NO},
+	{0x1F14F, UNICODE_NORM_QC_NO},
+	{0x1F16A, UNICODE_NORM_QC_NO},
+	{0x1F16B, UNICODE_NORM_QC_NO},
+	{0x1F16C, UNICODE_NORM_QC_NO},
+	{0x1F190, UNICODE_NORM_QC_NO},
+	{0x1F200, UNICODE_NORM_QC_NO},
+	{0x1F201, UNICODE_NORM_QC_NO},
+	{0x1F202, UNICODE_NORM_QC_NO},
+	{0x1F210, UNICODE_NORM_QC_NO},
+	{0x1F211, UNICODE_NORM_QC_NO},
+	{0x1F212, UNICODE_NORM_QC_NO},
+	{0x1F213, UNICODE_NORM_QC_NO},
+	{0x1F214, UNICODE_NORM_QC_NO},
+	{0x1F215, UNICODE_NORM_QC_NO},
+	{0x1F216, UNICODE_NORM_QC_NO},
+	{0x1F217, UNICODE_NORM_QC_NO},
+	{0x1F218, UNICODE_NORM_QC_NO},
+	{0x1F219, UNICODE_NORM_QC_NO},
+	{0x1F21A, UNICODE_NORM_QC_NO},
+	{0x1F21B, UNICODE_NORM_QC_NO},
+	{0x1F21C, UNICODE_NORM_QC_NO},
+	{0x1F21D, UNICODE_NORM_QC_NO},
+	{0x1F21E, UNICODE_NORM_QC_NO},
+	{0x1F21F, UNICODE_NORM_QC_NO},
+	{0x1F220, UNICODE_NORM_QC_NO},
+	{0x1F221, UNICODE_NORM_QC_NO},
+	{0x1F222, UNICODE_NORM_QC_NO},
+	{0x1F223, UNICODE_NORM_QC_NO},
+	{0x1F224, UNICODE_NORM_QC_NO},
+	{0x1F225, UNICODE_NORM_QC_NO},
+	{0x1F226, UNICODE_NORM_QC_NO},
+	{0x1F227, UNICODE_NORM_QC_NO},
+	{0x1F228, UNICODE_NORM_QC_NO},
+	{0x1F229, UNICODE_NORM_QC_NO},
+	{0x1F22A, UNICODE_NORM_QC_NO},
+	{0x1F22B, UNICODE_NORM_QC_NO},
+	{0x1F22C, UNICODE_NORM_QC_NO},
+	{0x1F22D, UNICODE_NORM_QC_NO},
+	{0x1F22E, UNICODE_NORM_QC_NO},
+	{0x1F22F, UNICODE_NORM_QC_NO},
+	{0x1F230, UNICODE_NORM_QC_NO},
+	{0x1F231, UNICODE_NORM_QC_NO},
+	{0x1F232, UNICODE_NORM_QC_NO},
+	{0x1F233, UNICODE_NORM_QC_NO},
+	{0x1F234, UNICODE_NORM_QC_NO},
+	{0x1F235, UNICODE_NORM_QC_NO},
+	{0x1F236, UNICODE_NORM_QC_NO},
+	{0x1F237, UNICODE_NORM_QC_NO},
+	{0x1F238, UNICODE_NORM_QC_NO},
+	{0x1F239, UNICODE_NORM_QC_NO},
+	{0x1F23A, UNICODE_NORM_QC_NO},
+	{0x1F23B, UNICODE_NORM_QC_NO},
+	{0x1F240, UNICODE_NORM_QC_NO},
+	{0x1F241, UNICODE_NORM_QC_NO},
+	{0x1F242, UNICODE_NORM_QC_NO},
+	{0x1F243, UNICODE_NORM_QC_NO},
+	{0x1F244, UNICODE_NORM_QC_NO},
+	{0x1F245, UNICODE_NORM_QC_NO},
+	{0x1F246, UNICODE_NORM_QC_NO},
+	{0x1F247, UNICODE_NORM_QC_NO},
+	{0x1F248, UNICODE_NORM_QC_NO},
+	{0x1F250, UNICODE_NORM_QC_NO},
+	{0x1F251, UNICODE_NORM_QC_NO},
+	{0x2F800, UNICODE_NORM_QC_NO},
+	{0x2F801, UNICODE_NORM_QC_NO},
+	{0x2F802, UNICODE_NORM_QC_NO},
+	{0x2F803, UNICODE_NORM_QC_NO},
+	{0x2F804, UNICODE_NORM_QC_NO},
+	{0x2F805, UNICODE_NORM_QC_NO},
+	{0x2F806, UNICODE_NORM_QC_NO},
+	{0x2F807, UNICODE_NORM_QC_NO},
+	{0x2F808, UNICODE_NORM_QC_NO},
+	{0x2F809, UNICODE_NORM_QC_NO},
+	{0x2F80A, UNICODE_NORM_QC_NO},
+	{0x2F80B, UNICODE_NORM_QC_NO},
+	{0x2F80C, UNICODE_NORM_QC_NO},
+	{0x2F80D, UNICODE_NORM_QC_NO},
+	{0x2F80E, UNICODE_NORM_QC_NO},
+	{0x2F80F, UNICODE_NORM_QC_NO},
+	{0x2F810, UNICODE_NORM_QC_NO},
+	{0x2F811, UNICODE_NORM_QC_NO},
+	{0x2F812, UNICODE_NORM_QC_NO},
+	{0x2F813, UNICODE_NORM_QC_NO},
+	{0x2F814, UNICODE_NORM_QC_NO},
+	{0x2F815, UNICODE_NORM_QC_NO},
+	{0x2F816, UNICODE_NORM_QC_NO},
+	{0x2F817, UNICODE_NORM_QC_NO},
+	{0x2F818, UNICODE_NORM_QC_NO},
+	{0x2F819, UNICODE_NORM_QC_NO},
+	{0x2F81A, UNICODE_NORM_QC_NO},
+	{0x2F81B, UNICODE_NORM_QC_NO},
+	{0x2F81C, UNICODE_NORM_QC_NO},
+	{0x2F81D, UNICODE_NORM_QC_NO},
+	{0x2F81E, UNICODE_NORM_QC_NO},
+	{0x2F81F, UNICODE_NORM_QC_NO},
+	{0x2F820, UNICODE_NORM_QC_NO},
+	{0x2F821, UNICODE_NORM_QC_NO},
+	{0x2F822, UNICODE_NORM_QC_NO},
+	{0x2F823, UNICODE_NORM_QC_NO},
+	{0x2F824, UNICODE_NORM_QC_NO},
+	{0x2F825, UNICODE_NORM_QC_NO},
+	{0x2F826, UNICODE_NORM_QC_NO},
+	{0x2F827, UNICODE_NORM_QC_NO},
+	{0x2F828, UNICODE_NORM_QC_NO},
+	{0x2F829, UNICODE_NORM_QC_NO},
+	{0x2F82A, UNICODE_NORM_QC_NO},
+	{0x2F82B, UNICODE_NORM_QC_NO},
+	{0x2F82C, UNICODE_NORM_QC_NO},
+	{0x2F82D, UNICODE_NORM_QC_NO},
+	{0x2F82E, UNICODE_NORM_QC_NO},
+	{0x2F82F, UNICODE_NORM_QC_NO},
+	{0x2F830, UNICODE_NORM_QC_NO},
+	{0x2F831, UNICODE_NORM_QC_NO},
+	{0x2F832, UNICODE_NORM_QC_NO},
+	{0x2F833, UNICODE_NORM_QC_NO},
+	{0x2F834, UNICODE_NORM_QC_NO},
+	{0x2F835, UNICODE_NORM_QC_NO},
+	{0x2F836, UNICODE_NORM_QC_NO},
+	{0x2F837, UNICODE_NORM_QC_NO},
+	{0x2F838, UNICODE_NORM_QC_NO},
+	{0x2F839, UNICODE_NORM_QC_NO},
+	{0x2F83A, UNICODE_NORM_QC_NO},
+	{0x2F83B, UNICODE_NORM_QC_NO},
+	{0x2F83C, UNICODE_NORM_QC_NO},
+	{0x2F83D, UNICODE_NORM_QC_NO},
+	{0x2F83E, UNICODE_NORM_QC_NO},
+	{0x2F83F, UNICODE_NORM_QC_NO},
+	{0x2F840, UNICODE_NORM_QC_NO},
+	{0x2F841, UNICODE_NORM_QC_NO},
+	{0x2F842, UNICODE_NORM_QC_NO},
+	{0x2F843, UNICODE_NORM_QC_NO},
+	{0x2F844, UNICODE_NORM_QC_NO},
+	{0x2F845, UNICODE_NORM_QC_NO},
+	{0x2F846, UNICODE_NORM_QC_NO},
+	{0x2F847, UNICODE_NORM_QC_NO},
+	{0x2F848, UNICODE_NORM_QC_NO},
+	{0x2F849, UNICODE_NORM_QC_NO},
+	{0x2F84A, UNICODE_NORM_QC_NO},
+	{0x2F84B, UNICODE_NORM_QC_NO},
+	{0x2F84C, UNICODE_NORM_QC_NO},
+	{0x2F84D, UNICODE_NORM_QC_NO},
+	{0x2F84E, UNICODE_NORM_QC_NO},
+	{0x2F84F, UNICODE_NORM_QC_NO},
+	{0x2F850, UNICODE_NORM_QC_NO},
+	{0x2F851, UNICODE_NORM_QC_NO},
+	{0x2F852, UNICODE_NORM_QC_NO},
+	{0x2F853, UNICODE_NORM_QC_NO},
+	{0x2F854, UNICODE_NORM_QC_NO},
+	{0x2F855, UNICODE_NORM_QC_NO},
+	{0x2F856, UNICODE_NORM_QC_NO},
+	{0x2F857, UNICODE_NORM_QC_NO},
+	{0x2F858, UNICODE_NORM_QC_NO},
+	{0x2F859, UNICODE_NORM_QC_NO},
+	{0x2F85A, UNICODE_NORM_QC_NO},
+	{0x2F85B, UNICODE_NORM_QC_NO},
+	{0x2F85C, UNICODE_NORM_QC_NO},
+	{0x2F85D, UNICODE_NORM_QC_NO},
+	{0x2F85E, UNICODE_NORM_QC_NO},
+	{0x2F85F, UNICODE_NORM_QC_NO},
+	{0x2F860, UNICODE_NORM_QC_NO},
+	{0x2F861, UNICODE_NORM_QC_NO},
+	{0x2F862, UNICODE_NORM_QC_NO},
+	{0x2F863, UNICODE_NORM_QC_NO},
+	{0x2F864, UNICODE_NORM_QC_NO},
+	{0x2F865, UNICODE_NORM_QC_NO},
+	{0x2F866, UNICODE_NORM_QC_NO},
+	{0x2F867, UNICODE_NORM_QC_NO},
+	{0x2F868, UNICODE_NORM_QC_NO},
+	{0x2F869, UNICODE_NORM_QC_NO},
+	{0x2F86A, UNICODE_NORM_QC_NO},
+	{0x2F86B, UNICODE_NORM_QC_NO},
+	{0x2F86C, UNICODE_NORM_QC_NO},
+	{0x2F86D, UNICODE_NORM_QC_NO},
+	{0x2F86E, UNICODE_NORM_QC_NO},
+	{0x2F86F, UNICODE_NORM_QC_NO},
+	{0x2F870, UNICODE_NORM_QC_NO},
+	{0x2F871, UNICODE_NORM_QC_NO},
+	{0x2F872, UNICODE_NORM_QC_NO},
+	{0x2F873, UNICODE_NORM_QC_NO},
+	{0x2F874, UNICODE_NORM_QC_NO},
+	{0x2F875, UNICODE_NORM_QC_NO},
+	{0x2F876, UNICODE_NORM_QC_NO},
+	{0x2F877, UNICODE_NORM_QC_NO},
+	{0x2F878, UNICODE_NORM_QC_NO},
+	{0x2F879, UNICODE_NORM_QC_NO},
+	{0x2F87A, UNICODE_NORM_QC_NO},
+	{0x2F87B, UNICODE_NORM_QC_NO},
+	{0x2F87C, UNICODE_NORM_QC_NO},
+	{0x2F87D, UNICODE_NORM_QC_NO},
+	{0x2F87E, UNICODE_NORM_QC_NO},
+	{0x2F87F, UNICODE_NORM_QC_NO},
+	{0x2F880, UNICODE_NORM_QC_NO},
+	{0x2F881, UNICODE_NORM_QC_NO},
+	{0x2F882, UNICODE_NORM_QC_NO},
+	{0x2F883, UNICODE_NORM_QC_NO},
+	{0x2F884, UNICODE_NORM_QC_NO},
+	{0x2F885, UNICODE_NORM_QC_NO},
+	{0x2F886, UNICODE_NORM_QC_NO},
+	{0x2F887, UNICODE_NORM_QC_NO},
+	{0x2F888, UNICODE_NORM_QC_NO},
+	{0x2F889, UNICODE_NORM_QC_NO},
+	{0x2F88A, UNICODE_NORM_QC_NO},
+	{0x2F88B, UNICODE_NORM_QC_NO},
+	{0x2F88C, UNICODE_NORM_QC_NO},
+	{0x2F88D, UNICODE_NORM_QC_NO},
+	{0x2F88E, UNICODE_NORM_QC_NO},
+	{0x2F88F, UNICODE_NORM_QC_NO},
+	{0x2F890, UNICODE_NORM_QC_NO},
+	{0x2F891, UNICODE_NORM_QC_NO},
+	{0x2F892, UNICODE_NORM_QC_NO},
+	{0x2F893, UNICODE_NORM_QC_NO},
+	{0x2F894, UNICODE_NORM_QC_NO},
+	{0x2F895, UNICODE_NORM_QC_NO},
+	{0x2F896, UNICODE_NORM_QC_NO},
+	{0x2F897, UNICODE_NORM_QC_NO},
+	{0x2F898, UNICODE_NORM_QC_NO},
+	{0x2F899, UNICODE_NORM_QC_NO},
+	{0x2F89A, UNICODE_NORM_QC_NO},
+	{0x2F89B, UNICODE_NORM_QC_NO},
+	{0x2F89C, UNICODE_NORM_QC_NO},
+	{0x2F89D, UNICODE_NORM_QC_NO},
+	{0x2F89E, UNICODE_NORM_QC_NO},
+	{0x2F89F, UNICODE_NORM_QC_NO},
+	{0x2F8A0, UNICODE_NORM_QC_NO},
+	{0x2F8A1, UNICODE_NORM_QC_NO},
+	{0x2F8A2, UNICODE_NORM_QC_NO},
+	{0x2F8A3, UNICODE_NORM_QC_NO},
+	{0x2F8A4, UNICODE_NORM_QC_NO},
+	{0x2F8A5, UNICODE_NORM_QC_NO},
+	{0x2F8A6, UNICODE_NORM_QC_NO},
+	{0x2F8A7, UNICODE_NORM_QC_NO},
+	{0x2F8A8, UNICODE_NORM_QC_NO},
+	{0x2F8A9, UNICODE_NORM_QC_NO},
+	{0x2F8AA, UNICODE_NORM_QC_NO},
+	{0x2F8AB, UNICODE_NORM_QC_NO},
+	{0x2F8AC, UNICODE_NORM_QC_NO},
+	{0x2F8AD, UNICODE_NORM_QC_NO},
+	{0x2F8AE, UNICODE_NORM_QC_NO},
+	{0x2F8AF, UNICODE_NORM_QC_NO},
+	{0x2F8B0, UNICODE_NORM_QC_NO},
+	{0x2F8B1, UNICODE_NORM_QC_NO},
+	{0x2F8B2, UNICODE_NORM_QC_NO},
+	{0x2F8B3, UNICODE_NORM_QC_NO},
+	{0x2F8B4, UNICODE_NORM_QC_NO},
+	{0x2F8B5, UNICODE_NORM_QC_NO},
+	{0x2F8B6, UNICODE_NORM_QC_NO},
+	{0x2F8B7, UNICODE_NORM_QC_NO},
+	{0x2F8B8, UNICODE_NORM_QC_NO},
+	{0x2F8B9, UNICODE_NORM_QC_NO},
+	{0x2F8BA, UNICODE_NORM_QC_NO},
+	{0x2F8BB, UNICODE_NORM_QC_NO},
+	{0x2F8BC, UNICODE_NORM_QC_NO},
+	{0x2F8BD, UNICODE_NORM_QC_NO},
+	{0x2F8BE, UNICODE_NORM_QC_NO},
+	{0x2F8BF, UNICODE_NORM_QC_NO},
+	{0x2F8C0, UNICODE_NORM_QC_NO},
+	{0x2F8C1, UNICODE_NORM_QC_NO},
+	{0x2F8C2, UNICODE_NORM_QC_NO},
+	{0x2F8C3, UNICODE_NORM_QC_NO},
+	{0x2F8C4, UNICODE_NORM_QC_NO},
+	{0x2F8C5, UNICODE_NORM_QC_NO},
+	{0x2F8C6, UNICODE_NORM_QC_NO},
+	{0x2F8C7, UNICODE_NORM_QC_NO},
+	{0x2F8C8, UNICODE_NORM_QC_NO},
+	{0x2F8C9, UNICODE_NORM_QC_NO},
+	{0x2F8CA, UNICODE_NORM_QC_NO},
+	{0x2F8CB, UNICODE_NORM_QC_NO},
+	{0x2F8CC, UNICODE_NORM_QC_NO},
+	{0x2F8CD, UNICODE_NORM_QC_NO},
+	{0x2F8CE, UNICODE_NORM_QC_NO},
+	{0x2F8CF, UNICODE_NORM_QC_NO},
+	{0x2F8D0, UNICODE_NORM_QC_NO},
+	{0x2F8D1, UNICODE_NORM_QC_NO},
+	{0x2F8D2, UNICODE_NORM_QC_NO},
+	{0x2F8D3, UNICODE_NORM_QC_NO},
+	{0x2F8D4, UNICODE_NORM_QC_NO},
+	{0x2F8D5, UNICODE_NORM_QC_NO},
+	{0x2F8D6, UNICODE_NORM_QC_NO},
+	{0x2F8D7, UNICODE_NORM_QC_NO},
+	{0x2F8D8, UNICODE_NORM_QC_NO},
+	{0x2F8D9, UNICODE_NORM_QC_NO},
+	{0x2F8DA, UNICODE_NORM_QC_NO},
+	{0x2F8DB, UNICODE_NORM_QC_NO},
+	{0x2F8DC, UNICODE_NORM_QC_NO},
+	{0x2F8DD, UNICODE_NORM_QC_NO},
+	{0x2F8DE, UNICODE_NORM_QC_NO},
+	{0x2F8DF, UNICODE_NORM_QC_NO},
+	{0x2F8E0, UNICODE_NORM_QC_NO},
+	{0x2F8E1, UNICODE_NORM_QC_NO},
+	{0x2F8E2, UNICODE_NORM_QC_NO},
+	{0x2F8E3, UNICODE_NORM_QC_NO},
+	{0x2F8E4, UNICODE_NORM_QC_NO},
+	{0x2F8E5, UNICODE_NORM_QC_NO},
+	{0x2F8E6, UNICODE_NORM_QC_NO},
+	{0x2F8E7, UNICODE_NORM_QC_NO},
+	{0x2F8E8, UNICODE_NORM_QC_NO},
+	{0x2F8E9, UNICODE_NORM_QC_NO},
+	{0x2F8EA, UNICODE_NORM_QC_NO},
+	{0x2F8EB, UNICODE_NORM_QC_NO},
+	{0x2F8EC, UNICODE_NORM_QC_NO},
+	{0x2F8ED, UNICODE_NORM_QC_NO},
+	{0x2F8EE, UNICODE_NORM_QC_NO},
+	{0x2F8EF, UNICODE_NORM_QC_NO},
+	{0x2F8F0, UNICODE_NORM_QC_NO},
+	{0x2F8F1, UNICODE_NORM_QC_NO},
+	{0x2F8F2, UNICODE_NORM_QC_NO},
+	{0x2F8F3, UNICODE_NORM_QC_NO},
+	{0x2F8F4, UNICODE_NORM_QC_NO},
+	{0x2F8F5, UNICODE_NORM_QC_NO},
+	{0x2F8F6, UNICODE_NORM_QC_NO},
+	{0x2F8F7, UNICODE_NORM_QC_NO},
+	{0x2F8F8, UNICODE_NORM_QC_NO},
+	{0x2F8F9, UNICODE_NORM_QC_NO},
+	{0x2F8FA, UNICODE_NORM_QC_NO},
+	{0x2F8FB, UNICODE_NORM_QC_NO},
+	{0x2F8FC, UNICODE_NORM_QC_NO},
+	{0x2F8FD, UNICODE_NORM_QC_NO},
+	{0x2F8FE, UNICODE_NORM_QC_NO},
+	{0x2F8FF, UNICODE_NORM_QC_NO},
+	{0x2F900, UNICODE_NORM_QC_NO},
+	{0x2F901, UNICODE_NORM_QC_NO},
+	{0x2F902, UNICODE_NORM_QC_NO},
+	{0x2F903, UNICODE_NORM_QC_NO},
+	{0x2F904, UNICODE_NORM_QC_NO},
+	{0x2F905, UNICODE_NORM_QC_NO},
+	{0x2F906, UNICODE_NORM_QC_NO},
+	{0x2F907, UNICODE_NORM_QC_NO},
+	{0x2F908, UNICODE_NORM_QC_NO},
+	{0x2F909, UNICODE_NORM_QC_NO},
+	{0x2F90A, UNICODE_NORM_QC_NO},
+	{0x2F90B, UNICODE_NORM_QC_NO},
+	{0x2F90C, UNICODE_NORM_QC_NO},
+	{0x2F90D, UNICODE_NORM_QC_NO},
+	{0x2F90E, UNICODE_NORM_QC_NO},
+	{0x2F90F, UNICODE_NORM_QC_NO},
+	{0x2F910, UNICODE_NORM_QC_NO},
+	{0x2F911, UNICODE_NORM_QC_NO},
+	{0x2F912, UNICODE_NORM_QC_NO},
+	{0x2F913, UNICODE_NORM_QC_NO},
+	{0x2F914, UNICODE_NORM_QC_NO},
+	{0x2F915, UNICODE_NORM_QC_NO},
+	{0x2F916, UNICODE_NORM_QC_NO},
+	{0x2F917, UNICODE_NORM_QC_NO},
+	{0x2F918, UNICODE_NORM_QC_NO},
+	{0x2F919, UNICODE_NORM_QC_NO},
+	{0x2F91A, UNICODE_NORM_QC_NO},
+	{0x2F91B, UNICODE_NORM_QC_NO},
+	{0x2F91C, UNICODE_NORM_QC_NO},
+	{0x2F91D, UNICODE_NORM_QC_NO},
+	{0x2F91E, UNICODE_NORM_QC_NO},
+	{0x2F91F, UNICODE_NORM_QC_NO},
+	{0x2F920, UNICODE_NORM_QC_NO},
+	{0x2F921, UNICODE_NORM_QC_NO},
+	{0x2F922, UNICODE_NORM_QC_NO},
+	{0x2F923, UNICODE_NORM_QC_NO},
+	{0x2F924, UNICODE_NORM_QC_NO},
+	{0x2F925, UNICODE_NORM_QC_NO},
+	{0x2F926, UNICODE_NORM_QC_NO},
+	{0x2F927, UNICODE_NORM_QC_NO},
+	{0x2F928, UNICODE_NORM_QC_NO},
+	{0x2F929, UNICODE_NORM_QC_NO},
+	{0x2F92A, UNICODE_NORM_QC_NO},
+	{0x2F92B, UNICODE_NORM_QC_NO},
+	{0x2F92C, UNICODE_NORM_QC_NO},
+	{0x2F92D, UNICODE_NORM_QC_NO},
+	{0x2F92E, UNICODE_NORM_QC_NO},
+	{0x2F92F, UNICODE_NORM_QC_NO},
+	{0x2F930, UNICODE_NORM_QC_NO},
+	{0x2F931, UNICODE_NORM_QC_NO},
+	{0x2F932, UNICODE_NORM_QC_NO},
+	{0x2F933, UNICODE_NORM_QC_NO},
+	{0x2F934, UNICODE_NORM_QC_NO},
+	{0x2F935, UNICODE_NORM_QC_NO},
+	{0x2F936, UNICODE_NORM_QC_NO},
+	{0x2F937, UNICODE_NORM_QC_NO},
+	{0x2F938, UNICODE_NORM_QC_NO},
+	{0x2F939, UNICODE_NORM_QC_NO},
+	{0x2F93A, UNICODE_NORM_QC_NO},
+	{0x2F93B, UNICODE_NORM_QC_NO},
+	{0x2F93C, UNICODE_NORM_QC_NO},
+	{0x2F93D, UNICODE_NORM_QC_NO},
+	{0x2F93E, UNICODE_NORM_QC_NO},
+	{0x2F93F, UNICODE_NORM_QC_NO},
+	{0x2F940, UNICODE_NORM_QC_NO},
+	{0x2F941, UNICODE_NORM_QC_NO},
+	{0x2F942, UNICODE_NORM_QC_NO},
+	{0x2F943, UNICODE_NORM_QC_NO},
+	{0x2F944, UNICODE_NORM_QC_NO},
+	{0x2F945, UNICODE_NORM_QC_NO},
+	{0x2F946, UNICODE_NORM_QC_NO},
+	{0x2F947, UNICODE_NORM_QC_NO},
+	{0x2F948, UNICODE_NORM_QC_NO},
+	{0x2F949, UNICODE_NORM_QC_NO},
+	{0x2F94A, UNICODE_NORM_QC_NO},
+	{0x2F94B, UNICODE_NORM_QC_NO},
+	{0x2F94C, UNICODE_NORM_QC_NO},
+	{0x2F94D, UNICODE_NORM_QC_NO},
+	{0x2F94E, UNICODE_NORM_QC_NO},
+	{0x2F94F, UNICODE_NORM_QC_NO},
+	{0x2F950, UNICODE_NORM_QC_NO},
+	{0x2F951, UNICODE_NORM_QC_NO},
+	{0x2F952, UNICODE_NORM_QC_NO},
+	{0x2F953, UNICODE_NORM_QC_NO},
+	{0x2F954, UNICODE_NORM_QC_NO},
+	{0x2F955, UNICODE_NORM_QC_NO},
+	{0x2F956, UNICODE_NORM_QC_NO},
+	{0x2F957, UNICODE_NORM_QC_NO},
+	{0x2F958, UNICODE_NORM_QC_NO},
+	{0x2F959, UNICODE_NORM_QC_NO},
+	{0x2F95A, UNICODE_NORM_QC_NO},
+	{0x2F95B, UNICODE_NORM_QC_NO},
+	{0x2F95C, UNICODE_NORM_QC_NO},
+	{0x2F95D, UNICODE_NORM_QC_NO},
+	{0x2F95E, UNICODE_NORM_QC_NO},
+	{0x2F95F, UNICODE_NORM_QC_NO},
+	{0x2F960, UNICODE_NORM_QC_NO},
+	{0x2F961, UNICODE_NORM_QC_NO},
+	{0x2F962, UNICODE_NORM_QC_NO},
+	{0x2F963, UNICODE_NORM_QC_NO},
+	{0x2F964, UNICODE_NORM_QC_NO},
+	{0x2F965, UNICODE_NORM_QC_NO},
+	{0x2F966, UNICODE_NORM_QC_NO},
+	{0x2F967, UNICODE_NORM_QC_NO},
+	{0x2F968, UNICODE_NORM_QC_NO},
+	{0x2F969, UNICODE_NORM_QC_NO},
+	{0x2F96A, UNICODE_NORM_QC_NO},
+	{0x2F96B, UNICODE_NORM_QC_NO},
+	{0x2F96C, UNICODE_NORM_QC_NO},
+	{0x2F96D, UNICODE_NORM_QC_NO},
+	{0x2F96E, UNICODE_NORM_QC_NO},
+	{0x2F96F, UNICODE_NORM_QC_NO},
+	{0x2F970, UNICODE_NORM_QC_NO},
+	{0x2F971, UNICODE_NORM_QC_NO},
+	{0x2F972, UNICODE_NORM_QC_NO},
+	{0x2F973, UNICODE_NORM_QC_NO},
+	{0x2F974, UNICODE_NORM_QC_NO},
+	{0x2F975, UNICODE_NORM_QC_NO},
+	{0x2F976, UNICODE_NORM_QC_NO},
+	{0x2F977, UNICODE_NORM_QC_NO},
+	{0x2F978, UNICODE_NORM_QC_NO},
+	{0x2F979, UNICODE_NORM_QC_NO},
+	{0x2F97A, UNICODE_NORM_QC_NO},
+	{0x2F97B, UNICODE_NORM_QC_NO},
+	{0x2F97C, UNICODE_NORM_QC_NO},
+	{0x2F97D, UNICODE_NORM_QC_NO},
+	{0x2F97E, UNICODE_NORM_QC_NO},
+	{0x2F97F, UNICODE_NORM_QC_NO},
+	{0x2F980, UNICODE_NORM_QC_NO},
+	{0x2F981, UNICODE_NORM_QC_NO},
+	{0x2F982, UNICODE_NORM_QC_NO},
+	{0x2F983, UNICODE_NORM_QC_NO},
+	{0x2F984, UNICODE_NORM_QC_NO},
+	{0x2F985, UNICODE_NORM_QC_NO},
+	{0x2F986, UNICODE_NORM_QC_NO},
+	{0x2F987, UNICODE_NORM_QC_NO},
+	{0x2F988, UNICODE_NORM_QC_NO},
+	{0x2F989, UNICODE_NORM_QC_NO},
+	{0x2F98A, UNICODE_NORM_QC_NO},
+	{0x2F98B, UNICODE_NORM_QC_NO},
+	{0x2F98C, UNICODE_NORM_QC_NO},
+	{0x2F98D, UNICODE_NORM_QC_NO},
+	{0x2F98E, UNICODE_NORM_QC_NO},
+	{0x2F98F, UNICODE_NORM_QC_NO},
+	{0x2F990, UNICODE_NORM_QC_NO},
+	{0x2F991, UNICODE_NORM_QC_NO},
+	{0x2F992, UNICODE_NORM_QC_NO},
+	{0x2F993, UNICODE_NORM_QC_NO},
+	{0x2F994, UNICODE_NORM_QC_NO},
+	{0x2F995, UNICODE_NORM_QC_NO},
+	{0x2F996, UNICODE_NORM_QC_NO},
+	{0x2F997, UNICODE_NORM_QC_NO},
+	{0x2F998, UNICODE_NORM_QC_NO},
+	{0x2F999, UNICODE_NORM_QC_NO},
+	{0x2F99A, UNICODE_NORM_QC_NO},
+	{0x2F99B, UNICODE_NORM_QC_NO},
+	{0x2F99C, UNICODE_NORM_QC_NO},
+	{0x2F99D, UNICODE_NORM_QC_NO},
+	{0x2F99E, UNICODE_NORM_QC_NO},
+	{0x2F99F, UNICODE_NORM_QC_NO},
+	{0x2F9A0, UNICODE_NORM_QC_NO},
+	{0x2F9A1, UNICODE_NORM_QC_NO},
+	{0x2F9A2, UNICODE_NORM_QC_NO},
+	{0x2F9A3, UNICODE_NORM_QC_NO},
+	{0x2F9A4, UNICODE_NORM_QC_NO},
+	{0x2F9A5, UNICODE_NORM_QC_NO},
+	{0x2F9A6, UNICODE_NORM_QC_NO},
+	{0x2F9A7, UNICODE_NORM_QC_NO},
+	{0x2F9A8, UNICODE_NORM_QC_NO},
+	{0x2F9A9, UNICODE_NORM_QC_NO},
+	{0x2F9AA, UNICODE_NORM_QC_NO},
+	{0x2F9AB, UNICODE_NORM_QC_NO},
+	{0x2F9AC, UNICODE_NORM_QC_NO},
+	{0x2F9AD, UNICODE_NORM_QC_NO},
+	{0x2F9AE, UNICODE_NORM_QC_NO},
+	{0x2F9AF, UNICODE_NORM_QC_NO},
+	{0x2F9B0, UNICODE_NORM_QC_NO},
+	{0x2F9B1, UNICODE_NORM_QC_NO},
+	{0x2F9B2, UNICODE_NORM_QC_NO},
+	{0x2F9B3, UNICODE_NORM_QC_NO},
+	{0x2F9B4, UNICODE_NORM_QC_NO},
+	{0x2F9B5, UNICODE_NORM_QC_NO},
+	{0x2F9B6, UNICODE_NORM_QC_NO},
+	{0x2F9B7, UNICODE_NORM_QC_NO},
+	{0x2F9B8, UNICODE_NORM_QC_NO},
+	{0x2F9B9, UNICODE_NORM_QC_NO},
+	{0x2F9BA, UNICODE_NORM_QC_NO},
+	{0x2F9BB, UNICODE_NORM_QC_NO},
+	{0x2F9BC, UNICODE_NORM_QC_NO},
+	{0x2F9BD, UNICODE_NORM_QC_NO},
+	{0x2F9BE, UNICODE_NORM_QC_NO},
+	{0x2F9BF, UNICODE_NORM_QC_NO},
+	{0x2F9C0, UNICODE_NORM_QC_NO},
+	{0x2F9C1, UNICODE_NORM_QC_NO},
+	{0x2F9C2, UNICODE_NORM_QC_NO},
+	{0x2F9C3, UNICODE_NORM_QC_NO},
+	{0x2F9C4, UNICODE_NORM_QC_NO},
+	{0x2F9C5, UNICODE_NORM_QC_NO},
+	{0x2F9C6, UNICODE_NORM_QC_NO},
+	{0x2F9C7, UNICODE_NORM_QC_NO},
+	{0x2F9C8, UNICODE_NORM_QC_NO},
+	{0x2F9C9, UNICODE_NORM_QC_NO},
+	{0x2F9CA, UNICODE_NORM_QC_NO},
+	{0x2F9CB, UNICODE_NORM_QC_NO},
+	{0x2F9CC, UNICODE_NORM_QC_NO},
+	{0x2F9CD, UNICODE_NORM_QC_NO},
+	{0x2F9CE, UNICODE_NORM_QC_NO},
+	{0x2F9CF, UNICODE_NORM_QC_NO},
+	{0x2F9D0, UNICODE_NORM_QC_NO},
+	{0x2F9D1, UNICODE_NORM_QC_NO},
+	{0x2F9D2, UNICODE_NORM_QC_NO},
+	{0x2F9D3, UNICODE_NORM_QC_NO},
+	{0x2F9D4, UNICODE_NORM_QC_NO},
+	{0x2F9D5, UNICODE_NORM_QC_NO},
+	{0x2F9D6, UNICODE_NORM_QC_NO},
+	{0x2F9D7, UNICODE_NORM_QC_NO},
+	{0x2F9D8, UNICODE_NORM_QC_NO},
+	{0x2F9D9, UNICODE_NORM_QC_NO},
+	{0x2F9DA, UNICODE_NORM_QC_NO},
+	{0x2F9DB, UNICODE_NORM_QC_NO},
+	{0x2F9DC, UNICODE_NORM_QC_NO},
+	{0x2F9DD, UNICODE_NORM_QC_NO},
+	{0x2F9DE, UNICODE_NORM_QC_NO},
+	{0x2F9DF, UNICODE_NORM_QC_NO},
+	{0x2F9E0, UNICODE_NORM_QC_NO},
+	{0x2F9E1, UNICODE_NORM_QC_NO},
+	{0x2F9E2, UNICODE_NORM_QC_NO},
+	{0x2F9E3, UNICODE_NORM_QC_NO},
+	{0x2F9E4, UNICODE_NORM_QC_NO},
+	{0x2F9E5, UNICODE_NORM_QC_NO},
+	{0x2F9E6, UNICODE_NORM_QC_NO},
+	{0x2F9E7, UNICODE_NORM_QC_NO},
+	{0x2F9E8, UNICODE_NORM_QC_NO},
+	{0x2F9E9, UNICODE_NORM_QC_NO},
+	{0x2F9EA, UNICODE_NORM_QC_NO},
+	{0x2F9EB, UNICODE_NORM_QC_NO},
+	{0x2F9EC, UNICODE_NORM_QC_NO},
+	{0x2F9ED, UNICODE_NORM_QC_NO},
+	{0x2F9EE, UNICODE_NORM_QC_NO},
+	{0x2F9EF, UNICODE_NORM_QC_NO},
+	{0x2F9F0, UNICODE_NORM_QC_NO},
+	{0x2F9F1, UNICODE_NORM_QC_NO},
+	{0x2F9F2, UNICODE_NORM_QC_NO},
+	{0x2F9F3, UNICODE_NORM_QC_NO},
+	{0x2F9F4, UNICODE_NORM_QC_NO},
+	{0x2F9F5, UNICODE_NORM_QC_NO},
+	{0x2F9F6, UNICODE_NORM_QC_NO},
+	{0x2F9F7, UNICODE_NORM_QC_NO},
+	{0x2F9F8, UNICODE_NORM_QC_NO},
+	{0x2F9F9, UNICODE_NORM_QC_NO},
+	{0x2F9FA, UNICODE_NORM_QC_NO},
+	{0x2F9FB, UNICODE_NORM_QC_NO},
+	{0x2F9FC, UNICODE_NORM_QC_NO},
+	{0x2F9FD, UNICODE_NORM_QC_NO},
+	{0x2F9FE, UNICODE_NORM_QC_NO},
+	{0x2F9FF, UNICODE_NORM_QC_NO},
+	{0x2FA00, UNICODE_NORM_QC_NO},
+	{0x2FA01, UNICODE_NORM_QC_NO},
+	{0x2FA02, UNICODE_NORM_QC_NO},
+	{0x2FA03, UNICODE_NORM_QC_NO},
+	{0x2FA04, UNICODE_NORM_QC_NO},
+	{0x2FA05, UNICODE_NORM_QC_NO},
+	{0x2FA06, UNICODE_NORM_QC_NO},
+	{0x2FA07, UNICODE_NORM_QC_NO},
+	{0x2FA08, UNICODE_NORM_QC_NO},
+	{0x2FA09, UNICODE_NORM_QC_NO},
+	{0x2FA0A, UNICODE_NORM_QC_NO},
+	{0x2FA0B, UNICODE_NORM_QC_NO},
+	{0x2FA0C, UNICODE_NORM_QC_NO},
+	{0x2FA0D, UNICODE_NORM_QC_NO},
+	{0x2FA0E, UNICODE_NORM_QC_NO},
+	{0x2FA0F, UNICODE_NORM_QC_NO},
+	{0x2FA10, UNICODE_NORM_QC_NO},
+	{0x2FA11, UNICODE_NORM_QC_NO},
+	{0x2FA12, UNICODE_NORM_QC_NO},
+	{0x2FA13, UNICODE_NORM_QC_NO},
+	{0x2FA14, UNICODE_NORM_QC_NO},
+	{0x2FA15, UNICODE_NORM_QC_NO},
+	{0x2FA16, UNICODE_NORM_QC_NO},
+	{0x2FA17, UNICODE_NORM_QC_NO},
+	{0x2FA18, UNICODE_NORM_QC_NO},
+	{0x2FA19, UNICODE_NORM_QC_NO},
+	{0x2FA1A, UNICODE_NORM_QC_NO},
+	{0x2FA1B, UNICODE_NORM_QC_NO},
+	{0x2FA1C, UNICODE_NORM_QC_NO},
+	{0x2FA1D, UNICODE_NORM_QC_NO},
+};
+
+static const pg_unicode_normprops UnicodeNormProps_NFKD_QC[] = {
+	{0x00A0, UNICODE_NORM_QC_NO},
+	{0x00A8, UNICODE_NORM_QC_NO},
+	{0x00AA, UNICODE_NORM_QC_NO},
+	{0x00AF, UNICODE_NORM_QC_NO},
+	{0x00B2, UNICODE_NORM_QC_NO},
+	{0x00B3, UNICODE_NORM_QC_NO},
+	{0x00B4, UNICODE_NORM_QC_NO},
+	{0x00B5, UNICODE_NORM_QC_NO},
+	{0x00B8, UNICODE_NORM_QC_NO},
+	{0x00B9, UNICODE_NORM_QC_NO},
+	{0x00BA, UNICODE_NORM_QC_NO},
+	{0x00BC, UNICODE_NORM_QC_NO},
+	{0x00BD, UNICODE_NORM_QC_NO},
+	{0x00BE, UNICODE_NORM_QC_NO},
+	{0x00C0, UNICODE_NORM_QC_NO},
+	{0x00C1, UNICODE_NORM_QC_NO},
+	{0x00C2, UNICODE_NORM_QC_NO},
+	{0x00C3, UNICODE_NORM_QC_NO},
+	{0x00C4, UNICODE_NORM_QC_NO},
+	{0x00C5, UNICODE_NORM_QC_NO},
+	{0x00C7, UNICODE_NORM_QC_NO},
+	{0x00C8, UNICODE_NORM_QC_NO},
+	{0x00C9, UNICODE_NORM_QC_NO},
+	{0x00CA, UNICODE_NORM_QC_NO},
+	{0x00CB, UNICODE_NORM_QC_NO},
+	{0x00CC, UNICODE_NORM_QC_NO},
+	{0x00CD, UNICODE_NORM_QC_NO},
+	{0x00CE, UNICODE_NORM_QC_NO},
+	{0x00CF, UNICODE_NORM_QC_NO},
+	{0x00D1, UNICODE_NORM_QC_NO},
+	{0x00D2, UNICODE_NORM_QC_NO},
+	{0x00D3, UNICODE_NORM_QC_NO},
+	{0x00D4, UNICODE_NORM_QC_NO},
+	{0x00D5, UNICODE_NORM_QC_NO},
+	{0x00D6, UNICODE_NORM_QC_NO},
+	{0x00D9, UNICODE_NORM_QC_NO},
+	{0x00DA, UNICODE_NORM_QC_NO},
+	{0x00DB, UNICODE_NORM_QC_NO},
+	{0x00DC, UNICODE_NORM_QC_NO},
+	{0x00DD, UNICODE_NORM_QC_NO},
+	{0x00E0, UNICODE_NORM_QC_NO},
+	{0x00E1, UNICODE_NORM_QC_NO},
+	{0x00E2, UNICODE_NORM_QC_NO},
+	{0x00E3, UNICODE_NORM_QC_NO},
+	{0x00E4, UNICODE_NORM_QC_NO},
+	{0x00E5, UNICODE_NORM_QC_NO},
+	{0x00E7, UNICODE_NORM_QC_NO},
+	{0x00E8, UNICODE_NORM_QC_NO},
+	{0x00E9, UNICODE_NORM_QC_NO},
+	{0x00EA, UNICODE_NORM_QC_NO},
+	{0x00EB, UNICODE_NORM_QC_NO},
+	{0x00EC, UNICODE_NORM_QC_NO},
+	{0x00ED, UNICODE_NORM_QC_NO},
+	{0x00EE, UNICODE_NORM_QC_NO},
+	{0x00EF, UNICODE_NORM_QC_NO},
+	{0x00F1, UNICODE_NORM_QC_NO},
+	{0x00F2, UNICODE_NORM_QC_NO},
+	{0x00F3, UNICODE_NORM_QC_NO},
+	{0x00F4, UNICODE_NORM_QC_NO},
+	{0x00F5, UNICODE_NORM_QC_NO},
+	{0x00F6, UNICODE_NORM_QC_NO},
+	{0x00F9, UNICODE_NORM_QC_NO},
+	{0x00FA, UNICODE_NORM_QC_NO},
+	{0x00FB, UNICODE_NORM_QC_NO},
+	{0x00FC, UNICODE_NORM_QC_NO},
+	{0x00FD, UNICODE_NORM_QC_NO},
+	{0x00FF, UNICODE_NORM_QC_NO},
+	{0x0100, UNICODE_NORM_QC_NO},
+	{0x0101, UNICODE_NORM_QC_NO},
+	{0x0102, UNICODE_NORM_QC_NO},
+	{0x0103, UNICODE_NORM_QC_NO},
+	{0x0104, UNICODE_NORM_QC_NO},
+	{0x0105, UNICODE_NORM_QC_NO},
+	{0x0106, UNICODE_NORM_QC_NO},
+	{0x0107, UNICODE_NORM_QC_NO},
+	{0x0108, UNICODE_NORM_QC_NO},
+	{0x0109, UNICODE_NORM_QC_NO},
+	{0x010A, UNICODE_NORM_QC_NO},
+	{0x010B, UNICODE_NORM_QC_NO},
+	{0x010C, UNICODE_NORM_QC_NO},
+	{0x010D, UNICODE_NORM_QC_NO},
+	{0x010E, UNICODE_NORM_QC_NO},
+	{0x010F, UNICODE_NORM_QC_NO},
+	{0x0112, UNICODE_NORM_QC_NO},
+	{0x0113, UNICODE_NORM_QC_NO},
+	{0x0114, UNICODE_NORM_QC_NO},
+	{0x0115, UNICODE_NORM_QC_NO},
+	{0x0116, UNICODE_NORM_QC_NO},
+	{0x0117, UNICODE_NORM_QC_NO},
+	{0x0118, UNICODE_NORM_QC_NO},
+	{0x0119, UNICODE_NORM_QC_NO},
+	{0x011A, UNICODE_NORM_QC_NO},
+	{0x011B, UNICODE_NORM_QC_NO},
+	{0x011C, UNICODE_NORM_QC_NO},
+	{0x011D, UNICODE_NORM_QC_NO},
+	{0x011E, UNICODE_NORM_QC_NO},
+	{0x011F, UNICODE_NORM_QC_NO},
+	{0x0120, UNICODE_NORM_QC_NO},
+	{0x0121, UNICODE_NORM_QC_NO},
+	{0x0122, UNICODE_NORM_QC_NO},
+	{0x0123, UNICODE_NORM_QC_NO},
+	{0x0124, UNICODE_NORM_QC_NO},
+	{0x0125, UNICODE_NORM_QC_NO},
+	{0x0128, UNICODE_NORM_QC_NO},
+	{0x0129, UNICODE_NORM_QC_NO},
+	{0x012A, UNICODE_NORM_QC_NO},
+	{0x012B, UNICODE_NORM_QC_NO},
+	{0x012C, UNICODE_NORM_QC_NO},
+	{0x012D, UNICODE_NORM_QC_NO},
+	{0x012E, UNICODE_NORM_QC_NO},
+	{0x012F, UNICODE_NORM_QC_NO},
+	{0x0130, UNICODE_NORM_QC_NO},
+	{0x0132, UNICODE_NORM_QC_NO},
+	{0x0133, UNICODE_NORM_QC_NO},
+	{0x0134, UNICODE_NORM_QC_NO},
+	{0x0135, UNICODE_NORM_QC_NO},
+	{0x0136, UNICODE_NORM_QC_NO},
+	{0x0137, UNICODE_NORM_QC_NO},
+	{0x0139, UNICODE_NORM_QC_NO},
+	{0x013A, UNICODE_NORM_QC_NO},
+	{0x013B, UNICODE_NORM_QC_NO},
+	{0x013C, UNICODE_NORM_QC_NO},
+	{0x013D, UNICODE_NORM_QC_NO},
+	{0x013E, UNICODE_NORM_QC_NO},
+	{0x013F, UNICODE_NORM_QC_NO},
+	{0x0140, UNICODE_NORM_QC_NO},
+	{0x0143, UNICODE_NORM_QC_NO},
+	{0x0144, UNICODE_NORM_QC_NO},
+	{0x0145, UNICODE_NORM_QC_NO},
+	{0x0146, UNICODE_NORM_QC_NO},
+	{0x0147, UNICODE_NORM_QC_NO},
+	{0x0148, UNICODE_NORM_QC_NO},
+	{0x0149, UNICODE_NORM_QC_NO},
+	{0x014C, UNICODE_NORM_QC_NO},
+	{0x014D, UNICODE_NORM_QC_NO},
+	{0x014E, UNICODE_NORM_QC_NO},
+	{0x014F, UNICODE_NORM_QC_NO},
+	{0x0150, UNICODE_NORM_QC_NO},
+	{0x0151, UNICODE_NORM_QC_NO},
+	{0x0154, UNICODE_NORM_QC_NO},
+	{0x0155, UNICODE_NORM_QC_NO},
+	{0x0156, UNICODE_NORM_QC_NO},
+	{0x0157, UNICODE_NORM_QC_NO},
+	{0x0158, UNICODE_NORM_QC_NO},
+	{0x0159, UNICODE_NORM_QC_NO},
+	{0x015A, UNICODE_NORM_QC_NO},
+	{0x015B, UNICODE_NORM_QC_NO},
+	{0x015C, UNICODE_NORM_QC_NO},
+	{0x015D, UNICODE_NORM_QC_NO},
+	{0x015E, UNICODE_NORM_QC_NO},
+	{0x015F, UNICODE_NORM_QC_NO},
+	{0x0160, UNICODE_NORM_QC_NO},
+	{0x0161, UNICODE_NORM_QC_NO},
+	{0x0162, UNICODE_NORM_QC_NO},
+	{0x0163, UNICODE_NORM_QC_NO},
+	{0x0164, UNICODE_NORM_QC_NO},
+	{0x0165, UNICODE_NORM_QC_NO},
+	{0x0168, UNICODE_NORM_QC_NO},
+	{0x0169, UNICODE_NORM_QC_NO},
+	{0x016A, UNICODE_NORM_QC_NO},
+	{0x016B, UNICODE_NORM_QC_NO},
+	{0x016C, UNICODE_NORM_QC_NO},
+	{0x016D, UNICODE_NORM_QC_NO},
+	{0x016E, UNICODE_NORM_QC_NO},
+	{0x016F, UNICODE_NORM_QC_NO},
+	{0x0170, UNICODE_NORM_QC_NO},
+	{0x0171, UNICODE_NORM_QC_NO},
+	{0x0172, UNICODE_NORM_QC_NO},
+	{0x0173, UNICODE_NORM_QC_NO},
+	{0x0174, UNICODE_NORM_QC_NO},
+	{0x0175, UNICODE_NORM_QC_NO},
+	{0x0176, UNICODE_NORM_QC_NO},
+	{0x0177, UNICODE_NORM_QC_NO},
+	{0x0178, UNICODE_NORM_QC_NO},
+	{0x0179, UNICODE_NORM_QC_NO},
+	{0x017A, UNICODE_NORM_QC_NO},
+	{0x017B, UNICODE_NORM_QC_NO},
+	{0x017C, UNICODE_NORM_QC_NO},
+	{0x017D, UNICODE_NORM_QC_NO},
+	{0x017E, UNICODE_NORM_QC_NO},
+	{0x017F, UNICODE_NORM_QC_NO},
+	{0x01A0, UNICODE_NORM_QC_NO},
+	{0x01A1, UNICODE_NORM_QC_NO},
+	{0x01AF, UNICODE_NORM_QC_NO},
+	{0x01B0, UNICODE_NORM_QC_NO},
+	{0x01C4, UNICODE_NORM_QC_NO},
+	{0x01C5, UNICODE_NORM_QC_NO},
+	{0x01C6, UNICODE_NORM_QC_NO},
+	{0x01C7, UNICODE_NORM_QC_NO},
+	{0x01C8, UNICODE_NORM_QC_NO},
+	{0x01C9, UNICODE_NORM_QC_NO},
+	{0x01CA, UNICODE_NORM_QC_NO},
+	{0x01CB, UNICODE_NORM_QC_NO},
+	{0x01CC, UNICODE_NORM_QC_NO},
+	{0x01CD, UNICODE_NORM_QC_NO},
+	{0x01CE, UNICODE_NORM_QC_NO},
+	{0x01CF, UNICODE_NORM_QC_NO},
+	{0x01D0, UNICODE_NORM_QC_NO},
+	{0x01D1, UNICODE_NORM_QC_NO},
+	{0x01D2, UNICODE_NORM_QC_NO},
+	{0x01D3, UNICODE_NORM_QC_NO},
+	{0x01D4, UNICODE_NORM_QC_NO},
+	{0x01D5, UNICODE_NORM_QC_NO},
+	{0x01D6, UNICODE_NORM_QC_NO},
+	{0x01D7, UNICODE_NORM_QC_NO},
+	{0x01D8, UNICODE_NORM_QC_NO},
+	{0x01D9, UNICODE_NORM_QC_NO},
+	{0x01DA, UNICODE_NORM_QC_NO},
+	{0x01DB, UNICODE_NORM_QC_NO},
+	{0x01DC, UNICODE_NORM_QC_NO},
+	{0x01DE, UNICODE_NORM_QC_NO},
+	{0x01DF, UNICODE_NORM_QC_NO},
+	{0x01E0, UNICODE_NORM_QC_NO},
+	{0x01E1, UNICODE_NORM_QC_NO},
+	{0x01E2, UNICODE_NORM_QC_NO},
+	{0x01E3, UNICODE_NORM_QC_NO},
+	{0x01E6, UNICODE_NORM_QC_NO},
+	{0x01E7, UNICODE_NORM_QC_NO},
+	{0x01E8, UNICODE_NORM_QC_NO},
+	{0x01E9, UNICODE_NORM_QC_NO},
+	{0x01EA, UNICODE_NORM_QC_NO},
+	{0x01EB, UNICODE_NORM_QC_NO},
+	{0x01EC, UNICODE_NORM_QC_NO},
+	{0x01ED, UNICODE_NORM_QC_NO},
+	{0x01EE, UNICODE_NORM_QC_NO},
+	{0x01EF, UNICODE_NORM_QC_NO},
+	{0x01F0, UNICODE_NORM_QC_NO},
+	{0x01F1, UNICODE_NORM_QC_NO},
+	{0x01F2, UNICODE_NORM_QC_NO},
+	{0x01F3, UNICODE_NORM_QC_NO},
+	{0x01F4, UNICODE_NORM_QC_NO},
+	{0x01F5, UNICODE_NORM_QC_NO},
+	{0x01F8, UNICODE_NORM_QC_NO},
+	{0x01F9, UNICODE_NORM_QC_NO},
+	{0x01FA, UNICODE_NORM_QC_NO},
+	{0x01FB, UNICODE_NORM_QC_NO},
+	{0x01FC, UNICODE_NORM_QC_NO},
+	{0x01FD, UNICODE_NORM_QC_NO},
+	{0x01FE, UNICODE_NORM_QC_NO},
+	{0x01FF, UNICODE_NORM_QC_NO},
+	{0x0200, UNICODE_NORM_QC_NO},
+	{0x0201, UNICODE_NORM_QC_NO},
+	{0x0202, UNICODE_NORM_QC_NO},
+	{0x0203, UNICODE_NORM_QC_NO},
+	{0x0204, UNICODE_NORM_QC_NO},
+	{0x0205, UNICODE_NORM_QC_NO},
+	{0x0206, UNICODE_NORM_QC_NO},
+	{0x0207, UNICODE_NORM_QC_NO},
+	{0x0208, UNICODE_NORM_QC_NO},
+	{0x0209, UNICODE_NORM_QC_NO},
+	{0x020A, UNICODE_NORM_QC_NO},
+	{0x020B, UNICODE_NORM_QC_NO},
+	{0x020C, UNICODE_NORM_QC_NO},
+	{0x020D, UNICODE_NORM_QC_NO},
+	{0x020E, UNICODE_NORM_QC_NO},
+	{0x020F, UNICODE_NORM_QC_NO},
+	{0x0210, UNICODE_NORM_QC_NO},
+	{0x0211, UNICODE_NORM_QC_NO},
+	{0x0212, UNICODE_NORM_QC_NO},
+	{0x0213, UNICODE_NORM_QC_NO},
+	{0x0214, UNICODE_NORM_QC_NO},
+	{0x0215, UNICODE_NORM_QC_NO},
+	{0x0216, UNICODE_NORM_QC_NO},
+	{0x0217, UNICODE_NORM_QC_NO},
+	{0x0218, UNICODE_NORM_QC_NO},
+	{0x0219, UNICODE_NORM_QC_NO},
+	{0x021A, UNICODE_NORM_QC_NO},
+	{0x021B, UNICODE_NORM_QC_NO},
+	{0x021E, UNICODE_NORM_QC_NO},
+	{0x021F, UNICODE_NORM_QC_NO},
+	{0x0226, UNICODE_NORM_QC_NO},
+	{0x0227, UNICODE_NORM_QC_NO},
+	{0x0228, UNICODE_NORM_QC_NO},
+	{0x0229, UNICODE_NORM_QC_NO},
+	{0x022A, UNICODE_NORM_QC_NO},
+	{0x022B, UNICODE_NORM_QC_NO},
+	{0x022C, UNICODE_NORM_QC_NO},
+	{0x022D, UNICODE_NORM_QC_NO},
+	{0x022E, UNICODE_NORM_QC_NO},
+	{0x022F, UNICODE_NORM_QC_NO},
+	{0x0230, UNICODE_NORM_QC_NO},
+	{0x0231, UNICODE_NORM_QC_NO},
+	{0x0232, UNICODE_NORM_QC_NO},
+	{0x0233, UNICODE_NORM_QC_NO},
+	{0x02B0, UNICODE_NORM_QC_NO},
+	{0x02B1, UNICODE_NORM_QC_NO},
+	{0x02B2, UNICODE_NORM_QC_NO},
+	{0x02B3, UNICODE_NORM_QC_NO},
+	{0x02B4, UNICODE_NORM_QC_NO},
+	{0x02B5, UNICODE_NORM_QC_NO},
+	{0x02B6, UNICODE_NORM_QC_NO},
+	{0x02B7, UNICODE_NORM_QC_NO},
+	{0x02B8, UNICODE_NORM_QC_NO},
+	{0x02D8, UNICODE_NORM_QC_NO},
+	{0x02D9, UNICODE_NORM_QC_NO},
+	{0x02DA, UNICODE_NORM_QC_NO},
+	{0x02DB, UNICODE_NORM_QC_NO},
+	{0x02DC, UNICODE_NORM_QC_NO},
+	{0x02DD, UNICODE_NORM_QC_NO},
+	{0x02E0, UNICODE_NORM_QC_NO},
+	{0x02E1, UNICODE_NORM_QC_NO},
+	{0x02E2, UNICODE_NORM_QC_NO},
+	{0x02E3, UNICODE_NORM_QC_NO},
+	{0x02E4, UNICODE_NORM_QC_NO},
+	{0x0340, UNICODE_NORM_QC_NO},
+	{0x0341, UNICODE_NORM_QC_NO},
+	{0x0343, UNICODE_NORM_QC_NO},
+	{0x0344, UNICODE_NORM_QC_NO},
+	{0x0374, UNICODE_NORM_QC_NO},
+	{0x037A, UNICODE_NORM_QC_NO},
+	{0x037E, UNICODE_NORM_QC_NO},
+	{0x0384, UNICODE_NORM_QC_NO},
+	{0x0385, UNICODE_NORM_QC_NO},
+	{0x0386, UNICODE_NORM_QC_NO},
+	{0x0387, UNICODE_NORM_QC_NO},
+	{0x0388, UNICODE_NORM_QC_NO},
+	{0x0389, UNICODE_NORM_QC_NO},
+	{0x038A, UNICODE_NORM_QC_NO},
+	{0x038C, UNICODE_NORM_QC_NO},
+	{0x038E, UNICODE_NORM_QC_NO},
+	{0x038F, UNICODE_NORM_QC_NO},
+	{0x0390, UNICODE_NORM_QC_NO},
+	{0x03AA, UNICODE_NORM_QC_NO},
+	{0x03AB, UNICODE_NORM_QC_NO},
+	{0x03AC, UNICODE_NORM_QC_NO},
+	{0x03AD, UNICODE_NORM_QC_NO},
+	{0x03AE, UNICODE_NORM_QC_NO},
+	{0x03AF, UNICODE_NORM_QC_NO},
+	{0x03B0, UNICODE_NORM_QC_NO},
+	{0x03CA, UNICODE_NORM_QC_NO},
+	{0x03CB, UNICODE_NORM_QC_NO},
+	{0x03CC, UNICODE_NORM_QC_NO},
+	{0x03CD, UNICODE_NORM_QC_NO},
+	{0x03CE, UNICODE_NORM_QC_NO},
+	{0x03D0, UNICODE_NORM_QC_NO},
+	{0x03D1, UNICODE_NORM_QC_NO},
+	{0x03D2, UNICODE_NORM_QC_NO},
+	{0x03D3, UNICODE_NORM_QC_NO},
+	{0x03D4, UNICODE_NORM_QC_NO},
+	{0x03D5, UNICODE_NORM_QC_NO},
+	{0x03D6, UNICODE_NORM_QC_NO},
+	{0x03F0, UNICODE_NORM_QC_NO},
+	{0x03F1, UNICODE_NORM_QC_NO},
+	{0x03F2, UNICODE_NORM_QC_NO},
+	{0x03F4, UNICODE_NORM_QC_NO},
+	{0x03F5, UNICODE_NORM_QC_NO},
+	{0x03F9, UNICODE_NORM_QC_NO},
+	{0x0400, UNICODE_NORM_QC_NO},
+	{0x0401, UNICODE_NORM_QC_NO},
+	{0x0403, UNICODE_NORM_QC_NO},
+	{0x0407, UNICODE_NORM_QC_NO},
+	{0x040C, UNICODE_NORM_QC_NO},
+	{0x040D, UNICODE_NORM_QC_NO},
+	{0x040E, UNICODE_NORM_QC_NO},
+	{0x0419, UNICODE_NORM_QC_NO},
+	{0x0439, UNICODE_NORM_QC_NO},
+	{0x0450, UNICODE_NORM_QC_NO},
+	{0x0451, UNICODE_NORM_QC_NO},
+	{0x0453, UNICODE_NORM_QC_NO},
+	{0x0457, UNICODE_NORM_QC_NO},
+	{0x045C, UNICODE_NORM_QC_NO},
+	{0x045D, UNICODE_NORM_QC_NO},
+	{0x045E, UNICODE_NORM_QC_NO},
+	{0x0476, UNICODE_NORM_QC_NO},
+	{0x0477, UNICODE_NORM_QC_NO},
+	{0x04C1, UNICODE_NORM_QC_NO},
+	{0x04C2, UNICODE_NORM_QC_NO},
+	{0x04D0, UNICODE_NORM_QC_NO},
+	{0x04D1, UNICODE_NORM_QC_NO},
+	{0x04D2, UNICODE_NORM_QC_NO},
+	{0x04D3, UNICODE_NORM_QC_NO},
+	{0x04D6, UNICODE_NORM_QC_NO},
+	{0x04D7, UNICODE_NORM_QC_NO},
+	{0x04DA, UNICODE_NORM_QC_NO},
+	{0x04DB, UNICODE_NORM_QC_NO},
+	{0x04DC, UNICODE_NORM_QC_NO},
+	{0x04DD, UNICODE_NORM_QC_NO},
+	{0x04DE, UNICODE_NORM_QC_NO},
+	{0x04DF, UNICODE_NORM_QC_NO},
+	{0x04E2, UNICODE_NORM_QC_NO},
+	{0x04E3, UNICODE_NORM_QC_NO},
+	{0x04E4, UNICODE_NORM_QC_NO},
+	{0x04E5, UNICODE_NORM_QC_NO},
+	{0x04E6, UNICODE_NORM_QC_NO},
+	{0x04E7, UNICODE_NORM_QC_NO},
+	{0x04EA, UNICODE_NORM_QC_NO},
+	{0x04EB, UNICODE_NORM_QC_NO},
+	{0x04EC, UNICODE_NORM_QC_NO},
+	{0x04ED, UNICODE_NORM_QC_NO},
+	{0x04EE, UNICODE_NORM_QC_NO},
+	{0x04EF, UNICODE_NORM_QC_NO},
+	{0x04F0, UNICODE_NORM_QC_NO},
+	{0x04F1, UNICODE_NORM_QC_NO},
+	{0x04F2, UNICODE_NORM_QC_NO},
+	{0x04F3, UNICODE_NORM_QC_NO},
+	{0x04F4, UNICODE_NORM_QC_NO},
+	{0x04F5, UNICODE_NORM_QC_NO},
+	{0x04F8, UNICODE_NORM_QC_NO},
+	{0x04F9, UNICODE_NORM_QC_NO},
+	{0x0587, UNICODE_NORM_QC_NO},
+	{0x0622, UNICODE_NORM_QC_NO},
+	{0x0623, UNICODE_NORM_QC_NO},
+	{0x0624, UNICODE_NORM_QC_NO},
+	{0x0625, UNICODE_NORM_QC_NO},
+	{0x0626, UNICODE_NORM_QC_NO},
+	{0x0675, UNICODE_NORM_QC_NO},
+	{0x0676, UNICODE_NORM_QC_NO},
+	{0x0677, UNICODE_NORM_QC_NO},
+	{0x0678, UNICODE_NORM_QC_NO},
+	{0x06C0, UNICODE_NORM_QC_NO},
+	{0x06C2, UNICODE_NORM_QC_NO},
+	{0x06D3, UNICODE_NORM_QC_NO},
+	{0x0929, UNICODE_NORM_QC_NO},
+	{0x0931, UNICODE_NORM_QC_NO},
+	{0x0934, UNICODE_NORM_QC_NO},
+	{0x0958, UNICODE_NORM_QC_NO},
+	{0x0959, UNICODE_NORM_QC_NO},
+	{0x095A, UNICODE_NORM_QC_NO},
+	{0x095B, UNICODE_NORM_QC_NO},
+	{0x095C, UNICODE_NORM_QC_NO},
+	{0x095D, UNICODE_NORM_QC_NO},
+	{0x095E, UNICODE_NORM_QC_NO},
+	{0x095F, UNICODE_NORM_QC_NO},
+	{0x09CB, UNICODE_NORM_QC_NO},
+	{0x09CC, UNICODE_NORM_QC_NO},
+	{0x09DC, UNICODE_NORM_QC_NO},
+	{0x09DD, UNICODE_NORM_QC_NO},
+	{0x09DF, UNICODE_NORM_QC_NO},
+	{0x0A33, UNICODE_NORM_QC_NO},
+	{0x0A36, UNICODE_NORM_QC_NO},
+	{0x0A59, UNICODE_NORM_QC_NO},
+	{0x0A5A, UNICODE_NORM_QC_NO},
+	{0x0A5B, UNICODE_NORM_QC_NO},
+	{0x0A5E, UNICODE_NORM_QC_NO},
+	{0x0B48, UNICODE_NORM_QC_NO},
+	{0x0B4B, UNICODE_NORM_QC_NO},
+	{0x0B4C, UNICODE_NORM_QC_NO},
+	{0x0B5C, UNICODE_NORM_QC_NO},
+	{0x0B5D, UNICODE_NORM_QC_NO},
+	{0x0B94, UNICODE_NORM_QC_NO},
+	{0x0BCA, UNICODE_NORM_QC_NO},
+	{0x0BCB, UNICODE_NORM_QC_NO},
+	{0x0BCC, UNICODE_NORM_QC_NO},
+	{0x0C48, UNICODE_NORM_QC_NO},
+	{0x0CC0, UNICODE_NORM_QC_NO},
+	{0x0CC7, UNICODE_NORM_QC_NO},
+	{0x0CC8, UNICODE_NORM_QC_NO},
+	{0x0CCA, UNICODE_NORM_QC_NO},
+	{0x0CCB, UNICODE_NORM_QC_NO},
+	{0x0D4A, UNICODE_NORM_QC_NO},
+	{0x0D4B, UNICODE_NORM_QC_NO},
+	{0x0D4C, UNICODE_NORM_QC_NO},
+	{0x0DDA, UNICODE_NORM_QC_NO},
+	{0x0DDC, UNICODE_NORM_QC_NO},
+	{0x0DDD, UNICODE_NORM_QC_NO},
+	{0x0DDE, UNICODE_NORM_QC_NO},
+	{0x0E33, UNICODE_NORM_QC_NO},
+	{0x0EB3, UNICODE_NORM_QC_NO},
+	{0x0EDC, UNICODE_NORM_QC_NO},
+	{0x0EDD, UNICODE_NORM_QC_NO},
+	{0x0F0C, UNICODE_NORM_QC_NO},
+	{0x0F43, UNICODE_NORM_QC_NO},
+	{0x0F4D, UNICODE_NORM_QC_NO},
+	{0x0F52, UNICODE_NORM_QC_NO},
+	{0x0F57, UNICODE_NORM_QC_NO},
+	{0x0F5C, UNICODE_NORM_QC_NO},
+	{0x0F69, UNICODE_NORM_QC_NO},
+	{0x0F73, UNICODE_NORM_QC_NO},
+	{0x0F75, UNICODE_NORM_QC_NO},
+	{0x0F76, UNICODE_NORM_QC_NO},
+	{0x0F77, UNICODE_NORM_QC_NO},
+	{0x0F78, UNICODE_NORM_QC_NO},
+	{0x0F79, UNICODE_NORM_QC_NO},
+	{0x0F81, UNICODE_NORM_QC_NO},
+	{0x0F93, UNICODE_NORM_QC_NO},
+	{0x0F9D, UNICODE_NORM_QC_NO},
+	{0x0FA2, UNICODE_NORM_QC_NO},
+	{0x0FA7, UNICODE_NORM_QC_NO},
+	{0x0FAC, UNICODE_NORM_QC_NO},
+	{0x0FB9, UNICODE_NORM_QC_NO},
+	{0x1026, UNICODE_NORM_QC_NO},
+	{0x10FC, UNICODE_NORM_QC_NO},
+	{0x1B06, UNICODE_NORM_QC_NO},
+	{0x1B08, UNICODE_NORM_QC_NO},
+	{0x1B0A, UNICODE_NORM_QC_NO},
+	{0x1B0C, UNICODE_NORM_QC_NO},
+	{0x1B0E, UNICODE_NORM_QC_NO},
+	{0x1B12, UNICODE_NORM_QC_NO},
+	{0x1B3B, UNICODE_NORM_QC_NO},
+	{0x1B3D, UNICODE_NORM_QC_NO},
+	{0x1B40, UNICODE_NORM_QC_NO},
+	{0x1B41, UNICODE_NORM_QC_NO},
+	{0x1B43, UNICODE_NORM_QC_NO},
+	{0x1D2C, UNICODE_NORM_QC_NO},
+	{0x1D2D, UNICODE_NORM_QC_NO},
+	{0x1D2E, UNICODE_NORM_QC_NO},
+	{0x1D30, UNICODE_NORM_QC_NO},
+	{0x1D31, UNICODE_NORM_QC_NO},
+	{0x1D32, UNICODE_NORM_QC_NO},
+	{0x1D33, UNICODE_NORM_QC_NO},
+	{0x1D34, UNICODE_NORM_QC_NO},
+	{0x1D35, UNICODE_NORM_QC_NO},
+	{0x1D36, UNICODE_NORM_QC_NO},
+	{0x1D37, UNICODE_NORM_QC_NO},
+	{0x1D38, UNICODE_NORM_QC_NO},
+	{0x1D39, UNICODE_NORM_QC_NO},
+	{0x1D3A, UNICODE_NORM_QC_NO},
+	{0x1D3C, UNICODE_NORM_QC_NO},
+	{0x1D3D, UNICODE_NORM_QC_NO},
+	{0x1D3E, UNICODE_NORM_QC_NO},
+	{0x1D3F, UNICODE_NORM_QC_NO},
+	{0x1D40, UNICODE_NORM_QC_NO},
+	{0x1D41, UNICODE_NORM_QC_NO},
+	{0x1D42, UNICODE_NORM_QC_NO},
+	{0x1D43, UNICODE_NORM_QC_NO},
+	{0x1D44, UNICODE_NORM_QC_NO},
+	{0x1D45, UNICODE_NORM_QC_NO},
+	{0x1D46, UNICODE_NORM_QC_NO},
+	{0x1D47, UNICODE_NORM_QC_NO},
+	{0x1D48, UNICODE_NORM_QC_NO},
+	{0x1D49, UNICODE_NORM_QC_NO},
+	{0x1D4A, UNICODE_NORM_QC_NO},
+	{0x1D4B, UNICODE_NORM_QC_NO},
+	{0x1D4C, UNICODE_NORM_QC_NO},
+	{0x1D4D, UNICODE_NORM_QC_NO},
+	{0x1D4F, UNICODE_NORM_QC_NO},
+	{0x1D50, UNICODE_NORM_QC_NO},
+	{0x1D51, UNICODE_NORM_QC_NO},
+	{0x1D52, UNICODE_NORM_QC_NO},
+	{0x1D53, UNICODE_NORM_QC_NO},
+	{0x1D54, UNICODE_NORM_QC_NO},
+	{0x1D55, UNICODE_NORM_QC_NO},
+	{0x1D56, UNICODE_NORM_QC_NO},
+	{0x1D57, UNICODE_NORM_QC_NO},
+	{0x1D58, UNICODE_NORM_QC_NO},
+	{0x1D59, UNICODE_NORM_QC_NO},
+	{0x1D5A, UNICODE_NORM_QC_NO},
+	{0x1D5B, UNICODE_NORM_QC_NO},
+	{0x1D5C, UNICODE_NORM_QC_NO},
+	{0x1D5D, UNICODE_NORM_QC_NO},
+	{0x1D5E, UNICODE_NORM_QC_NO},
+	{0x1D5F, UNICODE_NORM_QC_NO},
+	{0x1D60, UNICODE_NORM_QC_NO},
+	{0x1D61, UNICODE_NORM_QC_NO},
+	{0x1D62, UNICODE_NORM_QC_NO},
+	{0x1D63, UNICODE_NORM_QC_NO},
+	{0x1D64, UNICODE_NORM_QC_NO},
+	{0x1D65, UNICODE_NORM_QC_NO},
+	{0x1D66, UNICODE_NORM_QC_NO},
+	{0x1D67, UNICODE_NORM_QC_NO},
+	{0x1D68, UNICODE_NORM_QC_NO},
+	{0x1D69, UNICODE_NORM_QC_NO},
+	{0x1D6A, UNICODE_NORM_QC_NO},
+	{0x1D78, UNICODE_NORM_QC_NO},
+	{0x1D9B, UNICODE_NORM_QC_NO},
+	{0x1D9C, UNICODE_NORM_QC_NO},
+	{0x1D9D, UNICODE_NORM_QC_NO},
+	{0x1D9E, UNICODE_NORM_QC_NO},
+	{0x1D9F, UNICODE_NORM_QC_NO},
+	{0x1DA0, UNICODE_NORM_QC_NO},
+	{0x1DA1, UNICODE_NORM_QC_NO},
+	{0x1DA2, UNICODE_NORM_QC_NO},
+	{0x1DA3, UNICODE_NORM_QC_NO},
+	{0x1DA4, UNICODE_NORM_QC_NO},
+	{0x1DA5, UNICODE_NORM_QC_NO},
+	{0x1DA6, UNICODE_NORM_QC_NO},
+	{0x1DA7, UNICODE_NORM_QC_NO},
+	{0x1DA8, UNICODE_NORM_QC_NO},
+	{0x1DA9, UNICODE_NORM_QC_NO},
+	{0x1DAA, UNICODE_NORM_QC_NO},
+	{0x1DAB, UNICODE_NORM_QC_NO},
+	{0x1DAC, UNICODE_NORM_QC_NO},
+	{0x1DAD, UNICODE_NORM_QC_NO},
+	{0x1DAE, UNICODE_NORM_QC_NO},
+	{0x1DAF, UNICODE_NORM_QC_NO},
+	{0x1DB0, UNICODE_NORM_QC_NO},
+	{0x1DB1, UNICODE_NORM_QC_NO},
+	{0x1DB2, UNICODE_NORM_QC_NO},
+	{0x1DB3, UNICODE_NORM_QC_NO},
+	{0x1DB4, UNICODE_NORM_QC_NO},
+	{0x1DB5, UNICODE_NORM_QC_NO},
+	{0x1DB6, UNICODE_NORM_QC_NO},
+	{0x1DB7, UNICODE_NORM_QC_NO},
+	{0x1DB8, UNICODE_NORM_QC_NO},
+	{0x1DB9, UNICODE_NORM_QC_NO},
+	{0x1DBA, UNICODE_NORM_QC_NO},
+	{0x1DBB, UNICODE_NORM_QC_NO},
+	{0x1DBC, UNICODE_NORM_QC_NO},
+	{0x1DBD, UNICODE_NORM_QC_NO},
+	{0x1DBE, UNICODE_NORM_QC_NO},
+	{0x1DBF, UNICODE_NORM_QC_NO},
+	{0x1E00, UNICODE_NORM_QC_NO},
+	{0x1E01, UNICODE_NORM_QC_NO},
+	{0x1E02, UNICODE_NORM_QC_NO},
+	{0x1E03, UNICODE_NORM_QC_NO},
+	{0x1E04, UNICODE_NORM_QC_NO},
+	{0x1E05, UNICODE_NORM_QC_NO},
+	{0x1E06, UNICODE_NORM_QC_NO},
+	{0x1E07, UNICODE_NORM_QC_NO},
+	{0x1E08, UNICODE_NORM_QC_NO},
+	{0x1E09, UNICODE_NORM_QC_NO},
+	{0x1E0A, UNICODE_NORM_QC_NO},
+	{0x1E0B, UNICODE_NORM_QC_NO},
+	{0x1E0C, UNICODE_NORM_QC_NO},
+	{0x1E0D, UNICODE_NORM_QC_NO},
+	{0x1E0E, UNICODE_NORM_QC_NO},
+	{0x1E0F, UNICODE_NORM_QC_NO},
+	{0x1E10, UNICODE_NORM_QC_NO},
+	{0x1E11, UNICODE_NORM_QC_NO},
+	{0x1E12, UNICODE_NORM_QC_NO},
+	{0x1E13, UNICODE_NORM_QC_NO},
+	{0x1E14, UNICODE_NORM_QC_NO},
+	{0x1E15, UNICODE_NORM_QC_NO},
+	{0x1E16, UNICODE_NORM_QC_NO},
+	{0x1E17, UNICODE_NORM_QC_NO},
+	{0x1E18, UNICODE_NORM_QC_NO},
+	{0x1E19, UNICODE_NORM_QC_NO},
+	{0x1E1A, UNICODE_NORM_QC_NO},
+	{0x1E1B, UNICODE_NORM_QC_NO},
+	{0x1E1C, UNICODE_NORM_QC_NO},
+	{0x1E1D, UNICODE_NORM_QC_NO},
+	{0x1E1E, UNICODE_NORM_QC_NO},
+	{0x1E1F, UNICODE_NORM_QC_NO},
+	{0x1E20, UNICODE_NORM_QC_NO},
+	{0x1E21, UNICODE_NORM_QC_NO},
+	{0x1E22, UNICODE_NORM_QC_NO},
+	{0x1E23, UNICODE_NORM_QC_NO},
+	{0x1E24, UNICODE_NORM_QC_NO},
+	{0x1E25, UNICODE_NORM_QC_NO},
+	{0x1E26, UNICODE_NORM_QC_NO},
+	{0x1E27, UNICODE_NORM_QC_NO},
+	{0x1E28, UNICODE_NORM_QC_NO},
+	{0x1E29, UNICODE_NORM_QC_NO},
+	{0x1E2A, UNICODE_NORM_QC_NO},
+	{0x1E2B, UNICODE_NORM_QC_NO},
+	{0x1E2C, UNICODE_NORM_QC_NO},
+	{0x1E2D, UNICODE_NORM_QC_NO},
+	{0x1E2E, UNICODE_NORM_QC_NO},
+	{0x1E2F, UNICODE_NORM_QC_NO},
+	{0x1E30, UNICODE_NORM_QC_NO},
+	{0x1E31, UNICODE_NORM_QC_NO},
+	{0x1E32, UNICODE_NORM_QC_NO},
+	{0x1E33, UNICODE_NORM_QC_NO},
+	{0x1E34, UNICODE_NORM_QC_NO},
+	{0x1E35, UNICODE_NORM_QC_NO},
+	{0x1E36, UNICODE_NORM_QC_NO},
+	{0x1E37, UNICODE_NORM_QC_NO},
+	{0x1E38, UNICODE_NORM_QC_NO},
+	{0x1E39, UNICODE_NORM_QC_NO},
+	{0x1E3A, UNICODE_NORM_QC_NO},
+	{0x1E3B, UNICODE_NORM_QC_NO},
+	{0x1E3C, UNICODE_NORM_QC_NO},
+	{0x1E3D, UNICODE_NORM_QC_NO},
+	{0x1E3E, UNICODE_NORM_QC_NO},
+	{0x1E3F, UNICODE_NORM_QC_NO},
+	{0x1E40, UNICODE_NORM_QC_NO},
+	{0x1E41, UNICODE_NORM_QC_NO},
+	{0x1E42, UNICODE_NORM_QC_NO},
+	{0x1E43, UNICODE_NORM_QC_NO},
+	{0x1E44, UNICODE_NORM_QC_NO},
+	{0x1E45, UNICODE_NORM_QC_NO},
+	{0x1E46, UNICODE_NORM_QC_NO},
+	{0x1E47, UNICODE_NORM_QC_NO},
+	{0x1E48, UNICODE_NORM_QC_NO},
+	{0x1E49, UNICODE_NORM_QC_NO},
+	{0x1E4A, UNICODE_NORM_QC_NO},
+	{0x1E4B, UNICODE_NORM_QC_NO},
+	{0x1E4C, UNICODE_NORM_QC_NO},
+	{0x1E4D, UNICODE_NORM_QC_NO},
+	{0x1E4E, UNICODE_NORM_QC_NO},
+	{0x1E4F, UNICODE_NORM_QC_NO},
+	{0x1E50, UNICODE_NORM_QC_NO},
+	{0x1E51, UNICODE_NORM_QC_NO},
+	{0x1E52, UNICODE_NORM_QC_NO},
+	{0x1E53, UNICODE_NORM_QC_NO},
+	{0x1E54, UNICODE_NORM_QC_NO},
+	{0x1E55, UNICODE_NORM_QC_NO},
+	{0x1E56, UNICODE_NORM_QC_NO},
+	{0x1E57, UNICODE_NORM_QC_NO},
+	{0x1E58, UNICODE_NORM_QC_NO},
+	{0x1E59, UNICODE_NORM_QC_NO},
+	{0x1E5A, UNICODE_NORM_QC_NO},
+	{0x1E5B, UNICODE_NORM_QC_NO},
+	{0x1E5C, UNICODE_NORM_QC_NO},
+	{0x1E5D, UNICODE_NORM_QC_NO},
+	{0x1E5E, UNICODE_NORM_QC_NO},
+	{0x1E5F, UNICODE_NORM_QC_NO},
+	{0x1E60, UNICODE_NORM_QC_NO},
+	{0x1E61, UNICODE_NORM_QC_NO},
+	{0x1E62, UNICODE_NORM_QC_NO},
+	{0x1E63, UNICODE_NORM_QC_NO},
+	{0x1E64, UNICODE_NORM_QC_NO},
+	{0x1E65, UNICODE_NORM_QC_NO},
+	{0x1E66, UNICODE_NORM_QC_NO},
+	{0x1E67, UNICODE_NORM_QC_NO},
+	{0x1E68, UNICODE_NORM_QC_NO},
+	{0x1E69, UNICODE_NORM_QC_NO},
+	{0x1E6A, UNICODE_NORM_QC_NO},
+	{0x1E6B, UNICODE_NORM_QC_NO},
+	{0x1E6C, UNICODE_NORM_QC_NO},
+	{0x1E6D, UNICODE_NORM_QC_NO},
+	{0x1E6E, UNICODE_NORM_QC_NO},
+	{0x1E6F, UNICODE_NORM_QC_NO},
+	{0x1E70, UNICODE_NORM_QC_NO},
+	{0x1E71, UNICODE_NORM_QC_NO},
+	{0x1E72, UNICODE_NORM_QC_NO},
+	{0x1E73, UNICODE_NORM_QC_NO},
+	{0x1E74, UNICODE_NORM_QC_NO},
+	{0x1E75, UNICODE_NORM_QC_NO},
+	{0x1E76, UNICODE_NORM_QC_NO},
+	{0x1E77, UNICODE_NORM_QC_NO},
+	{0x1E78, UNICODE_NORM_QC_NO},
+	{0x1E79, UNICODE_NORM_QC_NO},
+	{0x1E7A, UNICODE_NORM_QC_NO},
+	{0x1E7B, UNICODE_NORM_QC_NO},
+	{0x1E7C, UNICODE_NORM_QC_NO},
+	{0x1E7D, UNICODE_NORM_QC_NO},
+	{0x1E7E, UNICODE_NORM_QC_NO},
+	{0x1E7F, UNICODE_NORM_QC_NO},
+	{0x1E80, UNICODE_NORM_QC_NO},
+	{0x1E81, UNICODE_NORM_QC_NO},
+	{0x1E82, UNICODE_NORM_QC_NO},
+	{0x1E83, UNICODE_NORM_QC_NO},
+	{0x1E84, UNICODE_NORM_QC_NO},
+	{0x1E85, UNICODE_NORM_QC_NO},
+	{0x1E86, UNICODE_NORM_QC_NO},
+	{0x1E87, UNICODE_NORM_QC_NO},
+	{0x1E88, UNICODE_NORM_QC_NO},
+	{0x1E89, UNICODE_NORM_QC_NO},
+	{0x1E8A, UNICODE_NORM_QC_NO},
+	{0x1E8B, UNICODE_NORM_QC_NO},
+	{0x1E8C, UNICODE_NORM_QC_NO},
+	{0x1E8D, UNICODE_NORM_QC_NO},
+	{0x1E8E, UNICODE_NORM_QC_NO},
+	{0x1E8F, UNICODE_NORM_QC_NO},
+	{0x1E90, UNICODE_NORM_QC_NO},
+	{0x1E91, UNICODE_NORM_QC_NO},
+	{0x1E92, UNICODE_NORM_QC_NO},
+	{0x1E93, UNICODE_NORM_QC_NO},
+	{0x1E94, UNICODE_NORM_QC_NO},
+	{0x1E95, UNICODE_NORM_QC_NO},
+	{0x1E96, UNICODE_NORM_QC_NO},
+	{0x1E97, UNICODE_NORM_QC_NO},
+	{0x1E98, UNICODE_NORM_QC_NO},
+	{0x1E99, UNICODE_NORM_QC_NO},
+	{0x1E9A, UNICODE_NORM_QC_NO},
+	{0x1E9B, UNICODE_NORM_QC_NO},
+	{0x1EA0, UNICODE_NORM_QC_NO},
+	{0x1EA1, UNICODE_NORM_QC_NO},
+	{0x1EA2, UNICODE_NORM_QC_NO},
+	{0x1EA3, UNICODE_NORM_QC_NO},
+	{0x1EA4, UNICODE_NORM_QC_NO},
+	{0x1EA5, UNICODE_NORM_QC_NO},
+	{0x1EA6, UNICODE_NORM_QC_NO},
+	{0x1EA7, UNICODE_NORM_QC_NO},
+	{0x1EA8, UNICODE_NORM_QC_NO},
+	{0x1EA9, UNICODE_NORM_QC_NO},
+	{0x1EAA, UNICODE_NORM_QC_NO},
+	{0x1EAB, UNICODE_NORM_QC_NO},
+	{0x1EAC, UNICODE_NORM_QC_NO},
+	{0x1EAD, UNICODE_NORM_QC_NO},
+	{0x1EAE, UNICODE_NORM_QC_NO},
+	{0x1EAF, UNICODE_NORM_QC_NO},
+	{0x1EB0, UNICODE_NORM_QC_NO},
+	{0x1EB1, UNICODE_NORM_QC_NO},
+	{0x1EB2, UNICODE_NORM_QC_NO},
+	{0x1EB3, UNICODE_NORM_QC_NO},
+	{0x1EB4, UNICODE_NORM_QC_NO},
+	{0x1EB5, UNICODE_NORM_QC_NO},
+	{0x1EB6, UNICODE_NORM_QC_NO},
+	{0x1EB7, UNICODE_NORM_QC_NO},
+	{0x1EB8, UNICODE_NORM_QC_NO},
+	{0x1EB9, UNICODE_NORM_QC_NO},
+	{0x1EBA, UNICODE_NORM_QC_NO},
+	{0x1EBB, UNICODE_NORM_QC_NO},
+	{0x1EBC, UNICODE_NORM_QC_NO},
+	{0x1EBD, UNICODE_NORM_QC_NO},
+	{0x1EBE, UNICODE_NORM_QC_NO},
+	{0x1EBF, UNICODE_NORM_QC_NO},
+	{0x1EC0, UNICODE_NORM_QC_NO},
+	{0x1EC1, UNICODE_NORM_QC_NO},
+	{0x1EC2, UNICODE_NORM_QC_NO},
+	{0x1EC3, UNICODE_NORM_QC_NO},
+	{0x1EC4, UNICODE_NORM_QC_NO},
+	{0x1EC5, UNICODE_NORM_QC_NO},
+	{0x1EC6, UNICODE_NORM_QC_NO},
+	{0x1EC7, UNICODE_NORM_QC_NO},
+	{0x1EC8, UNICODE_NORM_QC_NO},
+	{0x1EC9, UNICODE_NORM_QC_NO},
+	{0x1ECA, UNICODE_NORM_QC_NO},
+	{0x1ECB, UNICODE_NORM_QC_NO},
+	{0x1ECC, UNICODE_NORM_QC_NO},
+	{0x1ECD, UNICODE_NORM_QC_NO},
+	{0x1ECE, UNICODE_NORM_QC_NO},
+	{0x1ECF, UNICODE_NORM_QC_NO},
+	{0x1ED0, UNICODE_NORM_QC_NO},
+	{0x1ED1, UNICODE_NORM_QC_NO},
+	{0x1ED2, UNICODE_NORM_QC_NO},
+	{0x1ED3, UNICODE_NORM_QC_NO},
+	{0x1ED4, UNICODE_NORM_QC_NO},
+	{0x1ED5, UNICODE_NORM_QC_NO},
+	{0x1ED6, UNICODE_NORM_QC_NO},
+	{0x1ED7, UNICODE_NORM_QC_NO},
+	{0x1ED8, UNICODE_NORM_QC_NO},
+	{0x1ED9, UNICODE_NORM_QC_NO},
+	{0x1EDA, UNICODE_NORM_QC_NO},
+	{0x1EDB, UNICODE_NORM_QC_NO},
+	{0x1EDC, UNICODE_NORM_QC_NO},
+	{0x1EDD, UNICODE_NORM_QC_NO},
+	{0x1EDE, UNICODE_NORM_QC_NO},
+	{0x1EDF, UNICODE_NORM_QC_NO},
+	{0x1EE0, UNICODE_NORM_QC_NO},
+	{0x1EE1, UNICODE_NORM_QC_NO},
+	{0x1EE2, UNICODE_NORM_QC_NO},
+	{0x1EE3, UNICODE_NORM_QC_NO},
+	{0x1EE4, UNICODE_NORM_QC_NO},
+	{0x1EE5, UNICODE_NORM_QC_NO},
+	{0x1EE6, UNICODE_NORM_QC_NO},
+	{0x1EE7, UNICODE_NORM_QC_NO},
+	{0x1EE8, UNICODE_NORM_QC_NO},
+	{0x1EE9, UNICODE_NORM_QC_NO},
+	{0x1EEA, UNICODE_NORM_QC_NO},
+	{0x1EEB, UNICODE_NORM_QC_NO},
+	{0x1EEC, UNICODE_NORM_QC_NO},
+	{0x1EED, UNICODE_NORM_QC_NO},
+	{0x1EEE, UNICODE_NORM_QC_NO},
+	{0x1EEF, UNICODE_NORM_QC_NO},
+	{0x1EF0, UNICODE_NORM_QC_NO},
+	{0x1EF1, UNICODE_NORM_QC_NO},
+	{0x1EF2, UNICODE_NORM_QC_NO},
+	{0x1EF3, UNICODE_NORM_QC_NO},
+	{0x1EF4, UNICODE_NORM_QC_NO},
+	{0x1EF5, UNICODE_NORM_QC_NO},
+	{0x1EF6, UNICODE_NORM_QC_NO},
+	{0x1EF7, UNICODE_NORM_QC_NO},
+	{0x1EF8, UNICODE_NORM_QC_NO},
+	{0x1EF9, UNICODE_NORM_QC_NO},
+	{0x1F00, UNICODE_NORM_QC_NO},
+	{0x1F01, UNICODE_NORM_QC_NO},
+	{0x1F02, UNICODE_NORM_QC_NO},
+	{0x1F03, UNICODE_NORM_QC_NO},
+	{0x1F04, UNICODE_NORM_QC_NO},
+	{0x1F05, UNICODE_NORM_QC_NO},
+	{0x1F06, UNICODE_NORM_QC_NO},
+	{0x1F07, UNICODE_NORM_QC_NO},
+	{0x1F08, UNICODE_NORM_QC_NO},
+	{0x1F09, UNICODE_NORM_QC_NO},
+	{0x1F0A, UNICODE_NORM_QC_NO},
+	{0x1F0B, UNICODE_NORM_QC_NO},
+	{0x1F0C, UNICODE_NORM_QC_NO},
+	{0x1F0D, UNICODE_NORM_QC_NO},
+	{0x1F0E, UNICODE_NORM_QC_NO},
+	{0x1F0F, UNICODE_NORM_QC_NO},
+	{0x1F10, UNICODE_NORM_QC_NO},
+	{0x1F11, UNICODE_NORM_QC_NO},
+	{0x1F12, UNICODE_NORM_QC_NO},
+	{0x1F13, UNICODE_NORM_QC_NO},
+	{0x1F14, UNICODE_NORM_QC_NO},
+	{0x1F15, UNICODE_NORM_QC_NO},
+	{0x1F18, UNICODE_NORM_QC_NO},
+	{0x1F19, UNICODE_NORM_QC_NO},
+	{0x1F1A, UNICODE_NORM_QC_NO},
+	{0x1F1B, UNICODE_NORM_QC_NO},
+	{0x1F1C, UNICODE_NORM_QC_NO},
+	{0x1F1D, UNICODE_NORM_QC_NO},
+	{0x1F20, UNICODE_NORM_QC_NO},
+	{0x1F21, UNICODE_NORM_QC_NO},
+	{0x1F22, UNICODE_NORM_QC_NO},
+	{0x1F23, UNICODE_NORM_QC_NO},
+	{0x1F24, UNICODE_NORM_QC_NO},
+	{0x1F25, UNICODE_NORM_QC_NO},
+	{0x1F26, UNICODE_NORM_QC_NO},
+	{0x1F27, UNICODE_NORM_QC_NO},
+	{0x1F28, UNICODE_NORM_QC_NO},
+	{0x1F29, UNICODE_NORM_QC_NO},
+	{0x1F2A, UNICODE_NORM_QC_NO},
+	{0x1F2B, UNICODE_NORM_QC_NO},
+	{0x1F2C, UNICODE_NORM_QC_NO},
+	{0x1F2D, UNICODE_NORM_QC_NO},
+	{0x1F2E, UNICODE_NORM_QC_NO},
+	{0x1F2F, UNICODE_NORM_QC_NO},
+	{0x1F30, UNICODE_NORM_QC_NO},
+	{0x1F31, UNICODE_NORM_QC_NO},
+	{0x1F32, UNICODE_NORM_QC_NO},
+	{0x1F33, UNICODE_NORM_QC_NO},
+	{0x1F34, UNICODE_NORM_QC_NO},
+	{0x1F35, UNICODE_NORM_QC_NO},
+	{0x1F36, UNICODE_NORM_QC_NO},
+	{0x1F37, UNICODE_NORM_QC_NO},
+	{0x1F38, UNICODE_NORM_QC_NO},
+	{0x1F39, UNICODE_NORM_QC_NO},
+	{0x1F3A, UNICODE_NORM_QC_NO},
+	{0x1F3B, UNICODE_NORM_QC_NO},
+	{0x1F3C, UNICODE_NORM_QC_NO},
+	{0x1F3D, UNICODE_NORM_QC_NO},
+	{0x1F3E, UNICODE_NORM_QC_NO},
+	{0x1F3F, UNICODE_NORM_QC_NO},
+	{0x1F40, UNICODE_NORM_QC_NO},
+	{0x1F41, UNICODE_NORM_QC_NO},
+	{0x1F42, UNICODE_NORM_QC_NO},
+	{0x1F43, UNICODE_NORM_QC_NO},
+	{0x1F44, UNICODE_NORM_QC_NO},
+	{0x1F45, UNICODE_NORM_QC_NO},
+	{0x1F48, UNICODE_NORM_QC_NO},
+	{0x1F49, UNICODE_NORM_QC_NO},
+	{0x1F4A, UNICODE_NORM_QC_NO},
+	{0x1F4B, UNICODE_NORM_QC_NO},
+	{0x1F4C, UNICODE_NORM_QC_NO},
+	{0x1F4D, UNICODE_NORM_QC_NO},
+	{0x1F50, UNICODE_NORM_QC_NO},
+	{0x1F51, UNICODE_NORM_QC_NO},
+	{0x1F52, UNICODE_NORM_QC_NO},
+	{0x1F53, UNICODE_NORM_QC_NO},
+	{0x1F54, UNICODE_NORM_QC_NO},
+	{0x1F55, UNICODE_NORM_QC_NO},
+	{0x1F56, UNICODE_NORM_QC_NO},
+	{0x1F57, UNICODE_NORM_QC_NO},
+	{0x1F59, UNICODE_NORM_QC_NO},
+	{0x1F5B, UNICODE_NORM_QC_NO},
+	{0x1F5D, UNICODE_NORM_QC_NO},
+	{0x1F5F, UNICODE_NORM_QC_NO},
+	{0x1F60, UNICODE_NORM_QC_NO},
+	{0x1F61, UNICODE_NORM_QC_NO},
+	{0x1F62, UNICODE_NORM_QC_NO},
+	{0x1F63, UNICODE_NORM_QC_NO},
+	{0x1F64, UNICODE_NORM_QC_NO},
+	{0x1F65, UNICODE_NORM_QC_NO},
+	{0x1F66, UNICODE_NORM_QC_NO},
+	{0x1F67, UNICODE_NORM_QC_NO},
+	{0x1F68, UNICODE_NORM_QC_NO},
+	{0x1F69, UNICODE_NORM_QC_NO},
+	{0x1F6A, UNICODE_NORM_QC_NO},
+	{0x1F6B, UNICODE_NORM_QC_NO},
+	{0x1F6C, UNICODE_NORM_QC_NO},
+	{0x1F6D, UNICODE_NORM_QC_NO},
+	{0x1F6E, UNICODE_NORM_QC_NO},
+	{0x1F6F, UNICODE_NORM_QC_NO},
+	{0x1F70, UNICODE_NORM_QC_NO},
+	{0x1F71, UNICODE_NORM_QC_NO},
+	{0x1F72, UNICODE_NORM_QC_NO},
+	{0x1F73, UNICODE_NORM_QC_NO},
+	{0x1F74, UNICODE_NORM_QC_NO},
+	{0x1F75, UNICODE_NORM_QC_NO},
+	{0x1F76, UNICODE_NORM_QC_NO},
+	{0x1F77, UNICODE_NORM_QC_NO},
+	{0x1F78, UNICODE_NORM_QC_NO},
+	{0x1F79, UNICODE_NORM_QC_NO},
+	{0x1F7A, UNICODE_NORM_QC_NO},
+	{0x1F7B, UNICODE_NORM_QC_NO},
+	{0x1F7C, UNICODE_NORM_QC_NO},
+	{0x1F7D, UNICODE_NORM_QC_NO},
+	{0x1F80, UNICODE_NORM_QC_NO},
+	{0x1F81, UNICODE_NORM_QC_NO},
+	{0x1F82, UNICODE_NORM_QC_NO},
+	{0x1F83, UNICODE_NORM_QC_NO},
+	{0x1F84, UNICODE_NORM_QC_NO},
+	{0x1F85, UNICODE_NORM_QC_NO},
+	{0x1F86, UNICODE_NORM_QC_NO},
+	{0x1F87, UNICODE_NORM_QC_NO},
+	{0x1F88, UNICODE_NORM_QC_NO},
+	{0x1F89, UNICODE_NORM_QC_NO},
+	{0x1F8A, UNICODE_NORM_QC_NO},
+	{0x1F8B, UNICODE_NORM_QC_NO},
+	{0x1F8C, UNICODE_NORM_QC_NO},
+	{0x1F8D, UNICODE_NORM_QC_NO},
+	{0x1F8E, UNICODE_NORM_QC_NO},
+	{0x1F8F, UNICODE_NORM_QC_NO},
+	{0x1F90, UNICODE_NORM_QC_NO},
+	{0x1F91, UNICODE_NORM_QC_NO},
+	{0x1F92, UNICODE_NORM_QC_NO},
+	{0x1F93, UNICODE_NORM_QC_NO},
+	{0x1F94, UNICODE_NORM_QC_NO},
+	{0x1F95, UNICODE_NORM_QC_NO},
+	{0x1F96, UNICODE_NORM_QC_NO},
+	{0x1F97, UNICODE_NORM_QC_NO},
+	{0x1F98, UNICODE_NORM_QC_NO},
+	{0x1F99, UNICODE_NORM_QC_NO},
+	{0x1F9A, UNICODE_NORM_QC_NO},
+	{0x1F9B, UNICODE_NORM_QC_NO},
+	{0x1F9C, UNICODE_NORM_QC_NO},
+	{0x1F9D, UNICODE_NORM_QC_NO},
+	{0x1F9E, UNICODE_NORM_QC_NO},
+	{0x1F9F, UNICODE_NORM_QC_NO},
+	{0x1FA0, UNICODE_NORM_QC_NO},
+	{0x1FA1, UNICODE_NORM_QC_NO},
+	{0x1FA2, UNICODE_NORM_QC_NO},
+	{0x1FA3, UNICODE_NORM_QC_NO},
+	{0x1FA4, UNICODE_NORM_QC_NO},
+	{0x1FA5, UNICODE_NORM_QC_NO},
+	{0x1FA6, UNICODE_NORM_QC_NO},
+	{0x1FA7, UNICODE_NORM_QC_NO},
+	{0x1FA8, UNICODE_NORM_QC_NO},
+	{0x1FA9, UNICODE_NORM_QC_NO},
+	{0x1FAA, UNICODE_NORM_QC_NO},
+	{0x1FAB, UNICODE_NORM_QC_NO},
+	{0x1FAC, UNICODE_NORM_QC_NO},
+	{0x1FAD, UNICODE_NORM_QC_NO},
+	{0x1FAE, UNICODE_NORM_QC_NO},
+	{0x1FAF, UNICODE_NORM_QC_NO},
+	{0x1FB0, UNICODE_NORM_QC_NO},
+	{0x1FB1, UNICODE_NORM_QC_NO},
+	{0x1FB2, UNICODE_NORM_QC_NO},
+	{0x1FB3, UNICODE_NORM_QC_NO},
+	{0x1FB4, UNICODE_NORM_QC_NO},
+	{0x1FB6, UNICODE_NORM_QC_NO},
+	{0x1FB7, UNICODE_NORM_QC_NO},
+	{0x1FB8, UNICODE_NORM_QC_NO},
+	{0x1FB9, UNICODE_NORM_QC_NO},
+	{0x1FBA, UNICODE_NORM_QC_NO},
+	{0x1FBB, UNICODE_NORM_QC_NO},
+	{0x1FBC, UNICODE_NORM_QC_NO},
+	{0x1FBD, UNICODE_NORM_QC_NO},
+	{0x1FBE, UNICODE_NORM_QC_NO},
+	{0x1FBF, UNICODE_NORM_QC_NO},
+	{0x1FC0, UNICODE_NORM_QC_NO},
+	{0x1FC1, UNICODE_NORM_QC_NO},
+	{0x1FC2, UNICODE_NORM_QC_NO},
+	{0x1FC3, UNICODE_NORM_QC_NO},
+	{0x1FC4, UNICODE_NORM_QC_NO},
+	{0x1FC6, UNICODE_NORM_QC_NO},
+	{0x1FC7, UNICODE_NORM_QC_NO},
+	{0x1FC8, UNICODE_NORM_QC_NO},
+	{0x1FC9, UNICODE_NORM_QC_NO},
+	{0x1FCA, UNICODE_NORM_QC_NO},
+	{0x1FCB, UNICODE_NORM_QC_NO},
+	{0x1FCC, UNICODE_NORM_QC_NO},
+	{0x1FCD, UNICODE_NORM_QC_NO},
+	{0x1FCE, UNICODE_NORM_QC_NO},
+	{0x1FCF, UNICODE_NORM_QC_NO},
+	{0x1FD0, UNICODE_NORM_QC_NO},
+	{0x1FD1, UNICODE_NORM_QC_NO},
+	{0x1FD2, UNICODE_NORM_QC_NO},
+	{0x1FD3, UNICODE_NORM_QC_NO},
+	{0x1FD6, UNICODE_NORM_QC_NO},
+	{0x1FD7, UNICODE_NORM_QC_NO},
+	{0x1FD8, UNICODE_NORM_QC_NO},
+	{0x1FD9, UNICODE_NORM_QC_NO},
+	{0x1FDA, UNICODE_NORM_QC_NO},
+	{0x1FDB, UNICODE_NORM_QC_NO},
+	{0x1FDD, UNICODE_NORM_QC_NO},
+	{0x1FDE, UNICODE_NORM_QC_NO},
+	{0x1FDF, UNICODE_NORM_QC_NO},
+	{0x1FE0, UNICODE_NORM_QC_NO},
+	{0x1FE1, UNICODE_NORM_QC_NO},
+	{0x1FE2, UNICODE_NORM_QC_NO},
+	{0x1FE3, UNICODE_NORM_QC_NO},
+	{0x1FE4, UNICODE_NORM_QC_NO},
+	{0x1FE5, UNICODE_NORM_QC_NO},
+	{0x1FE6, UNICODE_NORM_QC_NO},
+	{0x1FE7, UNICODE_NORM_QC_NO},
+	{0x1FE8, UNICODE_NORM_QC_NO},
+	{0x1FE9, UNICODE_NORM_QC_NO},
+	{0x1FEA, UNICODE_NORM_QC_NO},
+	{0x1FEB, UNICODE_NORM_QC_NO},
+	{0x1FEC, UNICODE_NORM_QC_NO},
+	{0x1FED, UNICODE_NORM_QC_NO},
+	{0x1FEE, UNICODE_NORM_QC_NO},
+	{0x1FEF, UNICODE_NORM_QC_NO},
+	{0x1FF2, UNICODE_NORM_QC_NO},
+	{0x1FF3, UNICODE_NORM_QC_NO},
+	{0x1FF4, UNICODE_NORM_QC_NO},
+	{0x1FF6, UNICODE_NORM_QC_NO},
+	{0x1FF7, UNICODE_NORM_QC_NO},
+	{0x1FF8, UNICODE_NORM_QC_NO},
+	{0x1FF9, UNICODE_NORM_QC_NO},
+	{0x1FFA, UNICODE_NORM_QC_NO},
+	{0x1FFB, UNICODE_NORM_QC_NO},
+	{0x1FFC, UNICODE_NORM_QC_NO},
+	{0x1FFD, UNICODE_NORM_QC_NO},
+	{0x1FFE, UNICODE_NORM_QC_NO},
+	{0x2000, UNICODE_NORM_QC_NO},
+	{0x2001, UNICODE_NORM_QC_NO},
+	{0x2002, UNICODE_NORM_QC_NO},
+	{0x2003, UNICODE_NORM_QC_NO},
+	{0x2004, UNICODE_NORM_QC_NO},
+	{0x2005, UNICODE_NORM_QC_NO},
+	{0x2006, UNICODE_NORM_QC_NO},
+	{0x2007, UNICODE_NORM_QC_NO},
+	{0x2008, UNICODE_NORM_QC_NO},
+	{0x2009, UNICODE_NORM_QC_NO},
+	{0x200A, UNICODE_NORM_QC_NO},
+	{0x2011, UNICODE_NORM_QC_NO},
+	{0x2017, UNICODE_NORM_QC_NO},
+	{0x2024, UNICODE_NORM_QC_NO},
+	{0x2025, UNICODE_NORM_QC_NO},
+	{0x2026, UNICODE_NORM_QC_NO},
+	{0x202F, UNICODE_NORM_QC_NO},
+	{0x2033, UNICODE_NORM_QC_NO},
+	{0x2034, UNICODE_NORM_QC_NO},
+	{0x2036, UNICODE_NORM_QC_NO},
+	{0x2037, UNICODE_NORM_QC_NO},
+	{0x203C, UNICODE_NORM_QC_NO},
+	{0x203E, UNICODE_NORM_QC_NO},
+	{0x2047, UNICODE_NORM_QC_NO},
+	{0x2048, UNICODE_NORM_QC_NO},
+	{0x2049, UNICODE_NORM_QC_NO},
+	{0x2057, UNICODE_NORM_QC_NO},
+	{0x205F, UNICODE_NORM_QC_NO},
+	{0x2070, UNICODE_NORM_QC_NO},
+	{0x2071, UNICODE_NORM_QC_NO},
+	{0x2074, UNICODE_NORM_QC_NO},
+	{0x2075, UNICODE_NORM_QC_NO},
+	{0x2076, UNICODE_NORM_QC_NO},
+	{0x2077, UNICODE_NORM_QC_NO},
+	{0x2078, UNICODE_NORM_QC_NO},
+	{0x2079, UNICODE_NORM_QC_NO},
+	{0x207A, UNICODE_NORM_QC_NO},
+	{0x207B, UNICODE_NORM_QC_NO},
+	{0x207C, UNICODE_NORM_QC_NO},
+	{0x207D, UNICODE_NORM_QC_NO},
+	{0x207E, UNICODE_NORM_QC_NO},
+	{0x207F, UNICODE_NORM_QC_NO},
+	{0x2080, UNICODE_NORM_QC_NO},
+	{0x2081, UNICODE_NORM_QC_NO},
+	{0x2082, UNICODE_NORM_QC_NO},
+	{0x2083, UNICODE_NORM_QC_NO},
+	{0x2084, UNICODE_NORM_QC_NO},
+	{0x2085, UNICODE_NORM_QC_NO},
+	{0x2086, UNICODE_NORM_QC_NO},
+	{0x2087, UNICODE_NORM_QC_NO},
+	{0x2088, UNICODE_NORM_QC_NO},
+	{0x2089, UNICODE_NORM_QC_NO},
+	{0x208A, UNICODE_NORM_QC_NO},
+	{0x208B, UNICODE_NORM_QC_NO},
+	{0x208C, UNICODE_NORM_QC_NO},
+	{0x208D, UNICODE_NORM_QC_NO},
+	{0x208E, UNICODE_NORM_QC_NO},
+	{0x2090, UNICODE_NORM_QC_NO},
+	{0x2091, UNICODE_NORM_QC_NO},
+	{0x2092, UNICODE_NORM_QC_NO},
+	{0x2093, UNICODE_NORM_QC_NO},
+	{0x2094, UNICODE_NORM_QC_NO},
+	{0x2095, UNICODE_NORM_QC_NO},
+	{0x2096, UNICODE_NORM_QC_NO},
+	{0x2097, UNICODE_NORM_QC_NO},
+	{0x2098, UNICODE_NORM_QC_NO},
+	{0x2099, UNICODE_NORM_QC_NO},
+	{0x209A, UNICODE_NORM_QC_NO},
+	{0x209B, UNICODE_NORM_QC_NO},
+	{0x209C, UNICODE_NORM_QC_NO},
+	{0x20A8, UNICODE_NORM_QC_NO},
+	{0x2100, UNICODE_NORM_QC_NO},
+	{0x2101, UNICODE_NORM_QC_NO},
+	{0x2102, UNICODE_NORM_QC_NO},
+	{0x2103, UNICODE_NORM_QC_NO},
+	{0x2105, UNICODE_NORM_QC_NO},
+	{0x2106, UNICODE_NORM_QC_NO},
+	{0x2107, UNICODE_NORM_QC_NO},
+	{0x2109, UNICODE_NORM_QC_NO},
+	{0x210A, UNICODE_NORM_QC_NO},
+	{0x210B, UNICODE_NORM_QC_NO},
+	{0x210C, UNICODE_NORM_QC_NO},
+	{0x210D, UNICODE_NORM_QC_NO},
+	{0x210E, UNICODE_NORM_QC_NO},
+	{0x210F, UNICODE_NORM_QC_NO},
+	{0x2110, UNICODE_NORM_QC_NO},
+	{0x2111, UNICODE_NORM_QC_NO},
+	{0x2112, UNICODE_NORM_QC_NO},
+	{0x2113, UNICODE_NORM_QC_NO},
+	{0x2115, UNICODE_NORM_QC_NO},
+	{0x2116, UNICODE_NORM_QC_NO},
+	{0x2119, UNICODE_NORM_QC_NO},
+	{0x211A, UNICODE_NORM_QC_NO},
+	{0x211B, UNICODE_NORM_QC_NO},
+	{0x211C, UNICODE_NORM_QC_NO},
+	{0x211D, UNICODE_NORM_QC_NO},
+	{0x2120, UNICODE_NORM_QC_NO},
+	{0x2121, UNICODE_NORM_QC_NO},
+	{0x2122, UNICODE_NORM_QC_NO},
+	{0x2124, UNICODE_NORM_QC_NO},
+	{0x2126, UNICODE_NORM_QC_NO},
+	{0x2128, UNICODE_NORM_QC_NO},
+	{0x212A, UNICODE_NORM_QC_NO},
+	{0x212B, UNICODE_NORM_QC_NO},
+	{0x212C, UNICODE_NORM_QC_NO},
+	{0x212D, UNICODE_NORM_QC_NO},
+	{0x212F, UNICODE_NORM_QC_NO},
+	{0x2130, UNICODE_NORM_QC_NO},
+	{0x2131, UNICODE_NORM_QC_NO},
+	{0x2133, UNICODE_NORM_QC_NO},
+	{0x2134, UNICODE_NORM_QC_NO},
+	{0x2135, UNICODE_NORM_QC_NO},
+	{0x2136, UNICODE_NORM_QC_NO},
+	{0x2137, UNICODE_NORM_QC_NO},
+	{0x2138, UNICODE_NORM_QC_NO},
+	{0x2139, UNICODE_NORM_QC_NO},
+	{0x213B, UNICODE_NORM_QC_NO},
+	{0x213C, UNICODE_NORM_QC_NO},
+	{0x213D, UNICODE_NORM_QC_NO},
+	{0x213E, UNICODE_NORM_QC_NO},
+	{0x213F, UNICODE_NORM_QC_NO},
+	{0x2140, UNICODE_NORM_QC_NO},
+	{0x2145, UNICODE_NORM_QC_NO},
+	{0x2146, UNICODE_NORM_QC_NO},
+	{0x2147, UNICODE_NORM_QC_NO},
+	{0x2148, UNICODE_NORM_QC_NO},
+	{0x2149, UNICODE_NORM_QC_NO},
+	{0x2150, UNICODE_NORM_QC_NO},
+	{0x2151, UNICODE_NORM_QC_NO},
+	{0x2152, UNICODE_NORM_QC_NO},
+	{0x2153, UNICODE_NORM_QC_NO},
+	{0x2154, UNICODE_NORM_QC_NO},
+	{0x2155, UNICODE_NORM_QC_NO},
+	{0x2156, UNICODE_NORM_QC_NO},
+	{0x2157, UNICODE_NORM_QC_NO},
+	{0x2158, UNICODE_NORM_QC_NO},
+	{0x2159, UNICODE_NORM_QC_NO},
+	{0x215A, UNICODE_NORM_QC_NO},
+	{0x215B, UNICODE_NORM_QC_NO},
+	{0x215C, UNICODE_NORM_QC_NO},
+	{0x215D, UNICODE_NORM_QC_NO},
+	{0x215E, UNICODE_NORM_QC_NO},
+	{0x215F, UNICODE_NORM_QC_NO},
+	{0x2160, UNICODE_NORM_QC_NO},
+	{0x2161, UNICODE_NORM_QC_NO},
+	{0x2162, UNICODE_NORM_QC_NO},
+	{0x2163, UNICODE_NORM_QC_NO},
+	{0x2164, UNICODE_NORM_QC_NO},
+	{0x2165, UNICODE_NORM_QC_NO},
+	{0x2166, UNICODE_NORM_QC_NO},
+	{0x2167, UNICODE_NORM_QC_NO},
+	{0x2168, UNICODE_NORM_QC_NO},
+	{0x2169, UNICODE_NORM_QC_NO},
+	{0x216A, UNICODE_NORM_QC_NO},
+	{0x216B, UNICODE_NORM_QC_NO},
+	{0x216C, UNICODE_NORM_QC_NO},
+	{0x216D, UNICODE_NORM_QC_NO},
+	{0x216E, UNICODE_NORM_QC_NO},
+	{0x216F, UNICODE_NORM_QC_NO},
+	{0x2170, UNICODE_NORM_QC_NO},
+	{0x2171, UNICODE_NORM_QC_NO},
+	{0x2172, UNICODE_NORM_QC_NO},
+	{0x2173, UNICODE_NORM_QC_NO},
+	{0x2174, UNICODE_NORM_QC_NO},
+	{0x2175, UNICODE_NORM_QC_NO},
+	{0x2176, UNICODE_NORM_QC_NO},
+	{0x2177, UNICODE_NORM_QC_NO},
+	{0x2178, UNICODE_NORM_QC_NO},
+	{0x2179, UNICODE_NORM_QC_NO},
+	{0x217A, UNICODE_NORM_QC_NO},
+	{0x217B, UNICODE_NORM_QC_NO},
+	{0x217C, UNICODE_NORM_QC_NO},
+	{0x217D, UNICODE_NORM_QC_NO},
+	{0x217E, UNICODE_NORM_QC_NO},
+	{0x217F, UNICODE_NORM_QC_NO},
+	{0x2189, UNICODE_NORM_QC_NO},
+	{0x219A, UNICODE_NORM_QC_NO},
+	{0x219B, UNICODE_NORM_QC_NO},
+	{0x21AE, UNICODE_NORM_QC_NO},
+	{0x21CD, UNICODE_NORM_QC_NO},
+	{0x21CE, UNICODE_NORM_QC_NO},
+	{0x21CF, UNICODE_NORM_QC_NO},
+	{0x2204, UNICODE_NORM_QC_NO},
+	{0x2209, UNICODE_NORM_QC_NO},
+	{0x220C, UNICODE_NORM_QC_NO},
+	{0x2224, UNICODE_NORM_QC_NO},
+	{0x2226, UNICODE_NORM_QC_NO},
+	{0x222C, UNICODE_NORM_QC_NO},
+	{0x222D, UNICODE_NORM_QC_NO},
+	{0x222F, UNICODE_NORM_QC_NO},
+	{0x2230, UNICODE_NORM_QC_NO},
+	{0x2241, UNICODE_NORM_QC_NO},
+	{0x2244, UNICODE_NORM_QC_NO},
+	{0x2247, UNICODE_NORM_QC_NO},
+	{0x2249, UNICODE_NORM_QC_NO},
+	{0x2260, UNICODE_NORM_QC_NO},
+	{0x2262, UNICODE_NORM_QC_NO},
+	{0x226D, UNICODE_NORM_QC_NO},
+	{0x226E, UNICODE_NORM_QC_NO},
+	{0x226F, UNICODE_NORM_QC_NO},
+	{0x2270, UNICODE_NORM_QC_NO},
+	{0x2271, UNICODE_NORM_QC_NO},
+	{0x2274, UNICODE_NORM_QC_NO},
+	{0x2275, UNICODE_NORM_QC_NO},
+	{0x2278, UNICODE_NORM_QC_NO},
+	{0x2279, UNICODE_NORM_QC_NO},
+	{0x2280, UNICODE_NORM_QC_NO},
+	{0x2281, UNICODE_NORM_QC_NO},
+	{0x2284, UNICODE_NORM_QC_NO},
+	{0x2285, UNICODE_NORM_QC_NO},
+	{0x2288, UNICODE_NORM_QC_NO},
+	{0x2289, UNICODE_NORM_QC_NO},
+	{0x22AC, UNICODE_NORM_QC_NO},
+	{0x22AD, UNICODE_NORM_QC_NO},
+	{0x22AE, UNICODE_NORM_QC_NO},
+	{0x22AF, UNICODE_NORM_QC_NO},
+	{0x22E0, UNICODE_NORM_QC_NO},
+	{0x22E1, UNICODE_NORM_QC_NO},
+	{0x22E2, UNICODE_NORM_QC_NO},
+	{0x22E3, UNICODE_NORM_QC_NO},
+	{0x22EA, UNICODE_NORM_QC_NO},
+	{0x22EB, UNICODE_NORM_QC_NO},
+	{0x22EC, UNICODE_NORM_QC_NO},
+	{0x22ED, UNICODE_NORM_QC_NO},
+	{0x2329, UNICODE_NORM_QC_NO},
+	{0x232A, UNICODE_NORM_QC_NO},
+	{0x2460, UNICODE_NORM_QC_NO},
+	{0x2461, UNICODE_NORM_QC_NO},
+	{0x2462, UNICODE_NORM_QC_NO},
+	{0x2463, UNICODE_NORM_QC_NO},
+	{0x2464, UNICODE_NORM_QC_NO},
+	{0x2465, UNICODE_NORM_QC_NO},
+	{0x2466, UNICODE_NORM_QC_NO},
+	{0x2467, UNICODE_NORM_QC_NO},
+	{0x2468, UNICODE_NORM_QC_NO},
+	{0x2469, UNICODE_NORM_QC_NO},
+	{0x246A, UNICODE_NORM_QC_NO},
+	{0x246B, UNICODE_NORM_QC_NO},
+	{0x246C, UNICODE_NORM_QC_NO},
+	{0x246D, UNICODE_NORM_QC_NO},
+	{0x246E, UNICODE_NORM_QC_NO},
+	{0x246F, UNICODE_NORM_QC_NO},
+	{0x2470, UNICODE_NORM_QC_NO},
+	{0x2471, UNICODE_NORM_QC_NO},
+	{0x2472, UNICODE_NORM_QC_NO},
+	{0x2473, UNICODE_NORM_QC_NO},
+	{0x2474, UNICODE_NORM_QC_NO},
+	{0x2475, UNICODE_NORM_QC_NO},
+	{0x2476, UNICODE_NORM_QC_NO},
+	{0x2477, UNICODE_NORM_QC_NO},
+	{0x2478, UNICODE_NORM_QC_NO},
+	{0x2479, UNICODE_NORM_QC_NO},
+	{0x247A, UNICODE_NORM_QC_NO},
+	{0x247B, UNICODE_NORM_QC_NO},
+	{0x247C, UNICODE_NORM_QC_NO},
+	{0x247D, UNICODE_NORM_QC_NO},
+	{0x247E, UNICODE_NORM_QC_NO},
+	{0x247F, UNICODE_NORM_QC_NO},
+	{0x2480, UNICODE_NORM_QC_NO},
+	{0x2481, UNICODE_NORM_QC_NO},
+	{0x2482, UNICODE_NORM_QC_NO},
+	{0x2483, UNICODE_NORM_QC_NO},
+	{0x2484, UNICODE_NORM_QC_NO},
+	{0x2485, UNICODE_NORM_QC_NO},
+	{0x2486, UNICODE_NORM_QC_NO},
+	{0x2487, UNICODE_NORM_QC_NO},
+	{0x2488, UNICODE_NORM_QC_NO},
+	{0x2489, UNICODE_NORM_QC_NO},
+	{0x248A, UNICODE_NORM_QC_NO},
+	{0x248B, UNICODE_NORM_QC_NO},
+	{0x248C, UNICODE_NORM_QC_NO},
+	{0x248D, UNICODE_NORM_QC_NO},
+	{0x248E, UNICODE_NORM_QC_NO},
+	{0x248F, UNICODE_NORM_QC_NO},
+	{0x2490, UNICODE_NORM_QC_NO},
+	{0x2491, UNICODE_NORM_QC_NO},
+	{0x2492, UNICODE_NORM_QC_NO},
+	{0x2493, UNICODE_NORM_QC_NO},
+	{0x2494, UNICODE_NORM_QC_NO},
+	{0x2495, UNICODE_NORM_QC_NO},
+	{0x2496, UNICODE_NORM_QC_NO},
+	{0x2497, UNICODE_NORM_QC_NO},
+	{0x2498, UNICODE_NORM_QC_NO},
+	{0x2499, UNICODE_NORM_QC_NO},
+	{0x249A, UNICODE_NORM_QC_NO},
+	{0x249B, UNICODE_NORM_QC_NO},
+	{0x249C, UNICODE_NORM_QC_NO},
+	{0x249D, UNICODE_NORM_QC_NO},
+	{0x249E, UNICODE_NORM_QC_NO},
+	{0x249F, UNICODE_NORM_QC_NO},
+	{0x24A0, UNICODE_NORM_QC_NO},
+	{0x24A1, UNICODE_NORM_QC_NO},
+	{0x24A2, UNICODE_NORM_QC_NO},
+	{0x24A3, UNICODE_NORM_QC_NO},
+	{0x24A4, UNICODE_NORM_QC_NO},
+	{0x24A5, UNICODE_NORM_QC_NO},
+	{0x24A6, UNICODE_NORM_QC_NO},
+	{0x24A7, UNICODE_NORM_QC_NO},
+	{0x24A8, UNICODE_NORM_QC_NO},
+	{0x24A9, UNICODE_NORM_QC_NO},
+	{0x24AA, UNICODE_NORM_QC_NO},
+	{0x24AB, UNICODE_NORM_QC_NO},
+	{0x24AC, UNICODE_NORM_QC_NO},
+	{0x24AD, UNICODE_NORM_QC_NO},
+	{0x24AE, UNICODE_NORM_QC_NO},
+	{0x24AF, UNICODE_NORM_QC_NO},
+	{0x24B0, UNICODE_NORM_QC_NO},
+	{0x24B1, UNICODE_NORM_QC_NO},
+	{0x24B2, UNICODE_NORM_QC_NO},
+	{0x24B3, UNICODE_NORM_QC_NO},
+	{0x24B4, UNICODE_NORM_QC_NO},
+	{0x24B5, UNICODE_NORM_QC_NO},
+	{0x24B6, UNICODE_NORM_QC_NO},
+	{0x24B7, UNICODE_NORM_QC_NO},
+	{0x24B8, UNICODE_NORM_QC_NO},
+	{0x24B9, UNICODE_NORM_QC_NO},
+	{0x24BA, UNICODE_NORM_QC_NO},
+	{0x24BB, UNICODE_NORM_QC_NO},
+	{0x24BC, UNICODE_NORM_QC_NO},
+	{0x24BD, UNICODE_NORM_QC_NO},
+	{0x24BE, UNICODE_NORM_QC_NO},
+	{0x24BF, UNICODE_NORM_QC_NO},
+	{0x24C0, UNICODE_NORM_QC_NO},
+	{0x24C1, UNICODE_NORM_QC_NO},
+	{0x24C2, UNICODE_NORM_QC_NO},
+	{0x24C3, UNICODE_NORM_QC_NO},
+	{0x24C4, UNICODE_NORM_QC_NO},
+	{0x24C5, UNICODE_NORM_QC_NO},
+	{0x24C6, UNICODE_NORM_QC_NO},
+	{0x24C7, UNICODE_NORM_QC_NO},
+	{0x24C8, UNICODE_NORM_QC_NO},
+	{0x24C9, UNICODE_NORM_QC_NO},
+	{0x24CA, UNICODE_NORM_QC_NO},
+	{0x24CB, UNICODE_NORM_QC_NO},
+	{0x24CC, UNICODE_NORM_QC_NO},
+	{0x24CD, UNICODE_NORM_QC_NO},
+	{0x24CE, UNICODE_NORM_QC_NO},
+	{0x24CF, UNICODE_NORM_QC_NO},
+	{0x24D0, UNICODE_NORM_QC_NO},
+	{0x24D1, UNICODE_NORM_QC_NO},
+	{0x24D2, UNICODE_NORM_QC_NO},
+	{0x24D3, UNICODE_NORM_QC_NO},
+	{0x24D4, UNICODE_NORM_QC_NO},
+	{0x24D5, UNICODE_NORM_QC_NO},
+	{0x24D6, UNICODE_NORM_QC_NO},
+	{0x24D7, UNICODE_NORM_QC_NO},
+	{0x24D8, UNICODE_NORM_QC_NO},
+	{0x24D9, UNICODE_NORM_QC_NO},
+	{0x24DA, UNICODE_NORM_QC_NO},
+	{0x24DB, UNICODE_NORM_QC_NO},
+	{0x24DC, UNICODE_NORM_QC_NO},
+	{0x24DD, UNICODE_NORM_QC_NO},
+	{0x24DE, UNICODE_NORM_QC_NO},
+	{0x24DF, UNICODE_NORM_QC_NO},
+	{0x24E0, UNICODE_NORM_QC_NO},
+	{0x24E1, UNICODE_NORM_QC_NO},
+	{0x24E2, UNICODE_NORM_QC_NO},
+	{0x24E3, UNICODE_NORM_QC_NO},
+	{0x24E4, UNICODE_NORM_QC_NO},
+	{0x24E5, UNICODE_NORM_QC_NO},
+	{0x24E6, UNICODE_NORM_QC_NO},
+	{0x24E7, UNICODE_NORM_QC_NO},
+	{0x24E8, UNICODE_NORM_QC_NO},
+	{0x24E9, UNICODE_NORM_QC_NO},
+	{0x24EA, UNICODE_NORM_QC_NO},
+	{0x2A0C, UNICODE_NORM_QC_NO},
+	{0x2A74, UNICODE_NORM_QC_NO},
+	{0x2A75, UNICODE_NORM_QC_NO},
+	{0x2A76, UNICODE_NORM_QC_NO},
+	{0x2ADC, UNICODE_NORM_QC_NO},
+	{0x2C7C, UNICODE_NORM_QC_NO},
+	{0x2C7D, UNICODE_NORM_QC_NO},
+	{0x2D6F, UNICODE_NORM_QC_NO},
+	{0x2E9F, UNICODE_NORM_QC_NO},
+	{0x2EF3, UNICODE_NORM_QC_NO},
+	{0x2F00, UNICODE_NORM_QC_NO},
+	{0x2F01, UNICODE_NORM_QC_NO},
+	{0x2F02, UNICODE_NORM_QC_NO},
+	{0x2F03, UNICODE_NORM_QC_NO},
+	{0x2F04, UNICODE_NORM_QC_NO},
+	{0x2F05, UNICODE_NORM_QC_NO},
+	{0x2F06, UNICODE_NORM_QC_NO},
+	{0x2F07, UNICODE_NORM_QC_NO},
+	{0x2F08, UNICODE_NORM_QC_NO},
+	{0x2F09, UNICODE_NORM_QC_NO},
+	{0x2F0A, UNICODE_NORM_QC_NO},
+	{0x2F0B, UNICODE_NORM_QC_NO},
+	{0x2F0C, UNICODE_NORM_QC_NO},
+	{0x2F0D, UNICODE_NORM_QC_NO},
+	{0x2F0E, UNICODE_NORM_QC_NO},
+	{0x2F0F, UNICODE_NORM_QC_NO},
+	{0x2F10, UNICODE_NORM_QC_NO},
+	{0x2F11, UNICODE_NORM_QC_NO},
+	{0x2F12, UNICODE_NORM_QC_NO},
+	{0x2F13, UNICODE_NORM_QC_NO},
+	{0x2F14, UNICODE_NORM_QC_NO},
+	{0x2F15, UNICODE_NORM_QC_NO},
+	{0x2F16, UNICODE_NORM_QC_NO},
+	{0x2F17, UNICODE_NORM_QC_NO},
+	{0x2F18, UNICODE_NORM_QC_NO},
+	{0x2F19, UNICODE_NORM_QC_NO},
+	{0x2F1A, UNICODE_NORM_QC_NO},
+	{0x2F1B, UNICODE_NORM_QC_NO},
+	{0x2F1C, UNICODE_NORM_QC_NO},
+	{0x2F1D, UNICODE_NORM_QC_NO},
+	{0x2F1E, UNICODE_NORM_QC_NO},
+	{0x2F1F, UNICODE_NORM_QC_NO},
+	{0x2F20, UNICODE_NORM_QC_NO},
+	{0x2F21, UNICODE_NORM_QC_NO},
+	{0x2F22, UNICODE_NORM_QC_NO},
+	{0x2F23, UNICODE_NORM_QC_NO},
+	{0x2F24, UNICODE_NORM_QC_NO},
+	{0x2F25, UNICODE_NORM_QC_NO},
+	{0x2F26, UNICODE_NORM_QC_NO},
+	{0x2F27, UNICODE_NORM_QC_NO},
+	{0x2F28, UNICODE_NORM_QC_NO},
+	{0x2F29, UNICODE_NORM_QC_NO},
+	{0x2F2A, UNICODE_NORM_QC_NO},
+	{0x2F2B, UNICODE_NORM_QC_NO},
+	{0x2F2C, UNICODE_NORM_QC_NO},
+	{0x2F2D, UNICODE_NORM_QC_NO},
+	{0x2F2E, UNICODE_NORM_QC_NO},
+	{0x2F2F, UNICODE_NORM_QC_NO},
+	{0x2F30, UNICODE_NORM_QC_NO},
+	{0x2F31, UNICODE_NORM_QC_NO},
+	{0x2F32, UNICODE_NORM_QC_NO},
+	{0x2F33, UNICODE_NORM_QC_NO},
+	{0x2F34, UNICODE_NORM_QC_NO},
+	{0x2F35, UNICODE_NORM_QC_NO},
+	{0x2F36, UNICODE_NORM_QC_NO},
+	{0x2F37, UNICODE_NORM_QC_NO},
+	{0x2F38, UNICODE_NORM_QC_NO},
+	{0x2F39, UNICODE_NORM_QC_NO},
+	{0x2F3A, UNICODE_NORM_QC_NO},
+	{0x2F3B, UNICODE_NORM_QC_NO},
+	{0x2F3C, UNICODE_NORM_QC_NO},
+	{0x2F3D, UNICODE_NORM_QC_NO},
+	{0x2F3E, UNICODE_NORM_QC_NO},
+	{0x2F3F, UNICODE_NORM_QC_NO},
+	{0x2F40, UNICODE_NORM_QC_NO},
+	{0x2F41, UNICODE_NORM_QC_NO},
+	{0x2F42, UNICODE_NORM_QC_NO},
+	{0x2F43, UNICODE_NORM_QC_NO},
+	{0x2F44, UNICODE_NORM_QC_NO},
+	{0x2F45, UNICODE_NORM_QC_NO},
+	{0x2F46, UNICODE_NORM_QC_NO},
+	{0x2F47, UNICODE_NORM_QC_NO},
+	{0x2F48, UNICODE_NORM_QC_NO},
+	{0x2F49, UNICODE_NORM_QC_NO},
+	{0x2F4A, UNICODE_NORM_QC_NO},
+	{0x2F4B, UNICODE_NORM_QC_NO},
+	{0x2F4C, UNICODE_NORM_QC_NO},
+	{0x2F4D, UNICODE_NORM_QC_NO},
+	{0x2F4E, UNICODE_NORM_QC_NO},
+	{0x2F4F, UNICODE_NORM_QC_NO},
+	{0x2F50, UNICODE_NORM_QC_NO},
+	{0x2F51, UNICODE_NORM_QC_NO},
+	{0x2F52, UNICODE_NORM_QC_NO},
+	{0x2F53, UNICODE_NORM_QC_NO},
+	{0x2F54, UNICODE_NORM_QC_NO},
+	{0x2F55, UNICODE_NORM_QC_NO},
+	{0x2F56, UNICODE_NORM_QC_NO},
+	{0x2F57, UNICODE_NORM_QC_NO},
+	{0x2F58, UNICODE_NORM_QC_NO},
+	{0x2F59, UNICODE_NORM_QC_NO},
+	{0x2F5A, UNICODE_NORM_QC_NO},
+	{0x2F5B, UNICODE_NORM_QC_NO},
+	{0x2F5C, UNICODE_NORM_QC_NO},
+	{0x2F5D, UNICODE_NORM_QC_NO},
+	{0x2F5E, UNICODE_NORM_QC_NO},
+	{0x2F5F, UNICODE_NORM_QC_NO},
+	{0x2F60, UNICODE_NORM_QC_NO},
+	{0x2F61, UNICODE_NORM_QC_NO},
+	{0x2F62, UNICODE_NORM_QC_NO},
+	{0x2F63, UNICODE_NORM_QC_NO},
+	{0x2F64, UNICODE_NORM_QC_NO},
+	{0x2F65, UNICODE_NORM_QC_NO},
+	{0x2F66, UNICODE_NORM_QC_NO},
+	{0x2F67, UNICODE_NORM_QC_NO},
+	{0x2F68, UNICODE_NORM_QC_NO},
+	{0x2F69, UNICODE_NORM_QC_NO},
+	{0x2F6A, UNICODE_NORM_QC_NO},
+	{0x2F6B, UNICODE_NORM_QC_NO},
+	{0x2F6C, UNICODE_NORM_QC_NO},
+	{0x2F6D, UNICODE_NORM_QC_NO},
+	{0x2F6E, UNICODE_NORM_QC_NO},
+	{0x2F6F, UNICODE_NORM_QC_NO},
+	{0x2F70, UNICODE_NORM_QC_NO},
+	{0x2F71, UNICODE_NORM_QC_NO},
+	{0x2F72, UNICODE_NORM_QC_NO},
+	{0x2F73, UNICODE_NORM_QC_NO},
+	{0x2F74, UNICODE_NORM_QC_NO},
+	{0x2F75, UNICODE_NORM_QC_NO},
+	{0x2F76, UNICODE_NORM_QC_NO},
+	{0x2F77, UNICODE_NORM_QC_NO},
+	{0x2F78, UNICODE_NORM_QC_NO},
+	{0x2F79, UNICODE_NORM_QC_NO},
+	{0x2F7A, UNICODE_NORM_QC_NO},
+	{0x2F7B, UNICODE_NORM_QC_NO},
+	{0x2F7C, UNICODE_NORM_QC_NO},
+	{0x2F7D, UNICODE_NORM_QC_NO},
+	{0x2F7E, UNICODE_NORM_QC_NO},
+	{0x2F7F, UNICODE_NORM_QC_NO},
+	{0x2F80, UNICODE_NORM_QC_NO},
+	{0x2F81, UNICODE_NORM_QC_NO},
+	{0x2F82, UNICODE_NORM_QC_NO},
+	{0x2F83, UNICODE_NORM_QC_NO},
+	{0x2F84, UNICODE_NORM_QC_NO},
+	{0x2F85, UNICODE_NORM_QC_NO},
+	{0x2F86, UNICODE_NORM_QC_NO},
+	{0x2F87, UNICODE_NORM_QC_NO},
+	{0x2F88, UNICODE_NORM_QC_NO},
+	{0x2F89, UNICODE_NORM_QC_NO},
+	{0x2F8A, UNICODE_NORM_QC_NO},
+	{0x2F8B, UNICODE_NORM_QC_NO},
+	{0x2F8C, UNICODE_NORM_QC_NO},
+	{0x2F8D, UNICODE_NORM_QC_NO},
+	{0x2F8E, UNICODE_NORM_QC_NO},
+	{0x2F8F, UNICODE_NORM_QC_NO},
+	{0x2F90, UNICODE_NORM_QC_NO},
+	{0x2F91, UNICODE_NORM_QC_NO},
+	{0x2F92, UNICODE_NORM_QC_NO},
+	{0x2F93, UNICODE_NORM_QC_NO},
+	{0x2F94, UNICODE_NORM_QC_NO},
+	{0x2F95, UNICODE_NORM_QC_NO},
+	{0x2F96, UNICODE_NORM_QC_NO},
+	{0x2F97, UNICODE_NORM_QC_NO},
+	{0x2F98, UNICODE_NORM_QC_NO},
+	{0x2F99, UNICODE_NORM_QC_NO},
+	{0x2F9A, UNICODE_NORM_QC_NO},
+	{0x2F9B, UNICODE_NORM_QC_NO},
+	{0x2F9C, UNICODE_NORM_QC_NO},
+	{0x2F9D, UNICODE_NORM_QC_NO},
+	{0x2F9E, UNICODE_NORM_QC_NO},
+	{0x2F9F, UNICODE_NORM_QC_NO},
+	{0x2FA0, UNICODE_NORM_QC_NO},
+	{0x2FA1, UNICODE_NORM_QC_NO},
+	{0x2FA2, UNICODE_NORM_QC_NO},
+	{0x2FA3, UNICODE_NORM_QC_NO},
+	{0x2FA4, UNICODE_NORM_QC_NO},
+	{0x2FA5, UNICODE_NORM_QC_NO},
+	{0x2FA6, UNICODE_NORM_QC_NO},
+	{0x2FA7, UNICODE_NORM_QC_NO},
+	{0x2FA8, UNICODE_NORM_QC_NO},
+	{0x2FA9, UNICODE_NORM_QC_NO},
+	{0x2FAA, UNICODE_NORM_QC_NO},
+	{0x2FAB, UNICODE_NORM_QC_NO},
+	{0x2FAC, UNICODE_NORM_QC_NO},
+	{0x2FAD, UNICODE_NORM_QC_NO},
+	{0x2FAE, UNICODE_NORM_QC_NO},
+	{0x2FAF, UNICODE_NORM_QC_NO},
+	{0x2FB0, UNICODE_NORM_QC_NO},
+	{0x2FB1, UNICODE_NORM_QC_NO},
+	{0x2FB2, UNICODE_NORM_QC_NO},
+	{0x2FB3, UNICODE_NORM_QC_NO},
+	{0x2FB4, UNICODE_NORM_QC_NO},
+	{0x2FB5, UNICODE_NORM_QC_NO},
+	{0x2FB6, UNICODE_NORM_QC_NO},
+	{0x2FB7, UNICODE_NORM_QC_NO},
+	{0x2FB8, UNICODE_NORM_QC_NO},
+	{0x2FB9, UNICODE_NORM_QC_NO},
+	{0x2FBA, UNICODE_NORM_QC_NO},
+	{0x2FBB, UNICODE_NORM_QC_NO},
+	{0x2FBC, UNICODE_NORM_QC_NO},
+	{0x2FBD, UNICODE_NORM_QC_NO},
+	{0x2FBE, UNICODE_NORM_QC_NO},
+	{0x2FBF, UNICODE_NORM_QC_NO},
+	{0x2FC0, UNICODE_NORM_QC_NO},
+	{0x2FC1, UNICODE_NORM_QC_NO},
+	{0x2FC2, UNICODE_NORM_QC_NO},
+	{0x2FC3, UNICODE_NORM_QC_NO},
+	{0x2FC4, UNICODE_NORM_QC_NO},
+	{0x2FC5, UNICODE_NORM_QC_NO},
+	{0x2FC6, UNICODE_NORM_QC_NO},
+	{0x2FC7, UNICODE_NORM_QC_NO},
+	{0x2FC8, UNICODE_NORM_QC_NO},
+	{0x2FC9, UNICODE_NORM_QC_NO},
+	{0x2FCA, UNICODE_NORM_QC_NO},
+	{0x2FCB, UNICODE_NORM_QC_NO},
+	{0x2FCC, UNICODE_NORM_QC_NO},
+	{0x2FCD, UNICODE_NORM_QC_NO},
+	{0x2FCE, UNICODE_NORM_QC_NO},
+	{0x2FCF, UNICODE_NORM_QC_NO},
+	{0x2FD0, UNICODE_NORM_QC_NO},
+	{0x2FD1, UNICODE_NORM_QC_NO},
+	{0x2FD2, UNICODE_NORM_QC_NO},
+	{0x2FD3, UNICODE_NORM_QC_NO},
+	{0x2FD4, UNICODE_NORM_QC_NO},
+	{0x2FD5, UNICODE_NORM_QC_NO},
+	{0x3000, UNICODE_NORM_QC_NO},
+	{0x3036, UNICODE_NORM_QC_NO},
+	{0x3038, UNICODE_NORM_QC_NO},
+	{0x3039, UNICODE_NORM_QC_NO},
+	{0x303A, UNICODE_NORM_QC_NO},
+	{0x304C, UNICODE_NORM_QC_NO},
+	{0x304E, UNICODE_NORM_QC_NO},
+	{0x3050, UNICODE_NORM_QC_NO},
+	{0x3052, UNICODE_NORM_QC_NO},
+	{0x3054, UNICODE_NORM_QC_NO},
+	{0x3056, UNICODE_NORM_QC_NO},
+	{0x3058, UNICODE_NORM_QC_NO},
+	{0x305A, UNICODE_NORM_QC_NO},
+	{0x305C, UNICODE_NORM_QC_NO},
+	{0x305E, UNICODE_NORM_QC_NO},
+	{0x3060, UNICODE_NORM_QC_NO},
+	{0x3062, UNICODE_NORM_QC_NO},
+	{0x3065, UNICODE_NORM_QC_NO},
+	{0x3067, UNICODE_NORM_QC_NO},
+	{0x3069, UNICODE_NORM_QC_NO},
+	{0x3070, UNICODE_NORM_QC_NO},
+	{0x3071, UNICODE_NORM_QC_NO},
+	{0x3073, UNICODE_NORM_QC_NO},
+	{0x3074, UNICODE_NORM_QC_NO},
+	{0x3076, UNICODE_NORM_QC_NO},
+	{0x3077, UNICODE_NORM_QC_NO},
+	{0x3079, UNICODE_NORM_QC_NO},
+	{0x307A, UNICODE_NORM_QC_NO},
+	{0x307C, UNICODE_NORM_QC_NO},
+	{0x307D, UNICODE_NORM_QC_NO},
+	{0x3094, UNICODE_NORM_QC_NO},
+	{0x309B, UNICODE_NORM_QC_NO},
+	{0x309C, UNICODE_NORM_QC_NO},
+	{0x309E, UNICODE_NORM_QC_NO},
+	{0x309F, UNICODE_NORM_QC_NO},
+	{0x30AC, UNICODE_NORM_QC_NO},
+	{0x30AE, UNICODE_NORM_QC_NO},
+	{0x30B0, UNICODE_NORM_QC_NO},
+	{0x30B2, UNICODE_NORM_QC_NO},
+	{0x30B4, UNICODE_NORM_QC_NO},
+	{0x30B6, UNICODE_NORM_QC_NO},
+	{0x30B8, UNICODE_NORM_QC_NO},
+	{0x30BA, UNICODE_NORM_QC_NO},
+	{0x30BC, UNICODE_NORM_QC_NO},
+	{0x30BE, UNICODE_NORM_QC_NO},
+	{0x30C0, UNICODE_NORM_QC_NO},
+	{0x30C2, UNICODE_NORM_QC_NO},
+	{0x30C5, UNICODE_NORM_QC_NO},
+	{0x30C7, UNICODE_NORM_QC_NO},
+	{0x30C9, UNICODE_NORM_QC_NO},
+	{0x30D0, UNICODE_NORM_QC_NO},
+	{0x30D1, UNICODE_NORM_QC_NO},
+	{0x30D3, UNICODE_NORM_QC_NO},
+	{0x30D4, UNICODE_NORM_QC_NO},
+	{0x30D6, UNICODE_NORM_QC_NO},
+	{0x30D7, UNICODE_NORM_QC_NO},
+	{0x30D9, UNICODE_NORM_QC_NO},
+	{0x30DA, UNICODE_NORM_QC_NO},
+	{0x30DC, UNICODE_NORM_QC_NO},
+	{0x30DD, UNICODE_NORM_QC_NO},
+	{0x30F4, UNICODE_NORM_QC_NO},
+	{0x30F7, UNICODE_NORM_QC_NO},
+	{0x30F8, UNICODE_NORM_QC_NO},
+	{0x30F9, UNICODE_NORM_QC_NO},
+	{0x30FA, UNICODE_NORM_QC_NO},
+	{0x30FE, UNICODE_NORM_QC_NO},
+	{0x30FF, UNICODE_NORM_QC_NO},
+	{0x3131, UNICODE_NORM_QC_NO},
+	{0x3132, UNICODE_NORM_QC_NO},
+	{0x3133, UNICODE_NORM_QC_NO},
+	{0x3134, UNICODE_NORM_QC_NO},
+	{0x3135, UNICODE_NORM_QC_NO},
+	{0x3136, UNICODE_NORM_QC_NO},
+	{0x3137, UNICODE_NORM_QC_NO},
+	{0x3138, UNICODE_NORM_QC_NO},
+	{0x3139, UNICODE_NORM_QC_NO},
+	{0x313A, UNICODE_NORM_QC_NO},
+	{0x313B, UNICODE_NORM_QC_NO},
+	{0x313C, UNICODE_NORM_QC_NO},
+	{0x313D, UNICODE_NORM_QC_NO},
+	{0x313E, UNICODE_NORM_QC_NO},
+	{0x313F, UNICODE_NORM_QC_NO},
+	{0x3140, UNICODE_NORM_QC_NO},
+	{0x3141, UNICODE_NORM_QC_NO},
+	{0x3142, UNICODE_NORM_QC_NO},
+	{0x3143, UNICODE_NORM_QC_NO},
+	{0x3144, UNICODE_NORM_QC_NO},
+	{0x3145, UNICODE_NORM_QC_NO},
+	{0x3146, UNICODE_NORM_QC_NO},
+	{0x3147, UNICODE_NORM_QC_NO},
+	{0x3148, UNICODE_NORM_QC_NO},
+	{0x3149, UNICODE_NORM_QC_NO},
+	{0x314A, UNICODE_NORM_QC_NO},
+	{0x314B, UNICODE_NORM_QC_NO},
+	{0x314C, UNICODE_NORM_QC_NO},
+	{0x314D, UNICODE_NORM_QC_NO},
+	{0x314E, UNICODE_NORM_QC_NO},
+	{0x314F, UNICODE_NORM_QC_NO},
+	{0x3150, UNICODE_NORM_QC_NO},
+	{0x3151, UNICODE_NORM_QC_NO},
+	{0x3152, UNICODE_NORM_QC_NO},
+	{0x3153, UNICODE_NORM_QC_NO},
+	{0x3154, UNICODE_NORM_QC_NO},
+	{0x3155, UNICODE_NORM_QC_NO},
+	{0x3156, UNICODE_NORM_QC_NO},
+	{0x3157, UNICODE_NORM_QC_NO},
+	{0x3158, UNICODE_NORM_QC_NO},
+	{0x3159, UNICODE_NORM_QC_NO},
+	{0x315A, UNICODE_NORM_QC_NO},
+	{0x315B, UNICODE_NORM_QC_NO},
+	{0x315C, UNICODE_NORM_QC_NO},
+	{0x315D, UNICODE_NORM_QC_NO},
+	{0x315E, UNICODE_NORM_QC_NO},
+	{0x315F, UNICODE_NORM_QC_NO},
+	{0x3160, UNICODE_NORM_QC_NO},
+	{0x3161, UNICODE_NORM_QC_NO},
+	{0x3162, UNICODE_NORM_QC_NO},
+	{0x3163, UNICODE_NORM_QC_NO},
+	{0x3164, UNICODE_NORM_QC_NO},
+	{0x3165, UNICODE_NORM_QC_NO},
+	{0x3166, UNICODE_NORM_QC_NO},
+	{0x3167, UNICODE_NORM_QC_NO},
+	{0x3168, UNICODE_NORM_QC_NO},
+	{0x3169, UNICODE_NORM_QC_NO},
+	{0x316A, UNICODE_NORM_QC_NO},
+	{0x316B, UNICODE_NORM_QC_NO},
+	{0x316C, UNICODE_NORM_QC_NO},
+	{0x316D, UNICODE_NORM_QC_NO},
+	{0x316E, UNICODE_NORM_QC_NO},
+	{0x316F, UNICODE_NORM_QC_NO},
+	{0x3170, UNICODE_NORM_QC_NO},
+	{0x3171, UNICODE_NORM_QC_NO},
+	{0x3172, UNICODE_NORM_QC_NO},
+	{0x3173, UNICODE_NORM_QC_NO},
+	{0x3174, UNICODE_NORM_QC_NO},
+	{0x3175, UNICODE_NORM_QC_NO},
+	{0x3176, UNICODE_NORM_QC_NO},
+	{0x3177, UNICODE_NORM_QC_NO},
+	{0x3178, UNICODE_NORM_QC_NO},
+	{0x3179, UNICODE_NORM_QC_NO},
+	{0x317A, UNICODE_NORM_QC_NO},
+	{0x317B, UNICODE_NORM_QC_NO},
+	{0x317C, UNICODE_NORM_QC_NO},
+	{0x317D, UNICODE_NORM_QC_NO},
+	{0x317E, UNICODE_NORM_QC_NO},
+	{0x317F, UNICODE_NORM_QC_NO},
+	{0x3180, UNICODE_NORM_QC_NO},
+	{0x3181, UNICODE_NORM_QC_NO},
+	{0x3182, UNICODE_NORM_QC_NO},
+	{0x3183, UNICODE_NORM_QC_NO},
+	{0x3184, UNICODE_NORM_QC_NO},
+	{0x3185, UNICODE_NORM_QC_NO},
+	{0x3186, UNICODE_NORM_QC_NO},
+	{0x3187, UNICODE_NORM_QC_NO},
+	{0x3188, UNICODE_NORM_QC_NO},
+	{0x3189, UNICODE_NORM_QC_NO},
+	{0x318A, UNICODE_NORM_QC_NO},
+	{0x318B, UNICODE_NORM_QC_NO},
+	{0x318C, UNICODE_NORM_QC_NO},
+	{0x318D, UNICODE_NORM_QC_NO},
+	{0x318E, UNICODE_NORM_QC_NO},
+	{0x3192, UNICODE_NORM_QC_NO},
+	{0x3193, UNICODE_NORM_QC_NO},
+	{0x3194, UNICODE_NORM_QC_NO},
+	{0x3195, UNICODE_NORM_QC_NO},
+	{0x3196, UNICODE_NORM_QC_NO},
+	{0x3197, UNICODE_NORM_QC_NO},
+	{0x3198, UNICODE_NORM_QC_NO},
+	{0x3199, UNICODE_NORM_QC_NO},
+	{0x319A, UNICODE_NORM_QC_NO},
+	{0x319B, UNICODE_NORM_QC_NO},
+	{0x319C, UNICODE_NORM_QC_NO},
+	{0x319D, UNICODE_NORM_QC_NO},
+	{0x319E, UNICODE_NORM_QC_NO},
+	{0x319F, UNICODE_NORM_QC_NO},
+	{0x3200, UNICODE_NORM_QC_NO},
+	{0x3201, UNICODE_NORM_QC_NO},
+	{0x3202, UNICODE_NORM_QC_NO},
+	{0x3203, UNICODE_NORM_QC_NO},
+	{0x3204, UNICODE_NORM_QC_NO},
+	{0x3205, UNICODE_NORM_QC_NO},
+	{0x3206, UNICODE_NORM_QC_NO},
+	{0x3207, UNICODE_NORM_QC_NO},
+	{0x3208, UNICODE_NORM_QC_NO},
+	{0x3209, UNICODE_NORM_QC_NO},
+	{0x320A, UNICODE_NORM_QC_NO},
+	{0x320B, UNICODE_NORM_QC_NO},
+	{0x320C, UNICODE_NORM_QC_NO},
+	{0x320D, UNICODE_NORM_QC_NO},
+	{0x320E, UNICODE_NORM_QC_NO},
+	{0x320F, UNICODE_NORM_QC_NO},
+	{0x3210, UNICODE_NORM_QC_NO},
+	{0x3211, UNICODE_NORM_QC_NO},
+	{0x3212, UNICODE_NORM_QC_NO},
+	{0x3213, UNICODE_NORM_QC_NO},
+	{0x3214, UNICODE_NORM_QC_NO},
+	{0x3215, UNICODE_NORM_QC_NO},
+	{0x3216, UNICODE_NORM_QC_NO},
+	{0x3217, UNICODE_NORM_QC_NO},
+	{0x3218, UNICODE_NORM_QC_NO},
+	{0x3219, UNICODE_NORM_QC_NO},
+	{0x321A, UNICODE_NORM_QC_NO},
+	{0x321B, UNICODE_NORM_QC_NO},
+	{0x321C, UNICODE_NORM_QC_NO},
+	{0x321D, UNICODE_NORM_QC_NO},
+	{0x321E, UNICODE_NORM_QC_NO},
+	{0x3220, UNICODE_NORM_QC_NO},
+	{0x3221, UNICODE_NORM_QC_NO},
+	{0x3222, UNICODE_NORM_QC_NO},
+	{0x3223, UNICODE_NORM_QC_NO},
+	{0x3224, UNICODE_NORM_QC_NO},
+	{0x3225, UNICODE_NORM_QC_NO},
+	{0x3226, UNICODE_NORM_QC_NO},
+	{0x3227, UNICODE_NORM_QC_NO},
+	{0x3228, UNICODE_NORM_QC_NO},
+	{0x3229, UNICODE_NORM_QC_NO},
+	{0x322A, UNICODE_NORM_QC_NO},
+	{0x322B, UNICODE_NORM_QC_NO},
+	{0x322C, UNICODE_NORM_QC_NO},
+	{0x322D, UNICODE_NORM_QC_NO},
+	{0x322E, UNICODE_NORM_QC_NO},
+	{0x322F, UNICODE_NORM_QC_NO},
+	{0x3230, UNICODE_NORM_QC_NO},
+	{0x3231, UNICODE_NORM_QC_NO},
+	{0x3232, UNICODE_NORM_QC_NO},
+	{0x3233, UNICODE_NORM_QC_NO},
+	{0x3234, UNICODE_NORM_QC_NO},
+	{0x3235, UNICODE_NORM_QC_NO},
+	{0x3236, UNICODE_NORM_QC_NO},
+	{0x3237, UNICODE_NORM_QC_NO},
+	{0x3238, UNICODE_NORM_QC_NO},
+	{0x3239, UNICODE_NORM_QC_NO},
+	{0x323A, UNICODE_NORM_QC_NO},
+	{0x323B, UNICODE_NORM_QC_NO},
+	{0x323C, UNICODE_NORM_QC_NO},
+	{0x323D, UNICODE_NORM_QC_NO},
+	{0x323E, UNICODE_NORM_QC_NO},
+	{0x323F, UNICODE_NORM_QC_NO},
+	{0x3240, UNICODE_NORM_QC_NO},
+	{0x3241, UNICODE_NORM_QC_NO},
+	{0x3242, UNICODE_NORM_QC_NO},
+	{0x3243, UNICODE_NORM_QC_NO},
+	{0x3244, UNICODE_NORM_QC_NO},
+	{0x3245, UNICODE_NORM_QC_NO},
+	{0x3246, UNICODE_NORM_QC_NO},
+	{0x3247, UNICODE_NORM_QC_NO},
+	{0x3250, UNICODE_NORM_QC_NO},
+	{0x3251, UNICODE_NORM_QC_NO},
+	{0x3252, UNICODE_NORM_QC_NO},
+	{0x3253, UNICODE_NORM_QC_NO},
+	{0x3254, UNICODE_NORM_QC_NO},
+	{0x3255, UNICODE_NORM_QC_NO},
+	{0x3256, UNICODE_NORM_QC_NO},
+	{0x3257, UNICODE_NORM_QC_NO},
+	{0x3258, UNICODE_NORM_QC_NO},
+	{0x3259, UNICODE_NORM_QC_NO},
+	{0x325A, UNICODE_NORM_QC_NO},
+	{0x325B, UNICODE_NORM_QC_NO},
+	{0x325C, UNICODE_NORM_QC_NO},
+	{0x325D, UNICODE_NORM_QC_NO},
+	{0x325E, UNICODE_NORM_QC_NO},
+	{0x325F, UNICODE_NORM_QC_NO},
+	{0x3260, UNICODE_NORM_QC_NO},
+	{0x3261, UNICODE_NORM_QC_NO},
+	{0x3262, UNICODE_NORM_QC_NO},
+	{0x3263, UNICODE_NORM_QC_NO},
+	{0x3264, UNICODE_NORM_QC_NO},
+	{0x3265, UNICODE_NORM_QC_NO},
+	{0x3266, UNICODE_NORM_QC_NO},
+	{0x3267, UNICODE_NORM_QC_NO},
+	{0x3268, UNICODE_NORM_QC_NO},
+	{0x3269, UNICODE_NORM_QC_NO},
+	{0x326A, UNICODE_NORM_QC_NO},
+	{0x326B, UNICODE_NORM_QC_NO},
+	{0x326C, UNICODE_NORM_QC_NO},
+	{0x326D, UNICODE_NORM_QC_NO},
+	{0x326E, UNICODE_NORM_QC_NO},
+	{0x326F, UNICODE_NORM_QC_NO},
+	{0x3270, UNICODE_NORM_QC_NO},
+	{0x3271, UNICODE_NORM_QC_NO},
+	{0x3272, UNICODE_NORM_QC_NO},
+	{0x3273, UNICODE_NORM_QC_NO},
+	{0x3274, UNICODE_NORM_QC_NO},
+	{0x3275, UNICODE_NORM_QC_NO},
+	{0x3276, UNICODE_NORM_QC_NO},
+	{0x3277, UNICODE_NORM_QC_NO},
+	{0x3278, UNICODE_NORM_QC_NO},
+	{0x3279, UNICODE_NORM_QC_NO},
+	{0x327A, UNICODE_NORM_QC_NO},
+	{0x327B, UNICODE_NORM_QC_NO},
+	{0x327C, UNICODE_NORM_QC_NO},
+	{0x327D, UNICODE_NORM_QC_NO},
+	{0x327E, UNICODE_NORM_QC_NO},
+	{0x3280, UNICODE_NORM_QC_NO},
+	{0x3281, UNICODE_NORM_QC_NO},
+	{0x3282, UNICODE_NORM_QC_NO},
+	{0x3283, UNICODE_NORM_QC_NO},
+	{0x3284, UNICODE_NORM_QC_NO},
+	{0x3285, UNICODE_NORM_QC_NO},
+	{0x3286, UNICODE_NORM_QC_NO},
+	{0x3287, UNICODE_NORM_QC_NO},
+	{0x3288, UNICODE_NORM_QC_NO},
+	{0x3289, UNICODE_NORM_QC_NO},
+	{0x328A, UNICODE_NORM_QC_NO},
+	{0x328B, UNICODE_NORM_QC_NO},
+	{0x328C, UNICODE_NORM_QC_NO},
+	{0x328D, UNICODE_NORM_QC_NO},
+	{0x328E, UNICODE_NORM_QC_NO},
+	{0x328F, UNICODE_NORM_QC_NO},
+	{0x3290, UNICODE_NORM_QC_NO},
+	{0x3291, UNICODE_NORM_QC_NO},
+	{0x3292, UNICODE_NORM_QC_NO},
+	{0x3293, UNICODE_NORM_QC_NO},
+	{0x3294, UNICODE_NORM_QC_NO},
+	{0x3295, UNICODE_NORM_QC_NO},
+	{0x3296, UNICODE_NORM_QC_NO},
+	{0x3297, UNICODE_NORM_QC_NO},
+	{0x3298, UNICODE_NORM_QC_NO},
+	{0x3299, UNICODE_NORM_QC_NO},
+	{0x329A, UNICODE_NORM_QC_NO},
+	{0x329B, UNICODE_NORM_QC_NO},
+	{0x329C, UNICODE_NORM_QC_NO},
+	{0x329D, UNICODE_NORM_QC_NO},
+	{0x329E, UNICODE_NORM_QC_NO},
+	{0x329F, UNICODE_NORM_QC_NO},
+	{0x32A0, UNICODE_NORM_QC_NO},
+	{0x32A1, UNICODE_NORM_QC_NO},
+	{0x32A2, UNICODE_NORM_QC_NO},
+	{0x32A3, UNICODE_NORM_QC_NO},
+	{0x32A4, UNICODE_NORM_QC_NO},
+	{0x32A5, UNICODE_NORM_QC_NO},
+	{0x32A6, UNICODE_NORM_QC_NO},
+	{0x32A7, UNICODE_NORM_QC_NO},
+	{0x32A8, UNICODE_NORM_QC_NO},
+	{0x32A9, UNICODE_NORM_QC_NO},
+	{0x32AA, UNICODE_NORM_QC_NO},
+	{0x32AB, UNICODE_NORM_QC_NO},
+	{0x32AC, UNICODE_NORM_QC_NO},
+	{0x32AD, UNICODE_NORM_QC_NO},
+	{0x32AE, UNICODE_NORM_QC_NO},
+	{0x32AF, UNICODE_NORM_QC_NO},
+	{0x32B0, UNICODE_NORM_QC_NO},
+	{0x32B1, UNICODE_NORM_QC_NO},
+	{0x32B2, UNICODE_NORM_QC_NO},
+	{0x32B3, UNICODE_NORM_QC_NO},
+	{0x32B4, UNICODE_NORM_QC_NO},
+	{0x32B5, UNICODE_NORM_QC_NO},
+	{0x32B6, UNICODE_NORM_QC_NO},
+	{0x32B7, UNICODE_NORM_QC_NO},
+	{0x32B8, UNICODE_NORM_QC_NO},
+	{0x32B9, UNICODE_NORM_QC_NO},
+	{0x32BA, UNICODE_NORM_QC_NO},
+	{0x32BB, UNICODE_NORM_QC_NO},
+	{0x32BC, UNICODE_NORM_QC_NO},
+	{0x32BD, UNICODE_NORM_QC_NO},
+	{0x32BE, UNICODE_NORM_QC_NO},
+	{0x32BF, UNICODE_NORM_QC_NO},
+	{0x32C0, UNICODE_NORM_QC_NO},
+	{0x32C1, UNICODE_NORM_QC_NO},
+	{0x32C2, UNICODE_NORM_QC_NO},
+	{0x32C3, UNICODE_NORM_QC_NO},
+	{0x32C4, UNICODE_NORM_QC_NO},
+	{0x32C5, UNICODE_NORM_QC_NO},
+	{0x32C6, UNICODE_NORM_QC_NO},
+	{0x32C7, UNICODE_NORM_QC_NO},
+	{0x32C8, UNICODE_NORM_QC_NO},
+	{0x32C9, UNICODE_NORM_QC_NO},
+	{0x32CA, UNICODE_NORM_QC_NO},
+	{0x32CB, UNICODE_NORM_QC_NO},
+	{0x32CC, UNICODE_NORM_QC_NO},
+	{0x32CD, UNICODE_NORM_QC_NO},
+	{0x32CE, UNICODE_NORM_QC_NO},
+	{0x32CF, UNICODE_NORM_QC_NO},
+	{0x32D0, UNICODE_NORM_QC_NO},
+	{0x32D1, UNICODE_NORM_QC_NO},
+	{0x32D2, UNICODE_NORM_QC_NO},
+	{0x32D3, UNICODE_NORM_QC_NO},
+	{0x32D4, UNICODE_NORM_QC_NO},
+	{0x32D5, UNICODE_NORM_QC_NO},
+	{0x32D6, UNICODE_NORM_QC_NO},
+	{0x32D7, UNICODE_NORM_QC_NO},
+	{0x32D8, UNICODE_NORM_QC_NO},
+	{0x32D9, UNICODE_NORM_QC_NO},
+	{0x32DA, UNICODE_NORM_QC_NO},
+	{0x32DB, UNICODE_NORM_QC_NO},
+	{0x32DC, UNICODE_NORM_QC_NO},
+	{0x32DD, UNICODE_NORM_QC_NO},
+	{0x32DE, UNICODE_NORM_QC_NO},
+	{0x32DF, UNICODE_NORM_QC_NO},
+	{0x32E0, UNICODE_NORM_QC_NO},
+	{0x32E1, UNICODE_NORM_QC_NO},
+	{0x32E2, UNICODE_NORM_QC_NO},
+	{0x32E3, UNICODE_NORM_QC_NO},
+	{0x32E4, UNICODE_NORM_QC_NO},
+	{0x32E5, UNICODE_NORM_QC_NO},
+	{0x32E6, UNICODE_NORM_QC_NO},
+	{0x32E7, UNICODE_NORM_QC_NO},
+	{0x32E8, UNICODE_NORM_QC_NO},
+	{0x32E9, UNICODE_NORM_QC_NO},
+	{0x32EA, UNICODE_NORM_QC_NO},
+	{0x32EB, UNICODE_NORM_QC_NO},
+	{0x32EC, UNICODE_NORM_QC_NO},
+	{0x32ED, UNICODE_NORM_QC_NO},
+	{0x32EE, UNICODE_NORM_QC_NO},
+	{0x32EF, UNICODE_NORM_QC_NO},
+	{0x32F0, UNICODE_NORM_QC_NO},
+	{0x32F1, UNICODE_NORM_QC_NO},
+	{0x32F2, UNICODE_NORM_QC_NO},
+	{0x32F3, UNICODE_NORM_QC_NO},
+	{0x32F4, UNICODE_NORM_QC_NO},
+	{0x32F5, UNICODE_NORM_QC_NO},
+	{0x32F6, UNICODE_NORM_QC_NO},
+	{0x32F7, UNICODE_NORM_QC_NO},
+	{0x32F8, UNICODE_NORM_QC_NO},
+	{0x32F9, UNICODE_NORM_QC_NO},
+	{0x32FA, UNICODE_NORM_QC_NO},
+	{0x32FB, UNICODE_NORM_QC_NO},
+	{0x32FC, UNICODE_NORM_QC_NO},
+	{0x32FD, UNICODE_NORM_QC_NO},
+	{0x32FE, UNICODE_NORM_QC_NO},
+	{0x32FF, UNICODE_NORM_QC_NO},
+	{0x3300, UNICODE_NORM_QC_NO},
+	{0x3301, UNICODE_NORM_QC_NO},
+	{0x3302, UNICODE_NORM_QC_NO},
+	{0x3303, UNICODE_NORM_QC_NO},
+	{0x3304, UNICODE_NORM_QC_NO},
+	{0x3305, UNICODE_NORM_QC_NO},
+	{0x3306, UNICODE_NORM_QC_NO},
+	{0x3307, UNICODE_NORM_QC_NO},
+	{0x3308, UNICODE_NORM_QC_NO},
+	{0x3309, UNICODE_NORM_QC_NO},
+	{0x330A, UNICODE_NORM_QC_NO},
+	{0x330B, UNICODE_NORM_QC_NO},
+	{0x330C, UNICODE_NORM_QC_NO},
+	{0x330D, UNICODE_NORM_QC_NO},
+	{0x330E, UNICODE_NORM_QC_NO},
+	{0x330F, UNICODE_NORM_QC_NO},
+	{0x3310, UNICODE_NORM_QC_NO},
+	{0x3311, UNICODE_NORM_QC_NO},
+	{0x3312, UNICODE_NORM_QC_NO},
+	{0x3313, UNICODE_NORM_QC_NO},
+	{0x3314, UNICODE_NORM_QC_NO},
+	{0x3315, UNICODE_NORM_QC_NO},
+	{0x3316, UNICODE_NORM_QC_NO},
+	{0x3317, UNICODE_NORM_QC_NO},
+	{0x3318, UNICODE_NORM_QC_NO},
+	{0x3319, UNICODE_NORM_QC_NO},
+	{0x331A, UNICODE_NORM_QC_NO},
+	{0x331B, UNICODE_NORM_QC_NO},
+	{0x331C, UNICODE_NORM_QC_NO},
+	{0x331D, UNICODE_NORM_QC_NO},
+	{0x331E, UNICODE_NORM_QC_NO},
+	{0x331F, UNICODE_NORM_QC_NO},
+	{0x3320, UNICODE_NORM_QC_NO},
+	{0x3321, UNICODE_NORM_QC_NO},
+	{0x3322, UNICODE_NORM_QC_NO},
+	{0x3323, UNICODE_NORM_QC_NO},
+	{0x3324, UNICODE_NORM_QC_NO},
+	{0x3325, UNICODE_NORM_QC_NO},
+	{0x3326, UNICODE_NORM_QC_NO},
+	{0x3327, UNICODE_NORM_QC_NO},
+	{0x3328, UNICODE_NORM_QC_NO},
+	{0x3329, UNICODE_NORM_QC_NO},
+	{0x332A, UNICODE_NORM_QC_NO},
+	{0x332B, UNICODE_NORM_QC_NO},
+	{0x332C, UNICODE_NORM_QC_NO},
+	{0x332D, UNICODE_NORM_QC_NO},
+	{0x332E, UNICODE_NORM_QC_NO},
+	{0x332F, UNICODE_NORM_QC_NO},
+	{0x3330, UNICODE_NORM_QC_NO},
+	{0x3331, UNICODE_NORM_QC_NO},
+	{0x3332, UNICODE_NORM_QC_NO},
+	{0x3333, UNICODE_NORM_QC_NO},
+	{0x3334, UNICODE_NORM_QC_NO},
+	{0x3335, UNICODE_NORM_QC_NO},
+	{0x3336, UNICODE_NORM_QC_NO},
+	{0x3337, UNICODE_NORM_QC_NO},
+	{0x3338, UNICODE_NORM_QC_NO},
+	{0x3339, UNICODE_NORM_QC_NO},
+	{0x333A, UNICODE_NORM_QC_NO},
+	{0x333B, UNICODE_NORM_QC_NO},
+	{0x333C, UNICODE_NORM_QC_NO},
+	{0x333D, UNICODE_NORM_QC_NO},
+	{0x333E, UNICODE_NORM_QC_NO},
+	{0x333F, UNICODE_NORM_QC_NO},
+	{0x3340, UNICODE_NORM_QC_NO},
+	{0x3341, UNICODE_NORM_QC_NO},
+	{0x3342, UNICODE_NORM_QC_NO},
+	{0x3343, UNICODE_NORM_QC_NO},
+	{0x3344, UNICODE_NORM_QC_NO},
+	{0x3345, UNICODE_NORM_QC_NO},
+	{0x3346, UNICODE_NORM_QC_NO},
+	{0x3347, UNICODE_NORM_QC_NO},
+	{0x3348, UNICODE_NORM_QC_NO},
+	{0x3349, UNICODE_NORM_QC_NO},
+	{0x334A, UNICODE_NORM_QC_NO},
+	{0x334B, UNICODE_NORM_QC_NO},
+	{0x334C, UNICODE_NORM_QC_NO},
+	{0x334D, UNICODE_NORM_QC_NO},
+	{0x334E, UNICODE_NORM_QC_NO},
+	{0x334F, UNICODE_NORM_QC_NO},
+	{0x3350, UNICODE_NORM_QC_NO},
+	{0x3351, UNICODE_NORM_QC_NO},
+	{0x3352, UNICODE_NORM_QC_NO},
+	{0x3353, UNICODE_NORM_QC_NO},
+	{0x3354, UNICODE_NORM_QC_NO},
+	{0x3355, UNICODE_NORM_QC_NO},
+	{0x3356, UNICODE_NORM_QC_NO},
+	{0x3357, UNICODE_NORM_QC_NO},
+	{0x3358, UNICODE_NORM_QC_NO},
+	{0x3359, UNICODE_NORM_QC_NO},
+	{0x335A, UNICODE_NORM_QC_NO},
+	{0x335B, UNICODE_NORM_QC_NO},
+	{0x335C, UNICODE_NORM_QC_NO},
+	{0x335D, UNICODE_NORM_QC_NO},
+	{0x335E, UNICODE_NORM_QC_NO},
+	{0x335F, UNICODE_NORM_QC_NO},
+	{0x3360, UNICODE_NORM_QC_NO},
+	{0x3361, UNICODE_NORM_QC_NO},
+	{0x3362, UNICODE_NORM_QC_NO},
+	{0x3363, UNICODE_NORM_QC_NO},
+	{0x3364, UNICODE_NORM_QC_NO},
+	{0x3365, UNICODE_NORM_QC_NO},
+	{0x3366, UNICODE_NORM_QC_NO},
+	{0x3367, UNICODE_NORM_QC_NO},
+	{0x3368, UNICODE_NORM_QC_NO},
+	{0x3369, UNICODE_NORM_QC_NO},
+	{0x336A, UNICODE_NORM_QC_NO},
+	{0x336B, UNICODE_NORM_QC_NO},
+	{0x336C, UNICODE_NORM_QC_NO},
+	{0x336D, UNICODE_NORM_QC_NO},
+	{0x336E, UNICODE_NORM_QC_NO},
+	{0x336F, UNICODE_NORM_QC_NO},
+	{0x3370, UNICODE_NORM_QC_NO},
+	{0x3371, UNICODE_NORM_QC_NO},
+	{0x3372, UNICODE_NORM_QC_NO},
+	{0x3373, UNICODE_NORM_QC_NO},
+	{0x3374, UNICODE_NORM_QC_NO},
+	{0x3375, UNICODE_NORM_QC_NO},
+	{0x3376, UNICODE_NORM_QC_NO},
+	{0x3377, UNICODE_NORM_QC_NO},
+	{0x3378, UNICODE_NORM_QC_NO},
+	{0x3379, UNICODE_NORM_QC_NO},
+	{0x337A, UNICODE_NORM_QC_NO},
+	{0x337B, UNICODE_NORM_QC_NO},
+	{0x337C, UNICODE_NORM_QC_NO},
+	{0x337D, UNICODE_NORM_QC_NO},
+	{0x337E, UNICODE_NORM_QC_NO},
+	{0x337F, UNICODE_NORM_QC_NO},
+	{0x3380, UNICODE_NORM_QC_NO},
+	{0x3381, UNICODE_NORM_QC_NO},
+	{0x3382, UNICODE_NORM_QC_NO},
+	{0x3383, UNICODE_NORM_QC_NO},
+	{0x3384, UNICODE_NORM_QC_NO},
+	{0x3385, UNICODE_NORM_QC_NO},
+	{0x3386, UNICODE_NORM_QC_NO},
+	{0x3387, UNICODE_NORM_QC_NO},
+	{0x3388, UNICODE_NORM_QC_NO},
+	{0x3389, UNICODE_NORM_QC_NO},
+	{0x338A, UNICODE_NORM_QC_NO},
+	{0x338B, UNICODE_NORM_QC_NO},
+	{0x338C, UNICODE_NORM_QC_NO},
+	{0x338D, UNICODE_NORM_QC_NO},
+	{0x338E, UNICODE_NORM_QC_NO},
+	{0x338F, UNICODE_NORM_QC_NO},
+	{0x3390, UNICODE_NORM_QC_NO},
+	{0x3391, UNICODE_NORM_QC_NO},
+	{0x3392, UNICODE_NORM_QC_NO},
+	{0x3393, UNICODE_NORM_QC_NO},
+	{0x3394, UNICODE_NORM_QC_NO},
+	{0x3395, UNICODE_NORM_QC_NO},
+	{0x3396, UNICODE_NORM_QC_NO},
+	{0x3397, UNICODE_NORM_QC_NO},
+	{0x3398, UNICODE_NORM_QC_NO},
+	{0x3399, UNICODE_NORM_QC_NO},
+	{0x339A, UNICODE_NORM_QC_NO},
+	{0x339B, UNICODE_NORM_QC_NO},
+	{0x339C, UNICODE_NORM_QC_NO},
+	{0x339D, UNICODE_NORM_QC_NO},
+	{0x339E, UNICODE_NORM_QC_NO},
+	{0x339F, UNICODE_NORM_QC_NO},
+	{0x33A0, UNICODE_NORM_QC_NO},
+	{0x33A1, UNICODE_NORM_QC_NO},
+	{0x33A2, UNICODE_NORM_QC_NO},
+	{0x33A3, UNICODE_NORM_QC_NO},
+	{0x33A4, UNICODE_NORM_QC_NO},
+	{0x33A5, UNICODE_NORM_QC_NO},
+	{0x33A6, UNICODE_NORM_QC_NO},
+	{0x33A7, UNICODE_NORM_QC_NO},
+	{0x33A8, UNICODE_NORM_QC_NO},
+	{0x33A9, UNICODE_NORM_QC_NO},
+	{0x33AA, UNICODE_NORM_QC_NO},
+	{0x33AB, UNICODE_NORM_QC_NO},
+	{0x33AC, UNICODE_NORM_QC_NO},
+	{0x33AD, UNICODE_NORM_QC_NO},
+	{0x33AE, UNICODE_NORM_QC_NO},
+	{0x33AF, UNICODE_NORM_QC_NO},
+	{0x33B0, UNICODE_NORM_QC_NO},
+	{0x33B1, UNICODE_NORM_QC_NO},
+	{0x33B2, UNICODE_NORM_QC_NO},
+	{0x33B3, UNICODE_NORM_QC_NO},
+	{0x33B4, UNICODE_NORM_QC_NO},
+	{0x33B5, UNICODE_NORM_QC_NO},
+	{0x33B6, UNICODE_NORM_QC_NO},
+	{0x33B7, UNICODE_NORM_QC_NO},
+	{0x33B8, UNICODE_NORM_QC_NO},
+	{0x33B9, UNICODE_NORM_QC_NO},
+	{0x33BA, UNICODE_NORM_QC_NO},
+	{0x33BB, UNICODE_NORM_QC_NO},
+	{0x33BC, UNICODE_NORM_QC_NO},
+	{0x33BD, UNICODE_NORM_QC_NO},
+	{0x33BE, UNICODE_NORM_QC_NO},
+	{0x33BF, UNICODE_NORM_QC_NO},
+	{0x33C0, UNICODE_NORM_QC_NO},
+	{0x33C1, UNICODE_NORM_QC_NO},
+	{0x33C2, UNICODE_NORM_QC_NO},
+	{0x33C3, UNICODE_NORM_QC_NO},
+	{0x33C4, UNICODE_NORM_QC_NO},
+	{0x33C5, UNICODE_NORM_QC_NO},
+	{0x33C6, UNICODE_NORM_QC_NO},
+	{0x33C7, UNICODE_NORM_QC_NO},
+	{0x33C8, UNICODE_NORM_QC_NO},
+	{0x33C9, UNICODE_NORM_QC_NO},
+	{0x33CA, UNICODE_NORM_QC_NO},
+	{0x33CB, UNICODE_NORM_QC_NO},
+	{0x33CC, UNICODE_NORM_QC_NO},
+	{0x33CD, UNICODE_NORM_QC_NO},
+	{0x33CE, UNICODE_NORM_QC_NO},
+	{0x33CF, UNICODE_NORM_QC_NO},
+	{0x33D0, UNICODE_NORM_QC_NO},
+	{0x33D1, UNICODE_NORM_QC_NO},
+	{0x33D2, UNICODE_NORM_QC_NO},
+	{0x33D3, UNICODE_NORM_QC_NO},
+	{0x33D4, UNICODE_NORM_QC_NO},
+	{0x33D5, UNICODE_NORM_QC_NO},
+	{0x33D6, UNICODE_NORM_QC_NO},
+	{0x33D7, UNICODE_NORM_QC_NO},
+	{0x33D8, UNICODE_NORM_QC_NO},
+	{0x33D9, UNICODE_NORM_QC_NO},
+	{0x33DA, UNICODE_NORM_QC_NO},
+	{0x33DB, UNICODE_NORM_QC_NO},
+	{0x33DC, UNICODE_NORM_QC_NO},
+	{0x33DD, UNICODE_NORM_QC_NO},
+	{0x33DE, UNICODE_NORM_QC_NO},
+	{0x33DF, UNICODE_NORM_QC_NO},
+	{0x33E0, UNICODE_NORM_QC_NO},
+	{0x33E1, UNICODE_NORM_QC_NO},
+	{0x33E2, UNICODE_NORM_QC_NO},
+	{0x33E3, UNICODE_NORM_QC_NO},
+	{0x33E4, UNICODE_NORM_QC_NO},
+	{0x33E5, UNICODE_NORM_QC_NO},
+	{0x33E6, UNICODE_NORM_QC_NO},
+	{0x33E7, UNICODE_NORM_QC_NO},
+	{0x33E8, UNICODE_NORM_QC_NO},
+	{0x33E9, UNICODE_NORM_QC_NO},
+	{0x33EA, UNICODE_NORM_QC_NO},
+	{0x33EB, UNICODE_NORM_QC_NO},
+	{0x33EC, UNICODE_NORM_QC_NO},
+	{0x33ED, UNICODE_NORM_QC_NO},
+	{0x33EE, UNICODE_NORM_QC_NO},
+	{0x33EF, UNICODE_NORM_QC_NO},
+	{0x33F0, UNICODE_NORM_QC_NO},
+	{0x33F1, UNICODE_NORM_QC_NO},
+	{0x33F2, UNICODE_NORM_QC_NO},
+	{0x33F3, UNICODE_NORM_QC_NO},
+	{0x33F4, UNICODE_NORM_QC_NO},
+	{0x33F5, UNICODE_NORM_QC_NO},
+	{0x33F6, UNICODE_NORM_QC_NO},
+	{0x33F7, UNICODE_NORM_QC_NO},
+	{0x33F8, UNICODE_NORM_QC_NO},
+	{0x33F9, UNICODE_NORM_QC_NO},
+	{0x33FA, UNICODE_NORM_QC_NO},
+	{0x33FB, UNICODE_NORM_QC_NO},
+	{0x33FC, UNICODE_NORM_QC_NO},
+	{0x33FD, UNICODE_NORM_QC_NO},
+	{0x33FE, UNICODE_NORM_QC_NO},
+	{0x33FF, UNICODE_NORM_QC_NO},
+	{0xA69C, UNICODE_NORM_QC_NO},
+	{0xA69D, UNICODE_NORM_QC_NO},
+	{0xA770, UNICODE_NORM_QC_NO},
+	{0xA7F8, UNICODE_NORM_QC_NO},
+	{0xA7F9, UNICODE_NORM_QC_NO},
+	{0xAB5C, UNICODE_NORM_QC_NO},
+	{0xAB5D, UNICODE_NORM_QC_NO},
+	{0xAB5E, UNICODE_NORM_QC_NO},
+	{0xAB5F, UNICODE_NORM_QC_NO},
+	{0xAC00, UNICODE_NORM_QC_NO},
+	{0xAC01, UNICODE_NORM_QC_NO},
+	{0xAC02, UNICODE_NORM_QC_NO},
+	{0xAC03, UNICODE_NORM_QC_NO},
+	{0xAC04, UNICODE_NORM_QC_NO},
+	{0xAC05, UNICODE_NORM_QC_NO},
+	{0xAC06, UNICODE_NORM_QC_NO},
+	{0xAC07, UNICODE_NORM_QC_NO},
+	{0xAC08, UNICODE_NORM_QC_NO},
+	{0xAC09, UNICODE_NORM_QC_NO},
+	{0xAC0A, UNICODE_NORM_QC_NO},
+	{0xAC0B, UNICODE_NORM_QC_NO},
+	{0xAC0C, UNICODE_NORM_QC_NO},
+	{0xAC0D, UNICODE_NORM_QC_NO},
+	{0xAC0E, UNICODE_NORM_QC_NO},
+	{0xAC0F, UNICODE_NORM_QC_NO},
+	{0xAC10, UNICODE_NORM_QC_NO},
+	{0xAC11, UNICODE_NORM_QC_NO},
+	{0xAC12, UNICODE_NORM_QC_NO},
+	{0xAC13, UNICODE_NORM_QC_NO},
+	{0xAC14, UNICODE_NORM_QC_NO},
+	{0xAC15, UNICODE_NORM_QC_NO},
+	{0xAC16, UNICODE_NORM_QC_NO},
+	{0xAC17, UNICODE_NORM_QC_NO},
+	{0xAC18, UNICODE_NORM_QC_NO},
+	{0xAC19, UNICODE_NORM_QC_NO},
+	{0xAC1A, UNICODE_NORM_QC_NO},
+	{0xAC1B, UNICODE_NORM_QC_NO},
+	{0xAC1C, UNICODE_NORM_QC_NO},
+	{0xAC1D, UNICODE_NORM_QC_NO},
+	{0xAC1E, UNICODE_NORM_QC_NO},
+	{0xAC1F, UNICODE_NORM_QC_NO},
+	{0xAC20, UNICODE_NORM_QC_NO},
+	{0xAC21, UNICODE_NORM_QC_NO},
+	{0xAC22, UNICODE_NORM_QC_NO},
+	{0xAC23, UNICODE_NORM_QC_NO},
+	{0xAC24, UNICODE_NORM_QC_NO},
+	{0xAC25, UNICODE_NORM_QC_NO},
+	{0xAC26, UNICODE_NORM_QC_NO},
+	{0xAC27, UNICODE_NORM_QC_NO},
+	{0xAC28, UNICODE_NORM_QC_NO},
+	{0xAC29, UNICODE_NORM_QC_NO},
+	{0xAC2A, UNICODE_NORM_QC_NO},
+	{0xAC2B, UNICODE_NORM_QC_NO},
+	{0xAC2C, UNICODE_NORM_QC_NO},
+	{0xAC2D, UNICODE_NORM_QC_NO},
+	{0xAC2E, UNICODE_NORM_QC_NO},
+	{0xAC2F, UNICODE_NORM_QC_NO},
+	{0xAC30, UNICODE_NORM_QC_NO},
+	{0xAC31, UNICODE_NORM_QC_NO},
+	{0xAC32, UNICODE_NORM_QC_NO},
+	{0xAC33, UNICODE_NORM_QC_NO},
+	{0xAC34, UNICODE_NORM_QC_NO},
+	{0xAC35, UNICODE_NORM_QC_NO},
+	{0xAC36, UNICODE_NORM_QC_NO},
+	{0xAC37, UNICODE_NORM_QC_NO},
+	{0xAC38, UNICODE_NORM_QC_NO},
+	{0xAC39, UNICODE_NORM_QC_NO},
+	{0xAC3A, UNICODE_NORM_QC_NO},
+	{0xAC3B, UNICODE_NORM_QC_NO},
+	{0xAC3C, UNICODE_NORM_QC_NO},
+	{0xAC3D, UNICODE_NORM_QC_NO},
+	{0xAC3E, UNICODE_NORM_QC_NO},
+	{0xAC3F, UNICODE_NORM_QC_NO},
+	{0xAC40, UNICODE_NORM_QC_NO},
+	{0xAC41, UNICODE_NORM_QC_NO},
+	{0xAC42, UNICODE_NORM_QC_NO},
+	{0xAC43, UNICODE_NORM_QC_NO},
+	{0xAC44, UNICODE_NORM_QC_NO},
+	{0xAC45, UNICODE_NORM_QC_NO},
+	{0xAC46, UNICODE_NORM_QC_NO},
+	{0xAC47, UNICODE_NORM_QC_NO},
+	{0xAC48, UNICODE_NORM_QC_NO},
+	{0xAC49, UNICODE_NORM_QC_NO},
+	{0xAC4A, UNICODE_NORM_QC_NO},
+	{0xAC4B, UNICODE_NORM_QC_NO},
+	{0xAC4C, UNICODE_NORM_QC_NO},
+	{0xAC4D, UNICODE_NORM_QC_NO},
+	{0xAC4E, UNICODE_NORM_QC_NO},
+	{0xAC4F, UNICODE_NORM_QC_NO},
+	{0xAC50, UNICODE_NORM_QC_NO},
+	{0xAC51, UNICODE_NORM_QC_NO},
+	{0xAC52, UNICODE_NORM_QC_NO},
+	{0xAC53, UNICODE_NORM_QC_NO},
+	{0xAC54, UNICODE_NORM_QC_NO},
+	{0xAC55, UNICODE_NORM_QC_NO},
+	{0xAC56, UNICODE_NORM_QC_NO},
+	{0xAC57, UNICODE_NORM_QC_NO},
+	{0xAC58, UNICODE_NORM_QC_NO},
+	{0xAC59, UNICODE_NORM_QC_NO},
+	{0xAC5A, UNICODE_NORM_QC_NO},
+	{0xAC5B, UNICODE_NORM_QC_NO},
+	{0xAC5C, UNICODE_NORM_QC_NO},
+	{0xAC5D, UNICODE_NORM_QC_NO},
+	{0xAC5E, UNICODE_NORM_QC_NO},
+	{0xAC5F, UNICODE_NORM_QC_NO},
+	{0xAC60, UNICODE_NORM_QC_NO},
+	{0xAC61, UNICODE_NORM_QC_NO},
+	{0xAC62, UNICODE_NORM_QC_NO},
+	{0xAC63, UNICODE_NORM_QC_NO},
+	{0xAC64, UNICODE_NORM_QC_NO},
+	{0xAC65, UNICODE_NORM_QC_NO},
+	{0xAC66, UNICODE_NORM_QC_NO},
+	{0xAC67, UNICODE_NORM_QC_NO},
+	{0xAC68, UNICODE_NORM_QC_NO},
+	{0xAC69, UNICODE_NORM_QC_NO},
+	{0xAC6A, UNICODE_NORM_QC_NO},
+	{0xAC6B, UNICODE_NORM_QC_NO},
+	{0xAC6C, UNICODE_NORM_QC_NO},
+	{0xAC6D, UNICODE_NORM_QC_NO},
+	{0xAC6E, UNICODE_NORM_QC_NO},
+	{0xAC6F, UNICODE_NORM_QC_NO},
+	{0xAC70, UNICODE_NORM_QC_NO},
+	{0xAC71, UNICODE_NORM_QC_NO},
+	{0xAC72, UNICODE_NORM_QC_NO},
+	{0xAC73, UNICODE_NORM_QC_NO},
+	{0xAC74, UNICODE_NORM_QC_NO},
+	{0xAC75, UNICODE_NORM_QC_NO},
+	{0xAC76, UNICODE_NORM_QC_NO},
+	{0xAC77, UNICODE_NORM_QC_NO},
+	{0xAC78, UNICODE_NORM_QC_NO},
+	{0xAC79, UNICODE_NORM_QC_NO},
+	{0xAC7A, UNICODE_NORM_QC_NO},
+	{0xAC7B, UNICODE_NORM_QC_NO},
+	{0xAC7C, UNICODE_NORM_QC_NO},
+	{0xAC7D, UNICODE_NORM_QC_NO},
+	{0xAC7E, UNICODE_NORM_QC_NO},
+	{0xAC7F, UNICODE_NORM_QC_NO},
+	{0xAC80, UNICODE_NORM_QC_NO},
+	{0xAC81, UNICODE_NORM_QC_NO},
+	{0xAC82, UNICODE_NORM_QC_NO},
+	{0xAC83, UNICODE_NORM_QC_NO},
+	{0xAC84, UNICODE_NORM_QC_NO},
+	{0xAC85, UNICODE_NORM_QC_NO},
+	{0xAC86, UNICODE_NORM_QC_NO},
+	{0xAC87, UNICODE_NORM_QC_NO},
+	{0xAC88, UNICODE_NORM_QC_NO},
+	{0xAC89, UNICODE_NORM_QC_NO},
+	{0xAC8A, UNICODE_NORM_QC_NO},
+	{0xAC8B, UNICODE_NORM_QC_NO},
+	{0xAC8C, UNICODE_NORM_QC_NO},
+	{0xAC8D, UNICODE_NORM_QC_NO},
+	{0xAC8E, UNICODE_NORM_QC_NO},
+	{0xAC8F, UNICODE_NORM_QC_NO},
+	{0xAC90, UNICODE_NORM_QC_NO},
+	{0xAC91, UNICODE_NORM_QC_NO},
+	{0xAC92, UNICODE_NORM_QC_NO},
+	{0xAC93, UNICODE_NORM_QC_NO},
+	{0xAC94, UNICODE_NORM_QC_NO},
+	{0xAC95, UNICODE_NORM_QC_NO},
+	{0xAC96, UNICODE_NORM_QC_NO},
+	{0xAC97, UNICODE_NORM_QC_NO},
+	{0xAC98, UNICODE_NORM_QC_NO},
+	{0xAC99, UNICODE_NORM_QC_NO},
+	{0xAC9A, UNICODE_NORM_QC_NO},
+	{0xAC9B, UNICODE_NORM_QC_NO},
+	{0xAC9C, UNICODE_NORM_QC_NO},
+	{0xAC9D, UNICODE_NORM_QC_NO},
+	{0xAC9E, UNICODE_NORM_QC_NO},
+	{0xAC9F, UNICODE_NORM_QC_NO},
+	{0xACA0, UNICODE_NORM_QC_NO},
+	{0xACA1, UNICODE_NORM_QC_NO},
+	{0xACA2, UNICODE_NORM_QC_NO},
+	{0xACA3, UNICODE_NORM_QC_NO},
+	{0xACA4, UNICODE_NORM_QC_NO},
+	{0xACA5, UNICODE_NORM_QC_NO},
+	{0xACA6, UNICODE_NORM_QC_NO},
+	{0xACA7, UNICODE_NORM_QC_NO},
+	{0xACA8, UNICODE_NORM_QC_NO},
+	{0xACA9, UNICODE_NORM_QC_NO},
+	{0xACAA, UNICODE_NORM_QC_NO},
+	{0xACAB, UNICODE_NORM_QC_NO},
+	{0xACAC, UNICODE_NORM_QC_NO},
+	{0xACAD, UNICODE_NORM_QC_NO},
+	{0xACAE, UNICODE_NORM_QC_NO},
+	{0xACAF, UNICODE_NORM_QC_NO},
+	{0xACB0, UNICODE_NORM_QC_NO},
+	{0xACB1, UNICODE_NORM_QC_NO},
+	{0xACB2, UNICODE_NORM_QC_NO},
+	{0xACB3, UNICODE_NORM_QC_NO},
+	{0xACB4, UNICODE_NORM_QC_NO},
+	{0xACB5, UNICODE_NORM_QC_NO},
+	{0xACB6, UNICODE_NORM_QC_NO},
+	{0xACB7, UNICODE_NORM_QC_NO},
+	{0xACB8, UNICODE_NORM_QC_NO},
+	{0xACB9, UNICODE_NORM_QC_NO},
+	{0xACBA, UNICODE_NORM_QC_NO},
+	{0xACBB, UNICODE_NORM_QC_NO},
+	{0xACBC, UNICODE_NORM_QC_NO},
+	{0xACBD, UNICODE_NORM_QC_NO},
+	{0xACBE, UNICODE_NORM_QC_NO},
+	{0xACBF, UNICODE_NORM_QC_NO},
+	{0xACC0, UNICODE_NORM_QC_NO},
+	{0xACC1, UNICODE_NORM_QC_NO},
+	{0xACC2, UNICODE_NORM_QC_NO},
+	{0xACC3, UNICODE_NORM_QC_NO},
+	{0xACC4, UNICODE_NORM_QC_NO},
+	{0xACC5, UNICODE_NORM_QC_NO},
+	{0xACC6, UNICODE_NORM_QC_NO},
+	{0xACC7, UNICODE_NORM_QC_NO},
+	{0xACC8, UNICODE_NORM_QC_NO},
+	{0xACC9, UNICODE_NORM_QC_NO},
+	{0xACCA, UNICODE_NORM_QC_NO},
+	{0xACCB, UNICODE_NORM_QC_NO},
+	{0xACCC, UNICODE_NORM_QC_NO},
+	{0xACCD, UNICODE_NORM_QC_NO},
+	{0xACCE, UNICODE_NORM_QC_NO},
+	{0xACCF, UNICODE_NORM_QC_NO},
+	{0xACD0, UNICODE_NORM_QC_NO},
+	{0xACD1, UNICODE_NORM_QC_NO},
+	{0xACD2, UNICODE_NORM_QC_NO},
+	{0xACD3, UNICODE_NORM_QC_NO},
+	{0xACD4, UNICODE_NORM_QC_NO},
+	{0xACD5, UNICODE_NORM_QC_NO},
+	{0xACD6, UNICODE_NORM_QC_NO},
+	{0xACD7, UNICODE_NORM_QC_NO},
+	{0xACD8, UNICODE_NORM_QC_NO},
+	{0xACD9, UNICODE_NORM_QC_NO},
+	{0xACDA, UNICODE_NORM_QC_NO},
+	{0xACDB, UNICODE_NORM_QC_NO},
+	{0xACDC, UNICODE_NORM_QC_NO},
+	{0xACDD, UNICODE_NORM_QC_NO},
+	{0xACDE, UNICODE_NORM_QC_NO},
+	{0xACDF, UNICODE_NORM_QC_NO},
+	{0xACE0, UNICODE_NORM_QC_NO},
+	{0xACE1, UNICODE_NORM_QC_NO},
+	{0xACE2, UNICODE_NORM_QC_NO},
+	{0xACE3, UNICODE_NORM_QC_NO},
+	{0xACE4, UNICODE_NORM_QC_NO},
+	{0xACE5, UNICODE_NORM_QC_NO},
+	{0xACE6, UNICODE_NORM_QC_NO},
+	{0xACE7, UNICODE_NORM_QC_NO},
+	{0xACE8, UNICODE_NORM_QC_NO},
+	{0xACE9, UNICODE_NORM_QC_NO},
+	{0xACEA, UNICODE_NORM_QC_NO},
+	{0xACEB, UNICODE_NORM_QC_NO},
+	{0xACEC, UNICODE_NORM_QC_NO},
+	{0xACED, UNICODE_NORM_QC_NO},
+	{0xACEE, UNICODE_NORM_QC_NO},
+	{0xACEF, UNICODE_NORM_QC_NO},
+	{0xACF0, UNICODE_NORM_QC_NO},
+	{0xACF1, UNICODE_NORM_QC_NO},
+	{0xACF2, UNICODE_NORM_QC_NO},
+	{0xACF3, UNICODE_NORM_QC_NO},
+	{0xACF4, UNICODE_NORM_QC_NO},
+	{0xACF5, UNICODE_NORM_QC_NO},
+	{0xACF6, UNICODE_NORM_QC_NO},
+	{0xACF7, UNICODE_NORM_QC_NO},
+	{0xACF8, UNICODE_NORM_QC_NO},
+	{0xACF9, UNICODE_NORM_QC_NO},
+	{0xACFA, UNICODE_NORM_QC_NO},
+	{0xACFB, UNICODE_NORM_QC_NO},
+	{0xACFC, UNICODE_NORM_QC_NO},
+	{0xACFD, UNICODE_NORM_QC_NO},
+	{0xACFE, UNICODE_NORM_QC_NO},
+	{0xACFF, UNICODE_NORM_QC_NO},
+	{0xAD00, UNICODE_NORM_QC_NO},
+	{0xAD01, UNICODE_NORM_QC_NO},
+	{0xAD02, UNICODE_NORM_QC_NO},
+	{0xAD03, UNICODE_NORM_QC_NO},
+	{0xAD04, UNICODE_NORM_QC_NO},
+	{0xAD05, UNICODE_NORM_QC_NO},
+	{0xAD06, UNICODE_NORM_QC_NO},
+	{0xAD07, UNICODE_NORM_QC_NO},
+	{0xAD08, UNICODE_NORM_QC_NO},
+	{0xAD09, UNICODE_NORM_QC_NO},
+	{0xAD0A, UNICODE_NORM_QC_NO},
+	{0xAD0B, UNICODE_NORM_QC_NO},
+	{0xAD0C, UNICODE_NORM_QC_NO},
+	{0xAD0D, UNICODE_NORM_QC_NO},
+	{0xAD0E, UNICODE_NORM_QC_NO},
+	{0xAD0F, UNICODE_NORM_QC_NO},
+	{0xAD10, UNICODE_NORM_QC_NO},
+	{0xAD11, UNICODE_NORM_QC_NO},
+	{0xAD12, UNICODE_NORM_QC_NO},
+	{0xAD13, UNICODE_NORM_QC_NO},
+	{0xAD14, UNICODE_NORM_QC_NO},
+	{0xAD15, UNICODE_NORM_QC_NO},
+	{0xAD16, UNICODE_NORM_QC_NO},
+	{0xAD17, UNICODE_NORM_QC_NO},
+	{0xAD18, UNICODE_NORM_QC_NO},
+	{0xAD19, UNICODE_NORM_QC_NO},
+	{0xAD1A, UNICODE_NORM_QC_NO},
+	{0xAD1B, UNICODE_NORM_QC_NO},
+	{0xAD1C, UNICODE_NORM_QC_NO},
+	{0xAD1D, UNICODE_NORM_QC_NO},
+	{0xAD1E, UNICODE_NORM_QC_NO},
+	{0xAD1F, UNICODE_NORM_QC_NO},
+	{0xAD20, UNICODE_NORM_QC_NO},
+	{0xAD21, UNICODE_NORM_QC_NO},
+	{0xAD22, UNICODE_NORM_QC_NO},
+	{0xAD23, UNICODE_NORM_QC_NO},
+	{0xAD24, UNICODE_NORM_QC_NO},
+	{0xAD25, UNICODE_NORM_QC_NO},
+	{0xAD26, UNICODE_NORM_QC_NO},
+	{0xAD27, UNICODE_NORM_QC_NO},
+	{0xAD28, UNICODE_NORM_QC_NO},
+	{0xAD29, UNICODE_NORM_QC_NO},
+	{0xAD2A, UNICODE_NORM_QC_NO},
+	{0xAD2B, UNICODE_NORM_QC_NO},
+	{0xAD2C, UNICODE_NORM_QC_NO},
+	{0xAD2D, UNICODE_NORM_QC_NO},
+	{0xAD2E, UNICODE_NORM_QC_NO},
+	{0xAD2F, UNICODE_NORM_QC_NO},
+	{0xAD30, UNICODE_NORM_QC_NO},
+	{0xAD31, UNICODE_NORM_QC_NO},
+	{0xAD32, UNICODE_NORM_QC_NO},
+	{0xAD33, UNICODE_NORM_QC_NO},
+	{0xAD34, UNICODE_NORM_QC_NO},
+	{0xAD35, UNICODE_NORM_QC_NO},
+	{0xAD36, UNICODE_NORM_QC_NO},
+	{0xAD37, UNICODE_NORM_QC_NO},
+	{0xAD38, UNICODE_NORM_QC_NO},
+	{0xAD39, UNICODE_NORM_QC_NO},
+	{0xAD3A, UNICODE_NORM_QC_NO},
+	{0xAD3B, UNICODE_NORM_QC_NO},
+	{0xAD3C, UNICODE_NORM_QC_NO},
+	{0xAD3D, UNICODE_NORM_QC_NO},
+	{0xAD3E, UNICODE_NORM_QC_NO},
+	{0xAD3F, UNICODE_NORM_QC_NO},
+	{0xAD40, UNICODE_NORM_QC_NO},
+	{0xAD41, UNICODE_NORM_QC_NO},
+	{0xAD42, UNICODE_NORM_QC_NO},
+	{0xAD43, UNICODE_NORM_QC_NO},
+	{0xAD44, UNICODE_NORM_QC_NO},
+	{0xAD45, UNICODE_NORM_QC_NO},
+	{0xAD46, UNICODE_NORM_QC_NO},
+	{0xAD47, UNICODE_NORM_QC_NO},
+	{0xAD48, UNICODE_NORM_QC_NO},
+	{0xAD49, UNICODE_NORM_QC_NO},
+	{0xAD4A, UNICODE_NORM_QC_NO},
+	{0xAD4B, UNICODE_NORM_QC_NO},
+	{0xAD4C, UNICODE_NORM_QC_NO},
+	{0xAD4D, UNICODE_NORM_QC_NO},
+	{0xAD4E, UNICODE_NORM_QC_NO},
+	{0xAD4F, UNICODE_NORM_QC_NO},
+	{0xAD50, UNICODE_NORM_QC_NO},
+	{0xAD51, UNICODE_NORM_QC_NO},
+	{0xAD52, UNICODE_NORM_QC_NO},
+	{0xAD53, UNICODE_NORM_QC_NO},
+	{0xAD54, UNICODE_NORM_QC_NO},
+	{0xAD55, UNICODE_NORM_QC_NO},
+	{0xAD56, UNICODE_NORM_QC_NO},
+	{0xAD57, UNICODE_NORM_QC_NO},
+	{0xAD58, UNICODE_NORM_QC_NO},
+	{0xAD59, UNICODE_NORM_QC_NO},
+	{0xAD5A, UNICODE_NORM_QC_NO},
+	{0xAD5B, UNICODE_NORM_QC_NO},
+	{0xAD5C, UNICODE_NORM_QC_NO},
+	{0xAD5D, UNICODE_NORM_QC_NO},
+	{0xAD5E, UNICODE_NORM_QC_NO},
+	{0xAD5F, UNICODE_NORM_QC_NO},
+	{0xAD60, UNICODE_NORM_QC_NO},
+	{0xAD61, UNICODE_NORM_QC_NO},
+	{0xAD62, UNICODE_NORM_QC_NO},
+	{0xAD63, UNICODE_NORM_QC_NO},
+	{0xAD64, UNICODE_NORM_QC_NO},
+	{0xAD65, UNICODE_NORM_QC_NO},
+	{0xAD66, UNICODE_NORM_QC_NO},
+	{0xAD67, UNICODE_NORM_QC_NO},
+	{0xAD68, UNICODE_NORM_QC_NO},
+	{0xAD69, UNICODE_NORM_QC_NO},
+	{0xAD6A, UNICODE_NORM_QC_NO},
+	{0xAD6B, UNICODE_NORM_QC_NO},
+	{0xAD6C, UNICODE_NORM_QC_NO},
+	{0xAD6D, UNICODE_NORM_QC_NO},
+	{0xAD6E, UNICODE_NORM_QC_NO},
+	{0xAD6F, UNICODE_NORM_QC_NO},
+	{0xAD70, UNICODE_NORM_QC_NO},
+	{0xAD71, UNICODE_NORM_QC_NO},
+	{0xAD72, UNICODE_NORM_QC_NO},
+	{0xAD73, UNICODE_NORM_QC_NO},
+	{0xAD74, UNICODE_NORM_QC_NO},
+	{0xAD75, UNICODE_NORM_QC_NO},
+	{0xAD76, UNICODE_NORM_QC_NO},
+	{0xAD77, UNICODE_NORM_QC_NO},
+	{0xAD78, UNICODE_NORM_QC_NO},
+	{0xAD79, UNICODE_NORM_QC_NO},
+	{0xAD7A, UNICODE_NORM_QC_NO},
+	{0xAD7B, UNICODE_NORM_QC_NO},
+	{0xAD7C, UNICODE_NORM_QC_NO},
+	{0xAD7D, UNICODE_NORM_QC_NO},
+	{0xAD7E, UNICODE_NORM_QC_NO},
+	{0xAD7F, UNICODE_NORM_QC_NO},
+	{0xAD80, UNICODE_NORM_QC_NO},
+	{0xAD81, UNICODE_NORM_QC_NO},
+	{0xAD82, UNICODE_NORM_QC_NO},
+	{0xAD83, UNICODE_NORM_QC_NO},
+	{0xAD84, UNICODE_NORM_QC_NO},
+	{0xAD85, UNICODE_NORM_QC_NO},
+	{0xAD86, UNICODE_NORM_QC_NO},
+	{0xAD87, UNICODE_NORM_QC_NO},
+	{0xAD88, UNICODE_NORM_QC_NO},
+	{0xAD89, UNICODE_NORM_QC_NO},
+	{0xAD8A, UNICODE_NORM_QC_NO},
+	{0xAD8B, UNICODE_NORM_QC_NO},
+	{0xAD8C, UNICODE_NORM_QC_NO},
+	{0xAD8D, UNICODE_NORM_QC_NO},
+	{0xAD8E, UNICODE_NORM_QC_NO},
+	{0xAD8F, UNICODE_NORM_QC_NO},
+	{0xAD90, UNICODE_NORM_QC_NO},
+	{0xAD91, UNICODE_NORM_QC_NO},
+	{0xAD92, UNICODE_NORM_QC_NO},
+	{0xAD93, UNICODE_NORM_QC_NO},
+	{0xAD94, UNICODE_NORM_QC_NO},
+	{0xAD95, UNICODE_NORM_QC_NO},
+	{0xAD96, UNICODE_NORM_QC_NO},
+	{0xAD97, UNICODE_NORM_QC_NO},
+	{0xAD98, UNICODE_NORM_QC_NO},
+	{0xAD99, UNICODE_NORM_QC_NO},
+	{0xAD9A, UNICODE_NORM_QC_NO},
+	{0xAD9B, UNICODE_NORM_QC_NO},
+	{0xAD9C, UNICODE_NORM_QC_NO},
+	{0xAD9D, UNICODE_NORM_QC_NO},
+	{0xAD9E, UNICODE_NORM_QC_NO},
+	{0xAD9F, UNICODE_NORM_QC_NO},
+	{0xADA0, UNICODE_NORM_QC_NO},
+	{0xADA1, UNICODE_NORM_QC_NO},
+	{0xADA2, UNICODE_NORM_QC_NO},
+	{0xADA3, UNICODE_NORM_QC_NO},
+	{0xADA4, UNICODE_NORM_QC_NO},
+	{0xADA5, UNICODE_NORM_QC_NO},
+	{0xADA6, UNICODE_NORM_QC_NO},
+	{0xADA7, UNICODE_NORM_QC_NO},
+	{0xADA8, UNICODE_NORM_QC_NO},
+	{0xADA9, UNICODE_NORM_QC_NO},
+	{0xADAA, UNICODE_NORM_QC_NO},
+	{0xADAB, UNICODE_NORM_QC_NO},
+	{0xADAC, UNICODE_NORM_QC_NO},
+	{0xADAD, UNICODE_NORM_QC_NO},
+	{0xADAE, UNICODE_NORM_QC_NO},
+	{0xADAF, UNICODE_NORM_QC_NO},
+	{0xADB0, UNICODE_NORM_QC_NO},
+	{0xADB1, UNICODE_NORM_QC_NO},
+	{0xADB2, UNICODE_NORM_QC_NO},
+	{0xADB3, UNICODE_NORM_QC_NO},
+	{0xADB4, UNICODE_NORM_QC_NO},
+	{0xADB5, UNICODE_NORM_QC_NO},
+	{0xADB6, UNICODE_NORM_QC_NO},
+	{0xADB7, UNICODE_NORM_QC_NO},
+	{0xADB8, UNICODE_NORM_QC_NO},
+	{0xADB9, UNICODE_NORM_QC_NO},
+	{0xADBA, UNICODE_NORM_QC_NO},
+	{0xADBB, UNICODE_NORM_QC_NO},
+	{0xADBC, UNICODE_NORM_QC_NO},
+	{0xADBD, UNICODE_NORM_QC_NO},
+	{0xADBE, UNICODE_NORM_QC_NO},
+	{0xADBF, UNICODE_NORM_QC_NO},
+	{0xADC0, UNICODE_NORM_QC_NO},
+	{0xADC1, UNICODE_NORM_QC_NO},
+	{0xADC2, UNICODE_NORM_QC_NO},
+	{0xADC3, UNICODE_NORM_QC_NO},
+	{0xADC4, UNICODE_NORM_QC_NO},
+	{0xADC5, UNICODE_NORM_QC_NO},
+	{0xADC6, UNICODE_NORM_QC_NO},
+	{0xADC7, UNICODE_NORM_QC_NO},
+	{0xADC8, UNICODE_NORM_QC_NO},
+	{0xADC9, UNICODE_NORM_QC_NO},
+	{0xADCA, UNICODE_NORM_QC_NO},
+	{0xADCB, UNICODE_NORM_QC_NO},
+	{0xADCC, UNICODE_NORM_QC_NO},
+	{0xADCD, UNICODE_NORM_QC_NO},
+	{0xADCE, UNICODE_NORM_QC_NO},
+	{0xADCF, UNICODE_NORM_QC_NO},
+	{0xADD0, UNICODE_NORM_QC_NO},
+	{0xADD1, UNICODE_NORM_QC_NO},
+	{0xADD2, UNICODE_NORM_QC_NO},
+	{0xADD3, UNICODE_NORM_QC_NO},
+	{0xADD4, UNICODE_NORM_QC_NO},
+	{0xADD5, UNICODE_NORM_QC_NO},
+	{0xADD6, UNICODE_NORM_QC_NO},
+	{0xADD7, UNICODE_NORM_QC_NO},
+	{0xADD8, UNICODE_NORM_QC_NO},
+	{0xADD9, UNICODE_NORM_QC_NO},
+	{0xADDA, UNICODE_NORM_QC_NO},
+	{0xADDB, UNICODE_NORM_QC_NO},
+	{0xADDC, UNICODE_NORM_QC_NO},
+	{0xADDD, UNICODE_NORM_QC_NO},
+	{0xADDE, UNICODE_NORM_QC_NO},
+	{0xADDF, UNICODE_NORM_QC_NO},
+	{0xADE0, UNICODE_NORM_QC_NO},
+	{0xADE1, UNICODE_NORM_QC_NO},
+	{0xADE2, UNICODE_NORM_QC_NO},
+	{0xADE3, UNICODE_NORM_QC_NO},
+	{0xADE4, UNICODE_NORM_QC_NO},
+	{0xADE5, UNICODE_NORM_QC_NO},
+	{0xADE6, UNICODE_NORM_QC_NO},
+	{0xADE7, UNICODE_NORM_QC_NO},
+	{0xADE8, UNICODE_NORM_QC_NO},
+	{0xADE9, UNICODE_NORM_QC_NO},
+	{0xADEA, UNICODE_NORM_QC_NO},
+	{0xADEB, UNICODE_NORM_QC_NO},
+	{0xADEC, UNICODE_NORM_QC_NO},
+	{0xADED, UNICODE_NORM_QC_NO},
+	{0xADEE, UNICODE_NORM_QC_NO},
+	{0xADEF, UNICODE_NORM_QC_NO},
+	{0xADF0, UNICODE_NORM_QC_NO},
+	{0xADF1, UNICODE_NORM_QC_NO},
+	{0xADF2, UNICODE_NORM_QC_NO},
+	{0xADF3, UNICODE_NORM_QC_NO},
+	{0xADF4, UNICODE_NORM_QC_NO},
+	{0xADF5, UNICODE_NORM_QC_NO},
+	{0xADF6, UNICODE_NORM_QC_NO},
+	{0xADF7, UNICODE_NORM_QC_NO},
+	{0xADF8, UNICODE_NORM_QC_NO},
+	{0xADF9, UNICODE_NORM_QC_NO},
+	{0xADFA, UNICODE_NORM_QC_NO},
+	{0xADFB, UNICODE_NORM_QC_NO},
+	{0xADFC, UNICODE_NORM_QC_NO},
+	{0xADFD, UNICODE_NORM_QC_NO},
+	{0xADFE, UNICODE_NORM_QC_NO},
+	{0xADFF, UNICODE_NORM_QC_NO},
+	{0xAE00, UNICODE_NORM_QC_NO},
+	{0xAE01, UNICODE_NORM_QC_NO},
+	{0xAE02, UNICODE_NORM_QC_NO},
+	{0xAE03, UNICODE_NORM_QC_NO},
+	{0xAE04, UNICODE_NORM_QC_NO},
+	{0xAE05, UNICODE_NORM_QC_NO},
+	{0xAE06, UNICODE_NORM_QC_NO},
+	{0xAE07, UNICODE_NORM_QC_NO},
+	{0xAE08, UNICODE_NORM_QC_NO},
+	{0xAE09, UNICODE_NORM_QC_NO},
+	{0xAE0A, UNICODE_NORM_QC_NO},
+	{0xAE0B, UNICODE_NORM_QC_NO},
+	{0xAE0C, UNICODE_NORM_QC_NO},
+	{0xAE0D, UNICODE_NORM_QC_NO},
+	{0xAE0E, UNICODE_NORM_QC_NO},
+	{0xAE0F, UNICODE_NORM_QC_NO},
+	{0xAE10, UNICODE_NORM_QC_NO},
+	{0xAE11, UNICODE_NORM_QC_NO},
+	{0xAE12, UNICODE_NORM_QC_NO},
+	{0xAE13, UNICODE_NORM_QC_NO},
+	{0xAE14, UNICODE_NORM_QC_NO},
+	{0xAE15, UNICODE_NORM_QC_NO},
+	{0xAE16, UNICODE_NORM_QC_NO},
+	{0xAE17, UNICODE_NORM_QC_NO},
+	{0xAE18, UNICODE_NORM_QC_NO},
+	{0xAE19, UNICODE_NORM_QC_NO},
+	{0xAE1A, UNICODE_NORM_QC_NO},
+	{0xAE1B, UNICODE_NORM_QC_NO},
+	{0xAE1C, UNICODE_NORM_QC_NO},
+	{0xAE1D, UNICODE_NORM_QC_NO},
+	{0xAE1E, UNICODE_NORM_QC_NO},
+	{0xAE1F, UNICODE_NORM_QC_NO},
+	{0xAE20, UNICODE_NORM_QC_NO},
+	{0xAE21, UNICODE_NORM_QC_NO},
+	{0xAE22, UNICODE_NORM_QC_NO},
+	{0xAE23, UNICODE_NORM_QC_NO},
+	{0xAE24, UNICODE_NORM_QC_NO},
+	{0xAE25, UNICODE_NORM_QC_NO},
+	{0xAE26, UNICODE_NORM_QC_NO},
+	{0xAE27, UNICODE_NORM_QC_NO},
+	{0xAE28, UNICODE_NORM_QC_NO},
+	{0xAE29, UNICODE_NORM_QC_NO},
+	{0xAE2A, UNICODE_NORM_QC_NO},
+	{0xAE2B, UNICODE_NORM_QC_NO},
+	{0xAE2C, UNICODE_NORM_QC_NO},
+	{0xAE2D, UNICODE_NORM_QC_NO},
+	{0xAE2E, UNICODE_NORM_QC_NO},
+	{0xAE2F, UNICODE_NORM_QC_NO},
+	{0xAE30, UNICODE_NORM_QC_NO},
+	{0xAE31, UNICODE_NORM_QC_NO},
+	{0xAE32, UNICODE_NORM_QC_NO},
+	{0xAE33, UNICODE_NORM_QC_NO},
+	{0xAE34, UNICODE_NORM_QC_NO},
+	{0xAE35, UNICODE_NORM_QC_NO},
+	{0xAE36, UNICODE_NORM_QC_NO},
+	{0xAE37, UNICODE_NORM_QC_NO},
+	{0xAE38, UNICODE_NORM_QC_NO},
+	{0xAE39, UNICODE_NORM_QC_NO},
+	{0xAE3A, UNICODE_NORM_QC_NO},
+	{0xAE3B, UNICODE_NORM_QC_NO},
+	{0xAE3C, UNICODE_NORM_QC_NO},
+	{0xAE3D, UNICODE_NORM_QC_NO},
+	{0xAE3E, UNICODE_NORM_QC_NO},
+	{0xAE3F, UNICODE_NORM_QC_NO},
+	{0xAE40, UNICODE_NORM_QC_NO},
+	{0xAE41, UNICODE_NORM_QC_NO},
+	{0xAE42, UNICODE_NORM_QC_NO},
+	{0xAE43, UNICODE_NORM_QC_NO},
+	{0xAE44, UNICODE_NORM_QC_NO},
+	{0xAE45, UNICODE_NORM_QC_NO},
+	{0xAE46, UNICODE_NORM_QC_NO},
+	{0xAE47, UNICODE_NORM_QC_NO},
+	{0xAE48, UNICODE_NORM_QC_NO},
+	{0xAE49, UNICODE_NORM_QC_NO},
+	{0xAE4A, UNICODE_NORM_QC_NO},
+	{0xAE4B, UNICODE_NORM_QC_NO},
+	{0xAE4C, UNICODE_NORM_QC_NO},
+	{0xAE4D, UNICODE_NORM_QC_NO},
+	{0xAE4E, UNICODE_NORM_QC_NO},
+	{0xAE4F, UNICODE_NORM_QC_NO},
+	{0xAE50, UNICODE_NORM_QC_NO},
+	{0xAE51, UNICODE_NORM_QC_NO},
+	{0xAE52, UNICODE_NORM_QC_NO},
+	{0xAE53, UNICODE_NORM_QC_NO},
+	{0xAE54, UNICODE_NORM_QC_NO},
+	{0xAE55, UNICODE_NORM_QC_NO},
+	{0xAE56, UNICODE_NORM_QC_NO},
+	{0xAE57, UNICODE_NORM_QC_NO},
+	{0xAE58, UNICODE_NORM_QC_NO},
+	{0xAE59, UNICODE_NORM_QC_NO},
+	{0xAE5A, UNICODE_NORM_QC_NO},
+	{0xAE5B, UNICODE_NORM_QC_NO},
+	{0xAE5C, UNICODE_NORM_QC_NO},
+	{0xAE5D, UNICODE_NORM_QC_NO},
+	{0xAE5E, UNICODE_NORM_QC_NO},
+	{0xAE5F, UNICODE_NORM_QC_NO},
+	{0xAE60, UNICODE_NORM_QC_NO},
+	{0xAE61, UNICODE_NORM_QC_NO},
+	{0xAE62, UNICODE_NORM_QC_NO},
+	{0xAE63, UNICODE_NORM_QC_NO},
+	{0xAE64, UNICODE_NORM_QC_NO},
+	{0xAE65, UNICODE_NORM_QC_NO},
+	{0xAE66, UNICODE_NORM_QC_NO},
+	{0xAE67, UNICODE_NORM_QC_NO},
+	{0xAE68, UNICODE_NORM_QC_NO},
+	{0xAE69, UNICODE_NORM_QC_NO},
+	{0xAE6A, UNICODE_NORM_QC_NO},
+	{0xAE6B, UNICODE_NORM_QC_NO},
+	{0xAE6C, UNICODE_NORM_QC_NO},
+	{0xAE6D, UNICODE_NORM_QC_NO},
+	{0xAE6E, UNICODE_NORM_QC_NO},
+	{0xAE6F, UNICODE_NORM_QC_NO},
+	{0xAE70, UNICODE_NORM_QC_NO},
+	{0xAE71, UNICODE_NORM_QC_NO},
+	{0xAE72, UNICODE_NORM_QC_NO},
+	{0xAE73, UNICODE_NORM_QC_NO},
+	{0xAE74, UNICODE_NORM_QC_NO},
+	{0xAE75, UNICODE_NORM_QC_NO},
+	{0xAE76, UNICODE_NORM_QC_NO},
+	{0xAE77, UNICODE_NORM_QC_NO},
+	{0xAE78, UNICODE_NORM_QC_NO},
+	{0xAE79, UNICODE_NORM_QC_NO},
+	{0xAE7A, UNICODE_NORM_QC_NO},
+	{0xAE7B, UNICODE_NORM_QC_NO},
+	{0xAE7C, UNICODE_NORM_QC_NO},
+	{0xAE7D, UNICODE_NORM_QC_NO},
+	{0xAE7E, UNICODE_NORM_QC_NO},
+	{0xAE7F, UNICODE_NORM_QC_NO},
+	{0xAE80, UNICODE_NORM_QC_NO},
+	{0xAE81, UNICODE_NORM_QC_NO},
+	{0xAE82, UNICODE_NORM_QC_NO},
+	{0xAE83, UNICODE_NORM_QC_NO},
+	{0xAE84, UNICODE_NORM_QC_NO},
+	{0xAE85, UNICODE_NORM_QC_NO},
+	{0xAE86, UNICODE_NORM_QC_NO},
+	{0xAE87, UNICODE_NORM_QC_NO},
+	{0xAE88, UNICODE_NORM_QC_NO},
+	{0xAE89, UNICODE_NORM_QC_NO},
+	{0xAE8A, UNICODE_NORM_QC_NO},
+	{0xAE8B, UNICODE_NORM_QC_NO},
+	{0xAE8C, UNICODE_NORM_QC_NO},
+	{0xAE8D, UNICODE_NORM_QC_NO},
+	{0xAE8E, UNICODE_NORM_QC_NO},
+	{0xAE8F, UNICODE_NORM_QC_NO},
+	{0xAE90, UNICODE_NORM_QC_NO},
+	{0xAE91, UNICODE_NORM_QC_NO},
+	{0xAE92, UNICODE_NORM_QC_NO},
+	{0xAE93, UNICODE_NORM_QC_NO},
+	{0xAE94, UNICODE_NORM_QC_NO},
+	{0xAE95, UNICODE_NORM_QC_NO},
+	{0xAE96, UNICODE_NORM_QC_NO},
+	{0xAE97, UNICODE_NORM_QC_NO},
+	{0xAE98, UNICODE_NORM_QC_NO},
+	{0xAE99, UNICODE_NORM_QC_NO},
+	{0xAE9A, UNICODE_NORM_QC_NO},
+	{0xAE9B, UNICODE_NORM_QC_NO},
+	{0xAE9C, UNICODE_NORM_QC_NO},
+	{0xAE9D, UNICODE_NORM_QC_NO},
+	{0xAE9E, UNICODE_NORM_QC_NO},
+	{0xAE9F, UNICODE_NORM_QC_NO},
+	{0xAEA0, UNICODE_NORM_QC_NO},
+	{0xAEA1, UNICODE_NORM_QC_NO},
+	{0xAEA2, UNICODE_NORM_QC_NO},
+	{0xAEA3, UNICODE_NORM_QC_NO},
+	{0xAEA4, UNICODE_NORM_QC_NO},
+	{0xAEA5, UNICODE_NORM_QC_NO},
+	{0xAEA6, UNICODE_NORM_QC_NO},
+	{0xAEA7, UNICODE_NORM_QC_NO},
+	{0xAEA8, UNICODE_NORM_QC_NO},
+	{0xAEA9, UNICODE_NORM_QC_NO},
+	{0xAEAA, UNICODE_NORM_QC_NO},
+	{0xAEAB, UNICODE_NORM_QC_NO},
+	{0xAEAC, UNICODE_NORM_QC_NO},
+	{0xAEAD, UNICODE_NORM_QC_NO},
+	{0xAEAE, UNICODE_NORM_QC_NO},
+	{0xAEAF, UNICODE_NORM_QC_NO},
+	{0xAEB0, UNICODE_NORM_QC_NO},
+	{0xAEB1, UNICODE_NORM_QC_NO},
+	{0xAEB2, UNICODE_NORM_QC_NO},
+	{0xAEB3, UNICODE_NORM_QC_NO},
+	{0xAEB4, UNICODE_NORM_QC_NO},
+	{0xAEB5, UNICODE_NORM_QC_NO},
+	{0xAEB6, UNICODE_NORM_QC_NO},
+	{0xAEB7, UNICODE_NORM_QC_NO},
+	{0xAEB8, UNICODE_NORM_QC_NO},
+	{0xAEB9, UNICODE_NORM_QC_NO},
+	{0xAEBA, UNICODE_NORM_QC_NO},
+	{0xAEBB, UNICODE_NORM_QC_NO},
+	{0xAEBC, UNICODE_NORM_QC_NO},
+	{0xAEBD, UNICODE_NORM_QC_NO},
+	{0xAEBE, UNICODE_NORM_QC_NO},
+	{0xAEBF, UNICODE_NORM_QC_NO},
+	{0xAEC0, UNICODE_NORM_QC_NO},
+	{0xAEC1, UNICODE_NORM_QC_NO},
+	{0xAEC2, UNICODE_NORM_QC_NO},
+	{0xAEC3, UNICODE_NORM_QC_NO},
+	{0xAEC4, UNICODE_NORM_QC_NO},
+	{0xAEC5, UNICODE_NORM_QC_NO},
+	{0xAEC6, UNICODE_NORM_QC_NO},
+	{0xAEC7, UNICODE_NORM_QC_NO},
+	{0xAEC8, UNICODE_NORM_QC_NO},
+	{0xAEC9, UNICODE_NORM_QC_NO},
+	{0xAECA, UNICODE_NORM_QC_NO},
+	{0xAECB, UNICODE_NORM_QC_NO},
+	{0xAECC, UNICODE_NORM_QC_NO},
+	{0xAECD, UNICODE_NORM_QC_NO},
+	{0xAECE, UNICODE_NORM_QC_NO},
+	{0xAECF, UNICODE_NORM_QC_NO},
+	{0xAED0, UNICODE_NORM_QC_NO},
+	{0xAED1, UNICODE_NORM_QC_NO},
+	{0xAED2, UNICODE_NORM_QC_NO},
+	{0xAED3, UNICODE_NORM_QC_NO},
+	{0xAED4, UNICODE_NORM_QC_NO},
+	{0xAED5, UNICODE_NORM_QC_NO},
+	{0xAED6, UNICODE_NORM_QC_NO},
+	{0xAED7, UNICODE_NORM_QC_NO},
+	{0xAED8, UNICODE_NORM_QC_NO},
+	{0xAED9, UNICODE_NORM_QC_NO},
+	{0xAEDA, UNICODE_NORM_QC_NO},
+	{0xAEDB, UNICODE_NORM_QC_NO},
+	{0xAEDC, UNICODE_NORM_QC_NO},
+	{0xAEDD, UNICODE_NORM_QC_NO},
+	{0xAEDE, UNICODE_NORM_QC_NO},
+	{0xAEDF, UNICODE_NORM_QC_NO},
+	{0xAEE0, UNICODE_NORM_QC_NO},
+	{0xAEE1, UNICODE_NORM_QC_NO},
+	{0xAEE2, UNICODE_NORM_QC_NO},
+	{0xAEE3, UNICODE_NORM_QC_NO},
+	{0xAEE4, UNICODE_NORM_QC_NO},
+	{0xAEE5, UNICODE_NORM_QC_NO},
+	{0xAEE6, UNICODE_NORM_QC_NO},
+	{0xAEE7, UNICODE_NORM_QC_NO},
+	{0xAEE8, UNICODE_NORM_QC_NO},
+	{0xAEE9, UNICODE_NORM_QC_NO},
+	{0xAEEA, UNICODE_NORM_QC_NO},
+	{0xAEEB, UNICODE_NORM_QC_NO},
+	{0xAEEC, UNICODE_NORM_QC_NO},
+	{0xAEED, UNICODE_NORM_QC_NO},
+	{0xAEEE, UNICODE_NORM_QC_NO},
+	{0xAEEF, UNICODE_NORM_QC_NO},
+	{0xAEF0, UNICODE_NORM_QC_NO},
+	{0xAEF1, UNICODE_NORM_QC_NO},
+	{0xAEF2, UNICODE_NORM_QC_NO},
+	{0xAEF3, UNICODE_NORM_QC_NO},
+	{0xAEF4, UNICODE_NORM_QC_NO},
+	{0xAEF5, UNICODE_NORM_QC_NO},
+	{0xAEF6, UNICODE_NORM_QC_NO},
+	{0xAEF7, UNICODE_NORM_QC_NO},
+	{0xAEF8, UNICODE_NORM_QC_NO},
+	{0xAEF9, UNICODE_NORM_QC_NO},
+	{0xAEFA, UNICODE_NORM_QC_NO},
+	{0xAEFB, UNICODE_NORM_QC_NO},
+	{0xAEFC, UNICODE_NORM_QC_NO},
+	{0xAEFD, UNICODE_NORM_QC_NO},
+	{0xAEFE, UNICODE_NORM_QC_NO},
+	{0xAEFF, UNICODE_NORM_QC_NO},
+	{0xAF00, UNICODE_NORM_QC_NO},
+	{0xAF01, UNICODE_NORM_QC_NO},
+	{0xAF02, UNICODE_NORM_QC_NO},
+	{0xAF03, UNICODE_NORM_QC_NO},
+	{0xAF04, UNICODE_NORM_QC_NO},
+	{0xAF05, UNICODE_NORM_QC_NO},
+	{0xAF06, UNICODE_NORM_QC_NO},
+	{0xAF07, UNICODE_NORM_QC_NO},
+	{0xAF08, UNICODE_NORM_QC_NO},
+	{0xAF09, UNICODE_NORM_QC_NO},
+	{0xAF0A, UNICODE_NORM_QC_NO},
+	{0xAF0B, UNICODE_NORM_QC_NO},
+	{0xAF0C, UNICODE_NORM_QC_NO},
+	{0xAF0D, UNICODE_NORM_QC_NO},
+	{0xAF0E, UNICODE_NORM_QC_NO},
+	{0xAF0F, UNICODE_NORM_QC_NO},
+	{0xAF10, UNICODE_NORM_QC_NO},
+	{0xAF11, UNICODE_NORM_QC_NO},
+	{0xAF12, UNICODE_NORM_QC_NO},
+	{0xAF13, UNICODE_NORM_QC_NO},
+	{0xAF14, UNICODE_NORM_QC_NO},
+	{0xAF15, UNICODE_NORM_QC_NO},
+	{0xAF16, UNICODE_NORM_QC_NO},
+	{0xAF17, UNICODE_NORM_QC_NO},
+	{0xAF18, UNICODE_NORM_QC_NO},
+	{0xAF19, UNICODE_NORM_QC_NO},
+	{0xAF1A, UNICODE_NORM_QC_NO},
+	{0xAF1B, UNICODE_NORM_QC_NO},
+	{0xAF1C, UNICODE_NORM_QC_NO},
+	{0xAF1D, UNICODE_NORM_QC_NO},
+	{0xAF1E, UNICODE_NORM_QC_NO},
+	{0xAF1F, UNICODE_NORM_QC_NO},
+	{0xAF20, UNICODE_NORM_QC_NO},
+	{0xAF21, UNICODE_NORM_QC_NO},
+	{0xAF22, UNICODE_NORM_QC_NO},
+	{0xAF23, UNICODE_NORM_QC_NO},
+	{0xAF24, UNICODE_NORM_QC_NO},
+	{0xAF25, UNICODE_NORM_QC_NO},
+	{0xAF26, UNICODE_NORM_QC_NO},
+	{0xAF27, UNICODE_NORM_QC_NO},
+	{0xAF28, UNICODE_NORM_QC_NO},
+	{0xAF29, UNICODE_NORM_QC_NO},
+	{0xAF2A, UNICODE_NORM_QC_NO},
+	{0xAF2B, UNICODE_NORM_QC_NO},
+	{0xAF2C, UNICODE_NORM_QC_NO},
+	{0xAF2D, UNICODE_NORM_QC_NO},
+	{0xAF2E, UNICODE_NORM_QC_NO},
+	{0xAF2F, UNICODE_NORM_QC_NO},
+	{0xAF30, UNICODE_NORM_QC_NO},
+	{0xAF31, UNICODE_NORM_QC_NO},
+	{0xAF32, UNICODE_NORM_QC_NO},
+	{0xAF33, UNICODE_NORM_QC_NO},
+	{0xAF34, UNICODE_NORM_QC_NO},
+	{0xAF35, UNICODE_NORM_QC_NO},
+	{0xAF36, UNICODE_NORM_QC_NO},
+	{0xAF37, UNICODE_NORM_QC_NO},
+	{0xAF38, UNICODE_NORM_QC_NO},
+	{0xAF39, UNICODE_NORM_QC_NO},
+	{0xAF3A, UNICODE_NORM_QC_NO},
+	{0xAF3B, UNICODE_NORM_QC_NO},
+	{0xAF3C, UNICODE_NORM_QC_NO},
+	{0xAF3D, UNICODE_NORM_QC_NO},
+	{0xAF3E, UNICODE_NORM_QC_NO},
+	{0xAF3F, UNICODE_NORM_QC_NO},
+	{0xAF40, UNICODE_NORM_QC_NO},
+	{0xAF41, UNICODE_NORM_QC_NO},
+	{0xAF42, UNICODE_NORM_QC_NO},
+	{0xAF43, UNICODE_NORM_QC_NO},
+	{0xAF44, UNICODE_NORM_QC_NO},
+	{0xAF45, UNICODE_NORM_QC_NO},
+	{0xAF46, UNICODE_NORM_QC_NO},
+	{0xAF47, UNICODE_NORM_QC_NO},
+	{0xAF48, UNICODE_NORM_QC_NO},
+	{0xAF49, UNICODE_NORM_QC_NO},
+	{0xAF4A, UNICODE_NORM_QC_NO},
+	{0xAF4B, UNICODE_NORM_QC_NO},
+	{0xAF4C, UNICODE_NORM_QC_NO},
+	{0xAF4D, UNICODE_NORM_QC_NO},
+	{0xAF4E, UNICODE_NORM_QC_NO},
+	{0xAF4F, UNICODE_NORM_QC_NO},
+	{0xAF50, UNICODE_NORM_QC_NO},
+	{0xAF51, UNICODE_NORM_QC_NO},
+	{0xAF52, UNICODE_NORM_QC_NO},
+	{0xAF53, UNICODE_NORM_QC_NO},
+	{0xAF54, UNICODE_NORM_QC_NO},
+	{0xAF55, UNICODE_NORM_QC_NO},
+	{0xAF56, UNICODE_NORM_QC_NO},
+	{0xAF57, UNICODE_NORM_QC_NO},
+	{0xAF58, UNICODE_NORM_QC_NO},
+	{0xAF59, UNICODE_NORM_QC_NO},
+	{0xAF5A, UNICODE_NORM_QC_NO},
+	{0xAF5B, UNICODE_NORM_QC_NO},
+	{0xAF5C, UNICODE_NORM_QC_NO},
+	{0xAF5D, UNICODE_NORM_QC_NO},
+	{0xAF5E, UNICODE_NORM_QC_NO},
+	{0xAF5F, UNICODE_NORM_QC_NO},
+	{0xAF60, UNICODE_NORM_QC_NO},
+	{0xAF61, UNICODE_NORM_QC_NO},
+	{0xAF62, UNICODE_NORM_QC_NO},
+	{0xAF63, UNICODE_NORM_QC_NO},
+	{0xAF64, UNICODE_NORM_QC_NO},
+	{0xAF65, UNICODE_NORM_QC_NO},
+	{0xAF66, UNICODE_NORM_QC_NO},
+	{0xAF67, UNICODE_NORM_QC_NO},
+	{0xAF68, UNICODE_NORM_QC_NO},
+	{0xAF69, UNICODE_NORM_QC_NO},
+	{0xAF6A, UNICODE_NORM_QC_NO},
+	{0xAF6B, UNICODE_NORM_QC_NO},
+	{0xAF6C, UNICODE_NORM_QC_NO},
+	{0xAF6D, UNICODE_NORM_QC_NO},
+	{0xAF6E, UNICODE_NORM_QC_NO},
+	{0xAF6F, UNICODE_NORM_QC_NO},
+	{0xAF70, UNICODE_NORM_QC_NO},
+	{0xAF71, UNICODE_NORM_QC_NO},
+	{0xAF72, UNICODE_NORM_QC_NO},
+	{0xAF73, UNICODE_NORM_QC_NO},
+	{0xAF74, UNICODE_NORM_QC_NO},
+	{0xAF75, UNICODE_NORM_QC_NO},
+	{0xAF76, UNICODE_NORM_QC_NO},
+	{0xAF77, UNICODE_NORM_QC_NO},
+	{0xAF78, UNICODE_NORM_QC_NO},
+	{0xAF79, UNICODE_NORM_QC_NO},
+	{0xAF7A, UNICODE_NORM_QC_NO},
+	{0xAF7B, UNICODE_NORM_QC_NO},
+	{0xAF7C, UNICODE_NORM_QC_NO},
+	{0xAF7D, UNICODE_NORM_QC_NO},
+	{0xAF7E, UNICODE_NORM_QC_NO},
+	{0xAF7F, UNICODE_NORM_QC_NO},
+	{0xAF80, UNICODE_NORM_QC_NO},
+	{0xAF81, UNICODE_NORM_QC_NO},
+	{0xAF82, UNICODE_NORM_QC_NO},
+	{0xAF83, UNICODE_NORM_QC_NO},
+	{0xAF84, UNICODE_NORM_QC_NO},
+	{0xAF85, UNICODE_NORM_QC_NO},
+	{0xAF86, UNICODE_NORM_QC_NO},
+	{0xAF87, UNICODE_NORM_QC_NO},
+	{0xAF88, UNICODE_NORM_QC_NO},
+	{0xAF89, UNICODE_NORM_QC_NO},
+	{0xAF8A, UNICODE_NORM_QC_NO},
+	{0xAF8B, UNICODE_NORM_QC_NO},
+	{0xAF8C, UNICODE_NORM_QC_NO},
+	{0xAF8D, UNICODE_NORM_QC_NO},
+	{0xAF8E, UNICODE_NORM_QC_NO},
+	{0xAF8F, UNICODE_NORM_QC_NO},
+	{0xAF90, UNICODE_NORM_QC_NO},
+	{0xAF91, UNICODE_NORM_QC_NO},
+	{0xAF92, UNICODE_NORM_QC_NO},
+	{0xAF93, UNICODE_NORM_QC_NO},
+	{0xAF94, UNICODE_NORM_QC_NO},
+	{0xAF95, UNICODE_NORM_QC_NO},
+	{0xAF96, UNICODE_NORM_QC_NO},
+	{0xAF97, UNICODE_NORM_QC_NO},
+	{0xAF98, UNICODE_NORM_QC_NO},
+	{0xAF99, UNICODE_NORM_QC_NO},
+	{0xAF9A, UNICODE_NORM_QC_NO},
+	{0xAF9B, UNICODE_NORM_QC_NO},
+	{0xAF9C, UNICODE_NORM_QC_NO},
+	{0xAF9D, UNICODE_NORM_QC_NO},
+	{0xAF9E, UNICODE_NORM_QC_NO},
+	{0xAF9F, UNICODE_NORM_QC_NO},
+	{0xAFA0, UNICODE_NORM_QC_NO},
+	{0xAFA1, UNICODE_NORM_QC_NO},
+	{0xAFA2, UNICODE_NORM_QC_NO},
+	{0xAFA3, UNICODE_NORM_QC_NO},
+	{0xAFA4, UNICODE_NORM_QC_NO},
+	{0xAFA5, UNICODE_NORM_QC_NO},
+	{0xAFA6, UNICODE_NORM_QC_NO},
+	{0xAFA7, UNICODE_NORM_QC_NO},
+	{0xAFA8, UNICODE_NORM_QC_NO},
+	{0xAFA9, UNICODE_NORM_QC_NO},
+	{0xAFAA, UNICODE_NORM_QC_NO},
+	{0xAFAB, UNICODE_NORM_QC_NO},
+	{0xAFAC, UNICODE_NORM_QC_NO},
+	{0xAFAD, UNICODE_NORM_QC_NO},
+	{0xAFAE, UNICODE_NORM_QC_NO},
+	{0xAFAF, UNICODE_NORM_QC_NO},
+	{0xAFB0, UNICODE_NORM_QC_NO},
+	{0xAFB1, UNICODE_NORM_QC_NO},
+	{0xAFB2, UNICODE_NORM_QC_NO},
+	{0xAFB3, UNICODE_NORM_QC_NO},
+	{0xAFB4, UNICODE_NORM_QC_NO},
+	{0xAFB5, UNICODE_NORM_QC_NO},
+	{0xAFB6, UNICODE_NORM_QC_NO},
+	{0xAFB7, UNICODE_NORM_QC_NO},
+	{0xAFB8, UNICODE_NORM_QC_NO},
+	{0xAFB9, UNICODE_NORM_QC_NO},
+	{0xAFBA, UNICODE_NORM_QC_NO},
+	{0xAFBB, UNICODE_NORM_QC_NO},
+	{0xAFBC, UNICODE_NORM_QC_NO},
+	{0xAFBD, UNICODE_NORM_QC_NO},
+	{0xAFBE, UNICODE_NORM_QC_NO},
+	{0xAFBF, UNICODE_NORM_QC_NO},
+	{0xAFC0, UNICODE_NORM_QC_NO},
+	{0xAFC1, UNICODE_NORM_QC_NO},
+	{0xAFC2, UNICODE_NORM_QC_NO},
+	{0xAFC3, UNICODE_NORM_QC_NO},
+	{0xAFC4, UNICODE_NORM_QC_NO},
+	{0xAFC5, UNICODE_NORM_QC_NO},
+	{0xAFC6, UNICODE_NORM_QC_NO},
+	{0xAFC7, UNICODE_NORM_QC_NO},
+	{0xAFC8, UNICODE_NORM_QC_NO},
+	{0xAFC9, UNICODE_NORM_QC_NO},
+	{0xAFCA, UNICODE_NORM_QC_NO},
+	{0xAFCB, UNICODE_NORM_QC_NO},
+	{0xAFCC, UNICODE_NORM_QC_NO},
+	{0xAFCD, UNICODE_NORM_QC_NO},
+	{0xAFCE, UNICODE_NORM_QC_NO},
+	{0xAFCF, UNICODE_NORM_QC_NO},
+	{0xAFD0, UNICODE_NORM_QC_NO},
+	{0xAFD1, UNICODE_NORM_QC_NO},
+	{0xAFD2, UNICODE_NORM_QC_NO},
+	{0xAFD3, UNICODE_NORM_QC_NO},
+	{0xAFD4, UNICODE_NORM_QC_NO},
+	{0xAFD5, UNICODE_NORM_QC_NO},
+	{0xAFD6, UNICODE_NORM_QC_NO},
+	{0xAFD7, UNICODE_NORM_QC_NO},
+	{0xAFD8, UNICODE_NORM_QC_NO},
+	{0xAFD9, UNICODE_NORM_QC_NO},
+	{0xAFDA, UNICODE_NORM_QC_NO},
+	{0xAFDB, UNICODE_NORM_QC_NO},
+	{0xAFDC, UNICODE_NORM_QC_NO},
+	{0xAFDD, UNICODE_NORM_QC_NO},
+	{0xAFDE, UNICODE_NORM_QC_NO},
+	{0xAFDF, UNICODE_NORM_QC_NO},
+	{0xAFE0, UNICODE_NORM_QC_NO},
+	{0xAFE1, UNICODE_NORM_QC_NO},
+	{0xAFE2, UNICODE_NORM_QC_NO},
+	{0xAFE3, UNICODE_NORM_QC_NO},
+	{0xAFE4, UNICODE_NORM_QC_NO},
+	{0xAFE5, UNICODE_NORM_QC_NO},
+	{0xAFE6, UNICODE_NORM_QC_NO},
+	{0xAFE7, UNICODE_NORM_QC_NO},
+	{0xAFE8, UNICODE_NORM_QC_NO},
+	{0xAFE9, UNICODE_NORM_QC_NO},
+	{0xAFEA, UNICODE_NORM_QC_NO},
+	{0xAFEB, UNICODE_NORM_QC_NO},
+	{0xAFEC, UNICODE_NORM_QC_NO},
+	{0xAFED, UNICODE_NORM_QC_NO},
+	{0xAFEE, UNICODE_NORM_QC_NO},
+	{0xAFEF, UNICODE_NORM_QC_NO},
+	{0xAFF0, UNICODE_NORM_QC_NO},
+	{0xAFF1, UNICODE_NORM_QC_NO},
+	{0xAFF2, UNICODE_NORM_QC_NO},
+	{0xAFF3, UNICODE_NORM_QC_NO},
+	{0xAFF4, UNICODE_NORM_QC_NO},
+	{0xAFF5, UNICODE_NORM_QC_NO},
+	{0xAFF6, UNICODE_NORM_QC_NO},
+	{0xAFF7, UNICODE_NORM_QC_NO},
+	{0xAFF8, UNICODE_NORM_QC_NO},
+	{0xAFF9, UNICODE_NORM_QC_NO},
+	{0xAFFA, UNICODE_NORM_QC_NO},
+	{0xAFFB, UNICODE_NORM_QC_NO},
+	{0xAFFC, UNICODE_NORM_QC_NO},
+	{0xAFFD, UNICODE_NORM_QC_NO},
+	{0xAFFE, UNICODE_NORM_QC_NO},
+	{0xAFFF, UNICODE_NORM_QC_NO},
+	{0xB000, UNICODE_NORM_QC_NO},
+	{0xB001, UNICODE_NORM_QC_NO},
+	{0xB002, UNICODE_NORM_QC_NO},
+	{0xB003, UNICODE_NORM_QC_NO},
+	{0xB004, UNICODE_NORM_QC_NO},
+	{0xB005, UNICODE_NORM_QC_NO},
+	{0xB006, UNICODE_NORM_QC_NO},
+	{0xB007, UNICODE_NORM_QC_NO},
+	{0xB008, UNICODE_NORM_QC_NO},
+	{0xB009, UNICODE_NORM_QC_NO},
+	{0xB00A, UNICODE_NORM_QC_NO},
+	{0xB00B, UNICODE_NORM_QC_NO},
+	{0xB00C, UNICODE_NORM_QC_NO},
+	{0xB00D, UNICODE_NORM_QC_NO},
+	{0xB00E, UNICODE_NORM_QC_NO},
+	{0xB00F, UNICODE_NORM_QC_NO},
+	{0xB010, UNICODE_NORM_QC_NO},
+	{0xB011, UNICODE_NORM_QC_NO},
+	{0xB012, UNICODE_NORM_QC_NO},
+	{0xB013, UNICODE_NORM_QC_NO},
+	{0xB014, UNICODE_NORM_QC_NO},
+	{0xB015, UNICODE_NORM_QC_NO},
+	{0xB016, UNICODE_NORM_QC_NO},
+	{0xB017, UNICODE_NORM_QC_NO},
+	{0xB018, UNICODE_NORM_QC_NO},
+	{0xB019, UNICODE_NORM_QC_NO},
+	{0xB01A, UNICODE_NORM_QC_NO},
+	{0xB01B, UNICODE_NORM_QC_NO},
+	{0xB01C, UNICODE_NORM_QC_NO},
+	{0xB01D, UNICODE_NORM_QC_NO},
+	{0xB01E, UNICODE_NORM_QC_NO},
+	{0xB01F, UNICODE_NORM_QC_NO},
+	{0xB020, UNICODE_NORM_QC_NO},
+	{0xB021, UNICODE_NORM_QC_NO},
+	{0xB022, UNICODE_NORM_QC_NO},
+	{0xB023, UNICODE_NORM_QC_NO},
+	{0xB024, UNICODE_NORM_QC_NO},
+	{0xB025, UNICODE_NORM_QC_NO},
+	{0xB026, UNICODE_NORM_QC_NO},
+	{0xB027, UNICODE_NORM_QC_NO},
+	{0xB028, UNICODE_NORM_QC_NO},
+	{0xB029, UNICODE_NORM_QC_NO},
+	{0xB02A, UNICODE_NORM_QC_NO},
+	{0xB02B, UNICODE_NORM_QC_NO},
+	{0xB02C, UNICODE_NORM_QC_NO},
+	{0xB02D, UNICODE_NORM_QC_NO},
+	{0xB02E, UNICODE_NORM_QC_NO},
+	{0xB02F, UNICODE_NORM_QC_NO},
+	{0xB030, UNICODE_NORM_QC_NO},
+	{0xB031, UNICODE_NORM_QC_NO},
+	{0xB032, UNICODE_NORM_QC_NO},
+	{0xB033, UNICODE_NORM_QC_NO},
+	{0xB034, UNICODE_NORM_QC_NO},
+	{0xB035, UNICODE_NORM_QC_NO},
+	{0xB036, UNICODE_NORM_QC_NO},
+	{0xB037, UNICODE_NORM_QC_NO},
+	{0xB038, UNICODE_NORM_QC_NO},
+	{0xB039, UNICODE_NORM_QC_NO},
+	{0xB03A, UNICODE_NORM_QC_NO},
+	{0xB03B, UNICODE_NORM_QC_NO},
+	{0xB03C, UNICODE_NORM_QC_NO},
+	{0xB03D, UNICODE_NORM_QC_NO},
+	{0xB03E, UNICODE_NORM_QC_NO},
+	{0xB03F, UNICODE_NORM_QC_NO},
+	{0xB040, UNICODE_NORM_QC_NO},
+	{0xB041, UNICODE_NORM_QC_NO},
+	{0xB042, UNICODE_NORM_QC_NO},
+	{0xB043, UNICODE_NORM_QC_NO},
+	{0xB044, UNICODE_NORM_QC_NO},
+	{0xB045, UNICODE_NORM_QC_NO},
+	{0xB046, UNICODE_NORM_QC_NO},
+	{0xB047, UNICODE_NORM_QC_NO},
+	{0xB048, UNICODE_NORM_QC_NO},
+	{0xB049, UNICODE_NORM_QC_NO},
+	{0xB04A, UNICODE_NORM_QC_NO},
+	{0xB04B, UNICODE_NORM_QC_NO},
+	{0xB04C, UNICODE_NORM_QC_NO},
+	{0xB04D, UNICODE_NORM_QC_NO},
+	{0xB04E, UNICODE_NORM_QC_NO},
+	{0xB04F, UNICODE_NORM_QC_NO},
+	{0xB050, UNICODE_NORM_QC_NO},
+	{0xB051, UNICODE_NORM_QC_NO},
+	{0xB052, UNICODE_NORM_QC_NO},
+	{0xB053, UNICODE_NORM_QC_NO},
+	{0xB054, UNICODE_NORM_QC_NO},
+	{0xB055, UNICODE_NORM_QC_NO},
+	{0xB056, UNICODE_NORM_QC_NO},
+	{0xB057, UNICODE_NORM_QC_NO},
+	{0xB058, UNICODE_NORM_QC_NO},
+	{0xB059, UNICODE_NORM_QC_NO},
+	{0xB05A, UNICODE_NORM_QC_NO},
+	{0xB05B, UNICODE_NORM_QC_NO},
+	{0xB05C, UNICODE_NORM_QC_NO},
+	{0xB05D, UNICODE_NORM_QC_NO},
+	{0xB05E, UNICODE_NORM_QC_NO},
+	{0xB05F, UNICODE_NORM_QC_NO},
+	{0xB060, UNICODE_NORM_QC_NO},
+	{0xB061, UNICODE_NORM_QC_NO},
+	{0xB062, UNICODE_NORM_QC_NO},
+	{0xB063, UNICODE_NORM_QC_NO},
+	{0xB064, UNICODE_NORM_QC_NO},
+	{0xB065, UNICODE_NORM_QC_NO},
+	{0xB066, UNICODE_NORM_QC_NO},
+	{0xB067, UNICODE_NORM_QC_NO},
+	{0xB068, UNICODE_NORM_QC_NO},
+	{0xB069, UNICODE_NORM_QC_NO},
+	{0xB06A, UNICODE_NORM_QC_NO},
+	{0xB06B, UNICODE_NORM_QC_NO},
+	{0xB06C, UNICODE_NORM_QC_NO},
+	{0xB06D, UNICODE_NORM_QC_NO},
+	{0xB06E, UNICODE_NORM_QC_NO},
+	{0xB06F, UNICODE_NORM_QC_NO},
+	{0xB070, UNICODE_NORM_QC_NO},
+	{0xB071, UNICODE_NORM_QC_NO},
+	{0xB072, UNICODE_NORM_QC_NO},
+	{0xB073, UNICODE_NORM_QC_NO},
+	{0xB074, UNICODE_NORM_QC_NO},
+	{0xB075, UNICODE_NORM_QC_NO},
+	{0xB076, UNICODE_NORM_QC_NO},
+	{0xB077, UNICODE_NORM_QC_NO},
+	{0xB078, UNICODE_NORM_QC_NO},
+	{0xB079, UNICODE_NORM_QC_NO},
+	{0xB07A, UNICODE_NORM_QC_NO},
+	{0xB07B, UNICODE_NORM_QC_NO},
+	{0xB07C, UNICODE_NORM_QC_NO},
+	{0xB07D, UNICODE_NORM_QC_NO},
+	{0xB07E, UNICODE_NORM_QC_NO},
+	{0xB07F, UNICODE_NORM_QC_NO},
+	{0xB080, UNICODE_NORM_QC_NO},
+	{0xB081, UNICODE_NORM_QC_NO},
+	{0xB082, UNICODE_NORM_QC_NO},
+	{0xB083, UNICODE_NORM_QC_NO},
+	{0xB084, UNICODE_NORM_QC_NO},
+	{0xB085, UNICODE_NORM_QC_NO},
+	{0xB086, UNICODE_NORM_QC_NO},
+	{0xB087, UNICODE_NORM_QC_NO},
+	{0xB088, UNICODE_NORM_QC_NO},
+	{0xB089, UNICODE_NORM_QC_NO},
+	{0xB08A, UNICODE_NORM_QC_NO},
+	{0xB08B, UNICODE_NORM_QC_NO},
+	{0xB08C, UNICODE_NORM_QC_NO},
+	{0xB08D, UNICODE_NORM_QC_NO},
+	{0xB08E, UNICODE_NORM_QC_NO},
+	{0xB08F, UNICODE_NORM_QC_NO},
+	{0xB090, UNICODE_NORM_QC_NO},
+	{0xB091, UNICODE_NORM_QC_NO},
+	{0xB092, UNICODE_NORM_QC_NO},
+	{0xB093, UNICODE_NORM_QC_NO},
+	{0xB094, UNICODE_NORM_QC_NO},
+	{0xB095, UNICODE_NORM_QC_NO},
+	{0xB096, UNICODE_NORM_QC_NO},
+	{0xB097, UNICODE_NORM_QC_NO},
+	{0xB098, UNICODE_NORM_QC_NO},
+	{0xB099, UNICODE_NORM_QC_NO},
+	{0xB09A, UNICODE_NORM_QC_NO},
+	{0xB09B, UNICODE_NORM_QC_NO},
+	{0xB09C, UNICODE_NORM_QC_NO},
+	{0xB09D, UNICODE_NORM_QC_NO},
+	{0xB09E, UNICODE_NORM_QC_NO},
+	{0xB09F, UNICODE_NORM_QC_NO},
+	{0xB0A0, UNICODE_NORM_QC_NO},
+	{0xB0A1, UNICODE_NORM_QC_NO},
+	{0xB0A2, UNICODE_NORM_QC_NO},
+	{0xB0A3, UNICODE_NORM_QC_NO},
+	{0xB0A4, UNICODE_NORM_QC_NO},
+	{0xB0A5, UNICODE_NORM_QC_NO},
+	{0xB0A6, UNICODE_NORM_QC_NO},
+	{0xB0A7, UNICODE_NORM_QC_NO},
+	{0xB0A8, UNICODE_NORM_QC_NO},
+	{0xB0A9, UNICODE_NORM_QC_NO},
+	{0xB0AA, UNICODE_NORM_QC_NO},
+	{0xB0AB, UNICODE_NORM_QC_NO},
+	{0xB0AC, UNICODE_NORM_QC_NO},
+	{0xB0AD, UNICODE_NORM_QC_NO},
+	{0xB0AE, UNICODE_NORM_QC_NO},
+	{0xB0AF, UNICODE_NORM_QC_NO},
+	{0xB0B0, UNICODE_NORM_QC_NO},
+	{0xB0B1, UNICODE_NORM_QC_NO},
+	{0xB0B2, UNICODE_NORM_QC_NO},
+	{0xB0B3, UNICODE_NORM_QC_NO},
+	{0xB0B4, UNICODE_NORM_QC_NO},
+	{0xB0B5, UNICODE_NORM_QC_NO},
+	{0xB0B6, UNICODE_NORM_QC_NO},
+	{0xB0B7, UNICODE_NORM_QC_NO},
+	{0xB0B8, UNICODE_NORM_QC_NO},
+	{0xB0B9, UNICODE_NORM_QC_NO},
+	{0xB0BA, UNICODE_NORM_QC_NO},
+	{0xB0BB, UNICODE_NORM_QC_NO},
+	{0xB0BC, UNICODE_NORM_QC_NO},
+	{0xB0BD, UNICODE_NORM_QC_NO},
+	{0xB0BE, UNICODE_NORM_QC_NO},
+	{0xB0BF, UNICODE_NORM_QC_NO},
+	{0xB0C0, UNICODE_NORM_QC_NO},
+	{0xB0C1, UNICODE_NORM_QC_NO},
+	{0xB0C2, UNICODE_NORM_QC_NO},
+	{0xB0C3, UNICODE_NORM_QC_NO},
+	{0xB0C4, UNICODE_NORM_QC_NO},
+	{0xB0C5, UNICODE_NORM_QC_NO},
+	{0xB0C6, UNICODE_NORM_QC_NO},
+	{0xB0C7, UNICODE_NORM_QC_NO},
+	{0xB0C8, UNICODE_NORM_QC_NO},
+	{0xB0C9, UNICODE_NORM_QC_NO},
+	{0xB0CA, UNICODE_NORM_QC_NO},
+	{0xB0CB, UNICODE_NORM_QC_NO},
+	{0xB0CC, UNICODE_NORM_QC_NO},
+	{0xB0CD, UNICODE_NORM_QC_NO},
+	{0xB0CE, UNICODE_NORM_QC_NO},
+	{0xB0CF, UNICODE_NORM_QC_NO},
+	{0xB0D0, UNICODE_NORM_QC_NO},
+	{0xB0D1, UNICODE_NORM_QC_NO},
+	{0xB0D2, UNICODE_NORM_QC_NO},
+	{0xB0D3, UNICODE_NORM_QC_NO},
+	{0xB0D4, UNICODE_NORM_QC_NO},
+	{0xB0D5, UNICODE_NORM_QC_NO},
+	{0xB0D6, UNICODE_NORM_QC_NO},
+	{0xB0D7, UNICODE_NORM_QC_NO},
+	{0xB0D8, UNICODE_NORM_QC_NO},
+	{0xB0D9, UNICODE_NORM_QC_NO},
+	{0xB0DA, UNICODE_NORM_QC_NO},
+	{0xB0DB, UNICODE_NORM_QC_NO},
+	{0xB0DC, UNICODE_NORM_QC_NO},
+	{0xB0DD, UNICODE_NORM_QC_NO},
+	{0xB0DE, UNICODE_NORM_QC_NO},
+	{0xB0DF, UNICODE_NORM_QC_NO},
+	{0xB0E0, UNICODE_NORM_QC_NO},
+	{0xB0E1, UNICODE_NORM_QC_NO},
+	{0xB0E2, UNICODE_NORM_QC_NO},
+	{0xB0E3, UNICODE_NORM_QC_NO},
+	{0xB0E4, UNICODE_NORM_QC_NO},
+	{0xB0E5, UNICODE_NORM_QC_NO},
+	{0xB0E6, UNICODE_NORM_QC_NO},
+	{0xB0E7, UNICODE_NORM_QC_NO},
+	{0xB0E8, UNICODE_NORM_QC_NO},
+	{0xB0E9, UNICODE_NORM_QC_NO},
+	{0xB0EA, UNICODE_NORM_QC_NO},
+	{0xB0EB, UNICODE_NORM_QC_NO},
+	{0xB0EC, UNICODE_NORM_QC_NO},
+	{0xB0ED, UNICODE_NORM_QC_NO},
+	{0xB0EE, UNICODE_NORM_QC_NO},
+	{0xB0EF, UNICODE_NORM_QC_NO},
+	{0xB0F0, UNICODE_NORM_QC_NO},
+	{0xB0F1, UNICODE_NORM_QC_NO},
+	{0xB0F2, UNICODE_NORM_QC_NO},
+	{0xB0F3, UNICODE_NORM_QC_NO},
+	{0xB0F4, UNICODE_NORM_QC_NO},
+	{0xB0F5, UNICODE_NORM_QC_NO},
+	{0xB0F6, UNICODE_NORM_QC_NO},
+	{0xB0F7, UNICODE_NORM_QC_NO},
+	{0xB0F8, UNICODE_NORM_QC_NO},
+	{0xB0F9, UNICODE_NORM_QC_NO},
+	{0xB0FA, UNICODE_NORM_QC_NO},
+	{0xB0FB, UNICODE_NORM_QC_NO},
+	{0xB0FC, UNICODE_NORM_QC_NO},
+	{0xB0FD, UNICODE_NORM_QC_NO},
+	{0xB0FE, UNICODE_NORM_QC_NO},
+	{0xB0FF, UNICODE_NORM_QC_NO},
+	{0xB100, UNICODE_NORM_QC_NO},
+	{0xB101, UNICODE_NORM_QC_NO},
+	{0xB102, UNICODE_NORM_QC_NO},
+	{0xB103, UNICODE_NORM_QC_NO},
+	{0xB104, UNICODE_NORM_QC_NO},
+	{0xB105, UNICODE_NORM_QC_NO},
+	{0xB106, UNICODE_NORM_QC_NO},
+	{0xB107, UNICODE_NORM_QC_NO},
+	{0xB108, UNICODE_NORM_QC_NO},
+	{0xB109, UNICODE_NORM_QC_NO},
+	{0xB10A, UNICODE_NORM_QC_NO},
+	{0xB10B, UNICODE_NORM_QC_NO},
+	{0xB10C, UNICODE_NORM_QC_NO},
+	{0xB10D, UNICODE_NORM_QC_NO},
+	{0xB10E, UNICODE_NORM_QC_NO},
+	{0xB10F, UNICODE_NORM_QC_NO},
+	{0xB110, UNICODE_NORM_QC_NO},
+	{0xB111, UNICODE_NORM_QC_NO},
+	{0xB112, UNICODE_NORM_QC_NO},
+	{0xB113, UNICODE_NORM_QC_NO},
+	{0xB114, UNICODE_NORM_QC_NO},
+	{0xB115, UNICODE_NORM_QC_NO},
+	{0xB116, UNICODE_NORM_QC_NO},
+	{0xB117, UNICODE_NORM_QC_NO},
+	{0xB118, UNICODE_NORM_QC_NO},
+	{0xB119, UNICODE_NORM_QC_NO},
+	{0xB11A, UNICODE_NORM_QC_NO},
+	{0xB11B, UNICODE_NORM_QC_NO},
+	{0xB11C, UNICODE_NORM_QC_NO},
+	{0xB11D, UNICODE_NORM_QC_NO},
+	{0xB11E, UNICODE_NORM_QC_NO},
+	{0xB11F, UNICODE_NORM_QC_NO},
+	{0xB120, UNICODE_NORM_QC_NO},
+	{0xB121, UNICODE_NORM_QC_NO},
+	{0xB122, UNICODE_NORM_QC_NO},
+	{0xB123, UNICODE_NORM_QC_NO},
+	{0xB124, UNICODE_NORM_QC_NO},
+	{0xB125, UNICODE_NORM_QC_NO},
+	{0xB126, UNICODE_NORM_QC_NO},
+	{0xB127, UNICODE_NORM_QC_NO},
+	{0xB128, UNICODE_NORM_QC_NO},
+	{0xB129, UNICODE_NORM_QC_NO},
+	{0xB12A, UNICODE_NORM_QC_NO},
+	{0xB12B, UNICODE_NORM_QC_NO},
+	{0xB12C, UNICODE_NORM_QC_NO},
+	{0xB12D, UNICODE_NORM_QC_NO},
+	{0xB12E, UNICODE_NORM_QC_NO},
+	{0xB12F, UNICODE_NORM_QC_NO},
+	{0xB130, UNICODE_NORM_QC_NO},
+	{0xB131, UNICODE_NORM_QC_NO},
+	{0xB132, UNICODE_NORM_QC_NO},
+	{0xB133, UNICODE_NORM_QC_NO},
+	{0xB134, UNICODE_NORM_QC_NO},
+	{0xB135, UNICODE_NORM_QC_NO},
+	{0xB136, UNICODE_NORM_QC_NO},
+	{0xB137, UNICODE_NORM_QC_NO},
+	{0xB138, UNICODE_NORM_QC_NO},
+	{0xB139, UNICODE_NORM_QC_NO},
+	{0xB13A, UNICODE_NORM_QC_NO},
+	{0xB13B, UNICODE_NORM_QC_NO},
+	{0xB13C, UNICODE_NORM_QC_NO},
+	{0xB13D, UNICODE_NORM_QC_NO},
+	{0xB13E, UNICODE_NORM_QC_NO},
+	{0xB13F, UNICODE_NORM_QC_NO},
+	{0xB140, UNICODE_NORM_QC_NO},
+	{0xB141, UNICODE_NORM_QC_NO},
+	{0xB142, UNICODE_NORM_QC_NO},
+	{0xB143, UNICODE_NORM_QC_NO},
+	{0xB144, UNICODE_NORM_QC_NO},
+	{0xB145, UNICODE_NORM_QC_NO},
+	{0xB146, UNICODE_NORM_QC_NO},
+	{0xB147, UNICODE_NORM_QC_NO},
+	{0xB148, UNICODE_NORM_QC_NO},
+	{0xB149, UNICODE_NORM_QC_NO},
+	{0xB14A, UNICODE_NORM_QC_NO},
+	{0xB14B, UNICODE_NORM_QC_NO},
+	{0xB14C, UNICODE_NORM_QC_NO},
+	{0xB14D, UNICODE_NORM_QC_NO},
+	{0xB14E, UNICODE_NORM_QC_NO},
+	{0xB14F, UNICODE_NORM_QC_NO},
+	{0xB150, UNICODE_NORM_QC_NO},
+	{0xB151, UNICODE_NORM_QC_NO},
+	{0xB152, UNICODE_NORM_QC_NO},
+	{0xB153, UNICODE_NORM_QC_NO},
+	{0xB154, UNICODE_NORM_QC_NO},
+	{0xB155, UNICODE_NORM_QC_NO},
+	{0xB156, UNICODE_NORM_QC_NO},
+	{0xB157, UNICODE_NORM_QC_NO},
+	{0xB158, UNICODE_NORM_QC_NO},
+	{0xB159, UNICODE_NORM_QC_NO},
+	{0xB15A, UNICODE_NORM_QC_NO},
+	{0xB15B, UNICODE_NORM_QC_NO},
+	{0xB15C, UNICODE_NORM_QC_NO},
+	{0xB15D, UNICODE_NORM_QC_NO},
+	{0xB15E, UNICODE_NORM_QC_NO},
+	{0xB15F, UNICODE_NORM_QC_NO},
+	{0xB160, UNICODE_NORM_QC_NO},
+	{0xB161, UNICODE_NORM_QC_NO},
+	{0xB162, UNICODE_NORM_QC_NO},
+	{0xB163, UNICODE_NORM_QC_NO},
+	{0xB164, UNICODE_NORM_QC_NO},
+	{0xB165, UNICODE_NORM_QC_NO},
+	{0xB166, UNICODE_NORM_QC_NO},
+	{0xB167, UNICODE_NORM_QC_NO},
+	{0xB168, UNICODE_NORM_QC_NO},
+	{0xB169, UNICODE_NORM_QC_NO},
+	{0xB16A, UNICODE_NORM_QC_NO},
+	{0xB16B, UNICODE_NORM_QC_NO},
+	{0xB16C, UNICODE_NORM_QC_NO},
+	{0xB16D, UNICODE_NORM_QC_NO},
+	{0xB16E, UNICODE_NORM_QC_NO},
+	{0xB16F, UNICODE_NORM_QC_NO},
+	{0xB170, UNICODE_NORM_QC_NO},
+	{0xB171, UNICODE_NORM_QC_NO},
+	{0xB172, UNICODE_NORM_QC_NO},
+	{0xB173, UNICODE_NORM_QC_NO},
+	{0xB174, UNICODE_NORM_QC_NO},
+	{0xB175, UNICODE_NORM_QC_NO},
+	{0xB176, UNICODE_NORM_QC_NO},
+	{0xB177, UNICODE_NORM_QC_NO},
+	{0xB178, UNICODE_NORM_QC_NO},
+	{0xB179, UNICODE_NORM_QC_NO},
+	{0xB17A, UNICODE_NORM_QC_NO},
+	{0xB17B, UNICODE_NORM_QC_NO},
+	{0xB17C, UNICODE_NORM_QC_NO},
+	{0xB17D, UNICODE_NORM_QC_NO},
+	{0xB17E, UNICODE_NORM_QC_NO},
+	{0xB17F, UNICODE_NORM_QC_NO},
+	{0xB180, UNICODE_NORM_QC_NO},
+	{0xB181, UNICODE_NORM_QC_NO},
+	{0xB182, UNICODE_NORM_QC_NO},
+	{0xB183, UNICODE_NORM_QC_NO},
+	{0xB184, UNICODE_NORM_QC_NO},
+	{0xB185, UNICODE_NORM_QC_NO},
+	{0xB186, UNICODE_NORM_QC_NO},
+	{0xB187, UNICODE_NORM_QC_NO},
+	{0xB188, UNICODE_NORM_QC_NO},
+	{0xB189, UNICODE_NORM_QC_NO},
+	{0xB18A, UNICODE_NORM_QC_NO},
+	{0xB18B, UNICODE_NORM_QC_NO},
+	{0xB18C, UNICODE_NORM_QC_NO},
+	{0xB18D, UNICODE_NORM_QC_NO},
+	{0xB18E, UNICODE_NORM_QC_NO},
+	{0xB18F, UNICODE_NORM_QC_NO},
+	{0xB190, UNICODE_NORM_QC_NO},
+	{0xB191, UNICODE_NORM_QC_NO},
+	{0xB192, UNICODE_NORM_QC_NO},
+	{0xB193, UNICODE_NORM_QC_NO},
+	{0xB194, UNICODE_NORM_QC_NO},
+	{0xB195, UNICODE_NORM_QC_NO},
+	{0xB196, UNICODE_NORM_QC_NO},
+	{0xB197, UNICODE_NORM_QC_NO},
+	{0xB198, UNICODE_NORM_QC_NO},
+	{0xB199, UNICODE_NORM_QC_NO},
+	{0xB19A, UNICODE_NORM_QC_NO},
+	{0xB19B, UNICODE_NORM_QC_NO},
+	{0xB19C, UNICODE_NORM_QC_NO},
+	{0xB19D, UNICODE_NORM_QC_NO},
+	{0xB19E, UNICODE_NORM_QC_NO},
+	{0xB19F, UNICODE_NORM_QC_NO},
+	{0xB1A0, UNICODE_NORM_QC_NO},
+	{0xB1A1, UNICODE_NORM_QC_NO},
+	{0xB1A2, UNICODE_NORM_QC_NO},
+	{0xB1A3, UNICODE_NORM_QC_NO},
+	{0xB1A4, UNICODE_NORM_QC_NO},
+	{0xB1A5, UNICODE_NORM_QC_NO},
+	{0xB1A6, UNICODE_NORM_QC_NO},
+	{0xB1A7, UNICODE_NORM_QC_NO},
+	{0xB1A8, UNICODE_NORM_QC_NO},
+	{0xB1A9, UNICODE_NORM_QC_NO},
+	{0xB1AA, UNICODE_NORM_QC_NO},
+	{0xB1AB, UNICODE_NORM_QC_NO},
+	{0xB1AC, UNICODE_NORM_QC_NO},
+	{0xB1AD, UNICODE_NORM_QC_NO},
+	{0xB1AE, UNICODE_NORM_QC_NO},
+	{0xB1AF, UNICODE_NORM_QC_NO},
+	{0xB1B0, UNICODE_NORM_QC_NO},
+	{0xB1B1, UNICODE_NORM_QC_NO},
+	{0xB1B2, UNICODE_NORM_QC_NO},
+	{0xB1B3, UNICODE_NORM_QC_NO},
+	{0xB1B4, UNICODE_NORM_QC_NO},
+	{0xB1B5, UNICODE_NORM_QC_NO},
+	{0xB1B6, UNICODE_NORM_QC_NO},
+	{0xB1B7, UNICODE_NORM_QC_NO},
+	{0xB1B8, UNICODE_NORM_QC_NO},
+	{0xB1B9, UNICODE_NORM_QC_NO},
+	{0xB1BA, UNICODE_NORM_QC_NO},
+	{0xB1BB, UNICODE_NORM_QC_NO},
+	{0xB1BC, UNICODE_NORM_QC_NO},
+	{0xB1BD, UNICODE_NORM_QC_NO},
+	{0xB1BE, UNICODE_NORM_QC_NO},
+	{0xB1BF, UNICODE_NORM_QC_NO},
+	{0xB1C0, UNICODE_NORM_QC_NO},
+	{0xB1C1, UNICODE_NORM_QC_NO},
+	{0xB1C2, UNICODE_NORM_QC_NO},
+	{0xB1C3, UNICODE_NORM_QC_NO},
+	{0xB1C4, UNICODE_NORM_QC_NO},
+	{0xB1C5, UNICODE_NORM_QC_NO},
+	{0xB1C6, UNICODE_NORM_QC_NO},
+	{0xB1C7, UNICODE_NORM_QC_NO},
+	{0xB1C8, UNICODE_NORM_QC_NO},
+	{0xB1C9, UNICODE_NORM_QC_NO},
+	{0xB1CA, UNICODE_NORM_QC_NO},
+	{0xB1CB, UNICODE_NORM_QC_NO},
+	{0xB1CC, UNICODE_NORM_QC_NO},
+	{0xB1CD, UNICODE_NORM_QC_NO},
+	{0xB1CE, UNICODE_NORM_QC_NO},
+	{0xB1CF, UNICODE_NORM_QC_NO},
+	{0xB1D0, UNICODE_NORM_QC_NO},
+	{0xB1D1, UNICODE_NORM_QC_NO},
+	{0xB1D2, UNICODE_NORM_QC_NO},
+	{0xB1D3, UNICODE_NORM_QC_NO},
+	{0xB1D4, UNICODE_NORM_QC_NO},
+	{0xB1D5, UNICODE_NORM_QC_NO},
+	{0xB1D6, UNICODE_NORM_QC_NO},
+	{0xB1D7, UNICODE_NORM_QC_NO},
+	{0xB1D8, UNICODE_NORM_QC_NO},
+	{0xB1D9, UNICODE_NORM_QC_NO},
+	{0xB1DA, UNICODE_NORM_QC_NO},
+	{0xB1DB, UNICODE_NORM_QC_NO},
+	{0xB1DC, UNICODE_NORM_QC_NO},
+	{0xB1DD, UNICODE_NORM_QC_NO},
+	{0xB1DE, UNICODE_NORM_QC_NO},
+	{0xB1DF, UNICODE_NORM_QC_NO},
+	{0xB1E0, UNICODE_NORM_QC_NO},
+	{0xB1E1, UNICODE_NORM_QC_NO},
+	{0xB1E2, UNICODE_NORM_QC_NO},
+	{0xB1E3, UNICODE_NORM_QC_NO},
+	{0xB1E4, UNICODE_NORM_QC_NO},
+	{0xB1E5, UNICODE_NORM_QC_NO},
+	{0xB1E6, UNICODE_NORM_QC_NO},
+	{0xB1E7, UNICODE_NORM_QC_NO},
+	{0xB1E8, UNICODE_NORM_QC_NO},
+	{0xB1E9, UNICODE_NORM_QC_NO},
+	{0xB1EA, UNICODE_NORM_QC_NO},
+	{0xB1EB, UNICODE_NORM_QC_NO},
+	{0xB1EC, UNICODE_NORM_QC_NO},
+	{0xB1ED, UNICODE_NORM_QC_NO},
+	{0xB1EE, UNICODE_NORM_QC_NO},
+	{0xB1EF, UNICODE_NORM_QC_NO},
+	{0xB1F0, UNICODE_NORM_QC_NO},
+	{0xB1F1, UNICODE_NORM_QC_NO},
+	{0xB1F2, UNICODE_NORM_QC_NO},
+	{0xB1F3, UNICODE_NORM_QC_NO},
+	{0xB1F4, UNICODE_NORM_QC_NO},
+	{0xB1F5, UNICODE_NORM_QC_NO},
+	{0xB1F6, UNICODE_NORM_QC_NO},
+	{0xB1F7, UNICODE_NORM_QC_NO},
+	{0xB1F8, UNICODE_NORM_QC_NO},
+	{0xB1F9, UNICODE_NORM_QC_NO},
+	{0xB1FA, UNICODE_NORM_QC_NO},
+	{0xB1FB, UNICODE_NORM_QC_NO},
+	{0xB1FC, UNICODE_NORM_QC_NO},
+	{0xB1FD, UNICODE_NORM_QC_NO},
+	{0xB1FE, UNICODE_NORM_QC_NO},
+	{0xB1FF, UNICODE_NORM_QC_NO},
+	{0xB200, UNICODE_NORM_QC_NO},
+	{0xB201, UNICODE_NORM_QC_NO},
+	{0xB202, UNICODE_NORM_QC_NO},
+	{0xB203, UNICODE_NORM_QC_NO},
+	{0xB204, UNICODE_NORM_QC_NO},
+	{0xB205, UNICODE_NORM_QC_NO},
+	{0xB206, UNICODE_NORM_QC_NO},
+	{0xB207, UNICODE_NORM_QC_NO},
+	{0xB208, UNICODE_NORM_QC_NO},
+	{0xB209, UNICODE_NORM_QC_NO},
+	{0xB20A, UNICODE_NORM_QC_NO},
+	{0xB20B, UNICODE_NORM_QC_NO},
+	{0xB20C, UNICODE_NORM_QC_NO},
+	{0xB20D, UNICODE_NORM_QC_NO},
+	{0xB20E, UNICODE_NORM_QC_NO},
+	{0xB20F, UNICODE_NORM_QC_NO},
+	{0xB210, UNICODE_NORM_QC_NO},
+	{0xB211, UNICODE_NORM_QC_NO},
+	{0xB212, UNICODE_NORM_QC_NO},
+	{0xB213, UNICODE_NORM_QC_NO},
+	{0xB214, UNICODE_NORM_QC_NO},
+	{0xB215, UNICODE_NORM_QC_NO},
+	{0xB216, UNICODE_NORM_QC_NO},
+	{0xB217, UNICODE_NORM_QC_NO},
+	{0xB218, UNICODE_NORM_QC_NO},
+	{0xB219, UNICODE_NORM_QC_NO},
+	{0xB21A, UNICODE_NORM_QC_NO},
+	{0xB21B, UNICODE_NORM_QC_NO},
+	{0xB21C, UNICODE_NORM_QC_NO},
+	{0xB21D, UNICODE_NORM_QC_NO},
+	{0xB21E, UNICODE_NORM_QC_NO},
+	{0xB21F, UNICODE_NORM_QC_NO},
+	{0xB220, UNICODE_NORM_QC_NO},
+	{0xB221, UNICODE_NORM_QC_NO},
+	{0xB222, UNICODE_NORM_QC_NO},
+	{0xB223, UNICODE_NORM_QC_NO},
+	{0xB224, UNICODE_NORM_QC_NO},
+	{0xB225, UNICODE_NORM_QC_NO},
+	{0xB226, UNICODE_NORM_QC_NO},
+	{0xB227, UNICODE_NORM_QC_NO},
+	{0xB228, UNICODE_NORM_QC_NO},
+	{0xB229, UNICODE_NORM_QC_NO},
+	{0xB22A, UNICODE_NORM_QC_NO},
+	{0xB22B, UNICODE_NORM_QC_NO},
+	{0xB22C, UNICODE_NORM_QC_NO},
+	{0xB22D, UNICODE_NORM_QC_NO},
+	{0xB22E, UNICODE_NORM_QC_NO},
+	{0xB22F, UNICODE_NORM_QC_NO},
+	{0xB230, UNICODE_NORM_QC_NO},
+	{0xB231, UNICODE_NORM_QC_NO},
+	{0xB232, UNICODE_NORM_QC_NO},
+	{0xB233, UNICODE_NORM_QC_NO},
+	{0xB234, UNICODE_NORM_QC_NO},
+	{0xB235, UNICODE_NORM_QC_NO},
+	{0xB236, UNICODE_NORM_QC_NO},
+	{0xB237, UNICODE_NORM_QC_NO},
+	{0xB238, UNICODE_NORM_QC_NO},
+	{0xB239, UNICODE_NORM_QC_NO},
+	{0xB23A, UNICODE_NORM_QC_NO},
+	{0xB23B, UNICODE_NORM_QC_NO},
+	{0xB23C, UNICODE_NORM_QC_NO},
+	{0xB23D, UNICODE_NORM_QC_NO},
+	{0xB23E, UNICODE_NORM_QC_NO},
+	{0xB23F, UNICODE_NORM_QC_NO},
+	{0xB240, UNICODE_NORM_QC_NO},
+	{0xB241, UNICODE_NORM_QC_NO},
+	{0xB242, UNICODE_NORM_QC_NO},
+	{0xB243, UNICODE_NORM_QC_NO},
+	{0xB244, UNICODE_NORM_QC_NO},
+	{0xB245, UNICODE_NORM_QC_NO},
+	{0xB246, UNICODE_NORM_QC_NO},
+	{0xB247, UNICODE_NORM_QC_NO},
+	{0xB248, UNICODE_NORM_QC_NO},
+	{0xB249, UNICODE_NORM_QC_NO},
+	{0xB24A, UNICODE_NORM_QC_NO},
+	{0xB24B, UNICODE_NORM_QC_NO},
+	{0xB24C, UNICODE_NORM_QC_NO},
+	{0xB24D, UNICODE_NORM_QC_NO},
+	{0xB24E, UNICODE_NORM_QC_NO},
+	{0xB24F, UNICODE_NORM_QC_NO},
+	{0xB250, UNICODE_NORM_QC_NO},
+	{0xB251, UNICODE_NORM_QC_NO},
+	{0xB252, UNICODE_NORM_QC_NO},
+	{0xB253, UNICODE_NORM_QC_NO},
+	{0xB254, UNICODE_NORM_QC_NO},
+	{0xB255, UNICODE_NORM_QC_NO},
+	{0xB256, UNICODE_NORM_QC_NO},
+	{0xB257, UNICODE_NORM_QC_NO},
+	{0xB258, UNICODE_NORM_QC_NO},
+	{0xB259, UNICODE_NORM_QC_NO},
+	{0xB25A, UNICODE_NORM_QC_NO},
+	{0xB25B, UNICODE_NORM_QC_NO},
+	{0xB25C, UNICODE_NORM_QC_NO},
+	{0xB25D, UNICODE_NORM_QC_NO},
+	{0xB25E, UNICODE_NORM_QC_NO},
+	{0xB25F, UNICODE_NORM_QC_NO},
+	{0xB260, UNICODE_NORM_QC_NO},
+	{0xB261, UNICODE_NORM_QC_NO},
+	{0xB262, UNICODE_NORM_QC_NO},
+	{0xB263, UNICODE_NORM_QC_NO},
+	{0xB264, UNICODE_NORM_QC_NO},
+	{0xB265, UNICODE_NORM_QC_NO},
+	{0xB266, UNICODE_NORM_QC_NO},
+	{0xB267, UNICODE_NORM_QC_NO},
+	{0xB268, UNICODE_NORM_QC_NO},
+	{0xB269, UNICODE_NORM_QC_NO},
+	{0xB26A, UNICODE_NORM_QC_NO},
+	{0xB26B, UNICODE_NORM_QC_NO},
+	{0xB26C, UNICODE_NORM_QC_NO},
+	{0xB26D, UNICODE_NORM_QC_NO},
+	{0xB26E, UNICODE_NORM_QC_NO},
+	{0xB26F, UNICODE_NORM_QC_NO},
+	{0xB270, UNICODE_NORM_QC_NO},
+	{0xB271, UNICODE_NORM_QC_NO},
+	{0xB272, UNICODE_NORM_QC_NO},
+	{0xB273, UNICODE_NORM_QC_NO},
+	{0xB274, UNICODE_NORM_QC_NO},
+	{0xB275, UNICODE_NORM_QC_NO},
+	{0xB276, UNICODE_NORM_QC_NO},
+	{0xB277, UNICODE_NORM_QC_NO},
+	{0xB278, UNICODE_NORM_QC_NO},
+	{0xB279, UNICODE_NORM_QC_NO},
+	{0xB27A, UNICODE_NORM_QC_NO},
+	{0xB27B, UNICODE_NORM_QC_NO},
+	{0xB27C, UNICODE_NORM_QC_NO},
+	{0xB27D, UNICODE_NORM_QC_NO},
+	{0xB27E, UNICODE_NORM_QC_NO},
+	{0xB27F, UNICODE_NORM_QC_NO},
+	{0xB280, UNICODE_NORM_QC_NO},
+	{0xB281, UNICODE_NORM_QC_NO},
+	{0xB282, UNICODE_NORM_QC_NO},
+	{0xB283, UNICODE_NORM_QC_NO},
+	{0xB284, UNICODE_NORM_QC_NO},
+	{0xB285, UNICODE_NORM_QC_NO},
+	{0xB286, UNICODE_NORM_QC_NO},
+	{0xB287, UNICODE_NORM_QC_NO},
+	{0xB288, UNICODE_NORM_QC_NO},
+	{0xB289, UNICODE_NORM_QC_NO},
+	{0xB28A, UNICODE_NORM_QC_NO},
+	{0xB28B, UNICODE_NORM_QC_NO},
+	{0xB28C, UNICODE_NORM_QC_NO},
+	{0xB28D, UNICODE_NORM_QC_NO},
+	{0xB28E, UNICODE_NORM_QC_NO},
+	{0xB28F, UNICODE_NORM_QC_NO},
+	{0xB290, UNICODE_NORM_QC_NO},
+	{0xB291, UNICODE_NORM_QC_NO},
+	{0xB292, UNICODE_NORM_QC_NO},
+	{0xB293, UNICODE_NORM_QC_NO},
+	{0xB294, UNICODE_NORM_QC_NO},
+	{0xB295, UNICODE_NORM_QC_NO},
+	{0xB296, UNICODE_NORM_QC_NO},
+	{0xB297, UNICODE_NORM_QC_NO},
+	{0xB298, UNICODE_NORM_QC_NO},
+	{0xB299, UNICODE_NORM_QC_NO},
+	{0xB29A, UNICODE_NORM_QC_NO},
+	{0xB29B, UNICODE_NORM_QC_NO},
+	{0xB29C, UNICODE_NORM_QC_NO},
+	{0xB29D, UNICODE_NORM_QC_NO},
+	{0xB29E, UNICODE_NORM_QC_NO},
+	{0xB29F, UNICODE_NORM_QC_NO},
+	{0xB2A0, UNICODE_NORM_QC_NO},
+	{0xB2A1, UNICODE_NORM_QC_NO},
+	{0xB2A2, UNICODE_NORM_QC_NO},
+	{0xB2A3, UNICODE_NORM_QC_NO},
+	{0xB2A4, UNICODE_NORM_QC_NO},
+	{0xB2A5, UNICODE_NORM_QC_NO},
+	{0xB2A6, UNICODE_NORM_QC_NO},
+	{0xB2A7, UNICODE_NORM_QC_NO},
+	{0xB2A8, UNICODE_NORM_QC_NO},
+	{0xB2A9, UNICODE_NORM_QC_NO},
+	{0xB2AA, UNICODE_NORM_QC_NO},
+	{0xB2AB, UNICODE_NORM_QC_NO},
+	{0xB2AC, UNICODE_NORM_QC_NO},
+	{0xB2AD, UNICODE_NORM_QC_NO},
+	{0xB2AE, UNICODE_NORM_QC_NO},
+	{0xB2AF, UNICODE_NORM_QC_NO},
+	{0xB2B0, UNICODE_NORM_QC_NO},
+	{0xB2B1, UNICODE_NORM_QC_NO},
+	{0xB2B2, UNICODE_NORM_QC_NO},
+	{0xB2B3, UNICODE_NORM_QC_NO},
+	{0xB2B4, UNICODE_NORM_QC_NO},
+	{0xB2B5, UNICODE_NORM_QC_NO},
+	{0xB2B6, UNICODE_NORM_QC_NO},
+	{0xB2B7, UNICODE_NORM_QC_NO},
+	{0xB2B8, UNICODE_NORM_QC_NO},
+	{0xB2B9, UNICODE_NORM_QC_NO},
+	{0xB2BA, UNICODE_NORM_QC_NO},
+	{0xB2BB, UNICODE_NORM_QC_NO},
+	{0xB2BC, UNICODE_NORM_QC_NO},
+	{0xB2BD, UNICODE_NORM_QC_NO},
+	{0xB2BE, UNICODE_NORM_QC_NO},
+	{0xB2BF, UNICODE_NORM_QC_NO},
+	{0xB2C0, UNICODE_NORM_QC_NO},
+	{0xB2C1, UNICODE_NORM_QC_NO},
+	{0xB2C2, UNICODE_NORM_QC_NO},
+	{0xB2C3, UNICODE_NORM_QC_NO},
+	{0xB2C4, UNICODE_NORM_QC_NO},
+	{0xB2C5, UNICODE_NORM_QC_NO},
+	{0xB2C6, UNICODE_NORM_QC_NO},
+	{0xB2C7, UNICODE_NORM_QC_NO},
+	{0xB2C8, UNICODE_NORM_QC_NO},
+	{0xB2C9, UNICODE_NORM_QC_NO},
+	{0xB2CA, UNICODE_NORM_QC_NO},
+	{0xB2CB, UNICODE_NORM_QC_NO},
+	{0xB2CC, UNICODE_NORM_QC_NO},
+	{0xB2CD, UNICODE_NORM_QC_NO},
+	{0xB2CE, UNICODE_NORM_QC_NO},
+	{0xB2CF, UNICODE_NORM_QC_NO},
+	{0xB2D0, UNICODE_NORM_QC_NO},
+	{0xB2D1, UNICODE_NORM_QC_NO},
+	{0xB2D2, UNICODE_NORM_QC_NO},
+	{0xB2D3, UNICODE_NORM_QC_NO},
+	{0xB2D4, UNICODE_NORM_QC_NO},
+	{0xB2D5, UNICODE_NORM_QC_NO},
+	{0xB2D6, UNICODE_NORM_QC_NO},
+	{0xB2D7, UNICODE_NORM_QC_NO},
+	{0xB2D8, UNICODE_NORM_QC_NO},
+	{0xB2D9, UNICODE_NORM_QC_NO},
+	{0xB2DA, UNICODE_NORM_QC_NO},
+	{0xB2DB, UNICODE_NORM_QC_NO},
+	{0xB2DC, UNICODE_NORM_QC_NO},
+	{0xB2DD, UNICODE_NORM_QC_NO},
+	{0xB2DE, UNICODE_NORM_QC_NO},
+	{0xB2DF, UNICODE_NORM_QC_NO},
+	{0xB2E0, UNICODE_NORM_QC_NO},
+	{0xB2E1, UNICODE_NORM_QC_NO},
+	{0xB2E2, UNICODE_NORM_QC_NO},
+	{0xB2E3, UNICODE_NORM_QC_NO},
+	{0xB2E4, UNICODE_NORM_QC_NO},
+	{0xB2E5, UNICODE_NORM_QC_NO},
+	{0xB2E6, UNICODE_NORM_QC_NO},
+	{0xB2E7, UNICODE_NORM_QC_NO},
+	{0xB2E8, UNICODE_NORM_QC_NO},
+	{0xB2E9, UNICODE_NORM_QC_NO},
+	{0xB2EA, UNICODE_NORM_QC_NO},
+	{0xB2EB, UNICODE_NORM_QC_NO},
+	{0xB2EC, UNICODE_NORM_QC_NO},
+	{0xB2ED, UNICODE_NORM_QC_NO},
+	{0xB2EE, UNICODE_NORM_QC_NO},
+	{0xB2EF, UNICODE_NORM_QC_NO},
+	{0xB2F0, UNICODE_NORM_QC_NO},
+	{0xB2F1, UNICODE_NORM_QC_NO},
+	{0xB2F2, UNICODE_NORM_QC_NO},
+	{0xB2F3, UNICODE_NORM_QC_NO},
+	{0xB2F4, UNICODE_NORM_QC_NO},
+	{0xB2F5, UNICODE_NORM_QC_NO},
+	{0xB2F6, UNICODE_NORM_QC_NO},
+	{0xB2F7, UNICODE_NORM_QC_NO},
+	{0xB2F8, UNICODE_NORM_QC_NO},
+	{0xB2F9, UNICODE_NORM_QC_NO},
+	{0xB2FA, UNICODE_NORM_QC_NO},
+	{0xB2FB, UNICODE_NORM_QC_NO},
+	{0xB2FC, UNICODE_NORM_QC_NO},
+	{0xB2FD, UNICODE_NORM_QC_NO},
+	{0xB2FE, UNICODE_NORM_QC_NO},
+	{0xB2FF, UNICODE_NORM_QC_NO},
+	{0xB300, UNICODE_NORM_QC_NO},
+	{0xB301, UNICODE_NORM_QC_NO},
+	{0xB302, UNICODE_NORM_QC_NO},
+	{0xB303, UNICODE_NORM_QC_NO},
+	{0xB304, UNICODE_NORM_QC_NO},
+	{0xB305, UNICODE_NORM_QC_NO},
+	{0xB306, UNICODE_NORM_QC_NO},
+	{0xB307, UNICODE_NORM_QC_NO},
+	{0xB308, UNICODE_NORM_QC_NO},
+	{0xB309, UNICODE_NORM_QC_NO},
+	{0xB30A, UNICODE_NORM_QC_NO},
+	{0xB30B, UNICODE_NORM_QC_NO},
+	{0xB30C, UNICODE_NORM_QC_NO},
+	{0xB30D, UNICODE_NORM_QC_NO},
+	{0xB30E, UNICODE_NORM_QC_NO},
+	{0xB30F, UNICODE_NORM_QC_NO},
+	{0xB310, UNICODE_NORM_QC_NO},
+	{0xB311, UNICODE_NORM_QC_NO},
+	{0xB312, UNICODE_NORM_QC_NO},
+	{0xB313, UNICODE_NORM_QC_NO},
+	{0xB314, UNICODE_NORM_QC_NO},
+	{0xB315, UNICODE_NORM_QC_NO},
+	{0xB316, UNICODE_NORM_QC_NO},
+	{0xB317, UNICODE_NORM_QC_NO},
+	{0xB318, UNICODE_NORM_QC_NO},
+	{0xB319, UNICODE_NORM_QC_NO},
+	{0xB31A, UNICODE_NORM_QC_NO},
+	{0xB31B, UNICODE_NORM_QC_NO},
+	{0xB31C, UNICODE_NORM_QC_NO},
+	{0xB31D, UNICODE_NORM_QC_NO},
+	{0xB31E, UNICODE_NORM_QC_NO},
+	{0xB31F, UNICODE_NORM_QC_NO},
+	{0xB320, UNICODE_NORM_QC_NO},
+	{0xB321, UNICODE_NORM_QC_NO},
+	{0xB322, UNICODE_NORM_QC_NO},
+	{0xB323, UNICODE_NORM_QC_NO},
+	{0xB324, UNICODE_NORM_QC_NO},
+	{0xB325, UNICODE_NORM_QC_NO},
+	{0xB326, UNICODE_NORM_QC_NO},
+	{0xB327, UNICODE_NORM_QC_NO},
+	{0xB328, UNICODE_NORM_QC_NO},
+	{0xB329, UNICODE_NORM_QC_NO},
+	{0xB32A, UNICODE_NORM_QC_NO},
+	{0xB32B, UNICODE_NORM_QC_NO},
+	{0xB32C, UNICODE_NORM_QC_NO},
+	{0xB32D, UNICODE_NORM_QC_NO},
+	{0xB32E, UNICODE_NORM_QC_NO},
+	{0xB32F, UNICODE_NORM_QC_NO},
+	{0xB330, UNICODE_NORM_QC_NO},
+	{0xB331, UNICODE_NORM_QC_NO},
+	{0xB332, UNICODE_NORM_QC_NO},
+	{0xB333, UNICODE_NORM_QC_NO},
+	{0xB334, UNICODE_NORM_QC_NO},
+	{0xB335, UNICODE_NORM_QC_NO},
+	{0xB336, UNICODE_NORM_QC_NO},
+	{0xB337, UNICODE_NORM_QC_NO},
+	{0xB338, UNICODE_NORM_QC_NO},
+	{0xB339, UNICODE_NORM_QC_NO},
+	{0xB33A, UNICODE_NORM_QC_NO},
+	{0xB33B, UNICODE_NORM_QC_NO},
+	{0xB33C, UNICODE_NORM_QC_NO},
+	{0xB33D, UNICODE_NORM_QC_NO},
+	{0xB33E, UNICODE_NORM_QC_NO},
+	{0xB33F, UNICODE_NORM_QC_NO},
+	{0xB340, UNICODE_NORM_QC_NO},
+	{0xB341, UNICODE_NORM_QC_NO},
+	{0xB342, UNICODE_NORM_QC_NO},
+	{0xB343, UNICODE_NORM_QC_NO},
+	{0xB344, UNICODE_NORM_QC_NO},
+	{0xB345, UNICODE_NORM_QC_NO},
+	{0xB346, UNICODE_NORM_QC_NO},
+	{0xB347, UNICODE_NORM_QC_NO},
+	{0xB348, UNICODE_NORM_QC_NO},
+	{0xB349, UNICODE_NORM_QC_NO},
+	{0xB34A, UNICODE_NORM_QC_NO},
+	{0xB34B, UNICODE_NORM_QC_NO},
+	{0xB34C, UNICODE_NORM_QC_NO},
+	{0xB34D, UNICODE_NORM_QC_NO},
+	{0xB34E, UNICODE_NORM_QC_NO},
+	{0xB34F, UNICODE_NORM_QC_NO},
+	{0xB350, UNICODE_NORM_QC_NO},
+	{0xB351, UNICODE_NORM_QC_NO},
+	{0xB352, UNICODE_NORM_QC_NO},
+	{0xB353, UNICODE_NORM_QC_NO},
+	{0xB354, UNICODE_NORM_QC_NO},
+	{0xB355, UNICODE_NORM_QC_NO},
+	{0xB356, UNICODE_NORM_QC_NO},
+	{0xB357, UNICODE_NORM_QC_NO},
+	{0xB358, UNICODE_NORM_QC_NO},
+	{0xB359, UNICODE_NORM_QC_NO},
+	{0xB35A, UNICODE_NORM_QC_NO},
+	{0xB35B, UNICODE_NORM_QC_NO},
+	{0xB35C, UNICODE_NORM_QC_NO},
+	{0xB35D, UNICODE_NORM_QC_NO},
+	{0xB35E, UNICODE_NORM_QC_NO},
+	{0xB35F, UNICODE_NORM_QC_NO},
+	{0xB360, UNICODE_NORM_QC_NO},
+	{0xB361, UNICODE_NORM_QC_NO},
+	{0xB362, UNICODE_NORM_QC_NO},
+	{0xB363, UNICODE_NORM_QC_NO},
+	{0xB364, UNICODE_NORM_QC_NO},
+	{0xB365, UNICODE_NORM_QC_NO},
+	{0xB366, UNICODE_NORM_QC_NO},
+	{0xB367, UNICODE_NORM_QC_NO},
+	{0xB368, UNICODE_NORM_QC_NO},
+	{0xB369, UNICODE_NORM_QC_NO},
+	{0xB36A, UNICODE_NORM_QC_NO},
+	{0xB36B, UNICODE_NORM_QC_NO},
+	{0xB36C, UNICODE_NORM_QC_NO},
+	{0xB36D, UNICODE_NORM_QC_NO},
+	{0xB36E, UNICODE_NORM_QC_NO},
+	{0xB36F, UNICODE_NORM_QC_NO},
+	{0xB370, UNICODE_NORM_QC_NO},
+	{0xB371, UNICODE_NORM_QC_NO},
+	{0xB372, UNICODE_NORM_QC_NO},
+	{0xB373, UNICODE_NORM_QC_NO},
+	{0xB374, UNICODE_NORM_QC_NO},
+	{0xB375, UNICODE_NORM_QC_NO},
+	{0xB376, UNICODE_NORM_QC_NO},
+	{0xB377, UNICODE_NORM_QC_NO},
+	{0xB378, UNICODE_NORM_QC_NO},
+	{0xB379, UNICODE_NORM_QC_NO},
+	{0xB37A, UNICODE_NORM_QC_NO},
+	{0xB37B, UNICODE_NORM_QC_NO},
+	{0xB37C, UNICODE_NORM_QC_NO},
+	{0xB37D, UNICODE_NORM_QC_NO},
+	{0xB37E, UNICODE_NORM_QC_NO},
+	{0xB37F, UNICODE_NORM_QC_NO},
+	{0xB380, UNICODE_NORM_QC_NO},
+	{0xB381, UNICODE_NORM_QC_NO},
+	{0xB382, UNICODE_NORM_QC_NO},
+	{0xB383, UNICODE_NORM_QC_NO},
+	{0xB384, UNICODE_NORM_QC_NO},
+	{0xB385, UNICODE_NORM_QC_NO},
+	{0xB386, UNICODE_NORM_QC_NO},
+	{0xB387, UNICODE_NORM_QC_NO},
+	{0xB388, UNICODE_NORM_QC_NO},
+	{0xB389, UNICODE_NORM_QC_NO},
+	{0xB38A, UNICODE_NORM_QC_NO},
+	{0xB38B, UNICODE_NORM_QC_NO},
+	{0xB38C, UNICODE_NORM_QC_NO},
+	{0xB38D, UNICODE_NORM_QC_NO},
+	{0xB38E, UNICODE_NORM_QC_NO},
+	{0xB38F, UNICODE_NORM_QC_NO},
+	{0xB390, UNICODE_NORM_QC_NO},
+	{0xB391, UNICODE_NORM_QC_NO},
+	{0xB392, UNICODE_NORM_QC_NO},
+	{0xB393, UNICODE_NORM_QC_NO},
+	{0xB394, UNICODE_NORM_QC_NO},
+	{0xB395, UNICODE_NORM_QC_NO},
+	{0xB396, UNICODE_NORM_QC_NO},
+	{0xB397, UNICODE_NORM_QC_NO},
+	{0xB398, UNICODE_NORM_QC_NO},
+	{0xB399, UNICODE_NORM_QC_NO},
+	{0xB39A, UNICODE_NORM_QC_NO},
+	{0xB39B, UNICODE_NORM_QC_NO},
+	{0xB39C, UNICODE_NORM_QC_NO},
+	{0xB39D, UNICODE_NORM_QC_NO},
+	{0xB39E, UNICODE_NORM_QC_NO},
+	{0xB39F, UNICODE_NORM_QC_NO},
+	{0xB3A0, UNICODE_NORM_QC_NO},
+	{0xB3A1, UNICODE_NORM_QC_NO},
+	{0xB3A2, UNICODE_NORM_QC_NO},
+	{0xB3A3, UNICODE_NORM_QC_NO},
+	{0xB3A4, UNICODE_NORM_QC_NO},
+	{0xB3A5, UNICODE_NORM_QC_NO},
+	{0xB3A6, UNICODE_NORM_QC_NO},
+	{0xB3A7, UNICODE_NORM_QC_NO},
+	{0xB3A8, UNICODE_NORM_QC_NO},
+	{0xB3A9, UNICODE_NORM_QC_NO},
+	{0xB3AA, UNICODE_NORM_QC_NO},
+	{0xB3AB, UNICODE_NORM_QC_NO},
+	{0xB3AC, UNICODE_NORM_QC_NO},
+	{0xB3AD, UNICODE_NORM_QC_NO},
+	{0xB3AE, UNICODE_NORM_QC_NO},
+	{0xB3AF, UNICODE_NORM_QC_NO},
+	{0xB3B0, UNICODE_NORM_QC_NO},
+	{0xB3B1, UNICODE_NORM_QC_NO},
+	{0xB3B2, UNICODE_NORM_QC_NO},
+	{0xB3B3, UNICODE_NORM_QC_NO},
+	{0xB3B4, UNICODE_NORM_QC_NO},
+	{0xB3B5, UNICODE_NORM_QC_NO},
+	{0xB3B6, UNICODE_NORM_QC_NO},
+	{0xB3B7, UNICODE_NORM_QC_NO},
+	{0xB3B8, UNICODE_NORM_QC_NO},
+	{0xB3B9, UNICODE_NORM_QC_NO},
+	{0xB3BA, UNICODE_NORM_QC_NO},
+	{0xB3BB, UNICODE_NORM_QC_NO},
+	{0xB3BC, UNICODE_NORM_QC_NO},
+	{0xB3BD, UNICODE_NORM_QC_NO},
+	{0xB3BE, UNICODE_NORM_QC_NO},
+	{0xB3BF, UNICODE_NORM_QC_NO},
+	{0xB3C0, UNICODE_NORM_QC_NO},
+	{0xB3C1, UNICODE_NORM_QC_NO},
+	{0xB3C2, UNICODE_NORM_QC_NO},
+	{0xB3C3, UNICODE_NORM_QC_NO},
+	{0xB3C4, UNICODE_NORM_QC_NO},
+	{0xB3C5, UNICODE_NORM_QC_NO},
+	{0xB3C6, UNICODE_NORM_QC_NO},
+	{0xB3C7, UNICODE_NORM_QC_NO},
+	{0xB3C8, UNICODE_NORM_QC_NO},
+	{0xB3C9, UNICODE_NORM_QC_NO},
+	{0xB3CA, UNICODE_NORM_QC_NO},
+	{0xB3CB, UNICODE_NORM_QC_NO},
+	{0xB3CC, UNICODE_NORM_QC_NO},
+	{0xB3CD, UNICODE_NORM_QC_NO},
+	{0xB3CE, UNICODE_NORM_QC_NO},
+	{0xB3CF, UNICODE_NORM_QC_NO},
+	{0xB3D0, UNICODE_NORM_QC_NO},
+	{0xB3D1, UNICODE_NORM_QC_NO},
+	{0xB3D2, UNICODE_NORM_QC_NO},
+	{0xB3D3, UNICODE_NORM_QC_NO},
+	{0xB3D4, UNICODE_NORM_QC_NO},
+	{0xB3D5, UNICODE_NORM_QC_NO},
+	{0xB3D6, UNICODE_NORM_QC_NO},
+	{0xB3D7, UNICODE_NORM_QC_NO},
+	{0xB3D8, UNICODE_NORM_QC_NO},
+	{0xB3D9, UNICODE_NORM_QC_NO},
+	{0xB3DA, UNICODE_NORM_QC_NO},
+	{0xB3DB, UNICODE_NORM_QC_NO},
+	{0xB3DC, UNICODE_NORM_QC_NO},
+	{0xB3DD, UNICODE_NORM_QC_NO},
+	{0xB3DE, UNICODE_NORM_QC_NO},
+	{0xB3DF, UNICODE_NORM_QC_NO},
+	{0xB3E0, UNICODE_NORM_QC_NO},
+	{0xB3E1, UNICODE_NORM_QC_NO},
+	{0xB3E2, UNICODE_NORM_QC_NO},
+	{0xB3E3, UNICODE_NORM_QC_NO},
+	{0xB3E4, UNICODE_NORM_QC_NO},
+	{0xB3E5, UNICODE_NORM_QC_NO},
+	{0xB3E6, UNICODE_NORM_QC_NO},
+	{0xB3E7, UNICODE_NORM_QC_NO},
+	{0xB3E8, UNICODE_NORM_QC_NO},
+	{0xB3E9, UNICODE_NORM_QC_NO},
+	{0xB3EA, UNICODE_NORM_QC_NO},
+	{0xB3EB, UNICODE_NORM_QC_NO},
+	{0xB3EC, UNICODE_NORM_QC_NO},
+	{0xB3ED, UNICODE_NORM_QC_NO},
+	{0xB3EE, UNICODE_NORM_QC_NO},
+	{0xB3EF, UNICODE_NORM_QC_NO},
+	{0xB3F0, UNICODE_NORM_QC_NO},
+	{0xB3F1, UNICODE_NORM_QC_NO},
+	{0xB3F2, UNICODE_NORM_QC_NO},
+	{0xB3F3, UNICODE_NORM_QC_NO},
+	{0xB3F4, UNICODE_NORM_QC_NO},
+	{0xB3F5, UNICODE_NORM_QC_NO},
+	{0xB3F6, UNICODE_NORM_QC_NO},
+	{0xB3F7, UNICODE_NORM_QC_NO},
+	{0xB3F8, UNICODE_NORM_QC_NO},
+	{0xB3F9, UNICODE_NORM_QC_NO},
+	{0xB3FA, UNICODE_NORM_QC_NO},
+	{0xB3FB, UNICODE_NORM_QC_NO},
+	{0xB3FC, UNICODE_NORM_QC_NO},
+	{0xB3FD, UNICODE_NORM_QC_NO},
+	{0xB3FE, UNICODE_NORM_QC_NO},
+	{0xB3FF, UNICODE_NORM_QC_NO},
+	{0xB400, UNICODE_NORM_QC_NO},
+	{0xB401, UNICODE_NORM_QC_NO},
+	{0xB402, UNICODE_NORM_QC_NO},
+	{0xB403, UNICODE_NORM_QC_NO},
+	{0xB404, UNICODE_NORM_QC_NO},
+	{0xB405, UNICODE_NORM_QC_NO},
+	{0xB406, UNICODE_NORM_QC_NO},
+	{0xB407, UNICODE_NORM_QC_NO},
+	{0xB408, UNICODE_NORM_QC_NO},
+	{0xB409, UNICODE_NORM_QC_NO},
+	{0xB40A, UNICODE_NORM_QC_NO},
+	{0xB40B, UNICODE_NORM_QC_NO},
+	{0xB40C, UNICODE_NORM_QC_NO},
+	{0xB40D, UNICODE_NORM_QC_NO},
+	{0xB40E, UNICODE_NORM_QC_NO},
+	{0xB40F, UNICODE_NORM_QC_NO},
+	{0xB410, UNICODE_NORM_QC_NO},
+	{0xB411, UNICODE_NORM_QC_NO},
+	{0xB412, UNICODE_NORM_QC_NO},
+	{0xB413, UNICODE_NORM_QC_NO},
+	{0xB414, UNICODE_NORM_QC_NO},
+	{0xB415, UNICODE_NORM_QC_NO},
+	{0xB416, UNICODE_NORM_QC_NO},
+	{0xB417, UNICODE_NORM_QC_NO},
+	{0xB418, UNICODE_NORM_QC_NO},
+	{0xB419, UNICODE_NORM_QC_NO},
+	{0xB41A, UNICODE_NORM_QC_NO},
+	{0xB41B, UNICODE_NORM_QC_NO},
+	{0xB41C, UNICODE_NORM_QC_NO},
+	{0xB41D, UNICODE_NORM_QC_NO},
+	{0xB41E, UNICODE_NORM_QC_NO},
+	{0xB41F, UNICODE_NORM_QC_NO},
+	{0xB420, UNICODE_NORM_QC_NO},
+	{0xB421, UNICODE_NORM_QC_NO},
+	{0xB422, UNICODE_NORM_QC_NO},
+	{0xB423, UNICODE_NORM_QC_NO},
+	{0xB424, UNICODE_NORM_QC_NO},
+	{0xB425, UNICODE_NORM_QC_NO},
+	{0xB426, UNICODE_NORM_QC_NO},
+	{0xB427, UNICODE_NORM_QC_NO},
+	{0xB428, UNICODE_NORM_QC_NO},
+	{0xB429, UNICODE_NORM_QC_NO},
+	{0xB42A, UNICODE_NORM_QC_NO},
+	{0xB42B, UNICODE_NORM_QC_NO},
+	{0xB42C, UNICODE_NORM_QC_NO},
+	{0xB42D, UNICODE_NORM_QC_NO},
+	{0xB42E, UNICODE_NORM_QC_NO},
+	{0xB42F, UNICODE_NORM_QC_NO},
+	{0xB430, UNICODE_NORM_QC_NO},
+	{0xB431, UNICODE_NORM_QC_NO},
+	{0xB432, UNICODE_NORM_QC_NO},
+	{0xB433, UNICODE_NORM_QC_NO},
+	{0xB434, UNICODE_NORM_QC_NO},
+	{0xB435, UNICODE_NORM_QC_NO},
+	{0xB436, UNICODE_NORM_QC_NO},
+	{0xB437, UNICODE_NORM_QC_NO},
+	{0xB438, UNICODE_NORM_QC_NO},
+	{0xB439, UNICODE_NORM_QC_NO},
+	{0xB43A, UNICODE_NORM_QC_NO},
+	{0xB43B, UNICODE_NORM_QC_NO},
+	{0xB43C, UNICODE_NORM_QC_NO},
+	{0xB43D, UNICODE_NORM_QC_NO},
+	{0xB43E, UNICODE_NORM_QC_NO},
+	{0xB43F, UNICODE_NORM_QC_NO},
+	{0xB440, UNICODE_NORM_QC_NO},
+	{0xB441, UNICODE_NORM_QC_NO},
+	{0xB442, UNICODE_NORM_QC_NO},
+	{0xB443, UNICODE_NORM_QC_NO},
+	{0xB444, UNICODE_NORM_QC_NO},
+	{0xB445, UNICODE_NORM_QC_NO},
+	{0xB446, UNICODE_NORM_QC_NO},
+	{0xB447, UNICODE_NORM_QC_NO},
+	{0xB448, UNICODE_NORM_QC_NO},
+	{0xB449, UNICODE_NORM_QC_NO},
+	{0xB44A, UNICODE_NORM_QC_NO},
+	{0xB44B, UNICODE_NORM_QC_NO},
+	{0xB44C, UNICODE_NORM_QC_NO},
+	{0xB44D, UNICODE_NORM_QC_NO},
+	{0xB44E, UNICODE_NORM_QC_NO},
+	{0xB44F, UNICODE_NORM_QC_NO},
+	{0xB450, UNICODE_NORM_QC_NO},
+	{0xB451, UNICODE_NORM_QC_NO},
+	{0xB452, UNICODE_NORM_QC_NO},
+	{0xB453, UNICODE_NORM_QC_NO},
+	{0xB454, UNICODE_NORM_QC_NO},
+	{0xB455, UNICODE_NORM_QC_NO},
+	{0xB456, UNICODE_NORM_QC_NO},
+	{0xB457, UNICODE_NORM_QC_NO},
+	{0xB458, UNICODE_NORM_QC_NO},
+	{0xB459, UNICODE_NORM_QC_NO},
+	{0xB45A, UNICODE_NORM_QC_NO},
+	{0xB45B, UNICODE_NORM_QC_NO},
+	{0xB45C, UNICODE_NORM_QC_NO},
+	{0xB45D, UNICODE_NORM_QC_NO},
+	{0xB45E, UNICODE_NORM_QC_NO},
+	{0xB45F, UNICODE_NORM_QC_NO},
+	{0xB460, UNICODE_NORM_QC_NO},
+	{0xB461, UNICODE_NORM_QC_NO},
+	{0xB462, UNICODE_NORM_QC_NO},
+	{0xB463, UNICODE_NORM_QC_NO},
+	{0xB464, UNICODE_NORM_QC_NO},
+	{0xB465, UNICODE_NORM_QC_NO},
+	{0xB466, UNICODE_NORM_QC_NO},
+	{0xB467, UNICODE_NORM_QC_NO},
+	{0xB468, UNICODE_NORM_QC_NO},
+	{0xB469, UNICODE_NORM_QC_NO},
+	{0xB46A, UNICODE_NORM_QC_NO},
+	{0xB46B, UNICODE_NORM_QC_NO},
+	{0xB46C, UNICODE_NORM_QC_NO},
+	{0xB46D, UNICODE_NORM_QC_NO},
+	{0xB46E, UNICODE_NORM_QC_NO},
+	{0xB46F, UNICODE_NORM_QC_NO},
+	{0xB470, UNICODE_NORM_QC_NO},
+	{0xB471, UNICODE_NORM_QC_NO},
+	{0xB472, UNICODE_NORM_QC_NO},
+	{0xB473, UNICODE_NORM_QC_NO},
+	{0xB474, UNICODE_NORM_QC_NO},
+	{0xB475, UNICODE_NORM_QC_NO},
+	{0xB476, UNICODE_NORM_QC_NO},
+	{0xB477, UNICODE_NORM_QC_NO},
+	{0xB478, UNICODE_NORM_QC_NO},
+	{0xB479, UNICODE_NORM_QC_NO},
+	{0xB47A, UNICODE_NORM_QC_NO},
+	{0xB47B, UNICODE_NORM_QC_NO},
+	{0xB47C, UNICODE_NORM_QC_NO},
+	{0xB47D, UNICODE_NORM_QC_NO},
+	{0xB47E, UNICODE_NORM_QC_NO},
+	{0xB47F, UNICODE_NORM_QC_NO},
+	{0xB480, UNICODE_NORM_QC_NO},
+	{0xB481, UNICODE_NORM_QC_NO},
+	{0xB482, UNICODE_NORM_QC_NO},
+	{0xB483, UNICODE_NORM_QC_NO},
+	{0xB484, UNICODE_NORM_QC_NO},
+	{0xB485, UNICODE_NORM_QC_NO},
+	{0xB486, UNICODE_NORM_QC_NO},
+	{0xB487, UNICODE_NORM_QC_NO},
+	{0xB488, UNICODE_NORM_QC_NO},
+	{0xB489, UNICODE_NORM_QC_NO},
+	{0xB48A, UNICODE_NORM_QC_NO},
+	{0xB48B, UNICODE_NORM_QC_NO},
+	{0xB48C, UNICODE_NORM_QC_NO},
+	{0xB48D, UNICODE_NORM_QC_NO},
+	{0xB48E, UNICODE_NORM_QC_NO},
+	{0xB48F, UNICODE_NORM_QC_NO},
+	{0xB490, UNICODE_NORM_QC_NO},
+	{0xB491, UNICODE_NORM_QC_NO},
+	{0xB492, UNICODE_NORM_QC_NO},
+	{0xB493, UNICODE_NORM_QC_NO},
+	{0xB494, UNICODE_NORM_QC_NO},
+	{0xB495, UNICODE_NORM_QC_NO},
+	{0xB496, UNICODE_NORM_QC_NO},
+	{0xB497, UNICODE_NORM_QC_NO},
+	{0xB498, UNICODE_NORM_QC_NO},
+	{0xB499, UNICODE_NORM_QC_NO},
+	{0xB49A, UNICODE_NORM_QC_NO},
+	{0xB49B, UNICODE_NORM_QC_NO},
+	{0xB49C, UNICODE_NORM_QC_NO},
+	{0xB49D, UNICODE_NORM_QC_NO},
+	{0xB49E, UNICODE_NORM_QC_NO},
+	{0xB49F, UNICODE_NORM_QC_NO},
+	{0xB4A0, UNICODE_NORM_QC_NO},
+	{0xB4A1, UNICODE_NORM_QC_NO},
+	{0xB4A2, UNICODE_NORM_QC_NO},
+	{0xB4A3, UNICODE_NORM_QC_NO},
+	{0xB4A4, UNICODE_NORM_QC_NO},
+	{0xB4A5, UNICODE_NORM_QC_NO},
+	{0xB4A6, UNICODE_NORM_QC_NO},
+	{0xB4A7, UNICODE_NORM_QC_NO},
+	{0xB4A8, UNICODE_NORM_QC_NO},
+	{0xB4A9, UNICODE_NORM_QC_NO},
+	{0xB4AA, UNICODE_NORM_QC_NO},
+	{0xB4AB, UNICODE_NORM_QC_NO},
+	{0xB4AC, UNICODE_NORM_QC_NO},
+	{0xB4AD, UNICODE_NORM_QC_NO},
+	{0xB4AE, UNICODE_NORM_QC_NO},
+	{0xB4AF, UNICODE_NORM_QC_NO},
+	{0xB4B0, UNICODE_NORM_QC_NO},
+	{0xB4B1, UNICODE_NORM_QC_NO},
+	{0xB4B2, UNICODE_NORM_QC_NO},
+	{0xB4B3, UNICODE_NORM_QC_NO},
+	{0xB4B4, UNICODE_NORM_QC_NO},
+	{0xB4B5, UNICODE_NORM_QC_NO},
+	{0xB4B6, UNICODE_NORM_QC_NO},
+	{0xB4B7, UNICODE_NORM_QC_NO},
+	{0xB4B8, UNICODE_NORM_QC_NO},
+	{0xB4B9, UNICODE_NORM_QC_NO},
+	{0xB4BA, UNICODE_NORM_QC_NO},
+	{0xB4BB, UNICODE_NORM_QC_NO},
+	{0xB4BC, UNICODE_NORM_QC_NO},
+	{0xB4BD, UNICODE_NORM_QC_NO},
+	{0xB4BE, UNICODE_NORM_QC_NO},
+	{0xB4BF, UNICODE_NORM_QC_NO},
+	{0xB4C0, UNICODE_NORM_QC_NO},
+	{0xB4C1, UNICODE_NORM_QC_NO},
+	{0xB4C2, UNICODE_NORM_QC_NO},
+	{0xB4C3, UNICODE_NORM_QC_NO},
+	{0xB4C4, UNICODE_NORM_QC_NO},
+	{0xB4C5, UNICODE_NORM_QC_NO},
+	{0xB4C6, UNICODE_NORM_QC_NO},
+	{0xB4C7, UNICODE_NORM_QC_NO},
+	{0xB4C8, UNICODE_NORM_QC_NO},
+	{0xB4C9, UNICODE_NORM_QC_NO},
+	{0xB4CA, UNICODE_NORM_QC_NO},
+	{0xB4CB, UNICODE_NORM_QC_NO},
+	{0xB4CC, UNICODE_NORM_QC_NO},
+	{0xB4CD, UNICODE_NORM_QC_NO},
+	{0xB4CE, UNICODE_NORM_QC_NO},
+	{0xB4CF, UNICODE_NORM_QC_NO},
+	{0xB4D0, UNICODE_NORM_QC_NO},
+	{0xB4D1, UNICODE_NORM_QC_NO},
+	{0xB4D2, UNICODE_NORM_QC_NO},
+	{0xB4D3, UNICODE_NORM_QC_NO},
+	{0xB4D4, UNICODE_NORM_QC_NO},
+	{0xB4D5, UNICODE_NORM_QC_NO},
+	{0xB4D6, UNICODE_NORM_QC_NO},
+	{0xB4D7, UNICODE_NORM_QC_NO},
+	{0xB4D8, UNICODE_NORM_QC_NO},
+	{0xB4D9, UNICODE_NORM_QC_NO},
+	{0xB4DA, UNICODE_NORM_QC_NO},
+	{0xB4DB, UNICODE_NORM_QC_NO},
+	{0xB4DC, UNICODE_NORM_QC_NO},
+	{0xB4DD, UNICODE_NORM_QC_NO},
+	{0xB4DE, UNICODE_NORM_QC_NO},
+	{0xB4DF, UNICODE_NORM_QC_NO},
+	{0xB4E0, UNICODE_NORM_QC_NO},
+	{0xB4E1, UNICODE_NORM_QC_NO},
+	{0xB4E2, UNICODE_NORM_QC_NO},
+	{0xB4E3, UNICODE_NORM_QC_NO},
+	{0xB4E4, UNICODE_NORM_QC_NO},
+	{0xB4E5, UNICODE_NORM_QC_NO},
+	{0xB4E6, UNICODE_NORM_QC_NO},
+	{0xB4E7, UNICODE_NORM_QC_NO},
+	{0xB4E8, UNICODE_NORM_QC_NO},
+	{0xB4E9, UNICODE_NORM_QC_NO},
+	{0xB4EA, UNICODE_NORM_QC_NO},
+	{0xB4EB, UNICODE_NORM_QC_NO},
+	{0xB4EC, UNICODE_NORM_QC_NO},
+	{0xB4ED, UNICODE_NORM_QC_NO},
+	{0xB4EE, UNICODE_NORM_QC_NO},
+	{0xB4EF, UNICODE_NORM_QC_NO},
+	{0xB4F0, UNICODE_NORM_QC_NO},
+	{0xB4F1, UNICODE_NORM_QC_NO},
+	{0xB4F2, UNICODE_NORM_QC_NO},
+	{0xB4F3, UNICODE_NORM_QC_NO},
+	{0xB4F4, UNICODE_NORM_QC_NO},
+	{0xB4F5, UNICODE_NORM_QC_NO},
+	{0xB4F6, UNICODE_NORM_QC_NO},
+	{0xB4F7, UNICODE_NORM_QC_NO},
+	{0xB4F8, UNICODE_NORM_QC_NO},
+	{0xB4F9, UNICODE_NORM_QC_NO},
+	{0xB4FA, UNICODE_NORM_QC_NO},
+	{0xB4FB, UNICODE_NORM_QC_NO},
+	{0xB4FC, UNICODE_NORM_QC_NO},
+	{0xB4FD, UNICODE_NORM_QC_NO},
+	{0xB4FE, UNICODE_NORM_QC_NO},
+	{0xB4FF, UNICODE_NORM_QC_NO},
+	{0xB500, UNICODE_NORM_QC_NO},
+	{0xB501, UNICODE_NORM_QC_NO},
+	{0xB502, UNICODE_NORM_QC_NO},
+	{0xB503, UNICODE_NORM_QC_NO},
+	{0xB504, UNICODE_NORM_QC_NO},
+	{0xB505, UNICODE_NORM_QC_NO},
+	{0xB506, UNICODE_NORM_QC_NO},
+	{0xB507, UNICODE_NORM_QC_NO},
+	{0xB508, UNICODE_NORM_QC_NO},
+	{0xB509, UNICODE_NORM_QC_NO},
+	{0xB50A, UNICODE_NORM_QC_NO},
+	{0xB50B, UNICODE_NORM_QC_NO},
+	{0xB50C, UNICODE_NORM_QC_NO},
+	{0xB50D, UNICODE_NORM_QC_NO},
+	{0xB50E, UNICODE_NORM_QC_NO},
+	{0xB50F, UNICODE_NORM_QC_NO},
+	{0xB510, UNICODE_NORM_QC_NO},
+	{0xB511, UNICODE_NORM_QC_NO},
+	{0xB512, UNICODE_NORM_QC_NO},
+	{0xB513, UNICODE_NORM_QC_NO},
+	{0xB514, UNICODE_NORM_QC_NO},
+	{0xB515, UNICODE_NORM_QC_NO},
+	{0xB516, UNICODE_NORM_QC_NO},
+	{0xB517, UNICODE_NORM_QC_NO},
+	{0xB518, UNICODE_NORM_QC_NO},
+	{0xB519, UNICODE_NORM_QC_NO},
+	{0xB51A, UNICODE_NORM_QC_NO},
+	{0xB51B, UNICODE_NORM_QC_NO},
+	{0xB51C, UNICODE_NORM_QC_NO},
+	{0xB51D, UNICODE_NORM_QC_NO},
+	{0xB51E, UNICODE_NORM_QC_NO},
+	{0xB51F, UNICODE_NORM_QC_NO},
+	{0xB520, UNICODE_NORM_QC_NO},
+	{0xB521, UNICODE_NORM_QC_NO},
+	{0xB522, UNICODE_NORM_QC_NO},
+	{0xB523, UNICODE_NORM_QC_NO},
+	{0xB524, UNICODE_NORM_QC_NO},
+	{0xB525, UNICODE_NORM_QC_NO},
+	{0xB526, UNICODE_NORM_QC_NO},
+	{0xB527, UNICODE_NORM_QC_NO},
+	{0xB528, UNICODE_NORM_QC_NO},
+	{0xB529, UNICODE_NORM_QC_NO},
+	{0xB52A, UNICODE_NORM_QC_NO},
+	{0xB52B, UNICODE_NORM_QC_NO},
+	{0xB52C, UNICODE_NORM_QC_NO},
+	{0xB52D, UNICODE_NORM_QC_NO},
+	{0xB52E, UNICODE_NORM_QC_NO},
+	{0xB52F, UNICODE_NORM_QC_NO},
+	{0xB530, UNICODE_NORM_QC_NO},
+	{0xB531, UNICODE_NORM_QC_NO},
+	{0xB532, UNICODE_NORM_QC_NO},
+	{0xB533, UNICODE_NORM_QC_NO},
+	{0xB534, UNICODE_NORM_QC_NO},
+	{0xB535, UNICODE_NORM_QC_NO},
+	{0xB536, UNICODE_NORM_QC_NO},
+	{0xB537, UNICODE_NORM_QC_NO},
+	{0xB538, UNICODE_NORM_QC_NO},
+	{0xB539, UNICODE_NORM_QC_NO},
+	{0xB53A, UNICODE_NORM_QC_NO},
+	{0xB53B, UNICODE_NORM_QC_NO},
+	{0xB53C, UNICODE_NORM_QC_NO},
+	{0xB53D, UNICODE_NORM_QC_NO},
+	{0xB53E, UNICODE_NORM_QC_NO},
+	{0xB53F, UNICODE_NORM_QC_NO},
+	{0xB540, UNICODE_NORM_QC_NO},
+	{0xB541, UNICODE_NORM_QC_NO},
+	{0xB542, UNICODE_NORM_QC_NO},
+	{0xB543, UNICODE_NORM_QC_NO},
+	{0xB544, UNICODE_NORM_QC_NO},
+	{0xB545, UNICODE_NORM_QC_NO},
+	{0xB546, UNICODE_NORM_QC_NO},
+	{0xB547, UNICODE_NORM_QC_NO},
+	{0xB548, UNICODE_NORM_QC_NO},
+	{0xB549, UNICODE_NORM_QC_NO},
+	{0xB54A, UNICODE_NORM_QC_NO},
+	{0xB54B, UNICODE_NORM_QC_NO},
+	{0xB54C, UNICODE_NORM_QC_NO},
+	{0xB54D, UNICODE_NORM_QC_NO},
+	{0xB54E, UNICODE_NORM_QC_NO},
+	{0xB54F, UNICODE_NORM_QC_NO},
+	{0xB550, UNICODE_NORM_QC_NO},
+	{0xB551, UNICODE_NORM_QC_NO},
+	{0xB552, UNICODE_NORM_QC_NO},
+	{0xB553, UNICODE_NORM_QC_NO},
+	{0xB554, UNICODE_NORM_QC_NO},
+	{0xB555, UNICODE_NORM_QC_NO},
+	{0xB556, UNICODE_NORM_QC_NO},
+	{0xB557, UNICODE_NORM_QC_NO},
+	{0xB558, UNICODE_NORM_QC_NO},
+	{0xB559, UNICODE_NORM_QC_NO},
+	{0xB55A, UNICODE_NORM_QC_NO},
+	{0xB55B, UNICODE_NORM_QC_NO},
+	{0xB55C, UNICODE_NORM_QC_NO},
+	{0xB55D, UNICODE_NORM_QC_NO},
+	{0xB55E, UNICODE_NORM_QC_NO},
+	{0xB55F, UNICODE_NORM_QC_NO},
+	{0xB560, UNICODE_NORM_QC_NO},
+	{0xB561, UNICODE_NORM_QC_NO},
+	{0xB562, UNICODE_NORM_QC_NO},
+	{0xB563, UNICODE_NORM_QC_NO},
+	{0xB564, UNICODE_NORM_QC_NO},
+	{0xB565, UNICODE_NORM_QC_NO},
+	{0xB566, UNICODE_NORM_QC_NO},
+	{0xB567, UNICODE_NORM_QC_NO},
+	{0xB568, UNICODE_NORM_QC_NO},
+	{0xB569, UNICODE_NORM_QC_NO},
+	{0xB56A, UNICODE_NORM_QC_NO},
+	{0xB56B, UNICODE_NORM_QC_NO},
+	{0xB56C, UNICODE_NORM_QC_NO},
+	{0xB56D, UNICODE_NORM_QC_NO},
+	{0xB56E, UNICODE_NORM_QC_NO},
+	{0xB56F, UNICODE_NORM_QC_NO},
+	{0xB570, UNICODE_NORM_QC_NO},
+	{0xB571, UNICODE_NORM_QC_NO},
+	{0xB572, UNICODE_NORM_QC_NO},
+	{0xB573, UNICODE_NORM_QC_NO},
+	{0xB574, UNICODE_NORM_QC_NO},
+	{0xB575, UNICODE_NORM_QC_NO},
+	{0xB576, UNICODE_NORM_QC_NO},
+	{0xB577, UNICODE_NORM_QC_NO},
+	{0xB578, UNICODE_NORM_QC_NO},
+	{0xB579, UNICODE_NORM_QC_NO},
+	{0xB57A, UNICODE_NORM_QC_NO},
+	{0xB57B, UNICODE_NORM_QC_NO},
+	{0xB57C, UNICODE_NORM_QC_NO},
+	{0xB57D, UNICODE_NORM_QC_NO},
+	{0xB57E, UNICODE_NORM_QC_NO},
+	{0xB57F, UNICODE_NORM_QC_NO},
+	{0xB580, UNICODE_NORM_QC_NO},
+	{0xB581, UNICODE_NORM_QC_NO},
+	{0xB582, UNICODE_NORM_QC_NO},
+	{0xB583, UNICODE_NORM_QC_NO},
+	{0xB584, UNICODE_NORM_QC_NO},
+	{0xB585, UNICODE_NORM_QC_NO},
+	{0xB586, UNICODE_NORM_QC_NO},
+	{0xB587, UNICODE_NORM_QC_NO},
+	{0xB588, UNICODE_NORM_QC_NO},
+	{0xB589, UNICODE_NORM_QC_NO},
+	{0xB58A, UNICODE_NORM_QC_NO},
+	{0xB58B, UNICODE_NORM_QC_NO},
+	{0xB58C, UNICODE_NORM_QC_NO},
+	{0xB58D, UNICODE_NORM_QC_NO},
+	{0xB58E, UNICODE_NORM_QC_NO},
+	{0xB58F, UNICODE_NORM_QC_NO},
+	{0xB590, UNICODE_NORM_QC_NO},
+	{0xB591, UNICODE_NORM_QC_NO},
+	{0xB592, UNICODE_NORM_QC_NO},
+	{0xB593, UNICODE_NORM_QC_NO},
+	{0xB594, UNICODE_NORM_QC_NO},
+	{0xB595, UNICODE_NORM_QC_NO},
+	{0xB596, UNICODE_NORM_QC_NO},
+	{0xB597, UNICODE_NORM_QC_NO},
+	{0xB598, UNICODE_NORM_QC_NO},
+	{0xB599, UNICODE_NORM_QC_NO},
+	{0xB59A, UNICODE_NORM_QC_NO},
+	{0xB59B, UNICODE_NORM_QC_NO},
+	{0xB59C, UNICODE_NORM_QC_NO},
+	{0xB59D, UNICODE_NORM_QC_NO},
+	{0xB59E, UNICODE_NORM_QC_NO},
+	{0xB59F, UNICODE_NORM_QC_NO},
+	{0xB5A0, UNICODE_NORM_QC_NO},
+	{0xB5A1, UNICODE_NORM_QC_NO},
+	{0xB5A2, UNICODE_NORM_QC_NO},
+	{0xB5A3, UNICODE_NORM_QC_NO},
+	{0xB5A4, UNICODE_NORM_QC_NO},
+	{0xB5A5, UNICODE_NORM_QC_NO},
+	{0xB5A6, UNICODE_NORM_QC_NO},
+	{0xB5A7, UNICODE_NORM_QC_NO},
+	{0xB5A8, UNICODE_NORM_QC_NO},
+	{0xB5A9, UNICODE_NORM_QC_NO},
+	{0xB5AA, UNICODE_NORM_QC_NO},
+	{0xB5AB, UNICODE_NORM_QC_NO},
+	{0xB5AC, UNICODE_NORM_QC_NO},
+	{0xB5AD, UNICODE_NORM_QC_NO},
+	{0xB5AE, UNICODE_NORM_QC_NO},
+	{0xB5AF, UNICODE_NORM_QC_NO},
+	{0xB5B0, UNICODE_NORM_QC_NO},
+	{0xB5B1, UNICODE_NORM_QC_NO},
+	{0xB5B2, UNICODE_NORM_QC_NO},
+	{0xB5B3, UNICODE_NORM_QC_NO},
+	{0xB5B4, UNICODE_NORM_QC_NO},
+	{0xB5B5, UNICODE_NORM_QC_NO},
+	{0xB5B6, UNICODE_NORM_QC_NO},
+	{0xB5B7, UNICODE_NORM_QC_NO},
+	{0xB5B8, UNICODE_NORM_QC_NO},
+	{0xB5B9, UNICODE_NORM_QC_NO},
+	{0xB5BA, UNICODE_NORM_QC_NO},
+	{0xB5BB, UNICODE_NORM_QC_NO},
+	{0xB5BC, UNICODE_NORM_QC_NO},
+	{0xB5BD, UNICODE_NORM_QC_NO},
+	{0xB5BE, UNICODE_NORM_QC_NO},
+	{0xB5BF, UNICODE_NORM_QC_NO},
+	{0xB5C0, UNICODE_NORM_QC_NO},
+	{0xB5C1, UNICODE_NORM_QC_NO},
+	{0xB5C2, UNICODE_NORM_QC_NO},
+	{0xB5C3, UNICODE_NORM_QC_NO},
+	{0xB5C4, UNICODE_NORM_QC_NO},
+	{0xB5C5, UNICODE_NORM_QC_NO},
+	{0xB5C6, UNICODE_NORM_QC_NO},
+	{0xB5C7, UNICODE_NORM_QC_NO},
+	{0xB5C8, UNICODE_NORM_QC_NO},
+	{0xB5C9, UNICODE_NORM_QC_NO},
+	{0xB5CA, UNICODE_NORM_QC_NO},
+	{0xB5CB, UNICODE_NORM_QC_NO},
+	{0xB5CC, UNICODE_NORM_QC_NO},
+	{0xB5CD, UNICODE_NORM_QC_NO},
+	{0xB5CE, UNICODE_NORM_QC_NO},
+	{0xB5CF, UNICODE_NORM_QC_NO},
+	{0xB5D0, UNICODE_NORM_QC_NO},
+	{0xB5D1, UNICODE_NORM_QC_NO},
+	{0xB5D2, UNICODE_NORM_QC_NO},
+	{0xB5D3, UNICODE_NORM_QC_NO},
+	{0xB5D4, UNICODE_NORM_QC_NO},
+	{0xB5D5, UNICODE_NORM_QC_NO},
+	{0xB5D6, UNICODE_NORM_QC_NO},
+	{0xB5D7, UNICODE_NORM_QC_NO},
+	{0xB5D8, UNICODE_NORM_QC_NO},
+	{0xB5D9, UNICODE_NORM_QC_NO},
+	{0xB5DA, UNICODE_NORM_QC_NO},
+	{0xB5DB, UNICODE_NORM_QC_NO},
+	{0xB5DC, UNICODE_NORM_QC_NO},
+	{0xB5DD, UNICODE_NORM_QC_NO},
+	{0xB5DE, UNICODE_NORM_QC_NO},
+	{0xB5DF, UNICODE_NORM_QC_NO},
+	{0xB5E0, UNICODE_NORM_QC_NO},
+	{0xB5E1, UNICODE_NORM_QC_NO},
+	{0xB5E2, UNICODE_NORM_QC_NO},
+	{0xB5E3, UNICODE_NORM_QC_NO},
+	{0xB5E4, UNICODE_NORM_QC_NO},
+	{0xB5E5, UNICODE_NORM_QC_NO},
+	{0xB5E6, UNICODE_NORM_QC_NO},
+	{0xB5E7, UNICODE_NORM_QC_NO},
+	{0xB5E8, UNICODE_NORM_QC_NO},
+	{0xB5E9, UNICODE_NORM_QC_NO},
+	{0xB5EA, UNICODE_NORM_QC_NO},
+	{0xB5EB, UNICODE_NORM_QC_NO},
+	{0xB5EC, UNICODE_NORM_QC_NO},
+	{0xB5ED, UNICODE_NORM_QC_NO},
+	{0xB5EE, UNICODE_NORM_QC_NO},
+	{0xB5EF, UNICODE_NORM_QC_NO},
+	{0xB5F0, UNICODE_NORM_QC_NO},
+	{0xB5F1, UNICODE_NORM_QC_NO},
+	{0xB5F2, UNICODE_NORM_QC_NO},
+	{0xB5F3, UNICODE_NORM_QC_NO},
+	{0xB5F4, UNICODE_NORM_QC_NO},
+	{0xB5F5, UNICODE_NORM_QC_NO},
+	{0xB5F6, UNICODE_NORM_QC_NO},
+	{0xB5F7, UNICODE_NORM_QC_NO},
+	{0xB5F8, UNICODE_NORM_QC_NO},
+	{0xB5F9, UNICODE_NORM_QC_NO},
+	{0xB5FA, UNICODE_NORM_QC_NO},
+	{0xB5FB, UNICODE_NORM_QC_NO},
+	{0xB5FC, UNICODE_NORM_QC_NO},
+	{0xB5FD, UNICODE_NORM_QC_NO},
+	{0xB5FE, UNICODE_NORM_QC_NO},
+	{0xB5FF, UNICODE_NORM_QC_NO},
+	{0xB600, UNICODE_NORM_QC_NO},
+	{0xB601, UNICODE_NORM_QC_NO},
+	{0xB602, UNICODE_NORM_QC_NO},
+	{0xB603, UNICODE_NORM_QC_NO},
+	{0xB604, UNICODE_NORM_QC_NO},
+	{0xB605, UNICODE_NORM_QC_NO},
+	{0xB606, UNICODE_NORM_QC_NO},
+	{0xB607, UNICODE_NORM_QC_NO},
+	{0xB608, UNICODE_NORM_QC_NO},
+	{0xB609, UNICODE_NORM_QC_NO},
+	{0xB60A, UNICODE_NORM_QC_NO},
+	{0xB60B, UNICODE_NORM_QC_NO},
+	{0xB60C, UNICODE_NORM_QC_NO},
+	{0xB60D, UNICODE_NORM_QC_NO},
+	{0xB60E, UNICODE_NORM_QC_NO},
+	{0xB60F, UNICODE_NORM_QC_NO},
+	{0xB610, UNICODE_NORM_QC_NO},
+	{0xB611, UNICODE_NORM_QC_NO},
+	{0xB612, UNICODE_NORM_QC_NO},
+	{0xB613, UNICODE_NORM_QC_NO},
+	{0xB614, UNICODE_NORM_QC_NO},
+	{0xB615, UNICODE_NORM_QC_NO},
+	{0xB616, UNICODE_NORM_QC_NO},
+	{0xB617, UNICODE_NORM_QC_NO},
+	{0xB618, UNICODE_NORM_QC_NO},
+	{0xB619, UNICODE_NORM_QC_NO},
+	{0xB61A, UNICODE_NORM_QC_NO},
+	{0xB61B, UNICODE_NORM_QC_NO},
+	{0xB61C, UNICODE_NORM_QC_NO},
+	{0xB61D, UNICODE_NORM_QC_NO},
+	{0xB61E, UNICODE_NORM_QC_NO},
+	{0xB61F, UNICODE_NORM_QC_NO},
+	{0xB620, UNICODE_NORM_QC_NO},
+	{0xB621, UNICODE_NORM_QC_NO},
+	{0xB622, UNICODE_NORM_QC_NO},
+	{0xB623, UNICODE_NORM_QC_NO},
+	{0xB624, UNICODE_NORM_QC_NO},
+	{0xB625, UNICODE_NORM_QC_NO},
+	{0xB626, UNICODE_NORM_QC_NO},
+	{0xB627, UNICODE_NORM_QC_NO},
+	{0xB628, UNICODE_NORM_QC_NO},
+	{0xB629, UNICODE_NORM_QC_NO},
+	{0xB62A, UNICODE_NORM_QC_NO},
+	{0xB62B, UNICODE_NORM_QC_NO},
+	{0xB62C, UNICODE_NORM_QC_NO},
+	{0xB62D, UNICODE_NORM_QC_NO},
+	{0xB62E, UNICODE_NORM_QC_NO},
+	{0xB62F, UNICODE_NORM_QC_NO},
+	{0xB630, UNICODE_NORM_QC_NO},
+	{0xB631, UNICODE_NORM_QC_NO},
+	{0xB632, UNICODE_NORM_QC_NO},
+	{0xB633, UNICODE_NORM_QC_NO},
+	{0xB634, UNICODE_NORM_QC_NO},
+	{0xB635, UNICODE_NORM_QC_NO},
+	{0xB636, UNICODE_NORM_QC_NO},
+	{0xB637, UNICODE_NORM_QC_NO},
+	{0xB638, UNICODE_NORM_QC_NO},
+	{0xB639, UNICODE_NORM_QC_NO},
+	{0xB63A, UNICODE_NORM_QC_NO},
+	{0xB63B, UNICODE_NORM_QC_NO},
+	{0xB63C, UNICODE_NORM_QC_NO},
+	{0xB63D, UNICODE_NORM_QC_NO},
+	{0xB63E, UNICODE_NORM_QC_NO},
+	{0xB63F, UNICODE_NORM_QC_NO},
+	{0xB640, UNICODE_NORM_QC_NO},
+	{0xB641, UNICODE_NORM_QC_NO},
+	{0xB642, UNICODE_NORM_QC_NO},
+	{0xB643, UNICODE_NORM_QC_NO},
+	{0xB644, UNICODE_NORM_QC_NO},
+	{0xB645, UNICODE_NORM_QC_NO},
+	{0xB646, UNICODE_NORM_QC_NO},
+	{0xB647, UNICODE_NORM_QC_NO},
+	{0xB648, UNICODE_NORM_QC_NO},
+	{0xB649, UNICODE_NORM_QC_NO},
+	{0xB64A, UNICODE_NORM_QC_NO},
+	{0xB64B, UNICODE_NORM_QC_NO},
+	{0xB64C, UNICODE_NORM_QC_NO},
+	{0xB64D, UNICODE_NORM_QC_NO},
+	{0xB64E, UNICODE_NORM_QC_NO},
+	{0xB64F, UNICODE_NORM_QC_NO},
+	{0xB650, UNICODE_NORM_QC_NO},
+	{0xB651, UNICODE_NORM_QC_NO},
+	{0xB652, UNICODE_NORM_QC_NO},
+	{0xB653, UNICODE_NORM_QC_NO},
+	{0xB654, UNICODE_NORM_QC_NO},
+	{0xB655, UNICODE_NORM_QC_NO},
+	{0xB656, UNICODE_NORM_QC_NO},
+	{0xB657, UNICODE_NORM_QC_NO},
+	{0xB658, UNICODE_NORM_QC_NO},
+	{0xB659, UNICODE_NORM_QC_NO},
+	{0xB65A, UNICODE_NORM_QC_NO},
+	{0xB65B, UNICODE_NORM_QC_NO},
+	{0xB65C, UNICODE_NORM_QC_NO},
+	{0xB65D, UNICODE_NORM_QC_NO},
+	{0xB65E, UNICODE_NORM_QC_NO},
+	{0xB65F, UNICODE_NORM_QC_NO},
+	{0xB660, UNICODE_NORM_QC_NO},
+	{0xB661, UNICODE_NORM_QC_NO},
+	{0xB662, UNICODE_NORM_QC_NO},
+	{0xB663, UNICODE_NORM_QC_NO},
+	{0xB664, UNICODE_NORM_QC_NO},
+	{0xB665, UNICODE_NORM_QC_NO},
+	{0xB666, UNICODE_NORM_QC_NO},
+	{0xB667, UNICODE_NORM_QC_NO},
+	{0xB668, UNICODE_NORM_QC_NO},
+	{0xB669, UNICODE_NORM_QC_NO},
+	{0xB66A, UNICODE_NORM_QC_NO},
+	{0xB66B, UNICODE_NORM_QC_NO},
+	{0xB66C, UNICODE_NORM_QC_NO},
+	{0xB66D, UNICODE_NORM_QC_NO},
+	{0xB66E, UNICODE_NORM_QC_NO},
+	{0xB66F, UNICODE_NORM_QC_NO},
+	{0xB670, UNICODE_NORM_QC_NO},
+	{0xB671, UNICODE_NORM_QC_NO},
+	{0xB672, UNICODE_NORM_QC_NO},
+	{0xB673, UNICODE_NORM_QC_NO},
+	{0xB674, UNICODE_NORM_QC_NO},
+	{0xB675, UNICODE_NORM_QC_NO},
+	{0xB676, UNICODE_NORM_QC_NO},
+	{0xB677, UNICODE_NORM_QC_NO},
+	{0xB678, UNICODE_NORM_QC_NO},
+	{0xB679, UNICODE_NORM_QC_NO},
+	{0xB67A, UNICODE_NORM_QC_NO},
+	{0xB67B, UNICODE_NORM_QC_NO},
+	{0xB67C, UNICODE_NORM_QC_NO},
+	{0xB67D, UNICODE_NORM_QC_NO},
+	{0xB67E, UNICODE_NORM_QC_NO},
+	{0xB67F, UNICODE_NORM_QC_NO},
+	{0xB680, UNICODE_NORM_QC_NO},
+	{0xB681, UNICODE_NORM_QC_NO},
+	{0xB682, UNICODE_NORM_QC_NO},
+	{0xB683, UNICODE_NORM_QC_NO},
+	{0xB684, UNICODE_NORM_QC_NO},
+	{0xB685, UNICODE_NORM_QC_NO},
+	{0xB686, UNICODE_NORM_QC_NO},
+	{0xB687, UNICODE_NORM_QC_NO},
+	{0xB688, UNICODE_NORM_QC_NO},
+	{0xB689, UNICODE_NORM_QC_NO},
+	{0xB68A, UNICODE_NORM_QC_NO},
+	{0xB68B, UNICODE_NORM_QC_NO},
+	{0xB68C, UNICODE_NORM_QC_NO},
+	{0xB68D, UNICODE_NORM_QC_NO},
+	{0xB68E, UNICODE_NORM_QC_NO},
+	{0xB68F, UNICODE_NORM_QC_NO},
+	{0xB690, UNICODE_NORM_QC_NO},
+	{0xB691, UNICODE_NORM_QC_NO},
+	{0xB692, UNICODE_NORM_QC_NO},
+	{0xB693, UNICODE_NORM_QC_NO},
+	{0xB694, UNICODE_NORM_QC_NO},
+	{0xB695, UNICODE_NORM_QC_NO},
+	{0xB696, UNICODE_NORM_QC_NO},
+	{0xB697, UNICODE_NORM_QC_NO},
+	{0xB698, UNICODE_NORM_QC_NO},
+	{0xB699, UNICODE_NORM_QC_NO},
+	{0xB69A, UNICODE_NORM_QC_NO},
+	{0xB69B, UNICODE_NORM_QC_NO},
+	{0xB69C, UNICODE_NORM_QC_NO},
+	{0xB69D, UNICODE_NORM_QC_NO},
+	{0xB69E, UNICODE_NORM_QC_NO},
+	{0xB69F, UNICODE_NORM_QC_NO},
+	{0xB6A0, UNICODE_NORM_QC_NO},
+	{0xB6A1, UNICODE_NORM_QC_NO},
+	{0xB6A2, UNICODE_NORM_QC_NO},
+	{0xB6A3, UNICODE_NORM_QC_NO},
+	{0xB6A4, UNICODE_NORM_QC_NO},
+	{0xB6A5, UNICODE_NORM_QC_NO},
+	{0xB6A6, UNICODE_NORM_QC_NO},
+	{0xB6A7, UNICODE_NORM_QC_NO},
+	{0xB6A8, UNICODE_NORM_QC_NO},
+	{0xB6A9, UNICODE_NORM_QC_NO},
+	{0xB6AA, UNICODE_NORM_QC_NO},
+	{0xB6AB, UNICODE_NORM_QC_NO},
+	{0xB6AC, UNICODE_NORM_QC_NO},
+	{0xB6AD, UNICODE_NORM_QC_NO},
+	{0xB6AE, UNICODE_NORM_QC_NO},
+	{0xB6AF, UNICODE_NORM_QC_NO},
+	{0xB6B0, UNICODE_NORM_QC_NO},
+	{0xB6B1, UNICODE_NORM_QC_NO},
+	{0xB6B2, UNICODE_NORM_QC_NO},
+	{0xB6B3, UNICODE_NORM_QC_NO},
+	{0xB6B4, UNICODE_NORM_QC_NO},
+	{0xB6B5, UNICODE_NORM_QC_NO},
+	{0xB6B6, UNICODE_NORM_QC_NO},
+	{0xB6B7, UNICODE_NORM_QC_NO},
+	{0xB6B8, UNICODE_NORM_QC_NO},
+	{0xB6B9, UNICODE_NORM_QC_NO},
+	{0xB6BA, UNICODE_NORM_QC_NO},
+	{0xB6BB, UNICODE_NORM_QC_NO},
+	{0xB6BC, UNICODE_NORM_QC_NO},
+	{0xB6BD, UNICODE_NORM_QC_NO},
+	{0xB6BE, UNICODE_NORM_QC_NO},
+	{0xB6BF, UNICODE_NORM_QC_NO},
+	{0xB6C0, UNICODE_NORM_QC_NO},
+	{0xB6C1, UNICODE_NORM_QC_NO},
+	{0xB6C2, UNICODE_NORM_QC_NO},
+	{0xB6C3, UNICODE_NORM_QC_NO},
+	{0xB6C4, UNICODE_NORM_QC_NO},
+	{0xB6C5, UNICODE_NORM_QC_NO},
+	{0xB6C6, UNICODE_NORM_QC_NO},
+	{0xB6C7, UNICODE_NORM_QC_NO},
+	{0xB6C8, UNICODE_NORM_QC_NO},
+	{0xB6C9, UNICODE_NORM_QC_NO},
+	{0xB6CA, UNICODE_NORM_QC_NO},
+	{0xB6CB, UNICODE_NORM_QC_NO},
+	{0xB6CC, UNICODE_NORM_QC_NO},
+	{0xB6CD, UNICODE_NORM_QC_NO},
+	{0xB6CE, UNICODE_NORM_QC_NO},
+	{0xB6CF, UNICODE_NORM_QC_NO},
+	{0xB6D0, UNICODE_NORM_QC_NO},
+	{0xB6D1, UNICODE_NORM_QC_NO},
+	{0xB6D2, UNICODE_NORM_QC_NO},
+	{0xB6D3, UNICODE_NORM_QC_NO},
+	{0xB6D4, UNICODE_NORM_QC_NO},
+	{0xB6D5, UNICODE_NORM_QC_NO},
+	{0xB6D6, UNICODE_NORM_QC_NO},
+	{0xB6D7, UNICODE_NORM_QC_NO},
+	{0xB6D8, UNICODE_NORM_QC_NO},
+	{0xB6D9, UNICODE_NORM_QC_NO},
+	{0xB6DA, UNICODE_NORM_QC_NO},
+	{0xB6DB, UNICODE_NORM_QC_NO},
+	{0xB6DC, UNICODE_NORM_QC_NO},
+	{0xB6DD, UNICODE_NORM_QC_NO},
+	{0xB6DE, UNICODE_NORM_QC_NO},
+	{0xB6DF, UNICODE_NORM_QC_NO},
+	{0xB6E0, UNICODE_NORM_QC_NO},
+	{0xB6E1, UNICODE_NORM_QC_NO},
+	{0xB6E2, UNICODE_NORM_QC_NO},
+	{0xB6E3, UNICODE_NORM_QC_NO},
+	{0xB6E4, UNICODE_NORM_QC_NO},
+	{0xB6E5, UNICODE_NORM_QC_NO},
+	{0xB6E6, UNICODE_NORM_QC_NO},
+	{0xB6E7, UNICODE_NORM_QC_NO},
+	{0xB6E8, UNICODE_NORM_QC_NO},
+	{0xB6E9, UNICODE_NORM_QC_NO},
+	{0xB6EA, UNICODE_NORM_QC_NO},
+	{0xB6EB, UNICODE_NORM_QC_NO},
+	{0xB6EC, UNICODE_NORM_QC_NO},
+	{0xB6ED, UNICODE_NORM_QC_NO},
+	{0xB6EE, UNICODE_NORM_QC_NO},
+	{0xB6EF, UNICODE_NORM_QC_NO},
+	{0xB6F0, UNICODE_NORM_QC_NO},
+	{0xB6F1, UNICODE_NORM_QC_NO},
+	{0xB6F2, UNICODE_NORM_QC_NO},
+	{0xB6F3, UNICODE_NORM_QC_NO},
+	{0xB6F4, UNICODE_NORM_QC_NO},
+	{0xB6F5, UNICODE_NORM_QC_NO},
+	{0xB6F6, UNICODE_NORM_QC_NO},
+	{0xB6F7, UNICODE_NORM_QC_NO},
+	{0xB6F8, UNICODE_NORM_QC_NO},
+	{0xB6F9, UNICODE_NORM_QC_NO},
+	{0xB6FA, UNICODE_NORM_QC_NO},
+	{0xB6FB, UNICODE_NORM_QC_NO},
+	{0xB6FC, UNICODE_NORM_QC_NO},
+	{0xB6FD, UNICODE_NORM_QC_NO},
+	{0xB6FE, UNICODE_NORM_QC_NO},
+	{0xB6FF, UNICODE_NORM_QC_NO},
+	{0xB700, UNICODE_NORM_QC_NO},
+	{0xB701, UNICODE_NORM_QC_NO},
+	{0xB702, UNICODE_NORM_QC_NO},
+	{0xB703, UNICODE_NORM_QC_NO},
+	{0xB704, UNICODE_NORM_QC_NO},
+	{0xB705, UNICODE_NORM_QC_NO},
+	{0xB706, UNICODE_NORM_QC_NO},
+	{0xB707, UNICODE_NORM_QC_NO},
+	{0xB708, UNICODE_NORM_QC_NO},
+	{0xB709, UNICODE_NORM_QC_NO},
+	{0xB70A, UNICODE_NORM_QC_NO},
+	{0xB70B, UNICODE_NORM_QC_NO},
+	{0xB70C, UNICODE_NORM_QC_NO},
+	{0xB70D, UNICODE_NORM_QC_NO},
+	{0xB70E, UNICODE_NORM_QC_NO},
+	{0xB70F, UNICODE_NORM_QC_NO},
+	{0xB710, UNICODE_NORM_QC_NO},
+	{0xB711, UNICODE_NORM_QC_NO},
+	{0xB712, UNICODE_NORM_QC_NO},
+	{0xB713, UNICODE_NORM_QC_NO},
+	{0xB714, UNICODE_NORM_QC_NO},
+	{0xB715, UNICODE_NORM_QC_NO},
+	{0xB716, UNICODE_NORM_QC_NO},
+	{0xB717, UNICODE_NORM_QC_NO},
+	{0xB718, UNICODE_NORM_QC_NO},
+	{0xB719, UNICODE_NORM_QC_NO},
+	{0xB71A, UNICODE_NORM_QC_NO},
+	{0xB71B, UNICODE_NORM_QC_NO},
+	{0xB71C, UNICODE_NORM_QC_NO},
+	{0xB71D, UNICODE_NORM_QC_NO},
+	{0xB71E, UNICODE_NORM_QC_NO},
+	{0xB71F, UNICODE_NORM_QC_NO},
+	{0xB720, UNICODE_NORM_QC_NO},
+	{0xB721, UNICODE_NORM_QC_NO},
+	{0xB722, UNICODE_NORM_QC_NO},
+	{0xB723, UNICODE_NORM_QC_NO},
+	{0xB724, UNICODE_NORM_QC_NO},
+	{0xB725, UNICODE_NORM_QC_NO},
+	{0xB726, UNICODE_NORM_QC_NO},
+	{0xB727, UNICODE_NORM_QC_NO},
+	{0xB728, UNICODE_NORM_QC_NO},
+	{0xB729, UNICODE_NORM_QC_NO},
+	{0xB72A, UNICODE_NORM_QC_NO},
+	{0xB72B, UNICODE_NORM_QC_NO},
+	{0xB72C, UNICODE_NORM_QC_NO},
+	{0xB72D, UNICODE_NORM_QC_NO},
+	{0xB72E, UNICODE_NORM_QC_NO},
+	{0xB72F, UNICODE_NORM_QC_NO},
+	{0xB730, UNICODE_NORM_QC_NO},
+	{0xB731, UNICODE_NORM_QC_NO},
+	{0xB732, UNICODE_NORM_QC_NO},
+	{0xB733, UNICODE_NORM_QC_NO},
+	{0xB734, UNICODE_NORM_QC_NO},
+	{0xB735, UNICODE_NORM_QC_NO},
+	{0xB736, UNICODE_NORM_QC_NO},
+	{0xB737, UNICODE_NORM_QC_NO},
+	{0xB738, UNICODE_NORM_QC_NO},
+	{0xB739, UNICODE_NORM_QC_NO},
+	{0xB73A, UNICODE_NORM_QC_NO},
+	{0xB73B, UNICODE_NORM_QC_NO},
+	{0xB73C, UNICODE_NORM_QC_NO},
+	{0xB73D, UNICODE_NORM_QC_NO},
+	{0xB73E, UNICODE_NORM_QC_NO},
+	{0xB73F, UNICODE_NORM_QC_NO},
+	{0xB740, UNICODE_NORM_QC_NO},
+	{0xB741, UNICODE_NORM_QC_NO},
+	{0xB742, UNICODE_NORM_QC_NO},
+	{0xB743, UNICODE_NORM_QC_NO},
+	{0xB744, UNICODE_NORM_QC_NO},
+	{0xB745, UNICODE_NORM_QC_NO},
+	{0xB746, UNICODE_NORM_QC_NO},
+	{0xB747, UNICODE_NORM_QC_NO},
+	{0xB748, UNICODE_NORM_QC_NO},
+	{0xB749, UNICODE_NORM_QC_NO},
+	{0xB74A, UNICODE_NORM_QC_NO},
+	{0xB74B, UNICODE_NORM_QC_NO},
+	{0xB74C, UNICODE_NORM_QC_NO},
+	{0xB74D, UNICODE_NORM_QC_NO},
+	{0xB74E, UNICODE_NORM_QC_NO},
+	{0xB74F, UNICODE_NORM_QC_NO},
+	{0xB750, UNICODE_NORM_QC_NO},
+	{0xB751, UNICODE_NORM_QC_NO},
+	{0xB752, UNICODE_NORM_QC_NO},
+	{0xB753, UNICODE_NORM_QC_NO},
+	{0xB754, UNICODE_NORM_QC_NO},
+	{0xB755, UNICODE_NORM_QC_NO},
+	{0xB756, UNICODE_NORM_QC_NO},
+	{0xB757, UNICODE_NORM_QC_NO},
+	{0xB758, UNICODE_NORM_QC_NO},
+	{0xB759, UNICODE_NORM_QC_NO},
+	{0xB75A, UNICODE_NORM_QC_NO},
+	{0xB75B, UNICODE_NORM_QC_NO},
+	{0xB75C, UNICODE_NORM_QC_NO},
+	{0xB75D, UNICODE_NORM_QC_NO},
+	{0xB75E, UNICODE_NORM_QC_NO},
+	{0xB75F, UNICODE_NORM_QC_NO},
+	{0xB760, UNICODE_NORM_QC_NO},
+	{0xB761, UNICODE_NORM_QC_NO},
+	{0xB762, UNICODE_NORM_QC_NO},
+	{0xB763, UNICODE_NORM_QC_NO},
+	{0xB764, UNICODE_NORM_QC_NO},
+	{0xB765, UNICODE_NORM_QC_NO},
+	{0xB766, UNICODE_NORM_QC_NO},
+	{0xB767, UNICODE_NORM_QC_NO},
+	{0xB768, UNICODE_NORM_QC_NO},
+	{0xB769, UNICODE_NORM_QC_NO},
+	{0xB76A, UNICODE_NORM_QC_NO},
+	{0xB76B, UNICODE_NORM_QC_NO},
+	{0xB76C, UNICODE_NORM_QC_NO},
+	{0xB76D, UNICODE_NORM_QC_NO},
+	{0xB76E, UNICODE_NORM_QC_NO},
+	{0xB76F, UNICODE_NORM_QC_NO},
+	{0xB770, UNICODE_NORM_QC_NO},
+	{0xB771, UNICODE_NORM_QC_NO},
+	{0xB772, UNICODE_NORM_QC_NO},
+	{0xB773, UNICODE_NORM_QC_NO},
+	{0xB774, UNICODE_NORM_QC_NO},
+	{0xB775, UNICODE_NORM_QC_NO},
+	{0xB776, UNICODE_NORM_QC_NO},
+	{0xB777, UNICODE_NORM_QC_NO},
+	{0xB778, UNICODE_NORM_QC_NO},
+	{0xB779, UNICODE_NORM_QC_NO},
+	{0xB77A, UNICODE_NORM_QC_NO},
+	{0xB77B, UNICODE_NORM_QC_NO},
+	{0xB77C, UNICODE_NORM_QC_NO},
+	{0xB77D, UNICODE_NORM_QC_NO},
+	{0xB77E, UNICODE_NORM_QC_NO},
+	{0xB77F, UNICODE_NORM_QC_NO},
+	{0xB780, UNICODE_NORM_QC_NO},
+	{0xB781, UNICODE_NORM_QC_NO},
+	{0xB782, UNICODE_NORM_QC_NO},
+	{0xB783, UNICODE_NORM_QC_NO},
+	{0xB784, UNICODE_NORM_QC_NO},
+	{0xB785, UNICODE_NORM_QC_NO},
+	{0xB786, UNICODE_NORM_QC_NO},
+	{0xB787, UNICODE_NORM_QC_NO},
+	{0xB788, UNICODE_NORM_QC_NO},
+	{0xB789, UNICODE_NORM_QC_NO},
+	{0xB78A, UNICODE_NORM_QC_NO},
+	{0xB78B, UNICODE_NORM_QC_NO},
+	{0xB78C, UNICODE_NORM_QC_NO},
+	{0xB78D, UNICODE_NORM_QC_NO},
+	{0xB78E, UNICODE_NORM_QC_NO},
+	{0xB78F, UNICODE_NORM_QC_NO},
+	{0xB790, UNICODE_NORM_QC_NO},
+	{0xB791, UNICODE_NORM_QC_NO},
+	{0xB792, UNICODE_NORM_QC_NO},
+	{0xB793, UNICODE_NORM_QC_NO},
+	{0xB794, UNICODE_NORM_QC_NO},
+	{0xB795, UNICODE_NORM_QC_NO},
+	{0xB796, UNICODE_NORM_QC_NO},
+	{0xB797, UNICODE_NORM_QC_NO},
+	{0xB798, UNICODE_NORM_QC_NO},
+	{0xB799, UNICODE_NORM_QC_NO},
+	{0xB79A, UNICODE_NORM_QC_NO},
+	{0xB79B, UNICODE_NORM_QC_NO},
+	{0xB79C, UNICODE_NORM_QC_NO},
+	{0xB79D, UNICODE_NORM_QC_NO},
+	{0xB79E, UNICODE_NORM_QC_NO},
+	{0xB79F, UNICODE_NORM_QC_NO},
+	{0xB7A0, UNICODE_NORM_QC_NO},
+	{0xB7A1, UNICODE_NORM_QC_NO},
+	{0xB7A2, UNICODE_NORM_QC_NO},
+	{0xB7A3, UNICODE_NORM_QC_NO},
+	{0xB7A4, UNICODE_NORM_QC_NO},
+	{0xB7A5, UNICODE_NORM_QC_NO},
+	{0xB7A6, UNICODE_NORM_QC_NO},
+	{0xB7A7, UNICODE_NORM_QC_NO},
+	{0xB7A8, UNICODE_NORM_QC_NO},
+	{0xB7A9, UNICODE_NORM_QC_NO},
+	{0xB7AA, UNICODE_NORM_QC_NO},
+	{0xB7AB, UNICODE_NORM_QC_NO},
+	{0xB7AC, UNICODE_NORM_QC_NO},
+	{0xB7AD, UNICODE_NORM_QC_NO},
+	{0xB7AE, UNICODE_NORM_QC_NO},
+	{0xB7AF, UNICODE_NORM_QC_NO},
+	{0xB7B0, UNICODE_NORM_QC_NO},
+	{0xB7B1, UNICODE_NORM_QC_NO},
+	{0xB7B2, UNICODE_NORM_QC_NO},
+	{0xB7B3, UNICODE_NORM_QC_NO},
+	{0xB7B4, UNICODE_NORM_QC_NO},
+	{0xB7B5, UNICODE_NORM_QC_NO},
+	{0xB7B6, UNICODE_NORM_QC_NO},
+	{0xB7B7, UNICODE_NORM_QC_NO},
+	{0xB7B8, UNICODE_NORM_QC_NO},
+	{0xB7B9, UNICODE_NORM_QC_NO},
+	{0xB7BA, UNICODE_NORM_QC_NO},
+	{0xB7BB, UNICODE_NORM_QC_NO},
+	{0xB7BC, UNICODE_NORM_QC_NO},
+	{0xB7BD, UNICODE_NORM_QC_NO},
+	{0xB7BE, UNICODE_NORM_QC_NO},
+	{0xB7BF, UNICODE_NORM_QC_NO},
+	{0xB7C0, UNICODE_NORM_QC_NO},
+	{0xB7C1, UNICODE_NORM_QC_NO},
+	{0xB7C2, UNICODE_NORM_QC_NO},
+	{0xB7C3, UNICODE_NORM_QC_NO},
+	{0xB7C4, UNICODE_NORM_QC_NO},
+	{0xB7C5, UNICODE_NORM_QC_NO},
+	{0xB7C6, UNICODE_NORM_QC_NO},
+	{0xB7C7, UNICODE_NORM_QC_NO},
+	{0xB7C8, UNICODE_NORM_QC_NO},
+	{0xB7C9, UNICODE_NORM_QC_NO},
+	{0xB7CA, UNICODE_NORM_QC_NO},
+	{0xB7CB, UNICODE_NORM_QC_NO},
+	{0xB7CC, UNICODE_NORM_QC_NO},
+	{0xB7CD, UNICODE_NORM_QC_NO},
+	{0xB7CE, UNICODE_NORM_QC_NO},
+	{0xB7CF, UNICODE_NORM_QC_NO},
+	{0xB7D0, UNICODE_NORM_QC_NO},
+	{0xB7D1, UNICODE_NORM_QC_NO},
+	{0xB7D2, UNICODE_NORM_QC_NO},
+	{0xB7D3, UNICODE_NORM_QC_NO},
+	{0xB7D4, UNICODE_NORM_QC_NO},
+	{0xB7D5, UNICODE_NORM_QC_NO},
+	{0xB7D6, UNICODE_NORM_QC_NO},
+	{0xB7D7, UNICODE_NORM_QC_NO},
+	{0xB7D8, UNICODE_NORM_QC_NO},
+	{0xB7D9, UNICODE_NORM_QC_NO},
+	{0xB7DA, UNICODE_NORM_QC_NO},
+	{0xB7DB, UNICODE_NORM_QC_NO},
+	{0xB7DC, UNICODE_NORM_QC_NO},
+	{0xB7DD, UNICODE_NORM_QC_NO},
+	{0xB7DE, UNICODE_NORM_QC_NO},
+	{0xB7DF, UNICODE_NORM_QC_NO},
+	{0xB7E0, UNICODE_NORM_QC_NO},
+	{0xB7E1, UNICODE_NORM_QC_NO},
+	{0xB7E2, UNICODE_NORM_QC_NO},
+	{0xB7E3, UNICODE_NORM_QC_NO},
+	{0xB7E4, UNICODE_NORM_QC_NO},
+	{0xB7E5, UNICODE_NORM_QC_NO},
+	{0xB7E6, UNICODE_NORM_QC_NO},
+	{0xB7E7, UNICODE_NORM_QC_NO},
+	{0xB7E8, UNICODE_NORM_QC_NO},
+	{0xB7E9, UNICODE_NORM_QC_NO},
+	{0xB7EA, UNICODE_NORM_QC_NO},
+	{0xB7EB, UNICODE_NORM_QC_NO},
+	{0xB7EC, UNICODE_NORM_QC_NO},
+	{0xB7ED, UNICODE_NORM_QC_NO},
+	{0xB7EE, UNICODE_NORM_QC_NO},
+	{0xB7EF, UNICODE_NORM_QC_NO},
+	{0xB7F0, UNICODE_NORM_QC_NO},
+	{0xB7F1, UNICODE_NORM_QC_NO},
+	{0xB7F2, UNICODE_NORM_QC_NO},
+	{0xB7F3, UNICODE_NORM_QC_NO},
+	{0xB7F4, UNICODE_NORM_QC_NO},
+	{0xB7F5, UNICODE_NORM_QC_NO},
+	{0xB7F6, UNICODE_NORM_QC_NO},
+	{0xB7F7, UNICODE_NORM_QC_NO},
+	{0xB7F8, UNICODE_NORM_QC_NO},
+	{0xB7F9, UNICODE_NORM_QC_NO},
+	{0xB7FA, UNICODE_NORM_QC_NO},
+	{0xB7FB, UNICODE_NORM_QC_NO},
+	{0xB7FC, UNICODE_NORM_QC_NO},
+	{0xB7FD, UNICODE_NORM_QC_NO},
+	{0xB7FE, UNICODE_NORM_QC_NO},
+	{0xB7FF, UNICODE_NORM_QC_NO},
+	{0xB800, UNICODE_NORM_QC_NO},
+	{0xB801, UNICODE_NORM_QC_NO},
+	{0xB802, UNICODE_NORM_QC_NO},
+	{0xB803, UNICODE_NORM_QC_NO},
+	{0xB804, UNICODE_NORM_QC_NO},
+	{0xB805, UNICODE_NORM_QC_NO},
+	{0xB806, UNICODE_NORM_QC_NO},
+	{0xB807, UNICODE_NORM_QC_NO},
+	{0xB808, UNICODE_NORM_QC_NO},
+	{0xB809, UNICODE_NORM_QC_NO},
+	{0xB80A, UNICODE_NORM_QC_NO},
+	{0xB80B, UNICODE_NORM_QC_NO},
+	{0xB80C, UNICODE_NORM_QC_NO},
+	{0xB80D, UNICODE_NORM_QC_NO},
+	{0xB80E, UNICODE_NORM_QC_NO},
+	{0xB80F, UNICODE_NORM_QC_NO},
+	{0xB810, UNICODE_NORM_QC_NO},
+	{0xB811, UNICODE_NORM_QC_NO},
+	{0xB812, UNICODE_NORM_QC_NO},
+	{0xB813, UNICODE_NORM_QC_NO},
+	{0xB814, UNICODE_NORM_QC_NO},
+	{0xB815, UNICODE_NORM_QC_NO},
+	{0xB816, UNICODE_NORM_QC_NO},
+	{0xB817, UNICODE_NORM_QC_NO},
+	{0xB818, UNICODE_NORM_QC_NO},
+	{0xB819, UNICODE_NORM_QC_NO},
+	{0xB81A, UNICODE_NORM_QC_NO},
+	{0xB81B, UNICODE_NORM_QC_NO},
+	{0xB81C, UNICODE_NORM_QC_NO},
+	{0xB81D, UNICODE_NORM_QC_NO},
+	{0xB81E, UNICODE_NORM_QC_NO},
+	{0xB81F, UNICODE_NORM_QC_NO},
+	{0xB820, UNICODE_NORM_QC_NO},
+	{0xB821, UNICODE_NORM_QC_NO},
+	{0xB822, UNICODE_NORM_QC_NO},
+	{0xB823, UNICODE_NORM_QC_NO},
+	{0xB824, UNICODE_NORM_QC_NO},
+	{0xB825, UNICODE_NORM_QC_NO},
+	{0xB826, UNICODE_NORM_QC_NO},
+	{0xB827, UNICODE_NORM_QC_NO},
+	{0xB828, UNICODE_NORM_QC_NO},
+	{0xB829, UNICODE_NORM_QC_NO},
+	{0xB82A, UNICODE_NORM_QC_NO},
+	{0xB82B, UNICODE_NORM_QC_NO},
+	{0xB82C, UNICODE_NORM_QC_NO},
+	{0xB82D, UNICODE_NORM_QC_NO},
+	{0xB82E, UNICODE_NORM_QC_NO},
+	{0xB82F, UNICODE_NORM_QC_NO},
+	{0xB830, UNICODE_NORM_QC_NO},
+	{0xB831, UNICODE_NORM_QC_NO},
+	{0xB832, UNICODE_NORM_QC_NO},
+	{0xB833, UNICODE_NORM_QC_NO},
+	{0xB834, UNICODE_NORM_QC_NO},
+	{0xB835, UNICODE_NORM_QC_NO},
+	{0xB836, UNICODE_NORM_QC_NO},
+	{0xB837, UNICODE_NORM_QC_NO},
+	{0xB838, UNICODE_NORM_QC_NO},
+	{0xB839, UNICODE_NORM_QC_NO},
+	{0xB83A, UNICODE_NORM_QC_NO},
+	{0xB83B, UNICODE_NORM_QC_NO},
+	{0xB83C, UNICODE_NORM_QC_NO},
+	{0xB83D, UNICODE_NORM_QC_NO},
+	{0xB83E, UNICODE_NORM_QC_NO},
+	{0xB83F, UNICODE_NORM_QC_NO},
+	{0xB840, UNICODE_NORM_QC_NO},
+	{0xB841, UNICODE_NORM_QC_NO},
+	{0xB842, UNICODE_NORM_QC_NO},
+	{0xB843, UNICODE_NORM_QC_NO},
+	{0xB844, UNICODE_NORM_QC_NO},
+	{0xB845, UNICODE_NORM_QC_NO},
+	{0xB846, UNICODE_NORM_QC_NO},
+	{0xB847, UNICODE_NORM_QC_NO},
+	{0xB848, UNICODE_NORM_QC_NO},
+	{0xB849, UNICODE_NORM_QC_NO},
+	{0xB84A, UNICODE_NORM_QC_NO},
+	{0xB84B, UNICODE_NORM_QC_NO},
+	{0xB84C, UNICODE_NORM_QC_NO},
+	{0xB84D, UNICODE_NORM_QC_NO},
+	{0xB84E, UNICODE_NORM_QC_NO},
+	{0xB84F, UNICODE_NORM_QC_NO},
+	{0xB850, UNICODE_NORM_QC_NO},
+	{0xB851, UNICODE_NORM_QC_NO},
+	{0xB852, UNICODE_NORM_QC_NO},
+	{0xB853, UNICODE_NORM_QC_NO},
+	{0xB854, UNICODE_NORM_QC_NO},
+	{0xB855, UNICODE_NORM_QC_NO},
+	{0xB856, UNICODE_NORM_QC_NO},
+	{0xB857, UNICODE_NORM_QC_NO},
+	{0xB858, UNICODE_NORM_QC_NO},
+	{0xB859, UNICODE_NORM_QC_NO},
+	{0xB85A, UNICODE_NORM_QC_NO},
+	{0xB85B, UNICODE_NORM_QC_NO},
+	{0xB85C, UNICODE_NORM_QC_NO},
+	{0xB85D, UNICODE_NORM_QC_NO},
+	{0xB85E, UNICODE_NORM_QC_NO},
+	{0xB85F, UNICODE_NORM_QC_NO},
+	{0xB860, UNICODE_NORM_QC_NO},
+	{0xB861, UNICODE_NORM_QC_NO},
+	{0xB862, UNICODE_NORM_QC_NO},
+	{0xB863, UNICODE_NORM_QC_NO},
+	{0xB864, UNICODE_NORM_QC_NO},
+	{0xB865, UNICODE_NORM_QC_NO},
+	{0xB866, UNICODE_NORM_QC_NO},
+	{0xB867, UNICODE_NORM_QC_NO},
+	{0xB868, UNICODE_NORM_QC_NO},
+	{0xB869, UNICODE_NORM_QC_NO},
+	{0xB86A, UNICODE_NORM_QC_NO},
+	{0xB86B, UNICODE_NORM_QC_NO},
+	{0xB86C, UNICODE_NORM_QC_NO},
+	{0xB86D, UNICODE_NORM_QC_NO},
+	{0xB86E, UNICODE_NORM_QC_NO},
+	{0xB86F, UNICODE_NORM_QC_NO},
+	{0xB870, UNICODE_NORM_QC_NO},
+	{0xB871, UNICODE_NORM_QC_NO},
+	{0xB872, UNICODE_NORM_QC_NO},
+	{0xB873, UNICODE_NORM_QC_NO},
+	{0xB874, UNICODE_NORM_QC_NO},
+	{0xB875, UNICODE_NORM_QC_NO},
+	{0xB876, UNICODE_NORM_QC_NO},
+	{0xB877, UNICODE_NORM_QC_NO},
+	{0xB878, UNICODE_NORM_QC_NO},
+	{0xB879, UNICODE_NORM_QC_NO},
+	{0xB87A, UNICODE_NORM_QC_NO},
+	{0xB87B, UNICODE_NORM_QC_NO},
+	{0xB87C, UNICODE_NORM_QC_NO},
+	{0xB87D, UNICODE_NORM_QC_NO},
+	{0xB87E, UNICODE_NORM_QC_NO},
+	{0xB87F, UNICODE_NORM_QC_NO},
+	{0xB880, UNICODE_NORM_QC_NO},
+	{0xB881, UNICODE_NORM_QC_NO},
+	{0xB882, UNICODE_NORM_QC_NO},
+	{0xB883, UNICODE_NORM_QC_NO},
+	{0xB884, UNICODE_NORM_QC_NO},
+	{0xB885, UNICODE_NORM_QC_NO},
+	{0xB886, UNICODE_NORM_QC_NO},
+	{0xB887, UNICODE_NORM_QC_NO},
+	{0xB888, UNICODE_NORM_QC_NO},
+	{0xB889, UNICODE_NORM_QC_NO},
+	{0xB88A, UNICODE_NORM_QC_NO},
+	{0xB88B, UNICODE_NORM_QC_NO},
+	{0xB88C, UNICODE_NORM_QC_NO},
+	{0xB88D, UNICODE_NORM_QC_NO},
+	{0xB88E, UNICODE_NORM_QC_NO},
+	{0xB88F, UNICODE_NORM_QC_NO},
+	{0xB890, UNICODE_NORM_QC_NO},
+	{0xB891, UNICODE_NORM_QC_NO},
+	{0xB892, UNICODE_NORM_QC_NO},
+	{0xB893, UNICODE_NORM_QC_NO},
+	{0xB894, UNICODE_NORM_QC_NO},
+	{0xB895, UNICODE_NORM_QC_NO},
+	{0xB896, UNICODE_NORM_QC_NO},
+	{0xB897, UNICODE_NORM_QC_NO},
+	{0xB898, UNICODE_NORM_QC_NO},
+	{0xB899, UNICODE_NORM_QC_NO},
+	{0xB89A, UNICODE_NORM_QC_NO},
+	{0xB89B, UNICODE_NORM_QC_NO},
+	{0xB89C, UNICODE_NORM_QC_NO},
+	{0xB89D, UNICODE_NORM_QC_NO},
+	{0xB89E, UNICODE_NORM_QC_NO},
+	{0xB89F, UNICODE_NORM_QC_NO},
+	{0xB8A0, UNICODE_NORM_QC_NO},
+	{0xB8A1, UNICODE_NORM_QC_NO},
+	{0xB8A2, UNICODE_NORM_QC_NO},
+	{0xB8A3, UNICODE_NORM_QC_NO},
+	{0xB8A4, UNICODE_NORM_QC_NO},
+	{0xB8A5, UNICODE_NORM_QC_NO},
+	{0xB8A6, UNICODE_NORM_QC_NO},
+	{0xB8A7, UNICODE_NORM_QC_NO},
+	{0xB8A8, UNICODE_NORM_QC_NO},
+	{0xB8A9, UNICODE_NORM_QC_NO},
+	{0xB8AA, UNICODE_NORM_QC_NO},
+	{0xB8AB, UNICODE_NORM_QC_NO},
+	{0xB8AC, UNICODE_NORM_QC_NO},
+	{0xB8AD, UNICODE_NORM_QC_NO},
+	{0xB8AE, UNICODE_NORM_QC_NO},
+	{0xB8AF, UNICODE_NORM_QC_NO},
+	{0xB8B0, UNICODE_NORM_QC_NO},
+	{0xB8B1, UNICODE_NORM_QC_NO},
+	{0xB8B2, UNICODE_NORM_QC_NO},
+	{0xB8B3, UNICODE_NORM_QC_NO},
+	{0xB8B4, UNICODE_NORM_QC_NO},
+	{0xB8B5, UNICODE_NORM_QC_NO},
+	{0xB8B6, UNICODE_NORM_QC_NO},
+	{0xB8B7, UNICODE_NORM_QC_NO},
+	{0xB8B8, UNICODE_NORM_QC_NO},
+	{0xB8B9, UNICODE_NORM_QC_NO},
+	{0xB8BA, UNICODE_NORM_QC_NO},
+	{0xB8BB, UNICODE_NORM_QC_NO},
+	{0xB8BC, UNICODE_NORM_QC_NO},
+	{0xB8BD, UNICODE_NORM_QC_NO},
+	{0xB8BE, UNICODE_NORM_QC_NO},
+	{0xB8BF, UNICODE_NORM_QC_NO},
+	{0xB8C0, UNICODE_NORM_QC_NO},
+	{0xB8C1, UNICODE_NORM_QC_NO},
+	{0xB8C2, UNICODE_NORM_QC_NO},
+	{0xB8C3, UNICODE_NORM_QC_NO},
+	{0xB8C4, UNICODE_NORM_QC_NO},
+	{0xB8C5, UNICODE_NORM_QC_NO},
+	{0xB8C6, UNICODE_NORM_QC_NO},
+	{0xB8C7, UNICODE_NORM_QC_NO},
+	{0xB8C8, UNICODE_NORM_QC_NO},
+	{0xB8C9, UNICODE_NORM_QC_NO},
+	{0xB8CA, UNICODE_NORM_QC_NO},
+	{0xB8CB, UNICODE_NORM_QC_NO},
+	{0xB8CC, UNICODE_NORM_QC_NO},
+	{0xB8CD, UNICODE_NORM_QC_NO},
+	{0xB8CE, UNICODE_NORM_QC_NO},
+	{0xB8CF, UNICODE_NORM_QC_NO},
+	{0xB8D0, UNICODE_NORM_QC_NO},
+	{0xB8D1, UNICODE_NORM_QC_NO},
+	{0xB8D2, UNICODE_NORM_QC_NO},
+	{0xB8D3, UNICODE_NORM_QC_NO},
+	{0xB8D4, UNICODE_NORM_QC_NO},
+	{0xB8D5, UNICODE_NORM_QC_NO},
+	{0xB8D6, UNICODE_NORM_QC_NO},
+	{0xB8D7, UNICODE_NORM_QC_NO},
+	{0xB8D8, UNICODE_NORM_QC_NO},
+	{0xB8D9, UNICODE_NORM_QC_NO},
+	{0xB8DA, UNICODE_NORM_QC_NO},
+	{0xB8DB, UNICODE_NORM_QC_NO},
+	{0xB8DC, UNICODE_NORM_QC_NO},
+	{0xB8DD, UNICODE_NORM_QC_NO},
+	{0xB8DE, UNICODE_NORM_QC_NO},
+	{0xB8DF, UNICODE_NORM_QC_NO},
+	{0xB8E0, UNICODE_NORM_QC_NO},
+	{0xB8E1, UNICODE_NORM_QC_NO},
+	{0xB8E2, UNICODE_NORM_QC_NO},
+	{0xB8E3, UNICODE_NORM_QC_NO},
+	{0xB8E4, UNICODE_NORM_QC_NO},
+	{0xB8E5, UNICODE_NORM_QC_NO},
+	{0xB8E6, UNICODE_NORM_QC_NO},
+	{0xB8E7, UNICODE_NORM_QC_NO},
+	{0xB8E8, UNICODE_NORM_QC_NO},
+	{0xB8E9, UNICODE_NORM_QC_NO},
+	{0xB8EA, UNICODE_NORM_QC_NO},
+	{0xB8EB, UNICODE_NORM_QC_NO},
+	{0xB8EC, UNICODE_NORM_QC_NO},
+	{0xB8ED, UNICODE_NORM_QC_NO},
+	{0xB8EE, UNICODE_NORM_QC_NO},
+	{0xB8EF, UNICODE_NORM_QC_NO},
+	{0xB8F0, UNICODE_NORM_QC_NO},
+	{0xB8F1, UNICODE_NORM_QC_NO},
+	{0xB8F2, UNICODE_NORM_QC_NO},
+	{0xB8F3, UNICODE_NORM_QC_NO},
+	{0xB8F4, UNICODE_NORM_QC_NO},
+	{0xB8F5, UNICODE_NORM_QC_NO},
+	{0xB8F6, UNICODE_NORM_QC_NO},
+	{0xB8F7, UNICODE_NORM_QC_NO},
+	{0xB8F8, UNICODE_NORM_QC_NO},
+	{0xB8F9, UNICODE_NORM_QC_NO},
+	{0xB8FA, UNICODE_NORM_QC_NO},
+	{0xB8FB, UNICODE_NORM_QC_NO},
+	{0xB8FC, UNICODE_NORM_QC_NO},
+	{0xB8FD, UNICODE_NORM_QC_NO},
+	{0xB8FE, UNICODE_NORM_QC_NO},
+	{0xB8FF, UNICODE_NORM_QC_NO},
+	{0xB900, UNICODE_NORM_QC_NO},
+	{0xB901, UNICODE_NORM_QC_NO},
+	{0xB902, UNICODE_NORM_QC_NO},
+	{0xB903, UNICODE_NORM_QC_NO},
+	{0xB904, UNICODE_NORM_QC_NO},
+	{0xB905, UNICODE_NORM_QC_NO},
+	{0xB906, UNICODE_NORM_QC_NO},
+	{0xB907, UNICODE_NORM_QC_NO},
+	{0xB908, UNICODE_NORM_QC_NO},
+	{0xB909, UNICODE_NORM_QC_NO},
+	{0xB90A, UNICODE_NORM_QC_NO},
+	{0xB90B, UNICODE_NORM_QC_NO},
+	{0xB90C, UNICODE_NORM_QC_NO},
+	{0xB90D, UNICODE_NORM_QC_NO},
+	{0xB90E, UNICODE_NORM_QC_NO},
+	{0xB90F, UNICODE_NORM_QC_NO},
+	{0xB910, UNICODE_NORM_QC_NO},
+	{0xB911, UNICODE_NORM_QC_NO},
+	{0xB912, UNICODE_NORM_QC_NO},
+	{0xB913, UNICODE_NORM_QC_NO},
+	{0xB914, UNICODE_NORM_QC_NO},
+	{0xB915, UNICODE_NORM_QC_NO},
+	{0xB916, UNICODE_NORM_QC_NO},
+	{0xB917, UNICODE_NORM_QC_NO},
+	{0xB918, UNICODE_NORM_QC_NO},
+	{0xB919, UNICODE_NORM_QC_NO},
+	{0xB91A, UNICODE_NORM_QC_NO},
+	{0xB91B, UNICODE_NORM_QC_NO},
+	{0xB91C, UNICODE_NORM_QC_NO},
+	{0xB91D, UNICODE_NORM_QC_NO},
+	{0xB91E, UNICODE_NORM_QC_NO},
+	{0xB91F, UNICODE_NORM_QC_NO},
+	{0xB920, UNICODE_NORM_QC_NO},
+	{0xB921, UNICODE_NORM_QC_NO},
+	{0xB922, UNICODE_NORM_QC_NO},
+	{0xB923, UNICODE_NORM_QC_NO},
+	{0xB924, UNICODE_NORM_QC_NO},
+	{0xB925, UNICODE_NORM_QC_NO},
+	{0xB926, UNICODE_NORM_QC_NO},
+	{0xB927, UNICODE_NORM_QC_NO},
+	{0xB928, UNICODE_NORM_QC_NO},
+	{0xB929, UNICODE_NORM_QC_NO},
+	{0xB92A, UNICODE_NORM_QC_NO},
+	{0xB92B, UNICODE_NORM_QC_NO},
+	{0xB92C, UNICODE_NORM_QC_NO},
+	{0xB92D, UNICODE_NORM_QC_NO},
+	{0xB92E, UNICODE_NORM_QC_NO},
+	{0xB92F, UNICODE_NORM_QC_NO},
+	{0xB930, UNICODE_NORM_QC_NO},
+	{0xB931, UNICODE_NORM_QC_NO},
+	{0xB932, UNICODE_NORM_QC_NO},
+	{0xB933, UNICODE_NORM_QC_NO},
+	{0xB934, UNICODE_NORM_QC_NO},
+	{0xB935, UNICODE_NORM_QC_NO},
+	{0xB936, UNICODE_NORM_QC_NO},
+	{0xB937, UNICODE_NORM_QC_NO},
+	{0xB938, UNICODE_NORM_QC_NO},
+	{0xB939, UNICODE_NORM_QC_NO},
+	{0xB93A, UNICODE_NORM_QC_NO},
+	{0xB93B, UNICODE_NORM_QC_NO},
+	{0xB93C, UNICODE_NORM_QC_NO},
+	{0xB93D, UNICODE_NORM_QC_NO},
+	{0xB93E, UNICODE_NORM_QC_NO},
+	{0xB93F, UNICODE_NORM_QC_NO},
+	{0xB940, UNICODE_NORM_QC_NO},
+	{0xB941, UNICODE_NORM_QC_NO},
+	{0xB942, UNICODE_NORM_QC_NO},
+	{0xB943, UNICODE_NORM_QC_NO},
+	{0xB944, UNICODE_NORM_QC_NO},
+	{0xB945, UNICODE_NORM_QC_NO},
+	{0xB946, UNICODE_NORM_QC_NO},
+	{0xB947, UNICODE_NORM_QC_NO},
+	{0xB948, UNICODE_NORM_QC_NO},
+	{0xB949, UNICODE_NORM_QC_NO},
+	{0xB94A, UNICODE_NORM_QC_NO},
+	{0xB94B, UNICODE_NORM_QC_NO},
+	{0xB94C, UNICODE_NORM_QC_NO},
+	{0xB94D, UNICODE_NORM_QC_NO},
+	{0xB94E, UNICODE_NORM_QC_NO},
+	{0xB94F, UNICODE_NORM_QC_NO},
+	{0xB950, UNICODE_NORM_QC_NO},
+	{0xB951, UNICODE_NORM_QC_NO},
+	{0xB952, UNICODE_NORM_QC_NO},
+	{0xB953, UNICODE_NORM_QC_NO},
+	{0xB954, UNICODE_NORM_QC_NO},
+	{0xB955, UNICODE_NORM_QC_NO},
+	{0xB956, UNICODE_NORM_QC_NO},
+	{0xB957, UNICODE_NORM_QC_NO},
+	{0xB958, UNICODE_NORM_QC_NO},
+	{0xB959, UNICODE_NORM_QC_NO},
+	{0xB95A, UNICODE_NORM_QC_NO},
+	{0xB95B, UNICODE_NORM_QC_NO},
+	{0xB95C, UNICODE_NORM_QC_NO},
+	{0xB95D, UNICODE_NORM_QC_NO},
+	{0xB95E, UNICODE_NORM_QC_NO},
+	{0xB95F, UNICODE_NORM_QC_NO},
+	{0xB960, UNICODE_NORM_QC_NO},
+	{0xB961, UNICODE_NORM_QC_NO},
+	{0xB962, UNICODE_NORM_QC_NO},
+	{0xB963, UNICODE_NORM_QC_NO},
+	{0xB964, UNICODE_NORM_QC_NO},
+	{0xB965, UNICODE_NORM_QC_NO},
+	{0xB966, UNICODE_NORM_QC_NO},
+	{0xB967, UNICODE_NORM_QC_NO},
+	{0xB968, UNICODE_NORM_QC_NO},
+	{0xB969, UNICODE_NORM_QC_NO},
+	{0xB96A, UNICODE_NORM_QC_NO},
+	{0xB96B, UNICODE_NORM_QC_NO},
+	{0xB96C, UNICODE_NORM_QC_NO},
+	{0xB96D, UNICODE_NORM_QC_NO},
+	{0xB96E, UNICODE_NORM_QC_NO},
+	{0xB96F, UNICODE_NORM_QC_NO},
+	{0xB970, UNICODE_NORM_QC_NO},
+	{0xB971, UNICODE_NORM_QC_NO},
+	{0xB972, UNICODE_NORM_QC_NO},
+	{0xB973, UNICODE_NORM_QC_NO},
+	{0xB974, UNICODE_NORM_QC_NO},
+	{0xB975, UNICODE_NORM_QC_NO},
+	{0xB976, UNICODE_NORM_QC_NO},
+	{0xB977, UNICODE_NORM_QC_NO},
+	{0xB978, UNICODE_NORM_QC_NO},
+	{0xB979, UNICODE_NORM_QC_NO},
+	{0xB97A, UNICODE_NORM_QC_NO},
+	{0xB97B, UNICODE_NORM_QC_NO},
+	{0xB97C, UNICODE_NORM_QC_NO},
+	{0xB97D, UNICODE_NORM_QC_NO},
+	{0xB97E, UNICODE_NORM_QC_NO},
+	{0xB97F, UNICODE_NORM_QC_NO},
+	{0xB980, UNICODE_NORM_QC_NO},
+	{0xB981, UNICODE_NORM_QC_NO},
+	{0xB982, UNICODE_NORM_QC_NO},
+	{0xB983, UNICODE_NORM_QC_NO},
+	{0xB984, UNICODE_NORM_QC_NO},
+	{0xB985, UNICODE_NORM_QC_NO},
+	{0xB986, UNICODE_NORM_QC_NO},
+	{0xB987, UNICODE_NORM_QC_NO},
+	{0xB988, UNICODE_NORM_QC_NO},
+	{0xB989, UNICODE_NORM_QC_NO},
+	{0xB98A, UNICODE_NORM_QC_NO},
+	{0xB98B, UNICODE_NORM_QC_NO},
+	{0xB98C, UNICODE_NORM_QC_NO},
+	{0xB98D, UNICODE_NORM_QC_NO},
+	{0xB98E, UNICODE_NORM_QC_NO},
+	{0xB98F, UNICODE_NORM_QC_NO},
+	{0xB990, UNICODE_NORM_QC_NO},
+	{0xB991, UNICODE_NORM_QC_NO},
+	{0xB992, UNICODE_NORM_QC_NO},
+	{0xB993, UNICODE_NORM_QC_NO},
+	{0xB994, UNICODE_NORM_QC_NO},
+	{0xB995, UNICODE_NORM_QC_NO},
+	{0xB996, UNICODE_NORM_QC_NO},
+	{0xB997, UNICODE_NORM_QC_NO},
+	{0xB998, UNICODE_NORM_QC_NO},
+	{0xB999, UNICODE_NORM_QC_NO},
+	{0xB99A, UNICODE_NORM_QC_NO},
+	{0xB99B, UNICODE_NORM_QC_NO},
+	{0xB99C, UNICODE_NORM_QC_NO},
+	{0xB99D, UNICODE_NORM_QC_NO},
+	{0xB99E, UNICODE_NORM_QC_NO},
+	{0xB99F, UNICODE_NORM_QC_NO},
+	{0xB9A0, UNICODE_NORM_QC_NO},
+	{0xB9A1, UNICODE_NORM_QC_NO},
+	{0xB9A2, UNICODE_NORM_QC_NO},
+	{0xB9A3, UNICODE_NORM_QC_NO},
+	{0xB9A4, UNICODE_NORM_QC_NO},
+	{0xB9A5, UNICODE_NORM_QC_NO},
+	{0xB9A6, UNICODE_NORM_QC_NO},
+	{0xB9A7, UNICODE_NORM_QC_NO},
+	{0xB9A8, UNICODE_NORM_QC_NO},
+	{0xB9A9, UNICODE_NORM_QC_NO},
+	{0xB9AA, UNICODE_NORM_QC_NO},
+	{0xB9AB, UNICODE_NORM_QC_NO},
+	{0xB9AC, UNICODE_NORM_QC_NO},
+	{0xB9AD, UNICODE_NORM_QC_NO},
+	{0xB9AE, UNICODE_NORM_QC_NO},
+	{0xB9AF, UNICODE_NORM_QC_NO},
+	{0xB9B0, UNICODE_NORM_QC_NO},
+	{0xB9B1, UNICODE_NORM_QC_NO},
+	{0xB9B2, UNICODE_NORM_QC_NO},
+	{0xB9B3, UNICODE_NORM_QC_NO},
+	{0xB9B4, UNICODE_NORM_QC_NO},
+	{0xB9B5, UNICODE_NORM_QC_NO},
+	{0xB9B6, UNICODE_NORM_QC_NO},
+	{0xB9B7, UNICODE_NORM_QC_NO},
+	{0xB9B8, UNICODE_NORM_QC_NO},
+	{0xB9B9, UNICODE_NORM_QC_NO},
+	{0xB9BA, UNICODE_NORM_QC_NO},
+	{0xB9BB, UNICODE_NORM_QC_NO},
+	{0xB9BC, UNICODE_NORM_QC_NO},
+	{0xB9BD, UNICODE_NORM_QC_NO},
+	{0xB9BE, UNICODE_NORM_QC_NO},
+	{0xB9BF, UNICODE_NORM_QC_NO},
+	{0xB9C0, UNICODE_NORM_QC_NO},
+	{0xB9C1, UNICODE_NORM_QC_NO},
+	{0xB9C2, UNICODE_NORM_QC_NO},
+	{0xB9C3, UNICODE_NORM_QC_NO},
+	{0xB9C4, UNICODE_NORM_QC_NO},
+	{0xB9C5, UNICODE_NORM_QC_NO},
+	{0xB9C6, UNICODE_NORM_QC_NO},
+	{0xB9C7, UNICODE_NORM_QC_NO},
+	{0xB9C8, UNICODE_NORM_QC_NO},
+	{0xB9C9, UNICODE_NORM_QC_NO},
+	{0xB9CA, UNICODE_NORM_QC_NO},
+	{0xB9CB, UNICODE_NORM_QC_NO},
+	{0xB9CC, UNICODE_NORM_QC_NO},
+	{0xB9CD, UNICODE_NORM_QC_NO},
+	{0xB9CE, UNICODE_NORM_QC_NO},
+	{0xB9CF, UNICODE_NORM_QC_NO},
+	{0xB9D0, UNICODE_NORM_QC_NO},
+	{0xB9D1, UNICODE_NORM_QC_NO},
+	{0xB9D2, UNICODE_NORM_QC_NO},
+	{0xB9D3, UNICODE_NORM_QC_NO},
+	{0xB9D4, UNICODE_NORM_QC_NO},
+	{0xB9D5, UNICODE_NORM_QC_NO},
+	{0xB9D6, UNICODE_NORM_QC_NO},
+	{0xB9D7, UNICODE_NORM_QC_NO},
+	{0xB9D8, UNICODE_NORM_QC_NO},
+	{0xB9D9, UNICODE_NORM_QC_NO},
+	{0xB9DA, UNICODE_NORM_QC_NO},
+	{0xB9DB, UNICODE_NORM_QC_NO},
+	{0xB9DC, UNICODE_NORM_QC_NO},
+	{0xB9DD, UNICODE_NORM_QC_NO},
+	{0xB9DE, UNICODE_NORM_QC_NO},
+	{0xB9DF, UNICODE_NORM_QC_NO},
+	{0xB9E0, UNICODE_NORM_QC_NO},
+	{0xB9E1, UNICODE_NORM_QC_NO},
+	{0xB9E2, UNICODE_NORM_QC_NO},
+	{0xB9E3, UNICODE_NORM_QC_NO},
+	{0xB9E4, UNICODE_NORM_QC_NO},
+	{0xB9E5, UNICODE_NORM_QC_NO},
+	{0xB9E6, UNICODE_NORM_QC_NO},
+	{0xB9E7, UNICODE_NORM_QC_NO},
+	{0xB9E8, UNICODE_NORM_QC_NO},
+	{0xB9E9, UNICODE_NORM_QC_NO},
+	{0xB9EA, UNICODE_NORM_QC_NO},
+	{0xB9EB, UNICODE_NORM_QC_NO},
+	{0xB9EC, UNICODE_NORM_QC_NO},
+	{0xB9ED, UNICODE_NORM_QC_NO},
+	{0xB9EE, UNICODE_NORM_QC_NO},
+	{0xB9EF, UNICODE_NORM_QC_NO},
+	{0xB9F0, UNICODE_NORM_QC_NO},
+	{0xB9F1, UNICODE_NORM_QC_NO},
+	{0xB9F2, UNICODE_NORM_QC_NO},
+	{0xB9F3, UNICODE_NORM_QC_NO},
+	{0xB9F4, UNICODE_NORM_QC_NO},
+	{0xB9F5, UNICODE_NORM_QC_NO},
+	{0xB9F6, UNICODE_NORM_QC_NO},
+	{0xB9F7, UNICODE_NORM_QC_NO},
+	{0xB9F8, UNICODE_NORM_QC_NO},
+	{0xB9F9, UNICODE_NORM_QC_NO},
+	{0xB9FA, UNICODE_NORM_QC_NO},
+	{0xB9FB, UNICODE_NORM_QC_NO},
+	{0xB9FC, UNICODE_NORM_QC_NO},
+	{0xB9FD, UNICODE_NORM_QC_NO},
+	{0xB9FE, UNICODE_NORM_QC_NO},
+	{0xB9FF, UNICODE_NORM_QC_NO},
+	{0xBA00, UNICODE_NORM_QC_NO},
+	{0xBA01, UNICODE_NORM_QC_NO},
+	{0xBA02, UNICODE_NORM_QC_NO},
+	{0xBA03, UNICODE_NORM_QC_NO},
+	{0xBA04, UNICODE_NORM_QC_NO},
+	{0xBA05, UNICODE_NORM_QC_NO},
+	{0xBA06, UNICODE_NORM_QC_NO},
+	{0xBA07, UNICODE_NORM_QC_NO},
+	{0xBA08, UNICODE_NORM_QC_NO},
+	{0xBA09, UNICODE_NORM_QC_NO},
+	{0xBA0A, UNICODE_NORM_QC_NO},
+	{0xBA0B, UNICODE_NORM_QC_NO},
+	{0xBA0C, UNICODE_NORM_QC_NO},
+	{0xBA0D, UNICODE_NORM_QC_NO},
+	{0xBA0E, UNICODE_NORM_QC_NO},
+	{0xBA0F, UNICODE_NORM_QC_NO},
+	{0xBA10, UNICODE_NORM_QC_NO},
+	{0xBA11, UNICODE_NORM_QC_NO},
+	{0xBA12, UNICODE_NORM_QC_NO},
+	{0xBA13, UNICODE_NORM_QC_NO},
+	{0xBA14, UNICODE_NORM_QC_NO},
+	{0xBA15, UNICODE_NORM_QC_NO},
+	{0xBA16, UNICODE_NORM_QC_NO},
+	{0xBA17, UNICODE_NORM_QC_NO},
+	{0xBA18, UNICODE_NORM_QC_NO},
+	{0xBA19, UNICODE_NORM_QC_NO},
+	{0xBA1A, UNICODE_NORM_QC_NO},
+	{0xBA1B, UNICODE_NORM_QC_NO},
+	{0xBA1C, UNICODE_NORM_QC_NO},
+	{0xBA1D, UNICODE_NORM_QC_NO},
+	{0xBA1E, UNICODE_NORM_QC_NO},
+	{0xBA1F, UNICODE_NORM_QC_NO},
+	{0xBA20, UNICODE_NORM_QC_NO},
+	{0xBA21, UNICODE_NORM_QC_NO},
+	{0xBA22, UNICODE_NORM_QC_NO},
+	{0xBA23, UNICODE_NORM_QC_NO},
+	{0xBA24, UNICODE_NORM_QC_NO},
+	{0xBA25, UNICODE_NORM_QC_NO},
+	{0xBA26, UNICODE_NORM_QC_NO},
+	{0xBA27, UNICODE_NORM_QC_NO},
+	{0xBA28, UNICODE_NORM_QC_NO},
+	{0xBA29, UNICODE_NORM_QC_NO},
+	{0xBA2A, UNICODE_NORM_QC_NO},
+	{0xBA2B, UNICODE_NORM_QC_NO},
+	{0xBA2C, UNICODE_NORM_QC_NO},
+	{0xBA2D, UNICODE_NORM_QC_NO},
+	{0xBA2E, UNICODE_NORM_QC_NO},
+	{0xBA2F, UNICODE_NORM_QC_NO},
+	{0xBA30, UNICODE_NORM_QC_NO},
+	{0xBA31, UNICODE_NORM_QC_NO},
+	{0xBA32, UNICODE_NORM_QC_NO},
+	{0xBA33, UNICODE_NORM_QC_NO},
+	{0xBA34, UNICODE_NORM_QC_NO},
+	{0xBA35, UNICODE_NORM_QC_NO},
+	{0xBA36, UNICODE_NORM_QC_NO},
+	{0xBA37, UNICODE_NORM_QC_NO},
+	{0xBA38, UNICODE_NORM_QC_NO},
+	{0xBA39, UNICODE_NORM_QC_NO},
+	{0xBA3A, UNICODE_NORM_QC_NO},
+	{0xBA3B, UNICODE_NORM_QC_NO},
+	{0xBA3C, UNICODE_NORM_QC_NO},
+	{0xBA3D, UNICODE_NORM_QC_NO},
+	{0xBA3E, UNICODE_NORM_QC_NO},
+	{0xBA3F, UNICODE_NORM_QC_NO},
+	{0xBA40, UNICODE_NORM_QC_NO},
+	{0xBA41, UNICODE_NORM_QC_NO},
+	{0xBA42, UNICODE_NORM_QC_NO},
+	{0xBA43, UNICODE_NORM_QC_NO},
+	{0xBA44, UNICODE_NORM_QC_NO},
+	{0xBA45, UNICODE_NORM_QC_NO},
+	{0xBA46, UNICODE_NORM_QC_NO},
+	{0xBA47, UNICODE_NORM_QC_NO},
+	{0xBA48, UNICODE_NORM_QC_NO},
+	{0xBA49, UNICODE_NORM_QC_NO},
+	{0xBA4A, UNICODE_NORM_QC_NO},
+	{0xBA4B, UNICODE_NORM_QC_NO},
+	{0xBA4C, UNICODE_NORM_QC_NO},
+	{0xBA4D, UNICODE_NORM_QC_NO},
+	{0xBA4E, UNICODE_NORM_QC_NO},
+	{0xBA4F, UNICODE_NORM_QC_NO},
+	{0xBA50, UNICODE_NORM_QC_NO},
+	{0xBA51, UNICODE_NORM_QC_NO},
+	{0xBA52, UNICODE_NORM_QC_NO},
+	{0xBA53, UNICODE_NORM_QC_NO},
+	{0xBA54, UNICODE_NORM_QC_NO},
+	{0xBA55, UNICODE_NORM_QC_NO},
+	{0xBA56, UNICODE_NORM_QC_NO},
+	{0xBA57, UNICODE_NORM_QC_NO},
+	{0xBA58, UNICODE_NORM_QC_NO},
+	{0xBA59, UNICODE_NORM_QC_NO},
+	{0xBA5A, UNICODE_NORM_QC_NO},
+	{0xBA5B, UNICODE_NORM_QC_NO},
+	{0xBA5C, UNICODE_NORM_QC_NO},
+	{0xBA5D, UNICODE_NORM_QC_NO},
+	{0xBA5E, UNICODE_NORM_QC_NO},
+	{0xBA5F, UNICODE_NORM_QC_NO},
+	{0xBA60, UNICODE_NORM_QC_NO},
+	{0xBA61, UNICODE_NORM_QC_NO},
+	{0xBA62, UNICODE_NORM_QC_NO},
+	{0xBA63, UNICODE_NORM_QC_NO},
+	{0xBA64, UNICODE_NORM_QC_NO},
+	{0xBA65, UNICODE_NORM_QC_NO},
+	{0xBA66, UNICODE_NORM_QC_NO},
+	{0xBA67, UNICODE_NORM_QC_NO},
+	{0xBA68, UNICODE_NORM_QC_NO},
+	{0xBA69, UNICODE_NORM_QC_NO},
+	{0xBA6A, UNICODE_NORM_QC_NO},
+	{0xBA6B, UNICODE_NORM_QC_NO},
+	{0xBA6C, UNICODE_NORM_QC_NO},
+	{0xBA6D, UNICODE_NORM_QC_NO},
+	{0xBA6E, UNICODE_NORM_QC_NO},
+	{0xBA6F, UNICODE_NORM_QC_NO},
+	{0xBA70, UNICODE_NORM_QC_NO},
+	{0xBA71, UNICODE_NORM_QC_NO},
+	{0xBA72, UNICODE_NORM_QC_NO},
+	{0xBA73, UNICODE_NORM_QC_NO},
+	{0xBA74, UNICODE_NORM_QC_NO},
+	{0xBA75, UNICODE_NORM_QC_NO},
+	{0xBA76, UNICODE_NORM_QC_NO},
+	{0xBA77, UNICODE_NORM_QC_NO},
+	{0xBA78, UNICODE_NORM_QC_NO},
+	{0xBA79, UNICODE_NORM_QC_NO},
+	{0xBA7A, UNICODE_NORM_QC_NO},
+	{0xBA7B, UNICODE_NORM_QC_NO},
+	{0xBA7C, UNICODE_NORM_QC_NO},
+	{0xBA7D, UNICODE_NORM_QC_NO},
+	{0xBA7E, UNICODE_NORM_QC_NO},
+	{0xBA7F, UNICODE_NORM_QC_NO},
+	{0xBA80, UNICODE_NORM_QC_NO},
+	{0xBA81, UNICODE_NORM_QC_NO},
+	{0xBA82, UNICODE_NORM_QC_NO},
+	{0xBA83, UNICODE_NORM_QC_NO},
+	{0xBA84, UNICODE_NORM_QC_NO},
+	{0xBA85, UNICODE_NORM_QC_NO},
+	{0xBA86, UNICODE_NORM_QC_NO},
+	{0xBA87, UNICODE_NORM_QC_NO},
+	{0xBA88, UNICODE_NORM_QC_NO},
+	{0xBA89, UNICODE_NORM_QC_NO},
+	{0xBA8A, UNICODE_NORM_QC_NO},
+	{0xBA8B, UNICODE_NORM_QC_NO},
+	{0xBA8C, UNICODE_NORM_QC_NO},
+	{0xBA8D, UNICODE_NORM_QC_NO},
+	{0xBA8E, UNICODE_NORM_QC_NO},
+	{0xBA8F, UNICODE_NORM_QC_NO},
+	{0xBA90, UNICODE_NORM_QC_NO},
+	{0xBA91, UNICODE_NORM_QC_NO},
+	{0xBA92, UNICODE_NORM_QC_NO},
+	{0xBA93, UNICODE_NORM_QC_NO},
+	{0xBA94, UNICODE_NORM_QC_NO},
+	{0xBA95, UNICODE_NORM_QC_NO},
+	{0xBA96, UNICODE_NORM_QC_NO},
+	{0xBA97, UNICODE_NORM_QC_NO},
+	{0xBA98, UNICODE_NORM_QC_NO},
+	{0xBA99, UNICODE_NORM_QC_NO},
+	{0xBA9A, UNICODE_NORM_QC_NO},
+	{0xBA9B, UNICODE_NORM_QC_NO},
+	{0xBA9C, UNICODE_NORM_QC_NO},
+	{0xBA9D, UNICODE_NORM_QC_NO},
+	{0xBA9E, UNICODE_NORM_QC_NO},
+	{0xBA9F, UNICODE_NORM_QC_NO},
+	{0xBAA0, UNICODE_NORM_QC_NO},
+	{0xBAA1, UNICODE_NORM_QC_NO},
+	{0xBAA2, UNICODE_NORM_QC_NO},
+	{0xBAA3, UNICODE_NORM_QC_NO},
+	{0xBAA4, UNICODE_NORM_QC_NO},
+	{0xBAA5, UNICODE_NORM_QC_NO},
+	{0xBAA6, UNICODE_NORM_QC_NO},
+	{0xBAA7, UNICODE_NORM_QC_NO},
+	{0xBAA8, UNICODE_NORM_QC_NO},
+	{0xBAA9, UNICODE_NORM_QC_NO},
+	{0xBAAA, UNICODE_NORM_QC_NO},
+	{0xBAAB, UNICODE_NORM_QC_NO},
+	{0xBAAC, UNICODE_NORM_QC_NO},
+	{0xBAAD, UNICODE_NORM_QC_NO},
+	{0xBAAE, UNICODE_NORM_QC_NO},
+	{0xBAAF, UNICODE_NORM_QC_NO},
+	{0xBAB0, UNICODE_NORM_QC_NO},
+	{0xBAB1, UNICODE_NORM_QC_NO},
+	{0xBAB2, UNICODE_NORM_QC_NO},
+	{0xBAB3, UNICODE_NORM_QC_NO},
+	{0xBAB4, UNICODE_NORM_QC_NO},
+	{0xBAB5, UNICODE_NORM_QC_NO},
+	{0xBAB6, UNICODE_NORM_QC_NO},
+	{0xBAB7, UNICODE_NORM_QC_NO},
+	{0xBAB8, UNICODE_NORM_QC_NO},
+	{0xBAB9, UNICODE_NORM_QC_NO},
+	{0xBABA, UNICODE_NORM_QC_NO},
+	{0xBABB, UNICODE_NORM_QC_NO},
+	{0xBABC, UNICODE_NORM_QC_NO},
+	{0xBABD, UNICODE_NORM_QC_NO},
+	{0xBABE, UNICODE_NORM_QC_NO},
+	{0xBABF, UNICODE_NORM_QC_NO},
+	{0xBAC0, UNICODE_NORM_QC_NO},
+	{0xBAC1, UNICODE_NORM_QC_NO},
+	{0xBAC2, UNICODE_NORM_QC_NO},
+	{0xBAC3, UNICODE_NORM_QC_NO},
+	{0xBAC4, UNICODE_NORM_QC_NO},
+	{0xBAC5, UNICODE_NORM_QC_NO},
+	{0xBAC6, UNICODE_NORM_QC_NO},
+	{0xBAC7, UNICODE_NORM_QC_NO},
+	{0xBAC8, UNICODE_NORM_QC_NO},
+	{0xBAC9, UNICODE_NORM_QC_NO},
+	{0xBACA, UNICODE_NORM_QC_NO},
+	{0xBACB, UNICODE_NORM_QC_NO},
+	{0xBACC, UNICODE_NORM_QC_NO},
+	{0xBACD, UNICODE_NORM_QC_NO},
+	{0xBACE, UNICODE_NORM_QC_NO},
+	{0xBACF, UNICODE_NORM_QC_NO},
+	{0xBAD0, UNICODE_NORM_QC_NO},
+	{0xBAD1, UNICODE_NORM_QC_NO},
+	{0xBAD2, UNICODE_NORM_QC_NO},
+	{0xBAD3, UNICODE_NORM_QC_NO},
+	{0xBAD4, UNICODE_NORM_QC_NO},
+	{0xBAD5, UNICODE_NORM_QC_NO},
+	{0xBAD6, UNICODE_NORM_QC_NO},
+	{0xBAD7, UNICODE_NORM_QC_NO},
+	{0xBAD8, UNICODE_NORM_QC_NO},
+	{0xBAD9, UNICODE_NORM_QC_NO},
+	{0xBADA, UNICODE_NORM_QC_NO},
+	{0xBADB, UNICODE_NORM_QC_NO},
+	{0xBADC, UNICODE_NORM_QC_NO},
+	{0xBADD, UNICODE_NORM_QC_NO},
+	{0xBADE, UNICODE_NORM_QC_NO},
+	{0xBADF, UNICODE_NORM_QC_NO},
+	{0xBAE0, UNICODE_NORM_QC_NO},
+	{0xBAE1, UNICODE_NORM_QC_NO},
+	{0xBAE2, UNICODE_NORM_QC_NO},
+	{0xBAE3, UNICODE_NORM_QC_NO},
+	{0xBAE4, UNICODE_NORM_QC_NO},
+	{0xBAE5, UNICODE_NORM_QC_NO},
+	{0xBAE6, UNICODE_NORM_QC_NO},
+	{0xBAE7, UNICODE_NORM_QC_NO},
+	{0xBAE8, UNICODE_NORM_QC_NO},
+	{0xBAE9, UNICODE_NORM_QC_NO},
+	{0xBAEA, UNICODE_NORM_QC_NO},
+	{0xBAEB, UNICODE_NORM_QC_NO},
+	{0xBAEC, UNICODE_NORM_QC_NO},
+	{0xBAED, UNICODE_NORM_QC_NO},
+	{0xBAEE, UNICODE_NORM_QC_NO},
+	{0xBAEF, UNICODE_NORM_QC_NO},
+	{0xBAF0, UNICODE_NORM_QC_NO},
+	{0xBAF1, UNICODE_NORM_QC_NO},
+	{0xBAF2, UNICODE_NORM_QC_NO},
+	{0xBAF3, UNICODE_NORM_QC_NO},
+	{0xBAF4, UNICODE_NORM_QC_NO},
+	{0xBAF5, UNICODE_NORM_QC_NO},
+	{0xBAF6, UNICODE_NORM_QC_NO},
+	{0xBAF7, UNICODE_NORM_QC_NO},
+	{0xBAF8, UNICODE_NORM_QC_NO},
+	{0xBAF9, UNICODE_NORM_QC_NO},
+	{0xBAFA, UNICODE_NORM_QC_NO},
+	{0xBAFB, UNICODE_NORM_QC_NO},
+	{0xBAFC, UNICODE_NORM_QC_NO},
+	{0xBAFD, UNICODE_NORM_QC_NO},
+	{0xBAFE, UNICODE_NORM_QC_NO},
+	{0xBAFF, UNICODE_NORM_QC_NO},
+	{0xBB00, UNICODE_NORM_QC_NO},
+	{0xBB01, UNICODE_NORM_QC_NO},
+	{0xBB02, UNICODE_NORM_QC_NO},
+	{0xBB03, UNICODE_NORM_QC_NO},
+	{0xBB04, UNICODE_NORM_QC_NO},
+	{0xBB05, UNICODE_NORM_QC_NO},
+	{0xBB06, UNICODE_NORM_QC_NO},
+	{0xBB07, UNICODE_NORM_QC_NO},
+	{0xBB08, UNICODE_NORM_QC_NO},
+	{0xBB09, UNICODE_NORM_QC_NO},
+	{0xBB0A, UNICODE_NORM_QC_NO},
+	{0xBB0B, UNICODE_NORM_QC_NO},
+	{0xBB0C, UNICODE_NORM_QC_NO},
+	{0xBB0D, UNICODE_NORM_QC_NO},
+	{0xBB0E, UNICODE_NORM_QC_NO},
+	{0xBB0F, UNICODE_NORM_QC_NO},
+	{0xBB10, UNICODE_NORM_QC_NO},
+	{0xBB11, UNICODE_NORM_QC_NO},
+	{0xBB12, UNICODE_NORM_QC_NO},
+	{0xBB13, UNICODE_NORM_QC_NO},
+	{0xBB14, UNICODE_NORM_QC_NO},
+	{0xBB15, UNICODE_NORM_QC_NO},
+	{0xBB16, UNICODE_NORM_QC_NO},
+	{0xBB17, UNICODE_NORM_QC_NO},
+	{0xBB18, UNICODE_NORM_QC_NO},
+	{0xBB19, UNICODE_NORM_QC_NO},
+	{0xBB1A, UNICODE_NORM_QC_NO},
+	{0xBB1B, UNICODE_NORM_QC_NO},
+	{0xBB1C, UNICODE_NORM_QC_NO},
+	{0xBB1D, UNICODE_NORM_QC_NO},
+	{0xBB1E, UNICODE_NORM_QC_NO},
+	{0xBB1F, UNICODE_NORM_QC_NO},
+	{0xBB20, UNICODE_NORM_QC_NO},
+	{0xBB21, UNICODE_NORM_QC_NO},
+	{0xBB22, UNICODE_NORM_QC_NO},
+	{0xBB23, UNICODE_NORM_QC_NO},
+	{0xBB24, UNICODE_NORM_QC_NO},
+	{0xBB25, UNICODE_NORM_QC_NO},
+	{0xBB26, UNICODE_NORM_QC_NO},
+	{0xBB27, UNICODE_NORM_QC_NO},
+	{0xBB28, UNICODE_NORM_QC_NO},
+	{0xBB29, UNICODE_NORM_QC_NO},
+	{0xBB2A, UNICODE_NORM_QC_NO},
+	{0xBB2B, UNICODE_NORM_QC_NO},
+	{0xBB2C, UNICODE_NORM_QC_NO},
+	{0xBB2D, UNICODE_NORM_QC_NO},
+	{0xBB2E, UNICODE_NORM_QC_NO},
+	{0xBB2F, UNICODE_NORM_QC_NO},
+	{0xBB30, UNICODE_NORM_QC_NO},
+	{0xBB31, UNICODE_NORM_QC_NO},
+	{0xBB32, UNICODE_NORM_QC_NO},
+	{0xBB33, UNICODE_NORM_QC_NO},
+	{0xBB34, UNICODE_NORM_QC_NO},
+	{0xBB35, UNICODE_NORM_QC_NO},
+	{0xBB36, UNICODE_NORM_QC_NO},
+	{0xBB37, UNICODE_NORM_QC_NO},
+	{0xBB38, UNICODE_NORM_QC_NO},
+	{0xBB39, UNICODE_NORM_QC_NO},
+	{0xBB3A, UNICODE_NORM_QC_NO},
+	{0xBB3B, UNICODE_NORM_QC_NO},
+	{0xBB3C, UNICODE_NORM_QC_NO},
+	{0xBB3D, UNICODE_NORM_QC_NO},
+	{0xBB3E, UNICODE_NORM_QC_NO},
+	{0xBB3F, UNICODE_NORM_QC_NO},
+	{0xBB40, UNICODE_NORM_QC_NO},
+	{0xBB41, UNICODE_NORM_QC_NO},
+	{0xBB42, UNICODE_NORM_QC_NO},
+	{0xBB43, UNICODE_NORM_QC_NO},
+	{0xBB44, UNICODE_NORM_QC_NO},
+	{0xBB45, UNICODE_NORM_QC_NO},
+	{0xBB46, UNICODE_NORM_QC_NO},
+	{0xBB47, UNICODE_NORM_QC_NO},
+	{0xBB48, UNICODE_NORM_QC_NO},
+	{0xBB49, UNICODE_NORM_QC_NO},
+	{0xBB4A, UNICODE_NORM_QC_NO},
+	{0xBB4B, UNICODE_NORM_QC_NO},
+	{0xBB4C, UNICODE_NORM_QC_NO},
+	{0xBB4D, UNICODE_NORM_QC_NO},
+	{0xBB4E, UNICODE_NORM_QC_NO},
+	{0xBB4F, UNICODE_NORM_QC_NO},
+	{0xBB50, UNICODE_NORM_QC_NO},
+	{0xBB51, UNICODE_NORM_QC_NO},
+	{0xBB52, UNICODE_NORM_QC_NO},
+	{0xBB53, UNICODE_NORM_QC_NO},
+	{0xBB54, UNICODE_NORM_QC_NO},
+	{0xBB55, UNICODE_NORM_QC_NO},
+	{0xBB56, UNICODE_NORM_QC_NO},
+	{0xBB57, UNICODE_NORM_QC_NO},
+	{0xBB58, UNICODE_NORM_QC_NO},
+	{0xBB59, UNICODE_NORM_QC_NO},
+	{0xBB5A, UNICODE_NORM_QC_NO},
+	{0xBB5B, UNICODE_NORM_QC_NO},
+	{0xBB5C, UNICODE_NORM_QC_NO},
+	{0xBB5D, UNICODE_NORM_QC_NO},
+	{0xBB5E, UNICODE_NORM_QC_NO},
+	{0xBB5F, UNICODE_NORM_QC_NO},
+	{0xBB60, UNICODE_NORM_QC_NO},
+	{0xBB61, UNICODE_NORM_QC_NO},
+	{0xBB62, UNICODE_NORM_QC_NO},
+	{0xBB63, UNICODE_NORM_QC_NO},
+	{0xBB64, UNICODE_NORM_QC_NO},
+	{0xBB65, UNICODE_NORM_QC_NO},
+	{0xBB66, UNICODE_NORM_QC_NO},
+	{0xBB67, UNICODE_NORM_QC_NO},
+	{0xBB68, UNICODE_NORM_QC_NO},
+	{0xBB69, UNICODE_NORM_QC_NO},
+	{0xBB6A, UNICODE_NORM_QC_NO},
+	{0xBB6B, UNICODE_NORM_QC_NO},
+	{0xBB6C, UNICODE_NORM_QC_NO},
+	{0xBB6D, UNICODE_NORM_QC_NO},
+	{0xBB6E, UNICODE_NORM_QC_NO},
+	{0xBB6F, UNICODE_NORM_QC_NO},
+	{0xBB70, UNICODE_NORM_QC_NO},
+	{0xBB71, UNICODE_NORM_QC_NO},
+	{0xBB72, UNICODE_NORM_QC_NO},
+	{0xBB73, UNICODE_NORM_QC_NO},
+	{0xBB74, UNICODE_NORM_QC_NO},
+	{0xBB75, UNICODE_NORM_QC_NO},
+	{0xBB76, UNICODE_NORM_QC_NO},
+	{0xBB77, UNICODE_NORM_QC_NO},
+	{0xBB78, UNICODE_NORM_QC_NO},
+	{0xBB79, UNICODE_NORM_QC_NO},
+	{0xBB7A, UNICODE_NORM_QC_NO},
+	{0xBB7B, UNICODE_NORM_QC_NO},
+	{0xBB7C, UNICODE_NORM_QC_NO},
+	{0xBB7D, UNICODE_NORM_QC_NO},
+	{0xBB7E, UNICODE_NORM_QC_NO},
+	{0xBB7F, UNICODE_NORM_QC_NO},
+	{0xBB80, UNICODE_NORM_QC_NO},
+	{0xBB81, UNICODE_NORM_QC_NO},
+	{0xBB82, UNICODE_NORM_QC_NO},
+	{0xBB83, UNICODE_NORM_QC_NO},
+	{0xBB84, UNICODE_NORM_QC_NO},
+	{0xBB85, UNICODE_NORM_QC_NO},
+	{0xBB86, UNICODE_NORM_QC_NO},
+	{0xBB87, UNICODE_NORM_QC_NO},
+	{0xBB88, UNICODE_NORM_QC_NO},
+	{0xBB89, UNICODE_NORM_QC_NO},
+	{0xBB8A, UNICODE_NORM_QC_NO},
+	{0xBB8B, UNICODE_NORM_QC_NO},
+	{0xBB8C, UNICODE_NORM_QC_NO},
+	{0xBB8D, UNICODE_NORM_QC_NO},
+	{0xBB8E, UNICODE_NORM_QC_NO},
+	{0xBB8F, UNICODE_NORM_QC_NO},
+	{0xBB90, UNICODE_NORM_QC_NO},
+	{0xBB91, UNICODE_NORM_QC_NO},
+	{0xBB92, UNICODE_NORM_QC_NO},
+	{0xBB93, UNICODE_NORM_QC_NO},
+	{0xBB94, UNICODE_NORM_QC_NO},
+	{0xBB95, UNICODE_NORM_QC_NO},
+	{0xBB96, UNICODE_NORM_QC_NO},
+	{0xBB97, UNICODE_NORM_QC_NO},
+	{0xBB98, UNICODE_NORM_QC_NO},
+	{0xBB99, UNICODE_NORM_QC_NO},
+	{0xBB9A, UNICODE_NORM_QC_NO},
+	{0xBB9B, UNICODE_NORM_QC_NO},
+	{0xBB9C, UNICODE_NORM_QC_NO},
+	{0xBB9D, UNICODE_NORM_QC_NO},
+	{0xBB9E, UNICODE_NORM_QC_NO},
+	{0xBB9F, UNICODE_NORM_QC_NO},
+	{0xBBA0, UNICODE_NORM_QC_NO},
+	{0xBBA1, UNICODE_NORM_QC_NO},
+	{0xBBA2, UNICODE_NORM_QC_NO},
+	{0xBBA3, UNICODE_NORM_QC_NO},
+	{0xBBA4, UNICODE_NORM_QC_NO},
+	{0xBBA5, UNICODE_NORM_QC_NO},
+	{0xBBA6, UNICODE_NORM_QC_NO},
+	{0xBBA7, UNICODE_NORM_QC_NO},
+	{0xBBA8, UNICODE_NORM_QC_NO},
+	{0xBBA9, UNICODE_NORM_QC_NO},
+	{0xBBAA, UNICODE_NORM_QC_NO},
+	{0xBBAB, UNICODE_NORM_QC_NO},
+	{0xBBAC, UNICODE_NORM_QC_NO},
+	{0xBBAD, UNICODE_NORM_QC_NO},
+	{0xBBAE, UNICODE_NORM_QC_NO},
+	{0xBBAF, UNICODE_NORM_QC_NO},
+	{0xBBB0, UNICODE_NORM_QC_NO},
+	{0xBBB1, UNICODE_NORM_QC_NO},
+	{0xBBB2, UNICODE_NORM_QC_NO},
+	{0xBBB3, UNICODE_NORM_QC_NO},
+	{0xBBB4, UNICODE_NORM_QC_NO},
+	{0xBBB5, UNICODE_NORM_QC_NO},
+	{0xBBB6, UNICODE_NORM_QC_NO},
+	{0xBBB7, UNICODE_NORM_QC_NO},
+	{0xBBB8, UNICODE_NORM_QC_NO},
+	{0xBBB9, UNICODE_NORM_QC_NO},
+	{0xBBBA, UNICODE_NORM_QC_NO},
+	{0xBBBB, UNICODE_NORM_QC_NO},
+	{0xBBBC, UNICODE_NORM_QC_NO},
+	{0xBBBD, UNICODE_NORM_QC_NO},
+	{0xBBBE, UNICODE_NORM_QC_NO},
+	{0xBBBF, UNICODE_NORM_QC_NO},
+	{0xBBC0, UNICODE_NORM_QC_NO},
+	{0xBBC1, UNICODE_NORM_QC_NO},
+	{0xBBC2, UNICODE_NORM_QC_NO},
+	{0xBBC3, UNICODE_NORM_QC_NO},
+	{0xBBC4, UNICODE_NORM_QC_NO},
+	{0xBBC5, UNICODE_NORM_QC_NO},
+	{0xBBC6, UNICODE_NORM_QC_NO},
+	{0xBBC7, UNICODE_NORM_QC_NO},
+	{0xBBC8, UNICODE_NORM_QC_NO},
+	{0xBBC9, UNICODE_NORM_QC_NO},
+	{0xBBCA, UNICODE_NORM_QC_NO},
+	{0xBBCB, UNICODE_NORM_QC_NO},
+	{0xBBCC, UNICODE_NORM_QC_NO},
+	{0xBBCD, UNICODE_NORM_QC_NO},
+	{0xBBCE, UNICODE_NORM_QC_NO},
+	{0xBBCF, UNICODE_NORM_QC_NO},
+	{0xBBD0, UNICODE_NORM_QC_NO},
+	{0xBBD1, UNICODE_NORM_QC_NO},
+	{0xBBD2, UNICODE_NORM_QC_NO},
+	{0xBBD3, UNICODE_NORM_QC_NO},
+	{0xBBD4, UNICODE_NORM_QC_NO},
+	{0xBBD5, UNICODE_NORM_QC_NO},
+	{0xBBD6, UNICODE_NORM_QC_NO},
+	{0xBBD7, UNICODE_NORM_QC_NO},
+	{0xBBD8, UNICODE_NORM_QC_NO},
+	{0xBBD9, UNICODE_NORM_QC_NO},
+	{0xBBDA, UNICODE_NORM_QC_NO},
+	{0xBBDB, UNICODE_NORM_QC_NO},
+	{0xBBDC, UNICODE_NORM_QC_NO},
+	{0xBBDD, UNICODE_NORM_QC_NO},
+	{0xBBDE, UNICODE_NORM_QC_NO},
+	{0xBBDF, UNICODE_NORM_QC_NO},
+	{0xBBE0, UNICODE_NORM_QC_NO},
+	{0xBBE1, UNICODE_NORM_QC_NO},
+	{0xBBE2, UNICODE_NORM_QC_NO},
+	{0xBBE3, UNICODE_NORM_QC_NO},
+	{0xBBE4, UNICODE_NORM_QC_NO},
+	{0xBBE5, UNICODE_NORM_QC_NO},
+	{0xBBE6, UNICODE_NORM_QC_NO},
+	{0xBBE7, UNICODE_NORM_QC_NO},
+	{0xBBE8, UNICODE_NORM_QC_NO},
+	{0xBBE9, UNICODE_NORM_QC_NO},
+	{0xBBEA, UNICODE_NORM_QC_NO},
+	{0xBBEB, UNICODE_NORM_QC_NO},
+	{0xBBEC, UNICODE_NORM_QC_NO},
+	{0xBBED, UNICODE_NORM_QC_NO},
+	{0xBBEE, UNICODE_NORM_QC_NO},
+	{0xBBEF, UNICODE_NORM_QC_NO},
+	{0xBBF0, UNICODE_NORM_QC_NO},
+	{0xBBF1, UNICODE_NORM_QC_NO},
+	{0xBBF2, UNICODE_NORM_QC_NO},
+	{0xBBF3, UNICODE_NORM_QC_NO},
+	{0xBBF4, UNICODE_NORM_QC_NO},
+	{0xBBF5, UNICODE_NORM_QC_NO},
+	{0xBBF6, UNICODE_NORM_QC_NO},
+	{0xBBF7, UNICODE_NORM_QC_NO},
+	{0xBBF8, UNICODE_NORM_QC_NO},
+	{0xBBF9, UNICODE_NORM_QC_NO},
+	{0xBBFA, UNICODE_NORM_QC_NO},
+	{0xBBFB, UNICODE_NORM_QC_NO},
+	{0xBBFC, UNICODE_NORM_QC_NO},
+	{0xBBFD, UNICODE_NORM_QC_NO},
+	{0xBBFE, UNICODE_NORM_QC_NO},
+	{0xBBFF, UNICODE_NORM_QC_NO},
+	{0xBC00, UNICODE_NORM_QC_NO},
+	{0xBC01, UNICODE_NORM_QC_NO},
+	{0xBC02, UNICODE_NORM_QC_NO},
+	{0xBC03, UNICODE_NORM_QC_NO},
+	{0xBC04, UNICODE_NORM_QC_NO},
+	{0xBC05, UNICODE_NORM_QC_NO},
+	{0xBC06, UNICODE_NORM_QC_NO},
+	{0xBC07, UNICODE_NORM_QC_NO},
+	{0xBC08, UNICODE_NORM_QC_NO},
+	{0xBC09, UNICODE_NORM_QC_NO},
+	{0xBC0A, UNICODE_NORM_QC_NO},
+	{0xBC0B, UNICODE_NORM_QC_NO},
+	{0xBC0C, UNICODE_NORM_QC_NO},
+	{0xBC0D, UNICODE_NORM_QC_NO},
+	{0xBC0E, UNICODE_NORM_QC_NO},
+	{0xBC0F, UNICODE_NORM_QC_NO},
+	{0xBC10, UNICODE_NORM_QC_NO},
+	{0xBC11, UNICODE_NORM_QC_NO},
+	{0xBC12, UNICODE_NORM_QC_NO},
+	{0xBC13, UNICODE_NORM_QC_NO},
+	{0xBC14, UNICODE_NORM_QC_NO},
+	{0xBC15, UNICODE_NORM_QC_NO},
+	{0xBC16, UNICODE_NORM_QC_NO},
+	{0xBC17, UNICODE_NORM_QC_NO},
+	{0xBC18, UNICODE_NORM_QC_NO},
+	{0xBC19, UNICODE_NORM_QC_NO},
+	{0xBC1A, UNICODE_NORM_QC_NO},
+	{0xBC1B, UNICODE_NORM_QC_NO},
+	{0xBC1C, UNICODE_NORM_QC_NO},
+	{0xBC1D, UNICODE_NORM_QC_NO},
+	{0xBC1E, UNICODE_NORM_QC_NO},
+	{0xBC1F, UNICODE_NORM_QC_NO},
+	{0xBC20, UNICODE_NORM_QC_NO},
+	{0xBC21, UNICODE_NORM_QC_NO},
+	{0xBC22, UNICODE_NORM_QC_NO},
+	{0xBC23, UNICODE_NORM_QC_NO},
+	{0xBC24, UNICODE_NORM_QC_NO},
+	{0xBC25, UNICODE_NORM_QC_NO},
+	{0xBC26, UNICODE_NORM_QC_NO},
+	{0xBC27, UNICODE_NORM_QC_NO},
+	{0xBC28, UNICODE_NORM_QC_NO},
+	{0xBC29, UNICODE_NORM_QC_NO},
+	{0xBC2A, UNICODE_NORM_QC_NO},
+	{0xBC2B, UNICODE_NORM_QC_NO},
+	{0xBC2C, UNICODE_NORM_QC_NO},
+	{0xBC2D, UNICODE_NORM_QC_NO},
+	{0xBC2E, UNICODE_NORM_QC_NO},
+	{0xBC2F, UNICODE_NORM_QC_NO},
+	{0xBC30, UNICODE_NORM_QC_NO},
+	{0xBC31, UNICODE_NORM_QC_NO},
+	{0xBC32, UNICODE_NORM_QC_NO},
+	{0xBC33, UNICODE_NORM_QC_NO},
+	{0xBC34, UNICODE_NORM_QC_NO},
+	{0xBC35, UNICODE_NORM_QC_NO},
+	{0xBC36, UNICODE_NORM_QC_NO},
+	{0xBC37, UNICODE_NORM_QC_NO},
+	{0xBC38, UNICODE_NORM_QC_NO},
+	{0xBC39, UNICODE_NORM_QC_NO},
+	{0xBC3A, UNICODE_NORM_QC_NO},
+	{0xBC3B, UNICODE_NORM_QC_NO},
+	{0xBC3C, UNICODE_NORM_QC_NO},
+	{0xBC3D, UNICODE_NORM_QC_NO},
+	{0xBC3E, UNICODE_NORM_QC_NO},
+	{0xBC3F, UNICODE_NORM_QC_NO},
+	{0xBC40, UNICODE_NORM_QC_NO},
+	{0xBC41, UNICODE_NORM_QC_NO},
+	{0xBC42, UNICODE_NORM_QC_NO},
+	{0xBC43, UNICODE_NORM_QC_NO},
+	{0xBC44, UNICODE_NORM_QC_NO},
+	{0xBC45, UNICODE_NORM_QC_NO},
+	{0xBC46, UNICODE_NORM_QC_NO},
+	{0xBC47, UNICODE_NORM_QC_NO},
+	{0xBC48, UNICODE_NORM_QC_NO},
+	{0xBC49, UNICODE_NORM_QC_NO},
+	{0xBC4A, UNICODE_NORM_QC_NO},
+	{0xBC4B, UNICODE_NORM_QC_NO},
+	{0xBC4C, UNICODE_NORM_QC_NO},
+	{0xBC4D, UNICODE_NORM_QC_NO},
+	{0xBC4E, UNICODE_NORM_QC_NO},
+	{0xBC4F, UNICODE_NORM_QC_NO},
+	{0xBC50, UNICODE_NORM_QC_NO},
+	{0xBC51, UNICODE_NORM_QC_NO},
+	{0xBC52, UNICODE_NORM_QC_NO},
+	{0xBC53, UNICODE_NORM_QC_NO},
+	{0xBC54, UNICODE_NORM_QC_NO},
+	{0xBC55, UNICODE_NORM_QC_NO},
+	{0xBC56, UNICODE_NORM_QC_NO},
+	{0xBC57, UNICODE_NORM_QC_NO},
+	{0xBC58, UNICODE_NORM_QC_NO},
+	{0xBC59, UNICODE_NORM_QC_NO},
+	{0xBC5A, UNICODE_NORM_QC_NO},
+	{0xBC5B, UNICODE_NORM_QC_NO},
+	{0xBC5C, UNICODE_NORM_QC_NO},
+	{0xBC5D, UNICODE_NORM_QC_NO},
+	{0xBC5E, UNICODE_NORM_QC_NO},
+	{0xBC5F, UNICODE_NORM_QC_NO},
+	{0xBC60, UNICODE_NORM_QC_NO},
+	{0xBC61, UNICODE_NORM_QC_NO},
+	{0xBC62, UNICODE_NORM_QC_NO},
+	{0xBC63, UNICODE_NORM_QC_NO},
+	{0xBC64, UNICODE_NORM_QC_NO},
+	{0xBC65, UNICODE_NORM_QC_NO},
+	{0xBC66, UNICODE_NORM_QC_NO},
+	{0xBC67, UNICODE_NORM_QC_NO},
+	{0xBC68, UNICODE_NORM_QC_NO},
+	{0xBC69, UNICODE_NORM_QC_NO},
+	{0xBC6A, UNICODE_NORM_QC_NO},
+	{0xBC6B, UNICODE_NORM_QC_NO},
+	{0xBC6C, UNICODE_NORM_QC_NO},
+	{0xBC6D, UNICODE_NORM_QC_NO},
+	{0xBC6E, UNICODE_NORM_QC_NO},
+	{0xBC6F, UNICODE_NORM_QC_NO},
+	{0xBC70, UNICODE_NORM_QC_NO},
+	{0xBC71, UNICODE_NORM_QC_NO},
+	{0xBC72, UNICODE_NORM_QC_NO},
+	{0xBC73, UNICODE_NORM_QC_NO},
+	{0xBC74, UNICODE_NORM_QC_NO},
+	{0xBC75, UNICODE_NORM_QC_NO},
+	{0xBC76, UNICODE_NORM_QC_NO},
+	{0xBC77, UNICODE_NORM_QC_NO},
+	{0xBC78, UNICODE_NORM_QC_NO},
+	{0xBC79, UNICODE_NORM_QC_NO},
+	{0xBC7A, UNICODE_NORM_QC_NO},
+	{0xBC7B, UNICODE_NORM_QC_NO},
+	{0xBC7C, UNICODE_NORM_QC_NO},
+	{0xBC7D, UNICODE_NORM_QC_NO},
+	{0xBC7E, UNICODE_NORM_QC_NO},
+	{0xBC7F, UNICODE_NORM_QC_NO},
+	{0xBC80, UNICODE_NORM_QC_NO},
+	{0xBC81, UNICODE_NORM_QC_NO},
+	{0xBC82, UNICODE_NORM_QC_NO},
+	{0xBC83, UNICODE_NORM_QC_NO},
+	{0xBC84, UNICODE_NORM_QC_NO},
+	{0xBC85, UNICODE_NORM_QC_NO},
+	{0xBC86, UNICODE_NORM_QC_NO},
+	{0xBC87, UNICODE_NORM_QC_NO},
+	{0xBC88, UNICODE_NORM_QC_NO},
+	{0xBC89, UNICODE_NORM_QC_NO},
+	{0xBC8A, UNICODE_NORM_QC_NO},
+	{0xBC8B, UNICODE_NORM_QC_NO},
+	{0xBC8C, UNICODE_NORM_QC_NO},
+	{0xBC8D, UNICODE_NORM_QC_NO},
+	{0xBC8E, UNICODE_NORM_QC_NO},
+	{0xBC8F, UNICODE_NORM_QC_NO},
+	{0xBC90, UNICODE_NORM_QC_NO},
+	{0xBC91, UNICODE_NORM_QC_NO},
+	{0xBC92, UNICODE_NORM_QC_NO},
+	{0xBC93, UNICODE_NORM_QC_NO},
+	{0xBC94, UNICODE_NORM_QC_NO},
+	{0xBC95, UNICODE_NORM_QC_NO},
+	{0xBC96, UNICODE_NORM_QC_NO},
+	{0xBC97, UNICODE_NORM_QC_NO},
+	{0xBC98, UNICODE_NORM_QC_NO},
+	{0xBC99, UNICODE_NORM_QC_NO},
+	{0xBC9A, UNICODE_NORM_QC_NO},
+	{0xBC9B, UNICODE_NORM_QC_NO},
+	{0xBC9C, UNICODE_NORM_QC_NO},
+	{0xBC9D, UNICODE_NORM_QC_NO},
+	{0xBC9E, UNICODE_NORM_QC_NO},
+	{0xBC9F, UNICODE_NORM_QC_NO},
+	{0xBCA0, UNICODE_NORM_QC_NO},
+	{0xBCA1, UNICODE_NORM_QC_NO},
+	{0xBCA2, UNICODE_NORM_QC_NO},
+	{0xBCA3, UNICODE_NORM_QC_NO},
+	{0xBCA4, UNICODE_NORM_QC_NO},
+	{0xBCA5, UNICODE_NORM_QC_NO},
+	{0xBCA6, UNICODE_NORM_QC_NO},
+	{0xBCA7, UNICODE_NORM_QC_NO},
+	{0xBCA8, UNICODE_NORM_QC_NO},
+	{0xBCA9, UNICODE_NORM_QC_NO},
+	{0xBCAA, UNICODE_NORM_QC_NO},
+	{0xBCAB, UNICODE_NORM_QC_NO},
+	{0xBCAC, UNICODE_NORM_QC_NO},
+	{0xBCAD, UNICODE_NORM_QC_NO},
+	{0xBCAE, UNICODE_NORM_QC_NO},
+	{0xBCAF, UNICODE_NORM_QC_NO},
+	{0xBCB0, UNICODE_NORM_QC_NO},
+	{0xBCB1, UNICODE_NORM_QC_NO},
+	{0xBCB2, UNICODE_NORM_QC_NO},
+	{0xBCB3, UNICODE_NORM_QC_NO},
+	{0xBCB4, UNICODE_NORM_QC_NO},
+	{0xBCB5, UNICODE_NORM_QC_NO},
+	{0xBCB6, UNICODE_NORM_QC_NO},
+	{0xBCB7, UNICODE_NORM_QC_NO},
+	{0xBCB8, UNICODE_NORM_QC_NO},
+	{0xBCB9, UNICODE_NORM_QC_NO},
+	{0xBCBA, UNICODE_NORM_QC_NO},
+	{0xBCBB, UNICODE_NORM_QC_NO},
+	{0xBCBC, UNICODE_NORM_QC_NO},
+	{0xBCBD, UNICODE_NORM_QC_NO},
+	{0xBCBE, UNICODE_NORM_QC_NO},
+	{0xBCBF, UNICODE_NORM_QC_NO},
+	{0xBCC0, UNICODE_NORM_QC_NO},
+	{0xBCC1, UNICODE_NORM_QC_NO},
+	{0xBCC2, UNICODE_NORM_QC_NO},
+	{0xBCC3, UNICODE_NORM_QC_NO},
+	{0xBCC4, UNICODE_NORM_QC_NO},
+	{0xBCC5, UNICODE_NORM_QC_NO},
+	{0xBCC6, UNICODE_NORM_QC_NO},
+	{0xBCC7, UNICODE_NORM_QC_NO},
+	{0xBCC8, UNICODE_NORM_QC_NO},
+	{0xBCC9, UNICODE_NORM_QC_NO},
+	{0xBCCA, UNICODE_NORM_QC_NO},
+	{0xBCCB, UNICODE_NORM_QC_NO},
+	{0xBCCC, UNICODE_NORM_QC_NO},
+	{0xBCCD, UNICODE_NORM_QC_NO},
+	{0xBCCE, UNICODE_NORM_QC_NO},
+	{0xBCCF, UNICODE_NORM_QC_NO},
+	{0xBCD0, UNICODE_NORM_QC_NO},
+	{0xBCD1, UNICODE_NORM_QC_NO},
+	{0xBCD2, UNICODE_NORM_QC_NO},
+	{0xBCD3, UNICODE_NORM_QC_NO},
+	{0xBCD4, UNICODE_NORM_QC_NO},
+	{0xBCD5, UNICODE_NORM_QC_NO},
+	{0xBCD6, UNICODE_NORM_QC_NO},
+	{0xBCD7, UNICODE_NORM_QC_NO},
+	{0xBCD8, UNICODE_NORM_QC_NO},
+	{0xBCD9, UNICODE_NORM_QC_NO},
+	{0xBCDA, UNICODE_NORM_QC_NO},
+	{0xBCDB, UNICODE_NORM_QC_NO},
+	{0xBCDC, UNICODE_NORM_QC_NO},
+	{0xBCDD, UNICODE_NORM_QC_NO},
+	{0xBCDE, UNICODE_NORM_QC_NO},
+	{0xBCDF, UNICODE_NORM_QC_NO},
+	{0xBCE0, UNICODE_NORM_QC_NO},
+	{0xBCE1, UNICODE_NORM_QC_NO},
+	{0xBCE2, UNICODE_NORM_QC_NO},
+	{0xBCE3, UNICODE_NORM_QC_NO},
+	{0xBCE4, UNICODE_NORM_QC_NO},
+	{0xBCE5, UNICODE_NORM_QC_NO},
+	{0xBCE6, UNICODE_NORM_QC_NO},
+	{0xBCE7, UNICODE_NORM_QC_NO},
+	{0xBCE8, UNICODE_NORM_QC_NO},
+	{0xBCE9, UNICODE_NORM_QC_NO},
+	{0xBCEA, UNICODE_NORM_QC_NO},
+	{0xBCEB, UNICODE_NORM_QC_NO},
+	{0xBCEC, UNICODE_NORM_QC_NO},
+	{0xBCED, UNICODE_NORM_QC_NO},
+	{0xBCEE, UNICODE_NORM_QC_NO},
+	{0xBCEF, UNICODE_NORM_QC_NO},
+	{0xBCF0, UNICODE_NORM_QC_NO},
+	{0xBCF1, UNICODE_NORM_QC_NO},
+	{0xBCF2, UNICODE_NORM_QC_NO},
+	{0xBCF3, UNICODE_NORM_QC_NO},
+	{0xBCF4, UNICODE_NORM_QC_NO},
+	{0xBCF5, UNICODE_NORM_QC_NO},
+	{0xBCF6, UNICODE_NORM_QC_NO},
+	{0xBCF7, UNICODE_NORM_QC_NO},
+	{0xBCF8, UNICODE_NORM_QC_NO},
+	{0xBCF9, UNICODE_NORM_QC_NO},
+	{0xBCFA, UNICODE_NORM_QC_NO},
+	{0xBCFB, UNICODE_NORM_QC_NO},
+	{0xBCFC, UNICODE_NORM_QC_NO},
+	{0xBCFD, UNICODE_NORM_QC_NO},
+	{0xBCFE, UNICODE_NORM_QC_NO},
+	{0xBCFF, UNICODE_NORM_QC_NO},
+	{0xBD00, UNICODE_NORM_QC_NO},
+	{0xBD01, UNICODE_NORM_QC_NO},
+	{0xBD02, UNICODE_NORM_QC_NO},
+	{0xBD03, UNICODE_NORM_QC_NO},
+	{0xBD04, UNICODE_NORM_QC_NO},
+	{0xBD05, UNICODE_NORM_QC_NO},
+	{0xBD06, UNICODE_NORM_QC_NO},
+	{0xBD07, UNICODE_NORM_QC_NO},
+	{0xBD08, UNICODE_NORM_QC_NO},
+	{0xBD09, UNICODE_NORM_QC_NO},
+	{0xBD0A, UNICODE_NORM_QC_NO},
+	{0xBD0B, UNICODE_NORM_QC_NO},
+	{0xBD0C, UNICODE_NORM_QC_NO},
+	{0xBD0D, UNICODE_NORM_QC_NO},
+	{0xBD0E, UNICODE_NORM_QC_NO},
+	{0xBD0F, UNICODE_NORM_QC_NO},
+	{0xBD10, UNICODE_NORM_QC_NO},
+	{0xBD11, UNICODE_NORM_QC_NO},
+	{0xBD12, UNICODE_NORM_QC_NO},
+	{0xBD13, UNICODE_NORM_QC_NO},
+	{0xBD14, UNICODE_NORM_QC_NO},
+	{0xBD15, UNICODE_NORM_QC_NO},
+	{0xBD16, UNICODE_NORM_QC_NO},
+	{0xBD17, UNICODE_NORM_QC_NO},
+	{0xBD18, UNICODE_NORM_QC_NO},
+	{0xBD19, UNICODE_NORM_QC_NO},
+	{0xBD1A, UNICODE_NORM_QC_NO},
+	{0xBD1B, UNICODE_NORM_QC_NO},
+	{0xBD1C, UNICODE_NORM_QC_NO},
+	{0xBD1D, UNICODE_NORM_QC_NO},
+	{0xBD1E, UNICODE_NORM_QC_NO},
+	{0xBD1F, UNICODE_NORM_QC_NO},
+	{0xBD20, UNICODE_NORM_QC_NO},
+	{0xBD21, UNICODE_NORM_QC_NO},
+	{0xBD22, UNICODE_NORM_QC_NO},
+	{0xBD23, UNICODE_NORM_QC_NO},
+	{0xBD24, UNICODE_NORM_QC_NO},
+	{0xBD25, UNICODE_NORM_QC_NO},
+	{0xBD26, UNICODE_NORM_QC_NO},
+	{0xBD27, UNICODE_NORM_QC_NO},
+	{0xBD28, UNICODE_NORM_QC_NO},
+	{0xBD29, UNICODE_NORM_QC_NO},
+	{0xBD2A, UNICODE_NORM_QC_NO},
+	{0xBD2B, UNICODE_NORM_QC_NO},
+	{0xBD2C, UNICODE_NORM_QC_NO},
+	{0xBD2D, UNICODE_NORM_QC_NO},
+	{0xBD2E, UNICODE_NORM_QC_NO},
+	{0xBD2F, UNICODE_NORM_QC_NO},
+	{0xBD30, UNICODE_NORM_QC_NO},
+	{0xBD31, UNICODE_NORM_QC_NO},
+	{0xBD32, UNICODE_NORM_QC_NO},
+	{0xBD33, UNICODE_NORM_QC_NO},
+	{0xBD34, UNICODE_NORM_QC_NO},
+	{0xBD35, UNICODE_NORM_QC_NO},
+	{0xBD36, UNICODE_NORM_QC_NO},
+	{0xBD37, UNICODE_NORM_QC_NO},
+	{0xBD38, UNICODE_NORM_QC_NO},
+	{0xBD39, UNICODE_NORM_QC_NO},
+	{0xBD3A, UNICODE_NORM_QC_NO},
+	{0xBD3B, UNICODE_NORM_QC_NO},
+	{0xBD3C, UNICODE_NORM_QC_NO},
+	{0xBD3D, UNICODE_NORM_QC_NO},
+	{0xBD3E, UNICODE_NORM_QC_NO},
+	{0xBD3F, UNICODE_NORM_QC_NO},
+	{0xBD40, UNICODE_NORM_QC_NO},
+	{0xBD41, UNICODE_NORM_QC_NO},
+	{0xBD42, UNICODE_NORM_QC_NO},
+	{0xBD43, UNICODE_NORM_QC_NO},
+	{0xBD44, UNICODE_NORM_QC_NO},
+	{0xBD45, UNICODE_NORM_QC_NO},
+	{0xBD46, UNICODE_NORM_QC_NO},
+	{0xBD47, UNICODE_NORM_QC_NO},
+	{0xBD48, UNICODE_NORM_QC_NO},
+	{0xBD49, UNICODE_NORM_QC_NO},
+	{0xBD4A, UNICODE_NORM_QC_NO},
+	{0xBD4B, UNICODE_NORM_QC_NO},
+	{0xBD4C, UNICODE_NORM_QC_NO},
+	{0xBD4D, UNICODE_NORM_QC_NO},
+	{0xBD4E, UNICODE_NORM_QC_NO},
+	{0xBD4F, UNICODE_NORM_QC_NO},
+	{0xBD50, UNICODE_NORM_QC_NO},
+	{0xBD51, UNICODE_NORM_QC_NO},
+	{0xBD52, UNICODE_NORM_QC_NO},
+	{0xBD53, UNICODE_NORM_QC_NO},
+	{0xBD54, UNICODE_NORM_QC_NO},
+	{0xBD55, UNICODE_NORM_QC_NO},
+	{0xBD56, UNICODE_NORM_QC_NO},
+	{0xBD57, UNICODE_NORM_QC_NO},
+	{0xBD58, UNICODE_NORM_QC_NO},
+	{0xBD59, UNICODE_NORM_QC_NO},
+	{0xBD5A, UNICODE_NORM_QC_NO},
+	{0xBD5B, UNICODE_NORM_QC_NO},
+	{0xBD5C, UNICODE_NORM_QC_NO},
+	{0xBD5D, UNICODE_NORM_QC_NO},
+	{0xBD5E, UNICODE_NORM_QC_NO},
+	{0xBD5F, UNICODE_NORM_QC_NO},
+	{0xBD60, UNICODE_NORM_QC_NO},
+	{0xBD61, UNICODE_NORM_QC_NO},
+	{0xBD62, UNICODE_NORM_QC_NO},
+	{0xBD63, UNICODE_NORM_QC_NO},
+	{0xBD64, UNICODE_NORM_QC_NO},
+	{0xBD65, UNICODE_NORM_QC_NO},
+	{0xBD66, UNICODE_NORM_QC_NO},
+	{0xBD67, UNICODE_NORM_QC_NO},
+	{0xBD68, UNICODE_NORM_QC_NO},
+	{0xBD69, UNICODE_NORM_QC_NO},
+	{0xBD6A, UNICODE_NORM_QC_NO},
+	{0xBD6B, UNICODE_NORM_QC_NO},
+	{0xBD6C, UNICODE_NORM_QC_NO},
+	{0xBD6D, UNICODE_NORM_QC_NO},
+	{0xBD6E, UNICODE_NORM_QC_NO},
+	{0xBD6F, UNICODE_NORM_QC_NO},
+	{0xBD70, UNICODE_NORM_QC_NO},
+	{0xBD71, UNICODE_NORM_QC_NO},
+	{0xBD72, UNICODE_NORM_QC_NO},
+	{0xBD73, UNICODE_NORM_QC_NO},
+	{0xBD74, UNICODE_NORM_QC_NO},
+	{0xBD75, UNICODE_NORM_QC_NO},
+	{0xBD76, UNICODE_NORM_QC_NO},
+	{0xBD77, UNICODE_NORM_QC_NO},
+	{0xBD78, UNICODE_NORM_QC_NO},
+	{0xBD79, UNICODE_NORM_QC_NO},
+	{0xBD7A, UNICODE_NORM_QC_NO},
+	{0xBD7B, UNICODE_NORM_QC_NO},
+	{0xBD7C, UNICODE_NORM_QC_NO},
+	{0xBD7D, UNICODE_NORM_QC_NO},
+	{0xBD7E, UNICODE_NORM_QC_NO},
+	{0xBD7F, UNICODE_NORM_QC_NO},
+	{0xBD80, UNICODE_NORM_QC_NO},
+	{0xBD81, UNICODE_NORM_QC_NO},
+	{0xBD82, UNICODE_NORM_QC_NO},
+	{0xBD83, UNICODE_NORM_QC_NO},
+	{0xBD84, UNICODE_NORM_QC_NO},
+	{0xBD85, UNICODE_NORM_QC_NO},
+	{0xBD86, UNICODE_NORM_QC_NO},
+	{0xBD87, UNICODE_NORM_QC_NO},
+	{0xBD88, UNICODE_NORM_QC_NO},
+	{0xBD89, UNICODE_NORM_QC_NO},
+	{0xBD8A, UNICODE_NORM_QC_NO},
+	{0xBD8B, UNICODE_NORM_QC_NO},
+	{0xBD8C, UNICODE_NORM_QC_NO},
+	{0xBD8D, UNICODE_NORM_QC_NO},
+	{0xBD8E, UNICODE_NORM_QC_NO},
+	{0xBD8F, UNICODE_NORM_QC_NO},
+	{0xBD90, UNICODE_NORM_QC_NO},
+	{0xBD91, UNICODE_NORM_QC_NO},
+	{0xBD92, UNICODE_NORM_QC_NO},
+	{0xBD93, UNICODE_NORM_QC_NO},
+	{0xBD94, UNICODE_NORM_QC_NO},
+	{0xBD95, UNICODE_NORM_QC_NO},
+	{0xBD96, UNICODE_NORM_QC_NO},
+	{0xBD97, UNICODE_NORM_QC_NO},
+	{0xBD98, UNICODE_NORM_QC_NO},
+	{0xBD99, UNICODE_NORM_QC_NO},
+	{0xBD9A, UNICODE_NORM_QC_NO},
+	{0xBD9B, UNICODE_NORM_QC_NO},
+	{0xBD9C, UNICODE_NORM_QC_NO},
+	{0xBD9D, UNICODE_NORM_QC_NO},
+	{0xBD9E, UNICODE_NORM_QC_NO},
+	{0xBD9F, UNICODE_NORM_QC_NO},
+	{0xBDA0, UNICODE_NORM_QC_NO},
+	{0xBDA1, UNICODE_NORM_QC_NO},
+	{0xBDA2, UNICODE_NORM_QC_NO},
+	{0xBDA3, UNICODE_NORM_QC_NO},
+	{0xBDA4, UNICODE_NORM_QC_NO},
+	{0xBDA5, UNICODE_NORM_QC_NO},
+	{0xBDA6, UNICODE_NORM_QC_NO},
+	{0xBDA7, UNICODE_NORM_QC_NO},
+	{0xBDA8, UNICODE_NORM_QC_NO},
+	{0xBDA9, UNICODE_NORM_QC_NO},
+	{0xBDAA, UNICODE_NORM_QC_NO},
+	{0xBDAB, UNICODE_NORM_QC_NO},
+	{0xBDAC, UNICODE_NORM_QC_NO},
+	{0xBDAD, UNICODE_NORM_QC_NO},
+	{0xBDAE, UNICODE_NORM_QC_NO},
+	{0xBDAF, UNICODE_NORM_QC_NO},
+	{0xBDB0, UNICODE_NORM_QC_NO},
+	{0xBDB1, UNICODE_NORM_QC_NO},
+	{0xBDB2, UNICODE_NORM_QC_NO},
+	{0xBDB3, UNICODE_NORM_QC_NO},
+	{0xBDB4, UNICODE_NORM_QC_NO},
+	{0xBDB5, UNICODE_NORM_QC_NO},
+	{0xBDB6, UNICODE_NORM_QC_NO},
+	{0xBDB7, UNICODE_NORM_QC_NO},
+	{0xBDB8, UNICODE_NORM_QC_NO},
+	{0xBDB9, UNICODE_NORM_QC_NO},
+	{0xBDBA, UNICODE_NORM_QC_NO},
+	{0xBDBB, UNICODE_NORM_QC_NO},
+	{0xBDBC, UNICODE_NORM_QC_NO},
+	{0xBDBD, UNICODE_NORM_QC_NO},
+	{0xBDBE, UNICODE_NORM_QC_NO},
+	{0xBDBF, UNICODE_NORM_QC_NO},
+	{0xBDC0, UNICODE_NORM_QC_NO},
+	{0xBDC1, UNICODE_NORM_QC_NO},
+	{0xBDC2, UNICODE_NORM_QC_NO},
+	{0xBDC3, UNICODE_NORM_QC_NO},
+	{0xBDC4, UNICODE_NORM_QC_NO},
+	{0xBDC5, UNICODE_NORM_QC_NO},
+	{0xBDC6, UNICODE_NORM_QC_NO},
+	{0xBDC7, UNICODE_NORM_QC_NO},
+	{0xBDC8, UNICODE_NORM_QC_NO},
+	{0xBDC9, UNICODE_NORM_QC_NO},
+	{0xBDCA, UNICODE_NORM_QC_NO},
+	{0xBDCB, UNICODE_NORM_QC_NO},
+	{0xBDCC, UNICODE_NORM_QC_NO},
+	{0xBDCD, UNICODE_NORM_QC_NO},
+	{0xBDCE, UNICODE_NORM_QC_NO},
+	{0xBDCF, UNICODE_NORM_QC_NO},
+	{0xBDD0, UNICODE_NORM_QC_NO},
+	{0xBDD1, UNICODE_NORM_QC_NO},
+	{0xBDD2, UNICODE_NORM_QC_NO},
+	{0xBDD3, UNICODE_NORM_QC_NO},
+	{0xBDD4, UNICODE_NORM_QC_NO},
+	{0xBDD5, UNICODE_NORM_QC_NO},
+	{0xBDD6, UNICODE_NORM_QC_NO},
+	{0xBDD7, UNICODE_NORM_QC_NO},
+	{0xBDD8, UNICODE_NORM_QC_NO},
+	{0xBDD9, UNICODE_NORM_QC_NO},
+	{0xBDDA, UNICODE_NORM_QC_NO},
+	{0xBDDB, UNICODE_NORM_QC_NO},
+	{0xBDDC, UNICODE_NORM_QC_NO},
+	{0xBDDD, UNICODE_NORM_QC_NO},
+	{0xBDDE, UNICODE_NORM_QC_NO},
+	{0xBDDF, UNICODE_NORM_QC_NO},
+	{0xBDE0, UNICODE_NORM_QC_NO},
+	{0xBDE1, UNICODE_NORM_QC_NO},
+	{0xBDE2, UNICODE_NORM_QC_NO},
+	{0xBDE3, UNICODE_NORM_QC_NO},
+	{0xBDE4, UNICODE_NORM_QC_NO},
+	{0xBDE5, UNICODE_NORM_QC_NO},
+	{0xBDE6, UNICODE_NORM_QC_NO},
+	{0xBDE7, UNICODE_NORM_QC_NO},
+	{0xBDE8, UNICODE_NORM_QC_NO},
+	{0xBDE9, UNICODE_NORM_QC_NO},
+	{0xBDEA, UNICODE_NORM_QC_NO},
+	{0xBDEB, UNICODE_NORM_QC_NO},
+	{0xBDEC, UNICODE_NORM_QC_NO},
+	{0xBDED, UNICODE_NORM_QC_NO},
+	{0xBDEE, UNICODE_NORM_QC_NO},
+	{0xBDEF, UNICODE_NORM_QC_NO},
+	{0xBDF0, UNICODE_NORM_QC_NO},
+	{0xBDF1, UNICODE_NORM_QC_NO},
+	{0xBDF2, UNICODE_NORM_QC_NO},
+	{0xBDF3, UNICODE_NORM_QC_NO},
+	{0xBDF4, UNICODE_NORM_QC_NO},
+	{0xBDF5, UNICODE_NORM_QC_NO},
+	{0xBDF6, UNICODE_NORM_QC_NO},
+	{0xBDF7, UNICODE_NORM_QC_NO},
+	{0xBDF8, UNICODE_NORM_QC_NO},
+	{0xBDF9, UNICODE_NORM_QC_NO},
+	{0xBDFA, UNICODE_NORM_QC_NO},
+	{0xBDFB, UNICODE_NORM_QC_NO},
+	{0xBDFC, UNICODE_NORM_QC_NO},
+	{0xBDFD, UNICODE_NORM_QC_NO},
+	{0xBDFE, UNICODE_NORM_QC_NO},
+	{0xBDFF, UNICODE_NORM_QC_NO},
+	{0xBE00, UNICODE_NORM_QC_NO},
+	{0xBE01, UNICODE_NORM_QC_NO},
+	{0xBE02, UNICODE_NORM_QC_NO},
+	{0xBE03, UNICODE_NORM_QC_NO},
+	{0xBE04, UNICODE_NORM_QC_NO},
+	{0xBE05, UNICODE_NORM_QC_NO},
+	{0xBE06, UNICODE_NORM_QC_NO},
+	{0xBE07, UNICODE_NORM_QC_NO},
+	{0xBE08, UNICODE_NORM_QC_NO},
+	{0xBE09, UNICODE_NORM_QC_NO},
+	{0xBE0A, UNICODE_NORM_QC_NO},
+	{0xBE0B, UNICODE_NORM_QC_NO},
+	{0xBE0C, UNICODE_NORM_QC_NO},
+	{0xBE0D, UNICODE_NORM_QC_NO},
+	{0xBE0E, UNICODE_NORM_QC_NO},
+	{0xBE0F, UNICODE_NORM_QC_NO},
+	{0xBE10, UNICODE_NORM_QC_NO},
+	{0xBE11, UNICODE_NORM_QC_NO},
+	{0xBE12, UNICODE_NORM_QC_NO},
+	{0xBE13, UNICODE_NORM_QC_NO},
+	{0xBE14, UNICODE_NORM_QC_NO},
+	{0xBE15, UNICODE_NORM_QC_NO},
+	{0xBE16, UNICODE_NORM_QC_NO},
+	{0xBE17, UNICODE_NORM_QC_NO},
+	{0xBE18, UNICODE_NORM_QC_NO},
+	{0xBE19, UNICODE_NORM_QC_NO},
+	{0xBE1A, UNICODE_NORM_QC_NO},
+	{0xBE1B, UNICODE_NORM_QC_NO},
+	{0xBE1C, UNICODE_NORM_QC_NO},
+	{0xBE1D, UNICODE_NORM_QC_NO},
+	{0xBE1E, UNICODE_NORM_QC_NO},
+	{0xBE1F, UNICODE_NORM_QC_NO},
+	{0xBE20, UNICODE_NORM_QC_NO},
+	{0xBE21, UNICODE_NORM_QC_NO},
+	{0xBE22, UNICODE_NORM_QC_NO},
+	{0xBE23, UNICODE_NORM_QC_NO},
+	{0xBE24, UNICODE_NORM_QC_NO},
+	{0xBE25, UNICODE_NORM_QC_NO},
+	{0xBE26, UNICODE_NORM_QC_NO},
+	{0xBE27, UNICODE_NORM_QC_NO},
+	{0xBE28, UNICODE_NORM_QC_NO},
+	{0xBE29, UNICODE_NORM_QC_NO},
+	{0xBE2A, UNICODE_NORM_QC_NO},
+	{0xBE2B, UNICODE_NORM_QC_NO},
+	{0xBE2C, UNICODE_NORM_QC_NO},
+	{0xBE2D, UNICODE_NORM_QC_NO},
+	{0xBE2E, UNICODE_NORM_QC_NO},
+	{0xBE2F, UNICODE_NORM_QC_NO},
+	{0xBE30, UNICODE_NORM_QC_NO},
+	{0xBE31, UNICODE_NORM_QC_NO},
+	{0xBE32, UNICODE_NORM_QC_NO},
+	{0xBE33, UNICODE_NORM_QC_NO},
+	{0xBE34, UNICODE_NORM_QC_NO},
+	{0xBE35, UNICODE_NORM_QC_NO},
+	{0xBE36, UNICODE_NORM_QC_NO},
+	{0xBE37, UNICODE_NORM_QC_NO},
+	{0xBE38, UNICODE_NORM_QC_NO},
+	{0xBE39, UNICODE_NORM_QC_NO},
+	{0xBE3A, UNICODE_NORM_QC_NO},
+	{0xBE3B, UNICODE_NORM_QC_NO},
+	{0xBE3C, UNICODE_NORM_QC_NO},
+	{0xBE3D, UNICODE_NORM_QC_NO},
+	{0xBE3E, UNICODE_NORM_QC_NO},
+	{0xBE3F, UNICODE_NORM_QC_NO},
+	{0xBE40, UNICODE_NORM_QC_NO},
+	{0xBE41, UNICODE_NORM_QC_NO},
+	{0xBE42, UNICODE_NORM_QC_NO},
+	{0xBE43, UNICODE_NORM_QC_NO},
+	{0xBE44, UNICODE_NORM_QC_NO},
+	{0xBE45, UNICODE_NORM_QC_NO},
+	{0xBE46, UNICODE_NORM_QC_NO},
+	{0xBE47, UNICODE_NORM_QC_NO},
+	{0xBE48, UNICODE_NORM_QC_NO},
+	{0xBE49, UNICODE_NORM_QC_NO},
+	{0xBE4A, UNICODE_NORM_QC_NO},
+	{0xBE4B, UNICODE_NORM_QC_NO},
+	{0xBE4C, UNICODE_NORM_QC_NO},
+	{0xBE4D, UNICODE_NORM_QC_NO},
+	{0xBE4E, UNICODE_NORM_QC_NO},
+	{0xBE4F, UNICODE_NORM_QC_NO},
+	{0xBE50, UNICODE_NORM_QC_NO},
+	{0xBE51, UNICODE_NORM_QC_NO},
+	{0xBE52, UNICODE_NORM_QC_NO},
+	{0xBE53, UNICODE_NORM_QC_NO},
+	{0xBE54, UNICODE_NORM_QC_NO},
+	{0xBE55, UNICODE_NORM_QC_NO},
+	{0xBE56, UNICODE_NORM_QC_NO},
+	{0xBE57, UNICODE_NORM_QC_NO},
+	{0xBE58, UNICODE_NORM_QC_NO},
+	{0xBE59, UNICODE_NORM_QC_NO},
+	{0xBE5A, UNICODE_NORM_QC_NO},
+	{0xBE5B, UNICODE_NORM_QC_NO},
+	{0xBE5C, UNICODE_NORM_QC_NO},
+	{0xBE5D, UNICODE_NORM_QC_NO},
+	{0xBE5E, UNICODE_NORM_QC_NO},
+	{0xBE5F, UNICODE_NORM_QC_NO},
+	{0xBE60, UNICODE_NORM_QC_NO},
+	{0xBE61, UNICODE_NORM_QC_NO},
+	{0xBE62, UNICODE_NORM_QC_NO},
+	{0xBE63, UNICODE_NORM_QC_NO},
+	{0xBE64, UNICODE_NORM_QC_NO},
+	{0xBE65, UNICODE_NORM_QC_NO},
+	{0xBE66, UNICODE_NORM_QC_NO},
+	{0xBE67, UNICODE_NORM_QC_NO},
+	{0xBE68, UNICODE_NORM_QC_NO},
+	{0xBE69, UNICODE_NORM_QC_NO},
+	{0xBE6A, UNICODE_NORM_QC_NO},
+	{0xBE6B, UNICODE_NORM_QC_NO},
+	{0xBE6C, UNICODE_NORM_QC_NO},
+	{0xBE6D, UNICODE_NORM_QC_NO},
+	{0xBE6E, UNICODE_NORM_QC_NO},
+	{0xBE6F, UNICODE_NORM_QC_NO},
+	{0xBE70, UNICODE_NORM_QC_NO},
+	{0xBE71, UNICODE_NORM_QC_NO},
+	{0xBE72, UNICODE_NORM_QC_NO},
+	{0xBE73, UNICODE_NORM_QC_NO},
+	{0xBE74, UNICODE_NORM_QC_NO},
+	{0xBE75, UNICODE_NORM_QC_NO},
+	{0xBE76, UNICODE_NORM_QC_NO},
+	{0xBE77, UNICODE_NORM_QC_NO},
+	{0xBE78, UNICODE_NORM_QC_NO},
+	{0xBE79, UNICODE_NORM_QC_NO},
+	{0xBE7A, UNICODE_NORM_QC_NO},
+	{0xBE7B, UNICODE_NORM_QC_NO},
+	{0xBE7C, UNICODE_NORM_QC_NO},
+	{0xBE7D, UNICODE_NORM_QC_NO},
+	{0xBE7E, UNICODE_NORM_QC_NO},
+	{0xBE7F, UNICODE_NORM_QC_NO},
+	{0xBE80, UNICODE_NORM_QC_NO},
+	{0xBE81, UNICODE_NORM_QC_NO},
+	{0xBE82, UNICODE_NORM_QC_NO},
+	{0xBE83, UNICODE_NORM_QC_NO},
+	{0xBE84, UNICODE_NORM_QC_NO},
+	{0xBE85, UNICODE_NORM_QC_NO},
+	{0xBE86, UNICODE_NORM_QC_NO},
+	{0xBE87, UNICODE_NORM_QC_NO},
+	{0xBE88, UNICODE_NORM_QC_NO},
+	{0xBE89, UNICODE_NORM_QC_NO},
+	{0xBE8A, UNICODE_NORM_QC_NO},
+	{0xBE8B, UNICODE_NORM_QC_NO},
+	{0xBE8C, UNICODE_NORM_QC_NO},
+	{0xBE8D, UNICODE_NORM_QC_NO},
+	{0xBE8E, UNICODE_NORM_QC_NO},
+	{0xBE8F, UNICODE_NORM_QC_NO},
+	{0xBE90, UNICODE_NORM_QC_NO},
+	{0xBE91, UNICODE_NORM_QC_NO},
+	{0xBE92, UNICODE_NORM_QC_NO},
+	{0xBE93, UNICODE_NORM_QC_NO},
+	{0xBE94, UNICODE_NORM_QC_NO},
+	{0xBE95, UNICODE_NORM_QC_NO},
+	{0xBE96, UNICODE_NORM_QC_NO},
+	{0xBE97, UNICODE_NORM_QC_NO},
+	{0xBE98, UNICODE_NORM_QC_NO},
+	{0xBE99, UNICODE_NORM_QC_NO},
+	{0xBE9A, UNICODE_NORM_QC_NO},
+	{0xBE9B, UNICODE_NORM_QC_NO},
+	{0xBE9C, UNICODE_NORM_QC_NO},
+	{0xBE9D, UNICODE_NORM_QC_NO},
+	{0xBE9E, UNICODE_NORM_QC_NO},
+	{0xBE9F, UNICODE_NORM_QC_NO},
+	{0xBEA0, UNICODE_NORM_QC_NO},
+	{0xBEA1, UNICODE_NORM_QC_NO},
+	{0xBEA2, UNICODE_NORM_QC_NO},
+	{0xBEA3, UNICODE_NORM_QC_NO},
+	{0xBEA4, UNICODE_NORM_QC_NO},
+	{0xBEA5, UNICODE_NORM_QC_NO},
+	{0xBEA6, UNICODE_NORM_QC_NO},
+	{0xBEA7, UNICODE_NORM_QC_NO},
+	{0xBEA8, UNICODE_NORM_QC_NO},
+	{0xBEA9, UNICODE_NORM_QC_NO},
+	{0xBEAA, UNICODE_NORM_QC_NO},
+	{0xBEAB, UNICODE_NORM_QC_NO},
+	{0xBEAC, UNICODE_NORM_QC_NO},
+	{0xBEAD, UNICODE_NORM_QC_NO},
+	{0xBEAE, UNICODE_NORM_QC_NO},
+	{0xBEAF, UNICODE_NORM_QC_NO},
+	{0xBEB0, UNICODE_NORM_QC_NO},
+	{0xBEB1, UNICODE_NORM_QC_NO},
+	{0xBEB2, UNICODE_NORM_QC_NO},
+	{0xBEB3, UNICODE_NORM_QC_NO},
+	{0xBEB4, UNICODE_NORM_QC_NO},
+	{0xBEB5, UNICODE_NORM_QC_NO},
+	{0xBEB6, UNICODE_NORM_QC_NO},
+	{0xBEB7, UNICODE_NORM_QC_NO},
+	{0xBEB8, UNICODE_NORM_QC_NO},
+	{0xBEB9, UNICODE_NORM_QC_NO},
+	{0xBEBA, UNICODE_NORM_QC_NO},
+	{0xBEBB, UNICODE_NORM_QC_NO},
+	{0xBEBC, UNICODE_NORM_QC_NO},
+	{0xBEBD, UNICODE_NORM_QC_NO},
+	{0xBEBE, UNICODE_NORM_QC_NO},
+	{0xBEBF, UNICODE_NORM_QC_NO},
+	{0xBEC0, UNICODE_NORM_QC_NO},
+	{0xBEC1, UNICODE_NORM_QC_NO},
+	{0xBEC2, UNICODE_NORM_QC_NO},
+	{0xBEC3, UNICODE_NORM_QC_NO},
+	{0xBEC4, UNICODE_NORM_QC_NO},
+	{0xBEC5, UNICODE_NORM_QC_NO},
+	{0xBEC6, UNICODE_NORM_QC_NO},
+	{0xBEC7, UNICODE_NORM_QC_NO},
+	{0xBEC8, UNICODE_NORM_QC_NO},
+	{0xBEC9, UNICODE_NORM_QC_NO},
+	{0xBECA, UNICODE_NORM_QC_NO},
+	{0xBECB, UNICODE_NORM_QC_NO},
+	{0xBECC, UNICODE_NORM_QC_NO},
+	{0xBECD, UNICODE_NORM_QC_NO},
+	{0xBECE, UNICODE_NORM_QC_NO},
+	{0xBECF, UNICODE_NORM_QC_NO},
+	{0xBED0, UNICODE_NORM_QC_NO},
+	{0xBED1, UNICODE_NORM_QC_NO},
+	{0xBED2, UNICODE_NORM_QC_NO},
+	{0xBED3, UNICODE_NORM_QC_NO},
+	{0xBED4, UNICODE_NORM_QC_NO},
+	{0xBED5, UNICODE_NORM_QC_NO},
+	{0xBED6, UNICODE_NORM_QC_NO},
+	{0xBED7, UNICODE_NORM_QC_NO},
+	{0xBED8, UNICODE_NORM_QC_NO},
+	{0xBED9, UNICODE_NORM_QC_NO},
+	{0xBEDA, UNICODE_NORM_QC_NO},
+	{0xBEDB, UNICODE_NORM_QC_NO},
+	{0xBEDC, UNICODE_NORM_QC_NO},
+	{0xBEDD, UNICODE_NORM_QC_NO},
+	{0xBEDE, UNICODE_NORM_QC_NO},
+	{0xBEDF, UNICODE_NORM_QC_NO},
+	{0xBEE0, UNICODE_NORM_QC_NO},
+	{0xBEE1, UNICODE_NORM_QC_NO},
+	{0xBEE2, UNICODE_NORM_QC_NO},
+	{0xBEE3, UNICODE_NORM_QC_NO},
+	{0xBEE4, UNICODE_NORM_QC_NO},
+	{0xBEE5, UNICODE_NORM_QC_NO},
+	{0xBEE6, UNICODE_NORM_QC_NO},
+	{0xBEE7, UNICODE_NORM_QC_NO},
+	{0xBEE8, UNICODE_NORM_QC_NO},
+	{0xBEE9, UNICODE_NORM_QC_NO},
+	{0xBEEA, UNICODE_NORM_QC_NO},
+	{0xBEEB, UNICODE_NORM_QC_NO},
+	{0xBEEC, UNICODE_NORM_QC_NO},
+	{0xBEED, UNICODE_NORM_QC_NO},
+	{0xBEEE, UNICODE_NORM_QC_NO},
+	{0xBEEF, UNICODE_NORM_QC_NO},
+	{0xBEF0, UNICODE_NORM_QC_NO},
+	{0xBEF1, UNICODE_NORM_QC_NO},
+	{0xBEF2, UNICODE_NORM_QC_NO},
+	{0xBEF3, UNICODE_NORM_QC_NO},
+	{0xBEF4, UNICODE_NORM_QC_NO},
+	{0xBEF5, UNICODE_NORM_QC_NO},
+	{0xBEF6, UNICODE_NORM_QC_NO},
+	{0xBEF7, UNICODE_NORM_QC_NO},
+	{0xBEF8, UNICODE_NORM_QC_NO},
+	{0xBEF9, UNICODE_NORM_QC_NO},
+	{0xBEFA, UNICODE_NORM_QC_NO},
+	{0xBEFB, UNICODE_NORM_QC_NO},
+	{0xBEFC, UNICODE_NORM_QC_NO},
+	{0xBEFD, UNICODE_NORM_QC_NO},
+	{0xBEFE, UNICODE_NORM_QC_NO},
+	{0xBEFF, UNICODE_NORM_QC_NO},
+	{0xBF00, UNICODE_NORM_QC_NO},
+	{0xBF01, UNICODE_NORM_QC_NO},
+	{0xBF02, UNICODE_NORM_QC_NO},
+	{0xBF03, UNICODE_NORM_QC_NO},
+	{0xBF04, UNICODE_NORM_QC_NO},
+	{0xBF05, UNICODE_NORM_QC_NO},
+	{0xBF06, UNICODE_NORM_QC_NO},
+	{0xBF07, UNICODE_NORM_QC_NO},
+	{0xBF08, UNICODE_NORM_QC_NO},
+	{0xBF09, UNICODE_NORM_QC_NO},
+	{0xBF0A, UNICODE_NORM_QC_NO},
+	{0xBF0B, UNICODE_NORM_QC_NO},
+	{0xBF0C, UNICODE_NORM_QC_NO},
+	{0xBF0D, UNICODE_NORM_QC_NO},
+	{0xBF0E, UNICODE_NORM_QC_NO},
+	{0xBF0F, UNICODE_NORM_QC_NO},
+	{0xBF10, UNICODE_NORM_QC_NO},
+	{0xBF11, UNICODE_NORM_QC_NO},
+	{0xBF12, UNICODE_NORM_QC_NO},
+	{0xBF13, UNICODE_NORM_QC_NO},
+	{0xBF14, UNICODE_NORM_QC_NO},
+	{0xBF15, UNICODE_NORM_QC_NO},
+	{0xBF16, UNICODE_NORM_QC_NO},
+	{0xBF17, UNICODE_NORM_QC_NO},
+	{0xBF18, UNICODE_NORM_QC_NO},
+	{0xBF19, UNICODE_NORM_QC_NO},
+	{0xBF1A, UNICODE_NORM_QC_NO},
+	{0xBF1B, UNICODE_NORM_QC_NO},
+	{0xBF1C, UNICODE_NORM_QC_NO},
+	{0xBF1D, UNICODE_NORM_QC_NO},
+	{0xBF1E, UNICODE_NORM_QC_NO},
+	{0xBF1F, UNICODE_NORM_QC_NO},
+	{0xBF20, UNICODE_NORM_QC_NO},
+	{0xBF21, UNICODE_NORM_QC_NO},
+	{0xBF22, UNICODE_NORM_QC_NO},
+	{0xBF23, UNICODE_NORM_QC_NO},
+	{0xBF24, UNICODE_NORM_QC_NO},
+	{0xBF25, UNICODE_NORM_QC_NO},
+	{0xBF26, UNICODE_NORM_QC_NO},
+	{0xBF27, UNICODE_NORM_QC_NO},
+	{0xBF28, UNICODE_NORM_QC_NO},
+	{0xBF29, UNICODE_NORM_QC_NO},
+	{0xBF2A, UNICODE_NORM_QC_NO},
+	{0xBF2B, UNICODE_NORM_QC_NO},
+	{0xBF2C, UNICODE_NORM_QC_NO},
+	{0xBF2D, UNICODE_NORM_QC_NO},
+	{0xBF2E, UNICODE_NORM_QC_NO},
+	{0xBF2F, UNICODE_NORM_QC_NO},
+	{0xBF30, UNICODE_NORM_QC_NO},
+	{0xBF31, UNICODE_NORM_QC_NO},
+	{0xBF32, UNICODE_NORM_QC_NO},
+	{0xBF33, UNICODE_NORM_QC_NO},
+	{0xBF34, UNICODE_NORM_QC_NO},
+	{0xBF35, UNICODE_NORM_QC_NO},
+	{0xBF36, UNICODE_NORM_QC_NO},
+	{0xBF37, UNICODE_NORM_QC_NO},
+	{0xBF38, UNICODE_NORM_QC_NO},
+	{0xBF39, UNICODE_NORM_QC_NO},
+	{0xBF3A, UNICODE_NORM_QC_NO},
+	{0xBF3B, UNICODE_NORM_QC_NO},
+	{0xBF3C, UNICODE_NORM_QC_NO},
+	{0xBF3D, UNICODE_NORM_QC_NO},
+	{0xBF3E, UNICODE_NORM_QC_NO},
+	{0xBF3F, UNICODE_NORM_QC_NO},
+	{0xBF40, UNICODE_NORM_QC_NO},
+	{0xBF41, UNICODE_NORM_QC_NO},
+	{0xBF42, UNICODE_NORM_QC_NO},
+	{0xBF43, UNICODE_NORM_QC_NO},
+	{0xBF44, UNICODE_NORM_QC_NO},
+	{0xBF45, UNICODE_NORM_QC_NO},
+	{0xBF46, UNICODE_NORM_QC_NO},
+	{0xBF47, UNICODE_NORM_QC_NO},
+	{0xBF48, UNICODE_NORM_QC_NO},
+	{0xBF49, UNICODE_NORM_QC_NO},
+	{0xBF4A, UNICODE_NORM_QC_NO},
+	{0xBF4B, UNICODE_NORM_QC_NO},
+	{0xBF4C, UNICODE_NORM_QC_NO},
+	{0xBF4D, UNICODE_NORM_QC_NO},
+	{0xBF4E, UNICODE_NORM_QC_NO},
+	{0xBF4F, UNICODE_NORM_QC_NO},
+	{0xBF50, UNICODE_NORM_QC_NO},
+	{0xBF51, UNICODE_NORM_QC_NO},
+	{0xBF52, UNICODE_NORM_QC_NO},
+	{0xBF53, UNICODE_NORM_QC_NO},
+	{0xBF54, UNICODE_NORM_QC_NO},
+	{0xBF55, UNICODE_NORM_QC_NO},
+	{0xBF56, UNICODE_NORM_QC_NO},
+	{0xBF57, UNICODE_NORM_QC_NO},
+	{0xBF58, UNICODE_NORM_QC_NO},
+	{0xBF59, UNICODE_NORM_QC_NO},
+	{0xBF5A, UNICODE_NORM_QC_NO},
+	{0xBF5B, UNICODE_NORM_QC_NO},
+	{0xBF5C, UNICODE_NORM_QC_NO},
+	{0xBF5D, UNICODE_NORM_QC_NO},
+	{0xBF5E, UNICODE_NORM_QC_NO},
+	{0xBF5F, UNICODE_NORM_QC_NO},
+	{0xBF60, UNICODE_NORM_QC_NO},
+	{0xBF61, UNICODE_NORM_QC_NO},
+	{0xBF62, UNICODE_NORM_QC_NO},
+	{0xBF63, UNICODE_NORM_QC_NO},
+	{0xBF64, UNICODE_NORM_QC_NO},
+	{0xBF65, UNICODE_NORM_QC_NO},
+	{0xBF66, UNICODE_NORM_QC_NO},
+	{0xBF67, UNICODE_NORM_QC_NO},
+	{0xBF68, UNICODE_NORM_QC_NO},
+	{0xBF69, UNICODE_NORM_QC_NO},
+	{0xBF6A, UNICODE_NORM_QC_NO},
+	{0xBF6B, UNICODE_NORM_QC_NO},
+	{0xBF6C, UNICODE_NORM_QC_NO},
+	{0xBF6D, UNICODE_NORM_QC_NO},
+	{0xBF6E, UNICODE_NORM_QC_NO},
+	{0xBF6F, UNICODE_NORM_QC_NO},
+	{0xBF70, UNICODE_NORM_QC_NO},
+	{0xBF71, UNICODE_NORM_QC_NO},
+	{0xBF72, UNICODE_NORM_QC_NO},
+	{0xBF73, UNICODE_NORM_QC_NO},
+	{0xBF74, UNICODE_NORM_QC_NO},
+	{0xBF75, UNICODE_NORM_QC_NO},
+	{0xBF76, UNICODE_NORM_QC_NO},
+	{0xBF77, UNICODE_NORM_QC_NO},
+	{0xBF78, UNICODE_NORM_QC_NO},
+	{0xBF79, UNICODE_NORM_QC_NO},
+	{0xBF7A, UNICODE_NORM_QC_NO},
+	{0xBF7B, UNICODE_NORM_QC_NO},
+	{0xBF7C, UNICODE_NORM_QC_NO},
+	{0xBF7D, UNICODE_NORM_QC_NO},
+	{0xBF7E, UNICODE_NORM_QC_NO},
+	{0xBF7F, UNICODE_NORM_QC_NO},
+	{0xBF80, UNICODE_NORM_QC_NO},
+	{0xBF81, UNICODE_NORM_QC_NO},
+	{0xBF82, UNICODE_NORM_QC_NO},
+	{0xBF83, UNICODE_NORM_QC_NO},
+	{0xBF84, UNICODE_NORM_QC_NO},
+	{0xBF85, UNICODE_NORM_QC_NO},
+	{0xBF86, UNICODE_NORM_QC_NO},
+	{0xBF87, UNICODE_NORM_QC_NO},
+	{0xBF88, UNICODE_NORM_QC_NO},
+	{0xBF89, UNICODE_NORM_QC_NO},
+	{0xBF8A, UNICODE_NORM_QC_NO},
+	{0xBF8B, UNICODE_NORM_QC_NO},
+	{0xBF8C, UNICODE_NORM_QC_NO},
+	{0xBF8D, UNICODE_NORM_QC_NO},
+	{0xBF8E, UNICODE_NORM_QC_NO},
+	{0xBF8F, UNICODE_NORM_QC_NO},
+	{0xBF90, UNICODE_NORM_QC_NO},
+	{0xBF91, UNICODE_NORM_QC_NO},
+	{0xBF92, UNICODE_NORM_QC_NO},
+	{0xBF93, UNICODE_NORM_QC_NO},
+	{0xBF94, UNICODE_NORM_QC_NO},
+	{0xBF95, UNICODE_NORM_QC_NO},
+	{0xBF96, UNICODE_NORM_QC_NO},
+	{0xBF97, UNICODE_NORM_QC_NO},
+	{0xBF98, UNICODE_NORM_QC_NO},
+	{0xBF99, UNICODE_NORM_QC_NO},
+	{0xBF9A, UNICODE_NORM_QC_NO},
+	{0xBF9B, UNICODE_NORM_QC_NO},
+	{0xBF9C, UNICODE_NORM_QC_NO},
+	{0xBF9D, UNICODE_NORM_QC_NO},
+	{0xBF9E, UNICODE_NORM_QC_NO},
+	{0xBF9F, UNICODE_NORM_QC_NO},
+	{0xBFA0, UNICODE_NORM_QC_NO},
+	{0xBFA1, UNICODE_NORM_QC_NO},
+	{0xBFA2, UNICODE_NORM_QC_NO},
+	{0xBFA3, UNICODE_NORM_QC_NO},
+	{0xBFA4, UNICODE_NORM_QC_NO},
+	{0xBFA5, UNICODE_NORM_QC_NO},
+	{0xBFA6, UNICODE_NORM_QC_NO},
+	{0xBFA7, UNICODE_NORM_QC_NO},
+	{0xBFA8, UNICODE_NORM_QC_NO},
+	{0xBFA9, UNICODE_NORM_QC_NO},
+	{0xBFAA, UNICODE_NORM_QC_NO},
+	{0xBFAB, UNICODE_NORM_QC_NO},
+	{0xBFAC, UNICODE_NORM_QC_NO},
+	{0xBFAD, UNICODE_NORM_QC_NO},
+	{0xBFAE, UNICODE_NORM_QC_NO},
+	{0xBFAF, UNICODE_NORM_QC_NO},
+	{0xBFB0, UNICODE_NORM_QC_NO},
+	{0xBFB1, UNICODE_NORM_QC_NO},
+	{0xBFB2, UNICODE_NORM_QC_NO},
+	{0xBFB3, UNICODE_NORM_QC_NO},
+	{0xBFB4, UNICODE_NORM_QC_NO},
+	{0xBFB5, UNICODE_NORM_QC_NO},
+	{0xBFB6, UNICODE_NORM_QC_NO},
+	{0xBFB7, UNICODE_NORM_QC_NO},
+	{0xBFB8, UNICODE_NORM_QC_NO},
+	{0xBFB9, UNICODE_NORM_QC_NO},
+	{0xBFBA, UNICODE_NORM_QC_NO},
+	{0xBFBB, UNICODE_NORM_QC_NO},
+	{0xBFBC, UNICODE_NORM_QC_NO},
+	{0xBFBD, UNICODE_NORM_QC_NO},
+	{0xBFBE, UNICODE_NORM_QC_NO},
+	{0xBFBF, UNICODE_NORM_QC_NO},
+	{0xBFC0, UNICODE_NORM_QC_NO},
+	{0xBFC1, UNICODE_NORM_QC_NO},
+	{0xBFC2, UNICODE_NORM_QC_NO},
+	{0xBFC3, UNICODE_NORM_QC_NO},
+	{0xBFC4, UNICODE_NORM_QC_NO},
+	{0xBFC5, UNICODE_NORM_QC_NO},
+	{0xBFC6, UNICODE_NORM_QC_NO},
+	{0xBFC7, UNICODE_NORM_QC_NO},
+	{0xBFC8, UNICODE_NORM_QC_NO},
+	{0xBFC9, UNICODE_NORM_QC_NO},
+	{0xBFCA, UNICODE_NORM_QC_NO},
+	{0xBFCB, UNICODE_NORM_QC_NO},
+	{0xBFCC, UNICODE_NORM_QC_NO},
+	{0xBFCD, UNICODE_NORM_QC_NO},
+	{0xBFCE, UNICODE_NORM_QC_NO},
+	{0xBFCF, UNICODE_NORM_QC_NO},
+	{0xBFD0, UNICODE_NORM_QC_NO},
+	{0xBFD1, UNICODE_NORM_QC_NO},
+	{0xBFD2, UNICODE_NORM_QC_NO},
+	{0xBFD3, UNICODE_NORM_QC_NO},
+	{0xBFD4, UNICODE_NORM_QC_NO},
+	{0xBFD5, UNICODE_NORM_QC_NO},
+	{0xBFD6, UNICODE_NORM_QC_NO},
+	{0xBFD7, UNICODE_NORM_QC_NO},
+	{0xBFD8, UNICODE_NORM_QC_NO},
+	{0xBFD9, UNICODE_NORM_QC_NO},
+	{0xBFDA, UNICODE_NORM_QC_NO},
+	{0xBFDB, UNICODE_NORM_QC_NO},
+	{0xBFDC, UNICODE_NORM_QC_NO},
+	{0xBFDD, UNICODE_NORM_QC_NO},
+	{0xBFDE, UNICODE_NORM_QC_NO},
+	{0xBFDF, UNICODE_NORM_QC_NO},
+	{0xBFE0, UNICODE_NORM_QC_NO},
+	{0xBFE1, UNICODE_NORM_QC_NO},
+	{0xBFE2, UNICODE_NORM_QC_NO},
+	{0xBFE3, UNICODE_NORM_QC_NO},
+	{0xBFE4, UNICODE_NORM_QC_NO},
+	{0xBFE5, UNICODE_NORM_QC_NO},
+	{0xBFE6, UNICODE_NORM_QC_NO},
+	{0xBFE7, UNICODE_NORM_QC_NO},
+	{0xBFE8, UNICODE_NORM_QC_NO},
+	{0xBFE9, UNICODE_NORM_QC_NO},
+	{0xBFEA, UNICODE_NORM_QC_NO},
+	{0xBFEB, UNICODE_NORM_QC_NO},
+	{0xBFEC, UNICODE_NORM_QC_NO},
+	{0xBFED, UNICODE_NORM_QC_NO},
+	{0xBFEE, UNICODE_NORM_QC_NO},
+	{0xBFEF, UNICODE_NORM_QC_NO},
+	{0xBFF0, UNICODE_NORM_QC_NO},
+	{0xBFF1, UNICODE_NORM_QC_NO},
+	{0xBFF2, UNICODE_NORM_QC_NO},
+	{0xBFF3, UNICODE_NORM_QC_NO},
+	{0xBFF4, UNICODE_NORM_QC_NO},
+	{0xBFF5, UNICODE_NORM_QC_NO},
+	{0xBFF6, UNICODE_NORM_QC_NO},
+	{0xBFF7, UNICODE_NORM_QC_NO},
+	{0xBFF8, UNICODE_NORM_QC_NO},
+	{0xBFF9, UNICODE_NORM_QC_NO},
+	{0xBFFA, UNICODE_NORM_QC_NO},
+	{0xBFFB, UNICODE_NORM_QC_NO},
+	{0xBFFC, UNICODE_NORM_QC_NO},
+	{0xBFFD, UNICODE_NORM_QC_NO},
+	{0xBFFE, UNICODE_NORM_QC_NO},
+	{0xBFFF, UNICODE_NORM_QC_NO},
+	{0xC000, UNICODE_NORM_QC_NO},
+	{0xC001, UNICODE_NORM_QC_NO},
+	{0xC002, UNICODE_NORM_QC_NO},
+	{0xC003, UNICODE_NORM_QC_NO},
+	{0xC004, UNICODE_NORM_QC_NO},
+	{0xC005, UNICODE_NORM_QC_NO},
+	{0xC006, UNICODE_NORM_QC_NO},
+	{0xC007, UNICODE_NORM_QC_NO},
+	{0xC008, UNICODE_NORM_QC_NO},
+	{0xC009, UNICODE_NORM_QC_NO},
+	{0xC00A, UNICODE_NORM_QC_NO},
+	{0xC00B, UNICODE_NORM_QC_NO},
+	{0xC00C, UNICODE_NORM_QC_NO},
+	{0xC00D, UNICODE_NORM_QC_NO},
+	{0xC00E, UNICODE_NORM_QC_NO},
+	{0xC00F, UNICODE_NORM_QC_NO},
+	{0xC010, UNICODE_NORM_QC_NO},
+	{0xC011, UNICODE_NORM_QC_NO},
+	{0xC012, UNICODE_NORM_QC_NO},
+	{0xC013, UNICODE_NORM_QC_NO},
+	{0xC014, UNICODE_NORM_QC_NO},
+	{0xC015, UNICODE_NORM_QC_NO},
+	{0xC016, UNICODE_NORM_QC_NO},
+	{0xC017, UNICODE_NORM_QC_NO},
+	{0xC018, UNICODE_NORM_QC_NO},
+	{0xC019, UNICODE_NORM_QC_NO},
+	{0xC01A, UNICODE_NORM_QC_NO},
+	{0xC01B, UNICODE_NORM_QC_NO},
+	{0xC01C, UNICODE_NORM_QC_NO},
+	{0xC01D, UNICODE_NORM_QC_NO},
+	{0xC01E, UNICODE_NORM_QC_NO},
+	{0xC01F, UNICODE_NORM_QC_NO},
+	{0xC020, UNICODE_NORM_QC_NO},
+	{0xC021, UNICODE_NORM_QC_NO},
+	{0xC022, UNICODE_NORM_QC_NO},
+	{0xC023, UNICODE_NORM_QC_NO},
+	{0xC024, UNICODE_NORM_QC_NO},
+	{0xC025, UNICODE_NORM_QC_NO},
+	{0xC026, UNICODE_NORM_QC_NO},
+	{0xC027, UNICODE_NORM_QC_NO},
+	{0xC028, UNICODE_NORM_QC_NO},
+	{0xC029, UNICODE_NORM_QC_NO},
+	{0xC02A, UNICODE_NORM_QC_NO},
+	{0xC02B, UNICODE_NORM_QC_NO},
+	{0xC02C, UNICODE_NORM_QC_NO},
+	{0xC02D, UNICODE_NORM_QC_NO},
+	{0xC02E, UNICODE_NORM_QC_NO},
+	{0xC02F, UNICODE_NORM_QC_NO},
+	{0xC030, UNICODE_NORM_QC_NO},
+	{0xC031, UNICODE_NORM_QC_NO},
+	{0xC032, UNICODE_NORM_QC_NO},
+	{0xC033, UNICODE_NORM_QC_NO},
+	{0xC034, UNICODE_NORM_QC_NO},
+	{0xC035, UNICODE_NORM_QC_NO},
+	{0xC036, UNICODE_NORM_QC_NO},
+	{0xC037, UNICODE_NORM_QC_NO},
+	{0xC038, UNICODE_NORM_QC_NO},
+	{0xC039, UNICODE_NORM_QC_NO},
+	{0xC03A, UNICODE_NORM_QC_NO},
+	{0xC03B, UNICODE_NORM_QC_NO},
+	{0xC03C, UNICODE_NORM_QC_NO},
+	{0xC03D, UNICODE_NORM_QC_NO},
+	{0xC03E, UNICODE_NORM_QC_NO},
+	{0xC03F, UNICODE_NORM_QC_NO},
+	{0xC040, UNICODE_NORM_QC_NO},
+	{0xC041, UNICODE_NORM_QC_NO},
+	{0xC042, UNICODE_NORM_QC_NO},
+	{0xC043, UNICODE_NORM_QC_NO},
+	{0xC044, UNICODE_NORM_QC_NO},
+	{0xC045, UNICODE_NORM_QC_NO},
+	{0xC046, UNICODE_NORM_QC_NO},
+	{0xC047, UNICODE_NORM_QC_NO},
+	{0xC048, UNICODE_NORM_QC_NO},
+	{0xC049, UNICODE_NORM_QC_NO},
+	{0xC04A, UNICODE_NORM_QC_NO},
+	{0xC04B, UNICODE_NORM_QC_NO},
+	{0xC04C, UNICODE_NORM_QC_NO},
+	{0xC04D, UNICODE_NORM_QC_NO},
+	{0xC04E, UNICODE_NORM_QC_NO},
+	{0xC04F, UNICODE_NORM_QC_NO},
+	{0xC050, UNICODE_NORM_QC_NO},
+	{0xC051, UNICODE_NORM_QC_NO},
+	{0xC052, UNICODE_NORM_QC_NO},
+	{0xC053, UNICODE_NORM_QC_NO},
+	{0xC054, UNICODE_NORM_QC_NO},
+	{0xC055, UNICODE_NORM_QC_NO},
+	{0xC056, UNICODE_NORM_QC_NO},
+	{0xC057, UNICODE_NORM_QC_NO},
+	{0xC058, UNICODE_NORM_QC_NO},
+	{0xC059, UNICODE_NORM_QC_NO},
+	{0xC05A, UNICODE_NORM_QC_NO},
+	{0xC05B, UNICODE_NORM_QC_NO},
+	{0xC05C, UNICODE_NORM_QC_NO},
+	{0xC05D, UNICODE_NORM_QC_NO},
+	{0xC05E, UNICODE_NORM_QC_NO},
+	{0xC05F, UNICODE_NORM_QC_NO},
+	{0xC060, UNICODE_NORM_QC_NO},
+	{0xC061, UNICODE_NORM_QC_NO},
+	{0xC062, UNICODE_NORM_QC_NO},
+	{0xC063, UNICODE_NORM_QC_NO},
+	{0xC064, UNICODE_NORM_QC_NO},
+	{0xC065, UNICODE_NORM_QC_NO},
+	{0xC066, UNICODE_NORM_QC_NO},
+	{0xC067, UNICODE_NORM_QC_NO},
+	{0xC068, UNICODE_NORM_QC_NO},
+	{0xC069, UNICODE_NORM_QC_NO},
+	{0xC06A, UNICODE_NORM_QC_NO},
+	{0xC06B, UNICODE_NORM_QC_NO},
+	{0xC06C, UNICODE_NORM_QC_NO},
+	{0xC06D, UNICODE_NORM_QC_NO},
+	{0xC06E, UNICODE_NORM_QC_NO},
+	{0xC06F, UNICODE_NORM_QC_NO},
+	{0xC070, UNICODE_NORM_QC_NO},
+	{0xC071, UNICODE_NORM_QC_NO},
+	{0xC072, UNICODE_NORM_QC_NO},
+	{0xC073, UNICODE_NORM_QC_NO},
+	{0xC074, UNICODE_NORM_QC_NO},
+	{0xC075, UNICODE_NORM_QC_NO},
+	{0xC076, UNICODE_NORM_QC_NO},
+	{0xC077, UNICODE_NORM_QC_NO},
+	{0xC078, UNICODE_NORM_QC_NO},
+	{0xC079, UNICODE_NORM_QC_NO},
+	{0xC07A, UNICODE_NORM_QC_NO},
+	{0xC07B, UNICODE_NORM_QC_NO},
+	{0xC07C, UNICODE_NORM_QC_NO},
+	{0xC07D, UNICODE_NORM_QC_NO},
+	{0xC07E, UNICODE_NORM_QC_NO},
+	{0xC07F, UNICODE_NORM_QC_NO},
+	{0xC080, UNICODE_NORM_QC_NO},
+	{0xC081, UNICODE_NORM_QC_NO},
+	{0xC082, UNICODE_NORM_QC_NO},
+	{0xC083, UNICODE_NORM_QC_NO},
+	{0xC084, UNICODE_NORM_QC_NO},
+	{0xC085, UNICODE_NORM_QC_NO},
+	{0xC086, UNICODE_NORM_QC_NO},
+	{0xC087, UNICODE_NORM_QC_NO},
+	{0xC088, UNICODE_NORM_QC_NO},
+	{0xC089, UNICODE_NORM_QC_NO},
+	{0xC08A, UNICODE_NORM_QC_NO},
+	{0xC08B, UNICODE_NORM_QC_NO},
+	{0xC08C, UNICODE_NORM_QC_NO},
+	{0xC08D, UNICODE_NORM_QC_NO},
+	{0xC08E, UNICODE_NORM_QC_NO},
+	{0xC08F, UNICODE_NORM_QC_NO},
+	{0xC090, UNICODE_NORM_QC_NO},
+	{0xC091, UNICODE_NORM_QC_NO},
+	{0xC092, UNICODE_NORM_QC_NO},
+	{0xC093, UNICODE_NORM_QC_NO},
+	{0xC094, UNICODE_NORM_QC_NO},
+	{0xC095, UNICODE_NORM_QC_NO},
+	{0xC096, UNICODE_NORM_QC_NO},
+	{0xC097, UNICODE_NORM_QC_NO},
+	{0xC098, UNICODE_NORM_QC_NO},
+	{0xC099, UNICODE_NORM_QC_NO},
+	{0xC09A, UNICODE_NORM_QC_NO},
+	{0xC09B, UNICODE_NORM_QC_NO},
+	{0xC09C, UNICODE_NORM_QC_NO},
+	{0xC09D, UNICODE_NORM_QC_NO},
+	{0xC09E, UNICODE_NORM_QC_NO},
+	{0xC09F, UNICODE_NORM_QC_NO},
+	{0xC0A0, UNICODE_NORM_QC_NO},
+	{0xC0A1, UNICODE_NORM_QC_NO},
+	{0xC0A2, UNICODE_NORM_QC_NO},
+	{0xC0A3, UNICODE_NORM_QC_NO},
+	{0xC0A4, UNICODE_NORM_QC_NO},
+	{0xC0A5, UNICODE_NORM_QC_NO},
+	{0xC0A6, UNICODE_NORM_QC_NO},
+	{0xC0A7, UNICODE_NORM_QC_NO},
+	{0xC0A8, UNICODE_NORM_QC_NO},
+	{0xC0A9, UNICODE_NORM_QC_NO},
+	{0xC0AA, UNICODE_NORM_QC_NO},
+	{0xC0AB, UNICODE_NORM_QC_NO},
+	{0xC0AC, UNICODE_NORM_QC_NO},
+	{0xC0AD, UNICODE_NORM_QC_NO},
+	{0xC0AE, UNICODE_NORM_QC_NO},
+	{0xC0AF, UNICODE_NORM_QC_NO},
+	{0xC0B0, UNICODE_NORM_QC_NO},
+	{0xC0B1, UNICODE_NORM_QC_NO},
+	{0xC0B2, UNICODE_NORM_QC_NO},
+	{0xC0B3, UNICODE_NORM_QC_NO},
+	{0xC0B4, UNICODE_NORM_QC_NO},
+	{0xC0B5, UNICODE_NORM_QC_NO},
+	{0xC0B6, UNICODE_NORM_QC_NO},
+	{0xC0B7, UNICODE_NORM_QC_NO},
+	{0xC0B8, UNICODE_NORM_QC_NO},
+	{0xC0B9, UNICODE_NORM_QC_NO},
+	{0xC0BA, UNICODE_NORM_QC_NO},
+	{0xC0BB, UNICODE_NORM_QC_NO},
+	{0xC0BC, UNICODE_NORM_QC_NO},
+	{0xC0BD, UNICODE_NORM_QC_NO},
+	{0xC0BE, UNICODE_NORM_QC_NO},
+	{0xC0BF, UNICODE_NORM_QC_NO},
+	{0xC0C0, UNICODE_NORM_QC_NO},
+	{0xC0C1, UNICODE_NORM_QC_NO},
+	{0xC0C2, UNICODE_NORM_QC_NO},
+	{0xC0C3, UNICODE_NORM_QC_NO},
+	{0xC0C4, UNICODE_NORM_QC_NO},
+	{0xC0C5, UNICODE_NORM_QC_NO},
+	{0xC0C6, UNICODE_NORM_QC_NO},
+	{0xC0C7, UNICODE_NORM_QC_NO},
+	{0xC0C8, UNICODE_NORM_QC_NO},
+	{0xC0C9, UNICODE_NORM_QC_NO},
+	{0xC0CA, UNICODE_NORM_QC_NO},
+	{0xC0CB, UNICODE_NORM_QC_NO},
+	{0xC0CC, UNICODE_NORM_QC_NO},
+	{0xC0CD, UNICODE_NORM_QC_NO},
+	{0xC0CE, UNICODE_NORM_QC_NO},
+	{0xC0CF, UNICODE_NORM_QC_NO},
+	{0xC0D0, UNICODE_NORM_QC_NO},
+	{0xC0D1, UNICODE_NORM_QC_NO},
+	{0xC0D2, UNICODE_NORM_QC_NO},
+	{0xC0D3, UNICODE_NORM_QC_NO},
+	{0xC0D4, UNICODE_NORM_QC_NO},
+	{0xC0D5, UNICODE_NORM_QC_NO},
+	{0xC0D6, UNICODE_NORM_QC_NO},
+	{0xC0D7, UNICODE_NORM_QC_NO},
+	{0xC0D8, UNICODE_NORM_QC_NO},
+	{0xC0D9, UNICODE_NORM_QC_NO},
+	{0xC0DA, UNICODE_NORM_QC_NO},
+	{0xC0DB, UNICODE_NORM_QC_NO},
+	{0xC0DC, UNICODE_NORM_QC_NO},
+	{0xC0DD, UNICODE_NORM_QC_NO},
+	{0xC0DE, UNICODE_NORM_QC_NO},
+	{0xC0DF, UNICODE_NORM_QC_NO},
+	{0xC0E0, UNICODE_NORM_QC_NO},
+	{0xC0E1, UNICODE_NORM_QC_NO},
+	{0xC0E2, UNICODE_NORM_QC_NO},
+	{0xC0E3, UNICODE_NORM_QC_NO},
+	{0xC0E4, UNICODE_NORM_QC_NO},
+	{0xC0E5, UNICODE_NORM_QC_NO},
+	{0xC0E6, UNICODE_NORM_QC_NO},
+	{0xC0E7, UNICODE_NORM_QC_NO},
+	{0xC0E8, UNICODE_NORM_QC_NO},
+	{0xC0E9, UNICODE_NORM_QC_NO},
+	{0xC0EA, UNICODE_NORM_QC_NO},
+	{0xC0EB, UNICODE_NORM_QC_NO},
+	{0xC0EC, UNICODE_NORM_QC_NO},
+	{0xC0ED, UNICODE_NORM_QC_NO},
+	{0xC0EE, UNICODE_NORM_QC_NO},
+	{0xC0EF, UNICODE_NORM_QC_NO},
+	{0xC0F0, UNICODE_NORM_QC_NO},
+	{0xC0F1, UNICODE_NORM_QC_NO},
+	{0xC0F2, UNICODE_NORM_QC_NO},
+	{0xC0F3, UNICODE_NORM_QC_NO},
+	{0xC0F4, UNICODE_NORM_QC_NO},
+	{0xC0F5, UNICODE_NORM_QC_NO},
+	{0xC0F6, UNICODE_NORM_QC_NO},
+	{0xC0F7, UNICODE_NORM_QC_NO},
+	{0xC0F8, UNICODE_NORM_QC_NO},
+	{0xC0F9, UNICODE_NORM_QC_NO},
+	{0xC0FA, UNICODE_NORM_QC_NO},
+	{0xC0FB, UNICODE_NORM_QC_NO},
+	{0xC0FC, UNICODE_NORM_QC_NO},
+	{0xC0FD, UNICODE_NORM_QC_NO},
+	{0xC0FE, UNICODE_NORM_QC_NO},
+	{0xC0FF, UNICODE_NORM_QC_NO},
+	{0xC100, UNICODE_NORM_QC_NO},
+	{0xC101, UNICODE_NORM_QC_NO},
+	{0xC102, UNICODE_NORM_QC_NO},
+	{0xC103, UNICODE_NORM_QC_NO},
+	{0xC104, UNICODE_NORM_QC_NO},
+	{0xC105, UNICODE_NORM_QC_NO},
+	{0xC106, UNICODE_NORM_QC_NO},
+	{0xC107, UNICODE_NORM_QC_NO},
+	{0xC108, UNICODE_NORM_QC_NO},
+	{0xC109, UNICODE_NORM_QC_NO},
+	{0xC10A, UNICODE_NORM_QC_NO},
+	{0xC10B, UNICODE_NORM_QC_NO},
+	{0xC10C, UNICODE_NORM_QC_NO},
+	{0xC10D, UNICODE_NORM_QC_NO},
+	{0xC10E, UNICODE_NORM_QC_NO},
+	{0xC10F, UNICODE_NORM_QC_NO},
+	{0xC110, UNICODE_NORM_QC_NO},
+	{0xC111, UNICODE_NORM_QC_NO},
+	{0xC112, UNICODE_NORM_QC_NO},
+	{0xC113, UNICODE_NORM_QC_NO},
+	{0xC114, UNICODE_NORM_QC_NO},
+	{0xC115, UNICODE_NORM_QC_NO},
+	{0xC116, UNICODE_NORM_QC_NO},
+	{0xC117, UNICODE_NORM_QC_NO},
+	{0xC118, UNICODE_NORM_QC_NO},
+	{0xC119, UNICODE_NORM_QC_NO},
+	{0xC11A, UNICODE_NORM_QC_NO},
+	{0xC11B, UNICODE_NORM_QC_NO},
+	{0xC11C, UNICODE_NORM_QC_NO},
+	{0xC11D, UNICODE_NORM_QC_NO},
+	{0xC11E, UNICODE_NORM_QC_NO},
+	{0xC11F, UNICODE_NORM_QC_NO},
+	{0xC120, UNICODE_NORM_QC_NO},
+	{0xC121, UNICODE_NORM_QC_NO},
+	{0xC122, UNICODE_NORM_QC_NO},
+	{0xC123, UNICODE_NORM_QC_NO},
+	{0xC124, UNICODE_NORM_QC_NO},
+	{0xC125, UNICODE_NORM_QC_NO},
+	{0xC126, UNICODE_NORM_QC_NO},
+	{0xC127, UNICODE_NORM_QC_NO},
+	{0xC128, UNICODE_NORM_QC_NO},
+	{0xC129, UNICODE_NORM_QC_NO},
+	{0xC12A, UNICODE_NORM_QC_NO},
+	{0xC12B, UNICODE_NORM_QC_NO},
+	{0xC12C, UNICODE_NORM_QC_NO},
+	{0xC12D, UNICODE_NORM_QC_NO},
+	{0xC12E, UNICODE_NORM_QC_NO},
+	{0xC12F, UNICODE_NORM_QC_NO},
+	{0xC130, UNICODE_NORM_QC_NO},
+	{0xC131, UNICODE_NORM_QC_NO},
+	{0xC132, UNICODE_NORM_QC_NO},
+	{0xC133, UNICODE_NORM_QC_NO},
+	{0xC134, UNICODE_NORM_QC_NO},
+	{0xC135, UNICODE_NORM_QC_NO},
+	{0xC136, UNICODE_NORM_QC_NO},
+	{0xC137, UNICODE_NORM_QC_NO},
+	{0xC138, UNICODE_NORM_QC_NO},
+	{0xC139, UNICODE_NORM_QC_NO},
+	{0xC13A, UNICODE_NORM_QC_NO},
+	{0xC13B, UNICODE_NORM_QC_NO},
+	{0xC13C, UNICODE_NORM_QC_NO},
+	{0xC13D, UNICODE_NORM_QC_NO},
+	{0xC13E, UNICODE_NORM_QC_NO},
+	{0xC13F, UNICODE_NORM_QC_NO},
+	{0xC140, UNICODE_NORM_QC_NO},
+	{0xC141, UNICODE_NORM_QC_NO},
+	{0xC142, UNICODE_NORM_QC_NO},
+	{0xC143, UNICODE_NORM_QC_NO},
+	{0xC144, UNICODE_NORM_QC_NO},
+	{0xC145, UNICODE_NORM_QC_NO},
+	{0xC146, UNICODE_NORM_QC_NO},
+	{0xC147, UNICODE_NORM_QC_NO},
+	{0xC148, UNICODE_NORM_QC_NO},
+	{0xC149, UNICODE_NORM_QC_NO},
+	{0xC14A, UNICODE_NORM_QC_NO},
+	{0xC14B, UNICODE_NORM_QC_NO},
+	{0xC14C, UNICODE_NORM_QC_NO},
+	{0xC14D, UNICODE_NORM_QC_NO},
+	{0xC14E, UNICODE_NORM_QC_NO},
+	{0xC14F, UNICODE_NORM_QC_NO},
+	{0xC150, UNICODE_NORM_QC_NO},
+	{0xC151, UNICODE_NORM_QC_NO},
+	{0xC152, UNICODE_NORM_QC_NO},
+	{0xC153, UNICODE_NORM_QC_NO},
+	{0xC154, UNICODE_NORM_QC_NO},
+	{0xC155, UNICODE_NORM_QC_NO},
+	{0xC156, UNICODE_NORM_QC_NO},
+	{0xC157, UNICODE_NORM_QC_NO},
+	{0xC158, UNICODE_NORM_QC_NO},
+	{0xC159, UNICODE_NORM_QC_NO},
+	{0xC15A, UNICODE_NORM_QC_NO},
+	{0xC15B, UNICODE_NORM_QC_NO},
+	{0xC15C, UNICODE_NORM_QC_NO},
+	{0xC15D, UNICODE_NORM_QC_NO},
+	{0xC15E, UNICODE_NORM_QC_NO},
+	{0xC15F, UNICODE_NORM_QC_NO},
+	{0xC160, UNICODE_NORM_QC_NO},
+	{0xC161, UNICODE_NORM_QC_NO},
+	{0xC162, UNICODE_NORM_QC_NO},
+	{0xC163, UNICODE_NORM_QC_NO},
+	{0xC164, UNICODE_NORM_QC_NO},
+	{0xC165, UNICODE_NORM_QC_NO},
+	{0xC166, UNICODE_NORM_QC_NO},
+	{0xC167, UNICODE_NORM_QC_NO},
+	{0xC168, UNICODE_NORM_QC_NO},
+	{0xC169, UNICODE_NORM_QC_NO},
+	{0xC16A, UNICODE_NORM_QC_NO},
+	{0xC16B, UNICODE_NORM_QC_NO},
+	{0xC16C, UNICODE_NORM_QC_NO},
+	{0xC16D, UNICODE_NORM_QC_NO},
+	{0xC16E, UNICODE_NORM_QC_NO},
+	{0xC16F, UNICODE_NORM_QC_NO},
+	{0xC170, UNICODE_NORM_QC_NO},
+	{0xC171, UNICODE_NORM_QC_NO},
+	{0xC172, UNICODE_NORM_QC_NO},
+	{0xC173, UNICODE_NORM_QC_NO},
+	{0xC174, UNICODE_NORM_QC_NO},
+	{0xC175, UNICODE_NORM_QC_NO},
+	{0xC176, UNICODE_NORM_QC_NO},
+	{0xC177, UNICODE_NORM_QC_NO},
+	{0xC178, UNICODE_NORM_QC_NO},
+	{0xC179, UNICODE_NORM_QC_NO},
+	{0xC17A, UNICODE_NORM_QC_NO},
+	{0xC17B, UNICODE_NORM_QC_NO},
+	{0xC17C, UNICODE_NORM_QC_NO},
+	{0xC17D, UNICODE_NORM_QC_NO},
+	{0xC17E, UNICODE_NORM_QC_NO},
+	{0xC17F, UNICODE_NORM_QC_NO},
+	{0xC180, UNICODE_NORM_QC_NO},
+	{0xC181, UNICODE_NORM_QC_NO},
+	{0xC182, UNICODE_NORM_QC_NO},
+	{0xC183, UNICODE_NORM_QC_NO},
+	{0xC184, UNICODE_NORM_QC_NO},
+	{0xC185, UNICODE_NORM_QC_NO},
+	{0xC186, UNICODE_NORM_QC_NO},
+	{0xC187, UNICODE_NORM_QC_NO},
+	{0xC188, UNICODE_NORM_QC_NO},
+	{0xC189, UNICODE_NORM_QC_NO},
+	{0xC18A, UNICODE_NORM_QC_NO},
+	{0xC18B, UNICODE_NORM_QC_NO},
+	{0xC18C, UNICODE_NORM_QC_NO},
+	{0xC18D, UNICODE_NORM_QC_NO},
+	{0xC18E, UNICODE_NORM_QC_NO},
+	{0xC18F, UNICODE_NORM_QC_NO},
+	{0xC190, UNICODE_NORM_QC_NO},
+	{0xC191, UNICODE_NORM_QC_NO},
+	{0xC192, UNICODE_NORM_QC_NO},
+	{0xC193, UNICODE_NORM_QC_NO},
+	{0xC194, UNICODE_NORM_QC_NO},
+	{0xC195, UNICODE_NORM_QC_NO},
+	{0xC196, UNICODE_NORM_QC_NO},
+	{0xC197, UNICODE_NORM_QC_NO},
+	{0xC198, UNICODE_NORM_QC_NO},
+	{0xC199, UNICODE_NORM_QC_NO},
+	{0xC19A, UNICODE_NORM_QC_NO},
+	{0xC19B, UNICODE_NORM_QC_NO},
+	{0xC19C, UNICODE_NORM_QC_NO},
+	{0xC19D, UNICODE_NORM_QC_NO},
+	{0xC19E, UNICODE_NORM_QC_NO},
+	{0xC19F, UNICODE_NORM_QC_NO},
+	{0xC1A0, UNICODE_NORM_QC_NO},
+	{0xC1A1, UNICODE_NORM_QC_NO},
+	{0xC1A2, UNICODE_NORM_QC_NO},
+	{0xC1A3, UNICODE_NORM_QC_NO},
+	{0xC1A4, UNICODE_NORM_QC_NO},
+	{0xC1A5, UNICODE_NORM_QC_NO},
+	{0xC1A6, UNICODE_NORM_QC_NO},
+	{0xC1A7, UNICODE_NORM_QC_NO},
+	{0xC1A8, UNICODE_NORM_QC_NO},
+	{0xC1A9, UNICODE_NORM_QC_NO},
+	{0xC1AA, UNICODE_NORM_QC_NO},
+	{0xC1AB, UNICODE_NORM_QC_NO},
+	{0xC1AC, UNICODE_NORM_QC_NO},
+	{0xC1AD, UNICODE_NORM_QC_NO},
+	{0xC1AE, UNICODE_NORM_QC_NO},
+	{0xC1AF, UNICODE_NORM_QC_NO},
+	{0xC1B0, UNICODE_NORM_QC_NO},
+	{0xC1B1, UNICODE_NORM_QC_NO},
+	{0xC1B2, UNICODE_NORM_QC_NO},
+	{0xC1B3, UNICODE_NORM_QC_NO},
+	{0xC1B4, UNICODE_NORM_QC_NO},
+	{0xC1B5, UNICODE_NORM_QC_NO},
+	{0xC1B6, UNICODE_NORM_QC_NO},
+	{0xC1B7, UNICODE_NORM_QC_NO},
+	{0xC1B8, UNICODE_NORM_QC_NO},
+	{0xC1B9, UNICODE_NORM_QC_NO},
+	{0xC1BA, UNICODE_NORM_QC_NO},
+	{0xC1BB, UNICODE_NORM_QC_NO},
+	{0xC1BC, UNICODE_NORM_QC_NO},
+	{0xC1BD, UNICODE_NORM_QC_NO},
+	{0xC1BE, UNICODE_NORM_QC_NO},
+	{0xC1BF, UNICODE_NORM_QC_NO},
+	{0xC1C0, UNICODE_NORM_QC_NO},
+	{0xC1C1, UNICODE_NORM_QC_NO},
+	{0xC1C2, UNICODE_NORM_QC_NO},
+	{0xC1C3, UNICODE_NORM_QC_NO},
+	{0xC1C4, UNICODE_NORM_QC_NO},
+	{0xC1C5, UNICODE_NORM_QC_NO},
+	{0xC1C6, UNICODE_NORM_QC_NO},
+	{0xC1C7, UNICODE_NORM_QC_NO},
+	{0xC1C8, UNICODE_NORM_QC_NO},
+	{0xC1C9, UNICODE_NORM_QC_NO},
+	{0xC1CA, UNICODE_NORM_QC_NO},
+	{0xC1CB, UNICODE_NORM_QC_NO},
+	{0xC1CC, UNICODE_NORM_QC_NO},
+	{0xC1CD, UNICODE_NORM_QC_NO},
+	{0xC1CE, UNICODE_NORM_QC_NO},
+	{0xC1CF, UNICODE_NORM_QC_NO},
+	{0xC1D0, UNICODE_NORM_QC_NO},
+	{0xC1D1, UNICODE_NORM_QC_NO},
+	{0xC1D2, UNICODE_NORM_QC_NO},
+	{0xC1D3, UNICODE_NORM_QC_NO},
+	{0xC1D4, UNICODE_NORM_QC_NO},
+	{0xC1D5, UNICODE_NORM_QC_NO},
+	{0xC1D6, UNICODE_NORM_QC_NO},
+	{0xC1D7, UNICODE_NORM_QC_NO},
+	{0xC1D8, UNICODE_NORM_QC_NO},
+	{0xC1D9, UNICODE_NORM_QC_NO},
+	{0xC1DA, UNICODE_NORM_QC_NO},
+	{0xC1DB, UNICODE_NORM_QC_NO},
+	{0xC1DC, UNICODE_NORM_QC_NO},
+	{0xC1DD, UNICODE_NORM_QC_NO},
+	{0xC1DE, UNICODE_NORM_QC_NO},
+	{0xC1DF, UNICODE_NORM_QC_NO},
+	{0xC1E0, UNICODE_NORM_QC_NO},
+	{0xC1E1, UNICODE_NORM_QC_NO},
+	{0xC1E2, UNICODE_NORM_QC_NO},
+	{0xC1E3, UNICODE_NORM_QC_NO},
+	{0xC1E4, UNICODE_NORM_QC_NO},
+	{0xC1E5, UNICODE_NORM_QC_NO},
+	{0xC1E6, UNICODE_NORM_QC_NO},
+	{0xC1E7, UNICODE_NORM_QC_NO},
+	{0xC1E8, UNICODE_NORM_QC_NO},
+	{0xC1E9, UNICODE_NORM_QC_NO},
+	{0xC1EA, UNICODE_NORM_QC_NO},
+	{0xC1EB, UNICODE_NORM_QC_NO},
+	{0xC1EC, UNICODE_NORM_QC_NO},
+	{0xC1ED, UNICODE_NORM_QC_NO},
+	{0xC1EE, UNICODE_NORM_QC_NO},
+	{0xC1EF, UNICODE_NORM_QC_NO},
+	{0xC1F0, UNICODE_NORM_QC_NO},
+	{0xC1F1, UNICODE_NORM_QC_NO},
+	{0xC1F2, UNICODE_NORM_QC_NO},
+	{0xC1F3, UNICODE_NORM_QC_NO},
+	{0xC1F4, UNICODE_NORM_QC_NO},
+	{0xC1F5, UNICODE_NORM_QC_NO},
+	{0xC1F6, UNICODE_NORM_QC_NO},
+	{0xC1F7, UNICODE_NORM_QC_NO},
+	{0xC1F8, UNICODE_NORM_QC_NO},
+	{0xC1F9, UNICODE_NORM_QC_NO},
+	{0xC1FA, UNICODE_NORM_QC_NO},
+	{0xC1FB, UNICODE_NORM_QC_NO},
+	{0xC1FC, UNICODE_NORM_QC_NO},
+	{0xC1FD, UNICODE_NORM_QC_NO},
+	{0xC1FE, UNICODE_NORM_QC_NO},
+	{0xC1FF, UNICODE_NORM_QC_NO},
+	{0xC200, UNICODE_NORM_QC_NO},
+	{0xC201, UNICODE_NORM_QC_NO},
+	{0xC202, UNICODE_NORM_QC_NO},
+	{0xC203, UNICODE_NORM_QC_NO},
+	{0xC204, UNICODE_NORM_QC_NO},
+	{0xC205, UNICODE_NORM_QC_NO},
+	{0xC206, UNICODE_NORM_QC_NO},
+	{0xC207, UNICODE_NORM_QC_NO},
+	{0xC208, UNICODE_NORM_QC_NO},
+	{0xC209, UNICODE_NORM_QC_NO},
+	{0xC20A, UNICODE_NORM_QC_NO},
+	{0xC20B, UNICODE_NORM_QC_NO},
+	{0xC20C, UNICODE_NORM_QC_NO},
+	{0xC20D, UNICODE_NORM_QC_NO},
+	{0xC20E, UNICODE_NORM_QC_NO},
+	{0xC20F, UNICODE_NORM_QC_NO},
+	{0xC210, UNICODE_NORM_QC_NO},
+	{0xC211, UNICODE_NORM_QC_NO},
+	{0xC212, UNICODE_NORM_QC_NO},
+	{0xC213, UNICODE_NORM_QC_NO},
+	{0xC214, UNICODE_NORM_QC_NO},
+	{0xC215, UNICODE_NORM_QC_NO},
+	{0xC216, UNICODE_NORM_QC_NO},
+	{0xC217, UNICODE_NORM_QC_NO},
+	{0xC218, UNICODE_NORM_QC_NO},
+	{0xC219, UNICODE_NORM_QC_NO},
+	{0xC21A, UNICODE_NORM_QC_NO},
+	{0xC21B, UNICODE_NORM_QC_NO},
+	{0xC21C, UNICODE_NORM_QC_NO},
+	{0xC21D, UNICODE_NORM_QC_NO},
+	{0xC21E, UNICODE_NORM_QC_NO},
+	{0xC21F, UNICODE_NORM_QC_NO},
+	{0xC220, UNICODE_NORM_QC_NO},
+	{0xC221, UNICODE_NORM_QC_NO},
+	{0xC222, UNICODE_NORM_QC_NO},
+	{0xC223, UNICODE_NORM_QC_NO},
+	{0xC224, UNICODE_NORM_QC_NO},
+	{0xC225, UNICODE_NORM_QC_NO},
+	{0xC226, UNICODE_NORM_QC_NO},
+	{0xC227, UNICODE_NORM_QC_NO},
+	{0xC228, UNICODE_NORM_QC_NO},
+	{0xC229, UNICODE_NORM_QC_NO},
+	{0xC22A, UNICODE_NORM_QC_NO},
+	{0xC22B, UNICODE_NORM_QC_NO},
+	{0xC22C, UNICODE_NORM_QC_NO},
+	{0xC22D, UNICODE_NORM_QC_NO},
+	{0xC22E, UNICODE_NORM_QC_NO},
+	{0xC22F, UNICODE_NORM_QC_NO},
+	{0xC230, UNICODE_NORM_QC_NO},
+	{0xC231, UNICODE_NORM_QC_NO},
+	{0xC232, UNICODE_NORM_QC_NO},
+	{0xC233, UNICODE_NORM_QC_NO},
+	{0xC234, UNICODE_NORM_QC_NO},
+	{0xC235, UNICODE_NORM_QC_NO},
+	{0xC236, UNICODE_NORM_QC_NO},
+	{0xC237, UNICODE_NORM_QC_NO},
+	{0xC238, UNICODE_NORM_QC_NO},
+	{0xC239, UNICODE_NORM_QC_NO},
+	{0xC23A, UNICODE_NORM_QC_NO},
+	{0xC23B, UNICODE_NORM_QC_NO},
+	{0xC23C, UNICODE_NORM_QC_NO},
+	{0xC23D, UNICODE_NORM_QC_NO},
+	{0xC23E, UNICODE_NORM_QC_NO},
+	{0xC23F, UNICODE_NORM_QC_NO},
+	{0xC240, UNICODE_NORM_QC_NO},
+	{0xC241, UNICODE_NORM_QC_NO},
+	{0xC242, UNICODE_NORM_QC_NO},
+	{0xC243, UNICODE_NORM_QC_NO},
+	{0xC244, UNICODE_NORM_QC_NO},
+	{0xC245, UNICODE_NORM_QC_NO},
+	{0xC246, UNICODE_NORM_QC_NO},
+	{0xC247, UNICODE_NORM_QC_NO},
+	{0xC248, UNICODE_NORM_QC_NO},
+	{0xC249, UNICODE_NORM_QC_NO},
+	{0xC24A, UNICODE_NORM_QC_NO},
+	{0xC24B, UNICODE_NORM_QC_NO},
+	{0xC24C, UNICODE_NORM_QC_NO},
+	{0xC24D, UNICODE_NORM_QC_NO},
+	{0xC24E, UNICODE_NORM_QC_NO},
+	{0xC24F, UNICODE_NORM_QC_NO},
+	{0xC250, UNICODE_NORM_QC_NO},
+	{0xC251, UNICODE_NORM_QC_NO},
+	{0xC252, UNICODE_NORM_QC_NO},
+	{0xC253, UNICODE_NORM_QC_NO},
+	{0xC254, UNICODE_NORM_QC_NO},
+	{0xC255, UNICODE_NORM_QC_NO},
+	{0xC256, UNICODE_NORM_QC_NO},
+	{0xC257, UNICODE_NORM_QC_NO},
+	{0xC258, UNICODE_NORM_QC_NO},
+	{0xC259, UNICODE_NORM_QC_NO},
+	{0xC25A, UNICODE_NORM_QC_NO},
+	{0xC25B, UNICODE_NORM_QC_NO},
+	{0xC25C, UNICODE_NORM_QC_NO},
+	{0xC25D, UNICODE_NORM_QC_NO},
+	{0xC25E, UNICODE_NORM_QC_NO},
+	{0xC25F, UNICODE_NORM_QC_NO},
+	{0xC260, UNICODE_NORM_QC_NO},
+	{0xC261, UNICODE_NORM_QC_NO},
+	{0xC262, UNICODE_NORM_QC_NO},
+	{0xC263, UNICODE_NORM_QC_NO},
+	{0xC264, UNICODE_NORM_QC_NO},
+	{0xC265, UNICODE_NORM_QC_NO},
+	{0xC266, UNICODE_NORM_QC_NO},
+	{0xC267, UNICODE_NORM_QC_NO},
+	{0xC268, UNICODE_NORM_QC_NO},
+	{0xC269, UNICODE_NORM_QC_NO},
+	{0xC26A, UNICODE_NORM_QC_NO},
+	{0xC26B, UNICODE_NORM_QC_NO},
+	{0xC26C, UNICODE_NORM_QC_NO},
+	{0xC26D, UNICODE_NORM_QC_NO},
+	{0xC26E, UNICODE_NORM_QC_NO},
+	{0xC26F, UNICODE_NORM_QC_NO},
+	{0xC270, UNICODE_NORM_QC_NO},
+	{0xC271, UNICODE_NORM_QC_NO},
+	{0xC272, UNICODE_NORM_QC_NO},
+	{0xC273, UNICODE_NORM_QC_NO},
+	{0xC274, UNICODE_NORM_QC_NO},
+	{0xC275, UNICODE_NORM_QC_NO},
+	{0xC276, UNICODE_NORM_QC_NO},
+	{0xC277, UNICODE_NORM_QC_NO},
+	{0xC278, UNICODE_NORM_QC_NO},
+	{0xC279, UNICODE_NORM_QC_NO},
+	{0xC27A, UNICODE_NORM_QC_NO},
+	{0xC27B, UNICODE_NORM_QC_NO},
+	{0xC27C, UNICODE_NORM_QC_NO},
+	{0xC27D, UNICODE_NORM_QC_NO},
+	{0xC27E, UNICODE_NORM_QC_NO},
+	{0xC27F, UNICODE_NORM_QC_NO},
+	{0xC280, UNICODE_NORM_QC_NO},
+	{0xC281, UNICODE_NORM_QC_NO},
+	{0xC282, UNICODE_NORM_QC_NO},
+	{0xC283, UNICODE_NORM_QC_NO},
+	{0xC284, UNICODE_NORM_QC_NO},
+	{0xC285, UNICODE_NORM_QC_NO},
+	{0xC286, UNICODE_NORM_QC_NO},
+	{0xC287, UNICODE_NORM_QC_NO},
+	{0xC288, UNICODE_NORM_QC_NO},
+	{0xC289, UNICODE_NORM_QC_NO},
+	{0xC28A, UNICODE_NORM_QC_NO},
+	{0xC28B, UNICODE_NORM_QC_NO},
+	{0xC28C, UNICODE_NORM_QC_NO},
+	{0xC28D, UNICODE_NORM_QC_NO},
+	{0xC28E, UNICODE_NORM_QC_NO},
+	{0xC28F, UNICODE_NORM_QC_NO},
+	{0xC290, UNICODE_NORM_QC_NO},
+	{0xC291, UNICODE_NORM_QC_NO},
+	{0xC292, UNICODE_NORM_QC_NO},
+	{0xC293, UNICODE_NORM_QC_NO},
+	{0xC294, UNICODE_NORM_QC_NO},
+	{0xC295, UNICODE_NORM_QC_NO},
+	{0xC296, UNICODE_NORM_QC_NO},
+	{0xC297, UNICODE_NORM_QC_NO},
+	{0xC298, UNICODE_NORM_QC_NO},
+	{0xC299, UNICODE_NORM_QC_NO},
+	{0xC29A, UNICODE_NORM_QC_NO},
+	{0xC29B, UNICODE_NORM_QC_NO},
+	{0xC29C, UNICODE_NORM_QC_NO},
+	{0xC29D, UNICODE_NORM_QC_NO},
+	{0xC29E, UNICODE_NORM_QC_NO},
+	{0xC29F, UNICODE_NORM_QC_NO},
+	{0xC2A0, UNICODE_NORM_QC_NO},
+	{0xC2A1, UNICODE_NORM_QC_NO},
+	{0xC2A2, UNICODE_NORM_QC_NO},
+	{0xC2A3, UNICODE_NORM_QC_NO},
+	{0xC2A4, UNICODE_NORM_QC_NO},
+	{0xC2A5, UNICODE_NORM_QC_NO},
+	{0xC2A6, UNICODE_NORM_QC_NO},
+	{0xC2A7, UNICODE_NORM_QC_NO},
+	{0xC2A8, UNICODE_NORM_QC_NO},
+	{0xC2A9, UNICODE_NORM_QC_NO},
+	{0xC2AA, UNICODE_NORM_QC_NO},
+	{0xC2AB, UNICODE_NORM_QC_NO},
+	{0xC2AC, UNICODE_NORM_QC_NO},
+	{0xC2AD, UNICODE_NORM_QC_NO},
+	{0xC2AE, UNICODE_NORM_QC_NO},
+	{0xC2AF, UNICODE_NORM_QC_NO},
+	{0xC2B0, UNICODE_NORM_QC_NO},
+	{0xC2B1, UNICODE_NORM_QC_NO},
+	{0xC2B2, UNICODE_NORM_QC_NO},
+	{0xC2B3, UNICODE_NORM_QC_NO},
+	{0xC2B4, UNICODE_NORM_QC_NO},
+	{0xC2B5, UNICODE_NORM_QC_NO},
+	{0xC2B6, UNICODE_NORM_QC_NO},
+	{0xC2B7, UNICODE_NORM_QC_NO},
+	{0xC2B8, UNICODE_NORM_QC_NO},
+	{0xC2B9, UNICODE_NORM_QC_NO},
+	{0xC2BA, UNICODE_NORM_QC_NO},
+	{0xC2BB, UNICODE_NORM_QC_NO},
+	{0xC2BC, UNICODE_NORM_QC_NO},
+	{0xC2BD, UNICODE_NORM_QC_NO},
+	{0xC2BE, UNICODE_NORM_QC_NO},
+	{0xC2BF, UNICODE_NORM_QC_NO},
+	{0xC2C0, UNICODE_NORM_QC_NO},
+	{0xC2C1, UNICODE_NORM_QC_NO},
+	{0xC2C2, UNICODE_NORM_QC_NO},
+	{0xC2C3, UNICODE_NORM_QC_NO},
+	{0xC2C4, UNICODE_NORM_QC_NO},
+	{0xC2C5, UNICODE_NORM_QC_NO},
+	{0xC2C6, UNICODE_NORM_QC_NO},
+	{0xC2C7, UNICODE_NORM_QC_NO},
+	{0xC2C8, UNICODE_NORM_QC_NO},
+	{0xC2C9, UNICODE_NORM_QC_NO},
+	{0xC2CA, UNICODE_NORM_QC_NO},
+	{0xC2CB, UNICODE_NORM_QC_NO},
+	{0xC2CC, UNICODE_NORM_QC_NO},
+	{0xC2CD, UNICODE_NORM_QC_NO},
+	{0xC2CE, UNICODE_NORM_QC_NO},
+	{0xC2CF, UNICODE_NORM_QC_NO},
+	{0xC2D0, UNICODE_NORM_QC_NO},
+	{0xC2D1, UNICODE_NORM_QC_NO},
+	{0xC2D2, UNICODE_NORM_QC_NO},
+	{0xC2D3, UNICODE_NORM_QC_NO},
+	{0xC2D4, UNICODE_NORM_QC_NO},
+	{0xC2D5, UNICODE_NORM_QC_NO},
+	{0xC2D6, UNICODE_NORM_QC_NO},
+	{0xC2D7, UNICODE_NORM_QC_NO},
+	{0xC2D8, UNICODE_NORM_QC_NO},
+	{0xC2D9, UNICODE_NORM_QC_NO},
+	{0xC2DA, UNICODE_NORM_QC_NO},
+	{0xC2DB, UNICODE_NORM_QC_NO},
+	{0xC2DC, UNICODE_NORM_QC_NO},
+	{0xC2DD, UNICODE_NORM_QC_NO},
+	{0xC2DE, UNICODE_NORM_QC_NO},
+	{0xC2DF, UNICODE_NORM_QC_NO},
+	{0xC2E0, UNICODE_NORM_QC_NO},
+	{0xC2E1, UNICODE_NORM_QC_NO},
+	{0xC2E2, UNICODE_NORM_QC_NO},
+	{0xC2E3, UNICODE_NORM_QC_NO},
+	{0xC2E4, UNICODE_NORM_QC_NO},
+	{0xC2E5, UNICODE_NORM_QC_NO},
+	{0xC2E6, UNICODE_NORM_QC_NO},
+	{0xC2E7, UNICODE_NORM_QC_NO},
+	{0xC2E8, UNICODE_NORM_QC_NO},
+	{0xC2E9, UNICODE_NORM_QC_NO},
+	{0xC2EA, UNICODE_NORM_QC_NO},
+	{0xC2EB, UNICODE_NORM_QC_NO},
+	{0xC2EC, UNICODE_NORM_QC_NO},
+	{0xC2ED, UNICODE_NORM_QC_NO},
+	{0xC2EE, UNICODE_NORM_QC_NO},
+	{0xC2EF, UNICODE_NORM_QC_NO},
+	{0xC2F0, UNICODE_NORM_QC_NO},
+	{0xC2F1, UNICODE_NORM_QC_NO},
+	{0xC2F2, UNICODE_NORM_QC_NO},
+	{0xC2F3, UNICODE_NORM_QC_NO},
+	{0xC2F4, UNICODE_NORM_QC_NO},
+	{0xC2F5, UNICODE_NORM_QC_NO},
+	{0xC2F6, UNICODE_NORM_QC_NO},
+	{0xC2F7, UNICODE_NORM_QC_NO},
+	{0xC2F8, UNICODE_NORM_QC_NO},
+	{0xC2F9, UNICODE_NORM_QC_NO},
+	{0xC2FA, UNICODE_NORM_QC_NO},
+	{0xC2FB, UNICODE_NORM_QC_NO},
+	{0xC2FC, UNICODE_NORM_QC_NO},
+	{0xC2FD, UNICODE_NORM_QC_NO},
+	{0xC2FE, UNICODE_NORM_QC_NO},
+	{0xC2FF, UNICODE_NORM_QC_NO},
+	{0xC300, UNICODE_NORM_QC_NO},
+	{0xC301, UNICODE_NORM_QC_NO},
+	{0xC302, UNICODE_NORM_QC_NO},
+	{0xC303, UNICODE_NORM_QC_NO},
+	{0xC304, UNICODE_NORM_QC_NO},
+	{0xC305, UNICODE_NORM_QC_NO},
+	{0xC306, UNICODE_NORM_QC_NO},
+	{0xC307, UNICODE_NORM_QC_NO},
+	{0xC308, UNICODE_NORM_QC_NO},
+	{0xC309, UNICODE_NORM_QC_NO},
+	{0xC30A, UNICODE_NORM_QC_NO},
+	{0xC30B, UNICODE_NORM_QC_NO},
+	{0xC30C, UNICODE_NORM_QC_NO},
+	{0xC30D, UNICODE_NORM_QC_NO},
+	{0xC30E, UNICODE_NORM_QC_NO},
+	{0xC30F, UNICODE_NORM_QC_NO},
+	{0xC310, UNICODE_NORM_QC_NO},
+	{0xC311, UNICODE_NORM_QC_NO},
+	{0xC312, UNICODE_NORM_QC_NO},
+	{0xC313, UNICODE_NORM_QC_NO},
+	{0xC314, UNICODE_NORM_QC_NO},
+	{0xC315, UNICODE_NORM_QC_NO},
+	{0xC316, UNICODE_NORM_QC_NO},
+	{0xC317, UNICODE_NORM_QC_NO},
+	{0xC318, UNICODE_NORM_QC_NO},
+	{0xC319, UNICODE_NORM_QC_NO},
+	{0xC31A, UNICODE_NORM_QC_NO},
+	{0xC31B, UNICODE_NORM_QC_NO},
+	{0xC31C, UNICODE_NORM_QC_NO},
+	{0xC31D, UNICODE_NORM_QC_NO},
+	{0xC31E, UNICODE_NORM_QC_NO},
+	{0xC31F, UNICODE_NORM_QC_NO},
+	{0xC320, UNICODE_NORM_QC_NO},
+	{0xC321, UNICODE_NORM_QC_NO},
+	{0xC322, UNICODE_NORM_QC_NO},
+	{0xC323, UNICODE_NORM_QC_NO},
+	{0xC324, UNICODE_NORM_QC_NO},
+	{0xC325, UNICODE_NORM_QC_NO},
+	{0xC326, UNICODE_NORM_QC_NO},
+	{0xC327, UNICODE_NORM_QC_NO},
+	{0xC328, UNICODE_NORM_QC_NO},
+	{0xC329, UNICODE_NORM_QC_NO},
+	{0xC32A, UNICODE_NORM_QC_NO},
+	{0xC32B, UNICODE_NORM_QC_NO},
+	{0xC32C, UNICODE_NORM_QC_NO},
+	{0xC32D, UNICODE_NORM_QC_NO},
+	{0xC32E, UNICODE_NORM_QC_NO},
+	{0xC32F, UNICODE_NORM_QC_NO},
+	{0xC330, UNICODE_NORM_QC_NO},
+	{0xC331, UNICODE_NORM_QC_NO},
+	{0xC332, UNICODE_NORM_QC_NO},
+	{0xC333, UNICODE_NORM_QC_NO},
+	{0xC334, UNICODE_NORM_QC_NO},
+	{0xC335, UNICODE_NORM_QC_NO},
+	{0xC336, UNICODE_NORM_QC_NO},
+	{0xC337, UNICODE_NORM_QC_NO},
+	{0xC338, UNICODE_NORM_QC_NO},
+	{0xC339, UNICODE_NORM_QC_NO},
+	{0xC33A, UNICODE_NORM_QC_NO},
+	{0xC33B, UNICODE_NORM_QC_NO},
+	{0xC33C, UNICODE_NORM_QC_NO},
+	{0xC33D, UNICODE_NORM_QC_NO},
+	{0xC33E, UNICODE_NORM_QC_NO},
+	{0xC33F, UNICODE_NORM_QC_NO},
+	{0xC340, UNICODE_NORM_QC_NO},
+	{0xC341, UNICODE_NORM_QC_NO},
+	{0xC342, UNICODE_NORM_QC_NO},
+	{0xC343, UNICODE_NORM_QC_NO},
+	{0xC344, UNICODE_NORM_QC_NO},
+	{0xC345, UNICODE_NORM_QC_NO},
+	{0xC346, UNICODE_NORM_QC_NO},
+	{0xC347, UNICODE_NORM_QC_NO},
+	{0xC348, UNICODE_NORM_QC_NO},
+	{0xC349, UNICODE_NORM_QC_NO},
+	{0xC34A, UNICODE_NORM_QC_NO},
+	{0xC34B, UNICODE_NORM_QC_NO},
+	{0xC34C, UNICODE_NORM_QC_NO},
+	{0xC34D, UNICODE_NORM_QC_NO},
+	{0xC34E, UNICODE_NORM_QC_NO},
+	{0xC34F, UNICODE_NORM_QC_NO},
+	{0xC350, UNICODE_NORM_QC_NO},
+	{0xC351, UNICODE_NORM_QC_NO},
+	{0xC352, UNICODE_NORM_QC_NO},
+	{0xC353, UNICODE_NORM_QC_NO},
+	{0xC354, UNICODE_NORM_QC_NO},
+	{0xC355, UNICODE_NORM_QC_NO},
+	{0xC356, UNICODE_NORM_QC_NO},
+	{0xC357, UNICODE_NORM_QC_NO},
+	{0xC358, UNICODE_NORM_QC_NO},
+	{0xC359, UNICODE_NORM_QC_NO},
+	{0xC35A, UNICODE_NORM_QC_NO},
+	{0xC35B, UNICODE_NORM_QC_NO},
+	{0xC35C, UNICODE_NORM_QC_NO},
+	{0xC35D, UNICODE_NORM_QC_NO},
+	{0xC35E, UNICODE_NORM_QC_NO},
+	{0xC35F, UNICODE_NORM_QC_NO},
+	{0xC360, UNICODE_NORM_QC_NO},
+	{0xC361, UNICODE_NORM_QC_NO},
+	{0xC362, UNICODE_NORM_QC_NO},
+	{0xC363, UNICODE_NORM_QC_NO},
+	{0xC364, UNICODE_NORM_QC_NO},
+	{0xC365, UNICODE_NORM_QC_NO},
+	{0xC366, UNICODE_NORM_QC_NO},
+	{0xC367, UNICODE_NORM_QC_NO},
+	{0xC368, UNICODE_NORM_QC_NO},
+	{0xC369, UNICODE_NORM_QC_NO},
+	{0xC36A, UNICODE_NORM_QC_NO},
+	{0xC36B, UNICODE_NORM_QC_NO},
+	{0xC36C, UNICODE_NORM_QC_NO},
+	{0xC36D, UNICODE_NORM_QC_NO},
+	{0xC36E, UNICODE_NORM_QC_NO},
+	{0xC36F, UNICODE_NORM_QC_NO},
+	{0xC370, UNICODE_NORM_QC_NO},
+	{0xC371, UNICODE_NORM_QC_NO},
+	{0xC372, UNICODE_NORM_QC_NO},
+	{0xC373, UNICODE_NORM_QC_NO},
+	{0xC374, UNICODE_NORM_QC_NO},
+	{0xC375, UNICODE_NORM_QC_NO},
+	{0xC376, UNICODE_NORM_QC_NO},
+	{0xC377, UNICODE_NORM_QC_NO},
+	{0xC378, UNICODE_NORM_QC_NO},
+	{0xC379, UNICODE_NORM_QC_NO},
+	{0xC37A, UNICODE_NORM_QC_NO},
+	{0xC37B, UNICODE_NORM_QC_NO},
+	{0xC37C, UNICODE_NORM_QC_NO},
+	{0xC37D, UNICODE_NORM_QC_NO},
+	{0xC37E, UNICODE_NORM_QC_NO},
+	{0xC37F, UNICODE_NORM_QC_NO},
+	{0xC380, UNICODE_NORM_QC_NO},
+	{0xC381, UNICODE_NORM_QC_NO},
+	{0xC382, UNICODE_NORM_QC_NO},
+	{0xC383, UNICODE_NORM_QC_NO},
+	{0xC384, UNICODE_NORM_QC_NO},
+	{0xC385, UNICODE_NORM_QC_NO},
+	{0xC386, UNICODE_NORM_QC_NO},
+	{0xC387, UNICODE_NORM_QC_NO},
+	{0xC388, UNICODE_NORM_QC_NO},
+	{0xC389, UNICODE_NORM_QC_NO},
+	{0xC38A, UNICODE_NORM_QC_NO},
+	{0xC38B, UNICODE_NORM_QC_NO},
+	{0xC38C, UNICODE_NORM_QC_NO},
+	{0xC38D, UNICODE_NORM_QC_NO},
+	{0xC38E, UNICODE_NORM_QC_NO},
+	{0xC38F, UNICODE_NORM_QC_NO},
+	{0xC390, UNICODE_NORM_QC_NO},
+	{0xC391, UNICODE_NORM_QC_NO},
+	{0xC392, UNICODE_NORM_QC_NO},
+	{0xC393, UNICODE_NORM_QC_NO},
+	{0xC394, UNICODE_NORM_QC_NO},
+	{0xC395, UNICODE_NORM_QC_NO},
+	{0xC396, UNICODE_NORM_QC_NO},
+	{0xC397, UNICODE_NORM_QC_NO},
+	{0xC398, UNICODE_NORM_QC_NO},
+	{0xC399, UNICODE_NORM_QC_NO},
+	{0xC39A, UNICODE_NORM_QC_NO},
+	{0xC39B, UNICODE_NORM_QC_NO},
+	{0xC39C, UNICODE_NORM_QC_NO},
+	{0xC39D, UNICODE_NORM_QC_NO},
+	{0xC39E, UNICODE_NORM_QC_NO},
+	{0xC39F, UNICODE_NORM_QC_NO},
+	{0xC3A0, UNICODE_NORM_QC_NO},
+	{0xC3A1, UNICODE_NORM_QC_NO},
+	{0xC3A2, UNICODE_NORM_QC_NO},
+	{0xC3A3, UNICODE_NORM_QC_NO},
+	{0xC3A4, UNICODE_NORM_QC_NO},
+	{0xC3A5, UNICODE_NORM_QC_NO},
+	{0xC3A6, UNICODE_NORM_QC_NO},
+	{0xC3A7, UNICODE_NORM_QC_NO},
+	{0xC3A8, UNICODE_NORM_QC_NO},
+	{0xC3A9, UNICODE_NORM_QC_NO},
+	{0xC3AA, UNICODE_NORM_QC_NO},
+	{0xC3AB, UNICODE_NORM_QC_NO},
+	{0xC3AC, UNICODE_NORM_QC_NO},
+	{0xC3AD, UNICODE_NORM_QC_NO},
+	{0xC3AE, UNICODE_NORM_QC_NO},
+	{0xC3AF, UNICODE_NORM_QC_NO},
+	{0xC3B0, UNICODE_NORM_QC_NO},
+	{0xC3B1, UNICODE_NORM_QC_NO},
+	{0xC3B2, UNICODE_NORM_QC_NO},
+	{0xC3B3, UNICODE_NORM_QC_NO},
+	{0xC3B4, UNICODE_NORM_QC_NO},
+	{0xC3B5, UNICODE_NORM_QC_NO},
+	{0xC3B6, UNICODE_NORM_QC_NO},
+	{0xC3B7, UNICODE_NORM_QC_NO},
+	{0xC3B8, UNICODE_NORM_QC_NO},
+	{0xC3B9, UNICODE_NORM_QC_NO},
+	{0xC3BA, UNICODE_NORM_QC_NO},
+	{0xC3BB, UNICODE_NORM_QC_NO},
+	{0xC3BC, UNICODE_NORM_QC_NO},
+	{0xC3BD, UNICODE_NORM_QC_NO},
+	{0xC3BE, UNICODE_NORM_QC_NO},
+	{0xC3BF, UNICODE_NORM_QC_NO},
+	{0xC3C0, UNICODE_NORM_QC_NO},
+	{0xC3C1, UNICODE_NORM_QC_NO},
+	{0xC3C2, UNICODE_NORM_QC_NO},
+	{0xC3C3, UNICODE_NORM_QC_NO},
+	{0xC3C4, UNICODE_NORM_QC_NO},
+	{0xC3C5, UNICODE_NORM_QC_NO},
+	{0xC3C6, UNICODE_NORM_QC_NO},
+	{0xC3C7, UNICODE_NORM_QC_NO},
+	{0xC3C8, UNICODE_NORM_QC_NO},
+	{0xC3C9, UNICODE_NORM_QC_NO},
+	{0xC3CA, UNICODE_NORM_QC_NO},
+	{0xC3CB, UNICODE_NORM_QC_NO},
+	{0xC3CC, UNICODE_NORM_QC_NO},
+	{0xC3CD, UNICODE_NORM_QC_NO},
+	{0xC3CE, UNICODE_NORM_QC_NO},
+	{0xC3CF, UNICODE_NORM_QC_NO},
+	{0xC3D0, UNICODE_NORM_QC_NO},
+	{0xC3D1, UNICODE_NORM_QC_NO},
+	{0xC3D2, UNICODE_NORM_QC_NO},
+	{0xC3D3, UNICODE_NORM_QC_NO},
+	{0xC3D4, UNICODE_NORM_QC_NO},
+	{0xC3D5, UNICODE_NORM_QC_NO},
+	{0xC3D6, UNICODE_NORM_QC_NO},
+	{0xC3D7, UNICODE_NORM_QC_NO},
+	{0xC3D8, UNICODE_NORM_QC_NO},
+	{0xC3D9, UNICODE_NORM_QC_NO},
+	{0xC3DA, UNICODE_NORM_QC_NO},
+	{0xC3DB, UNICODE_NORM_QC_NO},
+	{0xC3DC, UNICODE_NORM_QC_NO},
+	{0xC3DD, UNICODE_NORM_QC_NO},
+	{0xC3DE, UNICODE_NORM_QC_NO},
+	{0xC3DF, UNICODE_NORM_QC_NO},
+	{0xC3E0, UNICODE_NORM_QC_NO},
+	{0xC3E1, UNICODE_NORM_QC_NO},
+	{0xC3E2, UNICODE_NORM_QC_NO},
+	{0xC3E3, UNICODE_NORM_QC_NO},
+	{0xC3E4, UNICODE_NORM_QC_NO},
+	{0xC3E5, UNICODE_NORM_QC_NO},
+	{0xC3E6, UNICODE_NORM_QC_NO},
+	{0xC3E7, UNICODE_NORM_QC_NO},
+	{0xC3E8, UNICODE_NORM_QC_NO},
+	{0xC3E9, UNICODE_NORM_QC_NO},
+	{0xC3EA, UNICODE_NORM_QC_NO},
+	{0xC3EB, UNICODE_NORM_QC_NO},
+	{0xC3EC, UNICODE_NORM_QC_NO},
+	{0xC3ED, UNICODE_NORM_QC_NO},
+	{0xC3EE, UNICODE_NORM_QC_NO},
+	{0xC3EF, UNICODE_NORM_QC_NO},
+	{0xC3F0, UNICODE_NORM_QC_NO},
+	{0xC3F1, UNICODE_NORM_QC_NO},
+	{0xC3F2, UNICODE_NORM_QC_NO},
+	{0xC3F3, UNICODE_NORM_QC_NO},
+	{0xC3F4, UNICODE_NORM_QC_NO},
+	{0xC3F5, UNICODE_NORM_QC_NO},
+	{0xC3F6, UNICODE_NORM_QC_NO},
+	{0xC3F7, UNICODE_NORM_QC_NO},
+	{0xC3F8, UNICODE_NORM_QC_NO},
+	{0xC3F9, UNICODE_NORM_QC_NO},
+	{0xC3FA, UNICODE_NORM_QC_NO},
+	{0xC3FB, UNICODE_NORM_QC_NO},
+	{0xC3FC, UNICODE_NORM_QC_NO},
+	{0xC3FD, UNICODE_NORM_QC_NO},
+	{0xC3FE, UNICODE_NORM_QC_NO},
+	{0xC3FF, UNICODE_NORM_QC_NO},
+	{0xC400, UNICODE_NORM_QC_NO},
+	{0xC401, UNICODE_NORM_QC_NO},
+	{0xC402, UNICODE_NORM_QC_NO},
+	{0xC403, UNICODE_NORM_QC_NO},
+	{0xC404, UNICODE_NORM_QC_NO},
+	{0xC405, UNICODE_NORM_QC_NO},
+	{0xC406, UNICODE_NORM_QC_NO},
+	{0xC407, UNICODE_NORM_QC_NO},
+	{0xC408, UNICODE_NORM_QC_NO},
+	{0xC409, UNICODE_NORM_QC_NO},
+	{0xC40A, UNICODE_NORM_QC_NO},
+	{0xC40B, UNICODE_NORM_QC_NO},
+	{0xC40C, UNICODE_NORM_QC_NO},
+	{0xC40D, UNICODE_NORM_QC_NO},
+	{0xC40E, UNICODE_NORM_QC_NO},
+	{0xC40F, UNICODE_NORM_QC_NO},
+	{0xC410, UNICODE_NORM_QC_NO},
+	{0xC411, UNICODE_NORM_QC_NO},
+	{0xC412, UNICODE_NORM_QC_NO},
+	{0xC413, UNICODE_NORM_QC_NO},
+	{0xC414, UNICODE_NORM_QC_NO},
+	{0xC415, UNICODE_NORM_QC_NO},
+	{0xC416, UNICODE_NORM_QC_NO},
+	{0xC417, UNICODE_NORM_QC_NO},
+	{0xC418, UNICODE_NORM_QC_NO},
+	{0xC419, UNICODE_NORM_QC_NO},
+	{0xC41A, UNICODE_NORM_QC_NO},
+	{0xC41B, UNICODE_NORM_QC_NO},
+	{0xC41C, UNICODE_NORM_QC_NO},
+	{0xC41D, UNICODE_NORM_QC_NO},
+	{0xC41E, UNICODE_NORM_QC_NO},
+	{0xC41F, UNICODE_NORM_QC_NO},
+	{0xC420, UNICODE_NORM_QC_NO},
+	{0xC421, UNICODE_NORM_QC_NO},
+	{0xC422, UNICODE_NORM_QC_NO},
+	{0xC423, UNICODE_NORM_QC_NO},
+	{0xC424, UNICODE_NORM_QC_NO},
+	{0xC425, UNICODE_NORM_QC_NO},
+	{0xC426, UNICODE_NORM_QC_NO},
+	{0xC427, UNICODE_NORM_QC_NO},
+	{0xC428, UNICODE_NORM_QC_NO},
+	{0xC429, UNICODE_NORM_QC_NO},
+	{0xC42A, UNICODE_NORM_QC_NO},
+	{0xC42B, UNICODE_NORM_QC_NO},
+	{0xC42C, UNICODE_NORM_QC_NO},
+	{0xC42D, UNICODE_NORM_QC_NO},
+	{0xC42E, UNICODE_NORM_QC_NO},
+	{0xC42F, UNICODE_NORM_QC_NO},
+	{0xC430, UNICODE_NORM_QC_NO},
+	{0xC431, UNICODE_NORM_QC_NO},
+	{0xC432, UNICODE_NORM_QC_NO},
+	{0xC433, UNICODE_NORM_QC_NO},
+	{0xC434, UNICODE_NORM_QC_NO},
+	{0xC435, UNICODE_NORM_QC_NO},
+	{0xC436, UNICODE_NORM_QC_NO},
+	{0xC437, UNICODE_NORM_QC_NO},
+	{0xC438, UNICODE_NORM_QC_NO},
+	{0xC439, UNICODE_NORM_QC_NO},
+	{0xC43A, UNICODE_NORM_QC_NO},
+	{0xC43B, UNICODE_NORM_QC_NO},
+	{0xC43C, UNICODE_NORM_QC_NO},
+	{0xC43D, UNICODE_NORM_QC_NO},
+	{0xC43E, UNICODE_NORM_QC_NO},
+	{0xC43F, UNICODE_NORM_QC_NO},
+	{0xC440, UNICODE_NORM_QC_NO},
+	{0xC441, UNICODE_NORM_QC_NO},
+	{0xC442, UNICODE_NORM_QC_NO},
+	{0xC443, UNICODE_NORM_QC_NO},
+	{0xC444, UNICODE_NORM_QC_NO},
+	{0xC445, UNICODE_NORM_QC_NO},
+	{0xC446, UNICODE_NORM_QC_NO},
+	{0xC447, UNICODE_NORM_QC_NO},
+	{0xC448, UNICODE_NORM_QC_NO},
+	{0xC449, UNICODE_NORM_QC_NO},
+	{0xC44A, UNICODE_NORM_QC_NO},
+	{0xC44B, UNICODE_NORM_QC_NO},
+	{0xC44C, UNICODE_NORM_QC_NO},
+	{0xC44D, UNICODE_NORM_QC_NO},
+	{0xC44E, UNICODE_NORM_QC_NO},
+	{0xC44F, UNICODE_NORM_QC_NO},
+	{0xC450, UNICODE_NORM_QC_NO},
+	{0xC451, UNICODE_NORM_QC_NO},
+	{0xC452, UNICODE_NORM_QC_NO},
+	{0xC453, UNICODE_NORM_QC_NO},
+	{0xC454, UNICODE_NORM_QC_NO},
+	{0xC455, UNICODE_NORM_QC_NO},
+	{0xC456, UNICODE_NORM_QC_NO},
+	{0xC457, UNICODE_NORM_QC_NO},
+	{0xC458, UNICODE_NORM_QC_NO},
+	{0xC459, UNICODE_NORM_QC_NO},
+	{0xC45A, UNICODE_NORM_QC_NO},
+	{0xC45B, UNICODE_NORM_QC_NO},
+	{0xC45C, UNICODE_NORM_QC_NO},
+	{0xC45D, UNICODE_NORM_QC_NO},
+	{0xC45E, UNICODE_NORM_QC_NO},
+	{0xC45F, UNICODE_NORM_QC_NO},
+	{0xC460, UNICODE_NORM_QC_NO},
+	{0xC461, UNICODE_NORM_QC_NO},
+	{0xC462, UNICODE_NORM_QC_NO},
+	{0xC463, UNICODE_NORM_QC_NO},
+	{0xC464, UNICODE_NORM_QC_NO},
+	{0xC465, UNICODE_NORM_QC_NO},
+	{0xC466, UNICODE_NORM_QC_NO},
+	{0xC467, UNICODE_NORM_QC_NO},
+	{0xC468, UNICODE_NORM_QC_NO},
+	{0xC469, UNICODE_NORM_QC_NO},
+	{0xC46A, UNICODE_NORM_QC_NO},
+	{0xC46B, UNICODE_NORM_QC_NO},
+	{0xC46C, UNICODE_NORM_QC_NO},
+	{0xC46D, UNICODE_NORM_QC_NO},
+	{0xC46E, UNICODE_NORM_QC_NO},
+	{0xC46F, UNICODE_NORM_QC_NO},
+	{0xC470, UNICODE_NORM_QC_NO},
+	{0xC471, UNICODE_NORM_QC_NO},
+	{0xC472, UNICODE_NORM_QC_NO},
+	{0xC473, UNICODE_NORM_QC_NO},
+	{0xC474, UNICODE_NORM_QC_NO},
+	{0xC475, UNICODE_NORM_QC_NO},
+	{0xC476, UNICODE_NORM_QC_NO},
+	{0xC477, UNICODE_NORM_QC_NO},
+	{0xC478, UNICODE_NORM_QC_NO},
+	{0xC479, UNICODE_NORM_QC_NO},
+	{0xC47A, UNICODE_NORM_QC_NO},
+	{0xC47B, UNICODE_NORM_QC_NO},
+	{0xC47C, UNICODE_NORM_QC_NO},
+	{0xC47D, UNICODE_NORM_QC_NO},
+	{0xC47E, UNICODE_NORM_QC_NO},
+	{0xC47F, UNICODE_NORM_QC_NO},
+	{0xC480, UNICODE_NORM_QC_NO},
+	{0xC481, UNICODE_NORM_QC_NO},
+	{0xC482, UNICODE_NORM_QC_NO},
+	{0xC483, UNICODE_NORM_QC_NO},
+	{0xC484, UNICODE_NORM_QC_NO},
+	{0xC485, UNICODE_NORM_QC_NO},
+	{0xC486, UNICODE_NORM_QC_NO},
+	{0xC487, UNICODE_NORM_QC_NO},
+	{0xC488, UNICODE_NORM_QC_NO},
+	{0xC489, UNICODE_NORM_QC_NO},
+	{0xC48A, UNICODE_NORM_QC_NO},
+	{0xC48B, UNICODE_NORM_QC_NO},
+	{0xC48C, UNICODE_NORM_QC_NO},
+	{0xC48D, UNICODE_NORM_QC_NO},
+	{0xC48E, UNICODE_NORM_QC_NO},
+	{0xC48F, UNICODE_NORM_QC_NO},
+	{0xC490, UNICODE_NORM_QC_NO},
+	{0xC491, UNICODE_NORM_QC_NO},
+	{0xC492, UNICODE_NORM_QC_NO},
+	{0xC493, UNICODE_NORM_QC_NO},
+	{0xC494, UNICODE_NORM_QC_NO},
+	{0xC495, UNICODE_NORM_QC_NO},
+	{0xC496, UNICODE_NORM_QC_NO},
+	{0xC497, UNICODE_NORM_QC_NO},
+	{0xC498, UNICODE_NORM_QC_NO},
+	{0xC499, UNICODE_NORM_QC_NO},
+	{0xC49A, UNICODE_NORM_QC_NO},
+	{0xC49B, UNICODE_NORM_QC_NO},
+	{0xC49C, UNICODE_NORM_QC_NO},
+	{0xC49D, UNICODE_NORM_QC_NO},
+	{0xC49E, UNICODE_NORM_QC_NO},
+	{0xC49F, UNICODE_NORM_QC_NO},
+	{0xC4A0, UNICODE_NORM_QC_NO},
+	{0xC4A1, UNICODE_NORM_QC_NO},
+	{0xC4A2, UNICODE_NORM_QC_NO},
+	{0xC4A3, UNICODE_NORM_QC_NO},
+	{0xC4A4, UNICODE_NORM_QC_NO},
+	{0xC4A5, UNICODE_NORM_QC_NO},
+	{0xC4A6, UNICODE_NORM_QC_NO},
+	{0xC4A7, UNICODE_NORM_QC_NO},
+	{0xC4A8, UNICODE_NORM_QC_NO},
+	{0xC4A9, UNICODE_NORM_QC_NO},
+	{0xC4AA, UNICODE_NORM_QC_NO},
+	{0xC4AB, UNICODE_NORM_QC_NO},
+	{0xC4AC, UNICODE_NORM_QC_NO},
+	{0xC4AD, UNICODE_NORM_QC_NO},
+	{0xC4AE, UNICODE_NORM_QC_NO},
+	{0xC4AF, UNICODE_NORM_QC_NO},
+	{0xC4B0, UNICODE_NORM_QC_NO},
+	{0xC4B1, UNICODE_NORM_QC_NO},
+	{0xC4B2, UNICODE_NORM_QC_NO},
+	{0xC4B3, UNICODE_NORM_QC_NO},
+	{0xC4B4, UNICODE_NORM_QC_NO},
+	{0xC4B5, UNICODE_NORM_QC_NO},
+	{0xC4B6, UNICODE_NORM_QC_NO},
+	{0xC4B7, UNICODE_NORM_QC_NO},
+	{0xC4B8, UNICODE_NORM_QC_NO},
+	{0xC4B9, UNICODE_NORM_QC_NO},
+	{0xC4BA, UNICODE_NORM_QC_NO},
+	{0xC4BB, UNICODE_NORM_QC_NO},
+	{0xC4BC, UNICODE_NORM_QC_NO},
+	{0xC4BD, UNICODE_NORM_QC_NO},
+	{0xC4BE, UNICODE_NORM_QC_NO},
+	{0xC4BF, UNICODE_NORM_QC_NO},
+	{0xC4C0, UNICODE_NORM_QC_NO},
+	{0xC4C1, UNICODE_NORM_QC_NO},
+	{0xC4C2, UNICODE_NORM_QC_NO},
+	{0xC4C3, UNICODE_NORM_QC_NO},
+	{0xC4C4, UNICODE_NORM_QC_NO},
+	{0xC4C5, UNICODE_NORM_QC_NO},
+	{0xC4C6, UNICODE_NORM_QC_NO},
+	{0xC4C7, UNICODE_NORM_QC_NO},
+	{0xC4C8, UNICODE_NORM_QC_NO},
+	{0xC4C9, UNICODE_NORM_QC_NO},
+	{0xC4CA, UNICODE_NORM_QC_NO},
+	{0xC4CB, UNICODE_NORM_QC_NO},
+	{0xC4CC, UNICODE_NORM_QC_NO},
+	{0xC4CD, UNICODE_NORM_QC_NO},
+	{0xC4CE, UNICODE_NORM_QC_NO},
+	{0xC4CF, UNICODE_NORM_QC_NO},
+	{0xC4D0, UNICODE_NORM_QC_NO},
+	{0xC4D1, UNICODE_NORM_QC_NO},
+	{0xC4D2, UNICODE_NORM_QC_NO},
+	{0xC4D3, UNICODE_NORM_QC_NO},
+	{0xC4D4, UNICODE_NORM_QC_NO},
+	{0xC4D5, UNICODE_NORM_QC_NO},
+	{0xC4D6, UNICODE_NORM_QC_NO},
+	{0xC4D7, UNICODE_NORM_QC_NO},
+	{0xC4D8, UNICODE_NORM_QC_NO},
+	{0xC4D9, UNICODE_NORM_QC_NO},
+	{0xC4DA, UNICODE_NORM_QC_NO},
+	{0xC4DB, UNICODE_NORM_QC_NO},
+	{0xC4DC, UNICODE_NORM_QC_NO},
+	{0xC4DD, UNICODE_NORM_QC_NO},
+	{0xC4DE, UNICODE_NORM_QC_NO},
+	{0xC4DF, UNICODE_NORM_QC_NO},
+	{0xC4E0, UNICODE_NORM_QC_NO},
+	{0xC4E1, UNICODE_NORM_QC_NO},
+	{0xC4E2, UNICODE_NORM_QC_NO},
+	{0xC4E3, UNICODE_NORM_QC_NO},
+	{0xC4E4, UNICODE_NORM_QC_NO},
+	{0xC4E5, UNICODE_NORM_QC_NO},
+	{0xC4E6, UNICODE_NORM_QC_NO},
+	{0xC4E7, UNICODE_NORM_QC_NO},
+	{0xC4E8, UNICODE_NORM_QC_NO},
+	{0xC4E9, UNICODE_NORM_QC_NO},
+	{0xC4EA, UNICODE_NORM_QC_NO},
+	{0xC4EB, UNICODE_NORM_QC_NO},
+	{0xC4EC, UNICODE_NORM_QC_NO},
+	{0xC4ED, UNICODE_NORM_QC_NO},
+	{0xC4EE, UNICODE_NORM_QC_NO},
+	{0xC4EF, UNICODE_NORM_QC_NO},
+	{0xC4F0, UNICODE_NORM_QC_NO},
+	{0xC4F1, UNICODE_NORM_QC_NO},
+	{0xC4F2, UNICODE_NORM_QC_NO},
+	{0xC4F3, UNICODE_NORM_QC_NO},
+	{0xC4F4, UNICODE_NORM_QC_NO},
+	{0xC4F5, UNICODE_NORM_QC_NO},
+	{0xC4F6, UNICODE_NORM_QC_NO},
+	{0xC4F7, UNICODE_NORM_QC_NO},
+	{0xC4F8, UNICODE_NORM_QC_NO},
+	{0xC4F9, UNICODE_NORM_QC_NO},
+	{0xC4FA, UNICODE_NORM_QC_NO},
+	{0xC4FB, UNICODE_NORM_QC_NO},
+	{0xC4FC, UNICODE_NORM_QC_NO},
+	{0xC4FD, UNICODE_NORM_QC_NO},
+	{0xC4FE, UNICODE_NORM_QC_NO},
+	{0xC4FF, UNICODE_NORM_QC_NO},
+	{0xC500, UNICODE_NORM_QC_NO},
+	{0xC501, UNICODE_NORM_QC_NO},
+	{0xC502, UNICODE_NORM_QC_NO},
+	{0xC503, UNICODE_NORM_QC_NO},
+	{0xC504, UNICODE_NORM_QC_NO},
+	{0xC505, UNICODE_NORM_QC_NO},
+	{0xC506, UNICODE_NORM_QC_NO},
+	{0xC507, UNICODE_NORM_QC_NO},
+	{0xC508, UNICODE_NORM_QC_NO},
+	{0xC509, UNICODE_NORM_QC_NO},
+	{0xC50A, UNICODE_NORM_QC_NO},
+	{0xC50B, UNICODE_NORM_QC_NO},
+	{0xC50C, UNICODE_NORM_QC_NO},
+	{0xC50D, UNICODE_NORM_QC_NO},
+	{0xC50E, UNICODE_NORM_QC_NO},
+	{0xC50F, UNICODE_NORM_QC_NO},
+	{0xC510, UNICODE_NORM_QC_NO},
+	{0xC511, UNICODE_NORM_QC_NO},
+	{0xC512, UNICODE_NORM_QC_NO},
+	{0xC513, UNICODE_NORM_QC_NO},
+	{0xC514, UNICODE_NORM_QC_NO},
+	{0xC515, UNICODE_NORM_QC_NO},
+	{0xC516, UNICODE_NORM_QC_NO},
+	{0xC517, UNICODE_NORM_QC_NO},
+	{0xC518, UNICODE_NORM_QC_NO},
+	{0xC519, UNICODE_NORM_QC_NO},
+	{0xC51A, UNICODE_NORM_QC_NO},
+	{0xC51B, UNICODE_NORM_QC_NO},
+	{0xC51C, UNICODE_NORM_QC_NO},
+	{0xC51D, UNICODE_NORM_QC_NO},
+	{0xC51E, UNICODE_NORM_QC_NO},
+	{0xC51F, UNICODE_NORM_QC_NO},
+	{0xC520, UNICODE_NORM_QC_NO},
+	{0xC521, UNICODE_NORM_QC_NO},
+	{0xC522, UNICODE_NORM_QC_NO},
+	{0xC523, UNICODE_NORM_QC_NO},
+	{0xC524, UNICODE_NORM_QC_NO},
+	{0xC525, UNICODE_NORM_QC_NO},
+	{0xC526, UNICODE_NORM_QC_NO},
+	{0xC527, UNICODE_NORM_QC_NO},
+	{0xC528, UNICODE_NORM_QC_NO},
+	{0xC529, UNICODE_NORM_QC_NO},
+	{0xC52A, UNICODE_NORM_QC_NO},
+	{0xC52B, UNICODE_NORM_QC_NO},
+	{0xC52C, UNICODE_NORM_QC_NO},
+	{0xC52D, UNICODE_NORM_QC_NO},
+	{0xC52E, UNICODE_NORM_QC_NO},
+	{0xC52F, UNICODE_NORM_QC_NO},
+	{0xC530, UNICODE_NORM_QC_NO},
+	{0xC531, UNICODE_NORM_QC_NO},
+	{0xC532, UNICODE_NORM_QC_NO},
+	{0xC533, UNICODE_NORM_QC_NO},
+	{0xC534, UNICODE_NORM_QC_NO},
+	{0xC535, UNICODE_NORM_QC_NO},
+	{0xC536, UNICODE_NORM_QC_NO},
+	{0xC537, UNICODE_NORM_QC_NO},
+	{0xC538, UNICODE_NORM_QC_NO},
+	{0xC539, UNICODE_NORM_QC_NO},
+	{0xC53A, UNICODE_NORM_QC_NO},
+	{0xC53B, UNICODE_NORM_QC_NO},
+	{0xC53C, UNICODE_NORM_QC_NO},
+	{0xC53D, UNICODE_NORM_QC_NO},
+	{0xC53E, UNICODE_NORM_QC_NO},
+	{0xC53F, UNICODE_NORM_QC_NO},
+	{0xC540, UNICODE_NORM_QC_NO},
+	{0xC541, UNICODE_NORM_QC_NO},
+	{0xC542, UNICODE_NORM_QC_NO},
+	{0xC543, UNICODE_NORM_QC_NO},
+	{0xC544, UNICODE_NORM_QC_NO},
+	{0xC545, UNICODE_NORM_QC_NO},
+	{0xC546, UNICODE_NORM_QC_NO},
+	{0xC547, UNICODE_NORM_QC_NO},
+	{0xC548, UNICODE_NORM_QC_NO},
+	{0xC549, UNICODE_NORM_QC_NO},
+	{0xC54A, UNICODE_NORM_QC_NO},
+	{0xC54B, UNICODE_NORM_QC_NO},
+	{0xC54C, UNICODE_NORM_QC_NO},
+	{0xC54D, UNICODE_NORM_QC_NO},
+	{0xC54E, UNICODE_NORM_QC_NO},
+	{0xC54F, UNICODE_NORM_QC_NO},
+	{0xC550, UNICODE_NORM_QC_NO},
+	{0xC551, UNICODE_NORM_QC_NO},
+	{0xC552, UNICODE_NORM_QC_NO},
+	{0xC553, UNICODE_NORM_QC_NO},
+	{0xC554, UNICODE_NORM_QC_NO},
+	{0xC555, UNICODE_NORM_QC_NO},
+	{0xC556, UNICODE_NORM_QC_NO},
+	{0xC557, UNICODE_NORM_QC_NO},
+	{0xC558, UNICODE_NORM_QC_NO},
+	{0xC559, UNICODE_NORM_QC_NO},
+	{0xC55A, UNICODE_NORM_QC_NO},
+	{0xC55B, UNICODE_NORM_QC_NO},
+	{0xC55C, UNICODE_NORM_QC_NO},
+	{0xC55D, UNICODE_NORM_QC_NO},
+	{0xC55E, UNICODE_NORM_QC_NO},
+	{0xC55F, UNICODE_NORM_QC_NO},
+	{0xC560, UNICODE_NORM_QC_NO},
+	{0xC561, UNICODE_NORM_QC_NO},
+	{0xC562, UNICODE_NORM_QC_NO},
+	{0xC563, UNICODE_NORM_QC_NO},
+	{0xC564, UNICODE_NORM_QC_NO},
+	{0xC565, UNICODE_NORM_QC_NO},
+	{0xC566, UNICODE_NORM_QC_NO},
+	{0xC567, UNICODE_NORM_QC_NO},
+	{0xC568, UNICODE_NORM_QC_NO},
+	{0xC569, UNICODE_NORM_QC_NO},
+	{0xC56A, UNICODE_NORM_QC_NO},
+	{0xC56B, UNICODE_NORM_QC_NO},
+	{0xC56C, UNICODE_NORM_QC_NO},
+	{0xC56D, UNICODE_NORM_QC_NO},
+	{0xC56E, UNICODE_NORM_QC_NO},
+	{0xC56F, UNICODE_NORM_QC_NO},
+	{0xC570, UNICODE_NORM_QC_NO},
+	{0xC571, UNICODE_NORM_QC_NO},
+	{0xC572, UNICODE_NORM_QC_NO},
+	{0xC573, UNICODE_NORM_QC_NO},
+	{0xC574, UNICODE_NORM_QC_NO},
+	{0xC575, UNICODE_NORM_QC_NO},
+	{0xC576, UNICODE_NORM_QC_NO},
+	{0xC577, UNICODE_NORM_QC_NO},
+	{0xC578, UNICODE_NORM_QC_NO},
+	{0xC579, UNICODE_NORM_QC_NO},
+	{0xC57A, UNICODE_NORM_QC_NO},
+	{0xC57B, UNICODE_NORM_QC_NO},
+	{0xC57C, UNICODE_NORM_QC_NO},
+	{0xC57D, UNICODE_NORM_QC_NO},
+	{0xC57E, UNICODE_NORM_QC_NO},
+	{0xC57F, UNICODE_NORM_QC_NO},
+	{0xC580, UNICODE_NORM_QC_NO},
+	{0xC581, UNICODE_NORM_QC_NO},
+	{0xC582, UNICODE_NORM_QC_NO},
+	{0xC583, UNICODE_NORM_QC_NO},
+	{0xC584, UNICODE_NORM_QC_NO},
+	{0xC585, UNICODE_NORM_QC_NO},
+	{0xC586, UNICODE_NORM_QC_NO},
+	{0xC587, UNICODE_NORM_QC_NO},
+	{0xC588, UNICODE_NORM_QC_NO},
+	{0xC589, UNICODE_NORM_QC_NO},
+	{0xC58A, UNICODE_NORM_QC_NO},
+	{0xC58B, UNICODE_NORM_QC_NO},
+	{0xC58C, UNICODE_NORM_QC_NO},
+	{0xC58D, UNICODE_NORM_QC_NO},
+	{0xC58E, UNICODE_NORM_QC_NO},
+	{0xC58F, UNICODE_NORM_QC_NO},
+	{0xC590, UNICODE_NORM_QC_NO},
+	{0xC591, UNICODE_NORM_QC_NO},
+	{0xC592, UNICODE_NORM_QC_NO},
+	{0xC593, UNICODE_NORM_QC_NO},
+	{0xC594, UNICODE_NORM_QC_NO},
+	{0xC595, UNICODE_NORM_QC_NO},
+	{0xC596, UNICODE_NORM_QC_NO},
+	{0xC597, UNICODE_NORM_QC_NO},
+	{0xC598, UNICODE_NORM_QC_NO},
+	{0xC599, UNICODE_NORM_QC_NO},
+	{0xC59A, UNICODE_NORM_QC_NO},
+	{0xC59B, UNICODE_NORM_QC_NO},
+	{0xC59C, UNICODE_NORM_QC_NO},
+	{0xC59D, UNICODE_NORM_QC_NO},
+	{0xC59E, UNICODE_NORM_QC_NO},
+	{0xC59F, UNICODE_NORM_QC_NO},
+	{0xC5A0, UNICODE_NORM_QC_NO},
+	{0xC5A1, UNICODE_NORM_QC_NO},
+	{0xC5A2, UNICODE_NORM_QC_NO},
+	{0xC5A3, UNICODE_NORM_QC_NO},
+	{0xC5A4, UNICODE_NORM_QC_NO},
+	{0xC5A5, UNICODE_NORM_QC_NO},
+	{0xC5A6, UNICODE_NORM_QC_NO},
+	{0xC5A7, UNICODE_NORM_QC_NO},
+	{0xC5A8, UNICODE_NORM_QC_NO},
+	{0xC5A9, UNICODE_NORM_QC_NO},
+	{0xC5AA, UNICODE_NORM_QC_NO},
+	{0xC5AB, UNICODE_NORM_QC_NO},
+	{0xC5AC, UNICODE_NORM_QC_NO},
+	{0xC5AD, UNICODE_NORM_QC_NO},
+	{0xC5AE, UNICODE_NORM_QC_NO},
+	{0xC5AF, UNICODE_NORM_QC_NO},
+	{0xC5B0, UNICODE_NORM_QC_NO},
+	{0xC5B1, UNICODE_NORM_QC_NO},
+	{0xC5B2, UNICODE_NORM_QC_NO},
+	{0xC5B3, UNICODE_NORM_QC_NO},
+	{0xC5B4, UNICODE_NORM_QC_NO},
+	{0xC5B5, UNICODE_NORM_QC_NO},
+	{0xC5B6, UNICODE_NORM_QC_NO},
+	{0xC5B7, UNICODE_NORM_QC_NO},
+	{0xC5B8, UNICODE_NORM_QC_NO},
+	{0xC5B9, UNICODE_NORM_QC_NO},
+	{0xC5BA, UNICODE_NORM_QC_NO},
+	{0xC5BB, UNICODE_NORM_QC_NO},
+	{0xC5BC, UNICODE_NORM_QC_NO},
+	{0xC5BD, UNICODE_NORM_QC_NO},
+	{0xC5BE, UNICODE_NORM_QC_NO},
+	{0xC5BF, UNICODE_NORM_QC_NO},
+	{0xC5C0, UNICODE_NORM_QC_NO},
+	{0xC5C1, UNICODE_NORM_QC_NO},
+	{0xC5C2, UNICODE_NORM_QC_NO},
+	{0xC5C3, UNICODE_NORM_QC_NO},
+	{0xC5C4, UNICODE_NORM_QC_NO},
+	{0xC5C5, UNICODE_NORM_QC_NO},
+	{0xC5C6, UNICODE_NORM_QC_NO},
+	{0xC5C7, UNICODE_NORM_QC_NO},
+	{0xC5C8, UNICODE_NORM_QC_NO},
+	{0xC5C9, UNICODE_NORM_QC_NO},
+	{0xC5CA, UNICODE_NORM_QC_NO},
+	{0xC5CB, UNICODE_NORM_QC_NO},
+	{0xC5CC, UNICODE_NORM_QC_NO},
+	{0xC5CD, UNICODE_NORM_QC_NO},
+	{0xC5CE, UNICODE_NORM_QC_NO},
+	{0xC5CF, UNICODE_NORM_QC_NO},
+	{0xC5D0, UNICODE_NORM_QC_NO},
+	{0xC5D1, UNICODE_NORM_QC_NO},
+	{0xC5D2, UNICODE_NORM_QC_NO},
+	{0xC5D3, UNICODE_NORM_QC_NO},
+	{0xC5D4, UNICODE_NORM_QC_NO},
+	{0xC5D5, UNICODE_NORM_QC_NO},
+	{0xC5D6, UNICODE_NORM_QC_NO},
+	{0xC5D7, UNICODE_NORM_QC_NO},
+	{0xC5D8, UNICODE_NORM_QC_NO},
+	{0xC5D9, UNICODE_NORM_QC_NO},
+	{0xC5DA, UNICODE_NORM_QC_NO},
+	{0xC5DB, UNICODE_NORM_QC_NO},
+	{0xC5DC, UNICODE_NORM_QC_NO},
+	{0xC5DD, UNICODE_NORM_QC_NO},
+	{0xC5DE, UNICODE_NORM_QC_NO},
+	{0xC5DF, UNICODE_NORM_QC_NO},
+	{0xC5E0, UNICODE_NORM_QC_NO},
+	{0xC5E1, UNICODE_NORM_QC_NO},
+	{0xC5E2, UNICODE_NORM_QC_NO},
+	{0xC5E3, UNICODE_NORM_QC_NO},
+	{0xC5E4, UNICODE_NORM_QC_NO},
+	{0xC5E5, UNICODE_NORM_QC_NO},
+	{0xC5E6, UNICODE_NORM_QC_NO},
+	{0xC5E7, UNICODE_NORM_QC_NO},
+	{0xC5E8, UNICODE_NORM_QC_NO},
+	{0xC5E9, UNICODE_NORM_QC_NO},
+	{0xC5EA, UNICODE_NORM_QC_NO},
+	{0xC5EB, UNICODE_NORM_QC_NO},
+	{0xC5EC, UNICODE_NORM_QC_NO},
+	{0xC5ED, UNICODE_NORM_QC_NO},
+	{0xC5EE, UNICODE_NORM_QC_NO},
+	{0xC5EF, UNICODE_NORM_QC_NO},
+	{0xC5F0, UNICODE_NORM_QC_NO},
+	{0xC5F1, UNICODE_NORM_QC_NO},
+	{0xC5F2, UNICODE_NORM_QC_NO},
+	{0xC5F3, UNICODE_NORM_QC_NO},
+	{0xC5F4, UNICODE_NORM_QC_NO},
+	{0xC5F5, UNICODE_NORM_QC_NO},
+	{0xC5F6, UNICODE_NORM_QC_NO},
+	{0xC5F7, UNICODE_NORM_QC_NO},
+	{0xC5F8, UNICODE_NORM_QC_NO},
+	{0xC5F9, UNICODE_NORM_QC_NO},
+	{0xC5FA, UNICODE_NORM_QC_NO},
+	{0xC5FB, UNICODE_NORM_QC_NO},
+	{0xC5FC, UNICODE_NORM_QC_NO},
+	{0xC5FD, UNICODE_NORM_QC_NO},
+	{0xC5FE, UNICODE_NORM_QC_NO},
+	{0xC5FF, UNICODE_NORM_QC_NO},
+	{0xC600, UNICODE_NORM_QC_NO},
+	{0xC601, UNICODE_NORM_QC_NO},
+	{0xC602, UNICODE_NORM_QC_NO},
+	{0xC603, UNICODE_NORM_QC_NO},
+	{0xC604, UNICODE_NORM_QC_NO},
+	{0xC605, UNICODE_NORM_QC_NO},
+	{0xC606, UNICODE_NORM_QC_NO},
+	{0xC607, UNICODE_NORM_QC_NO},
+	{0xC608, UNICODE_NORM_QC_NO},
+	{0xC609, UNICODE_NORM_QC_NO},
+	{0xC60A, UNICODE_NORM_QC_NO},
+	{0xC60B, UNICODE_NORM_QC_NO},
+	{0xC60C, UNICODE_NORM_QC_NO},
+	{0xC60D, UNICODE_NORM_QC_NO},
+	{0xC60E, UNICODE_NORM_QC_NO},
+	{0xC60F, UNICODE_NORM_QC_NO},
+	{0xC610, UNICODE_NORM_QC_NO},
+	{0xC611, UNICODE_NORM_QC_NO},
+	{0xC612, UNICODE_NORM_QC_NO},
+	{0xC613, UNICODE_NORM_QC_NO},
+	{0xC614, UNICODE_NORM_QC_NO},
+	{0xC615, UNICODE_NORM_QC_NO},
+	{0xC616, UNICODE_NORM_QC_NO},
+	{0xC617, UNICODE_NORM_QC_NO},
+	{0xC618, UNICODE_NORM_QC_NO},
+	{0xC619, UNICODE_NORM_QC_NO},
+	{0xC61A, UNICODE_NORM_QC_NO},
+	{0xC61B, UNICODE_NORM_QC_NO},
+	{0xC61C, UNICODE_NORM_QC_NO},
+	{0xC61D, UNICODE_NORM_QC_NO},
+	{0xC61E, UNICODE_NORM_QC_NO},
+	{0xC61F, UNICODE_NORM_QC_NO},
+	{0xC620, UNICODE_NORM_QC_NO},
+	{0xC621, UNICODE_NORM_QC_NO},
+	{0xC622, UNICODE_NORM_QC_NO},
+	{0xC623, UNICODE_NORM_QC_NO},
+	{0xC624, UNICODE_NORM_QC_NO},
+	{0xC625, UNICODE_NORM_QC_NO},
+	{0xC626, UNICODE_NORM_QC_NO},
+	{0xC627, UNICODE_NORM_QC_NO},
+	{0xC628, UNICODE_NORM_QC_NO},
+	{0xC629, UNICODE_NORM_QC_NO},
+	{0xC62A, UNICODE_NORM_QC_NO},
+	{0xC62B, UNICODE_NORM_QC_NO},
+	{0xC62C, UNICODE_NORM_QC_NO},
+	{0xC62D, UNICODE_NORM_QC_NO},
+	{0xC62E, UNICODE_NORM_QC_NO},
+	{0xC62F, UNICODE_NORM_QC_NO},
+	{0xC630, UNICODE_NORM_QC_NO},
+	{0xC631, UNICODE_NORM_QC_NO},
+	{0xC632, UNICODE_NORM_QC_NO},
+	{0xC633, UNICODE_NORM_QC_NO},
+	{0xC634, UNICODE_NORM_QC_NO},
+	{0xC635, UNICODE_NORM_QC_NO},
+	{0xC636, UNICODE_NORM_QC_NO},
+	{0xC637, UNICODE_NORM_QC_NO},
+	{0xC638, UNICODE_NORM_QC_NO},
+	{0xC639, UNICODE_NORM_QC_NO},
+	{0xC63A, UNICODE_NORM_QC_NO},
+	{0xC63B, UNICODE_NORM_QC_NO},
+	{0xC63C, UNICODE_NORM_QC_NO},
+	{0xC63D, UNICODE_NORM_QC_NO},
+	{0xC63E, UNICODE_NORM_QC_NO},
+	{0xC63F, UNICODE_NORM_QC_NO},
+	{0xC640, UNICODE_NORM_QC_NO},
+	{0xC641, UNICODE_NORM_QC_NO},
+	{0xC642, UNICODE_NORM_QC_NO},
+	{0xC643, UNICODE_NORM_QC_NO},
+	{0xC644, UNICODE_NORM_QC_NO},
+	{0xC645, UNICODE_NORM_QC_NO},
+	{0xC646, UNICODE_NORM_QC_NO},
+	{0xC647, UNICODE_NORM_QC_NO},
+	{0xC648, UNICODE_NORM_QC_NO},
+	{0xC649, UNICODE_NORM_QC_NO},
+	{0xC64A, UNICODE_NORM_QC_NO},
+	{0xC64B, UNICODE_NORM_QC_NO},
+	{0xC64C, UNICODE_NORM_QC_NO},
+	{0xC64D, UNICODE_NORM_QC_NO},
+	{0xC64E, UNICODE_NORM_QC_NO},
+	{0xC64F, UNICODE_NORM_QC_NO},
+	{0xC650, UNICODE_NORM_QC_NO},
+	{0xC651, UNICODE_NORM_QC_NO},
+	{0xC652, UNICODE_NORM_QC_NO},
+	{0xC653, UNICODE_NORM_QC_NO},
+	{0xC654, UNICODE_NORM_QC_NO},
+	{0xC655, UNICODE_NORM_QC_NO},
+	{0xC656, UNICODE_NORM_QC_NO},
+	{0xC657, UNICODE_NORM_QC_NO},
+	{0xC658, UNICODE_NORM_QC_NO},
+	{0xC659, UNICODE_NORM_QC_NO},
+	{0xC65A, UNICODE_NORM_QC_NO},
+	{0xC65B, UNICODE_NORM_QC_NO},
+	{0xC65C, UNICODE_NORM_QC_NO},
+	{0xC65D, UNICODE_NORM_QC_NO},
+	{0xC65E, UNICODE_NORM_QC_NO},
+	{0xC65F, UNICODE_NORM_QC_NO},
+	{0xC660, UNICODE_NORM_QC_NO},
+	{0xC661, UNICODE_NORM_QC_NO},
+	{0xC662, UNICODE_NORM_QC_NO},
+	{0xC663, UNICODE_NORM_QC_NO},
+	{0xC664, UNICODE_NORM_QC_NO},
+	{0xC665, UNICODE_NORM_QC_NO},
+	{0xC666, UNICODE_NORM_QC_NO},
+	{0xC667, UNICODE_NORM_QC_NO},
+	{0xC668, UNICODE_NORM_QC_NO},
+	{0xC669, UNICODE_NORM_QC_NO},
+	{0xC66A, UNICODE_NORM_QC_NO},
+	{0xC66B, UNICODE_NORM_QC_NO},
+	{0xC66C, UNICODE_NORM_QC_NO},
+	{0xC66D, UNICODE_NORM_QC_NO},
+	{0xC66E, UNICODE_NORM_QC_NO},
+	{0xC66F, UNICODE_NORM_QC_NO},
+	{0xC670, UNICODE_NORM_QC_NO},
+	{0xC671, UNICODE_NORM_QC_NO},
+	{0xC672, UNICODE_NORM_QC_NO},
+	{0xC673, UNICODE_NORM_QC_NO},
+	{0xC674, UNICODE_NORM_QC_NO},
+	{0xC675, UNICODE_NORM_QC_NO},
+	{0xC676, UNICODE_NORM_QC_NO},
+	{0xC677, UNICODE_NORM_QC_NO},
+	{0xC678, UNICODE_NORM_QC_NO},
+	{0xC679, UNICODE_NORM_QC_NO},
+	{0xC67A, UNICODE_NORM_QC_NO},
+	{0xC67B, UNICODE_NORM_QC_NO},
+	{0xC67C, UNICODE_NORM_QC_NO},
+	{0xC67D, UNICODE_NORM_QC_NO},
+	{0xC67E, UNICODE_NORM_QC_NO},
+	{0xC67F, UNICODE_NORM_QC_NO},
+	{0xC680, UNICODE_NORM_QC_NO},
+	{0xC681, UNICODE_NORM_QC_NO},
+	{0xC682, UNICODE_NORM_QC_NO},
+	{0xC683, UNICODE_NORM_QC_NO},
+	{0xC684, UNICODE_NORM_QC_NO},
+	{0xC685, UNICODE_NORM_QC_NO},
+	{0xC686, UNICODE_NORM_QC_NO},
+	{0xC687, UNICODE_NORM_QC_NO},
+	{0xC688, UNICODE_NORM_QC_NO},
+	{0xC689, UNICODE_NORM_QC_NO},
+	{0xC68A, UNICODE_NORM_QC_NO},
+	{0xC68B, UNICODE_NORM_QC_NO},
+	{0xC68C, UNICODE_NORM_QC_NO},
+	{0xC68D, UNICODE_NORM_QC_NO},
+	{0xC68E, UNICODE_NORM_QC_NO},
+	{0xC68F, UNICODE_NORM_QC_NO},
+	{0xC690, UNICODE_NORM_QC_NO},
+	{0xC691, UNICODE_NORM_QC_NO},
+	{0xC692, UNICODE_NORM_QC_NO},
+	{0xC693, UNICODE_NORM_QC_NO},
+	{0xC694, UNICODE_NORM_QC_NO},
+	{0xC695, UNICODE_NORM_QC_NO},
+	{0xC696, UNICODE_NORM_QC_NO},
+	{0xC697, UNICODE_NORM_QC_NO},
+	{0xC698, UNICODE_NORM_QC_NO},
+	{0xC699, UNICODE_NORM_QC_NO},
+	{0xC69A, UNICODE_NORM_QC_NO},
+	{0xC69B, UNICODE_NORM_QC_NO},
+	{0xC69C, UNICODE_NORM_QC_NO},
+	{0xC69D, UNICODE_NORM_QC_NO},
+	{0xC69E, UNICODE_NORM_QC_NO},
+	{0xC69F, UNICODE_NORM_QC_NO},
+	{0xC6A0, UNICODE_NORM_QC_NO},
+	{0xC6A1, UNICODE_NORM_QC_NO},
+	{0xC6A2, UNICODE_NORM_QC_NO},
+	{0xC6A3, UNICODE_NORM_QC_NO},
+	{0xC6A4, UNICODE_NORM_QC_NO},
+	{0xC6A5, UNICODE_NORM_QC_NO},
+	{0xC6A6, UNICODE_NORM_QC_NO},
+	{0xC6A7, UNICODE_NORM_QC_NO},
+	{0xC6A8, UNICODE_NORM_QC_NO},
+	{0xC6A9, UNICODE_NORM_QC_NO},
+	{0xC6AA, UNICODE_NORM_QC_NO},
+	{0xC6AB, UNICODE_NORM_QC_NO},
+	{0xC6AC, UNICODE_NORM_QC_NO},
+	{0xC6AD, UNICODE_NORM_QC_NO},
+	{0xC6AE, UNICODE_NORM_QC_NO},
+	{0xC6AF, UNICODE_NORM_QC_NO},
+	{0xC6B0, UNICODE_NORM_QC_NO},
+	{0xC6B1, UNICODE_NORM_QC_NO},
+	{0xC6B2, UNICODE_NORM_QC_NO},
+	{0xC6B3, UNICODE_NORM_QC_NO},
+	{0xC6B4, UNICODE_NORM_QC_NO},
+	{0xC6B5, UNICODE_NORM_QC_NO},
+	{0xC6B6, UNICODE_NORM_QC_NO},
+	{0xC6B7, UNICODE_NORM_QC_NO},
+	{0xC6B8, UNICODE_NORM_QC_NO},
+	{0xC6B9, UNICODE_NORM_QC_NO},
+	{0xC6BA, UNICODE_NORM_QC_NO},
+	{0xC6BB, UNICODE_NORM_QC_NO},
+	{0xC6BC, UNICODE_NORM_QC_NO},
+	{0xC6BD, UNICODE_NORM_QC_NO},
+	{0xC6BE, UNICODE_NORM_QC_NO},
+	{0xC6BF, UNICODE_NORM_QC_NO},
+	{0xC6C0, UNICODE_NORM_QC_NO},
+	{0xC6C1, UNICODE_NORM_QC_NO},
+	{0xC6C2, UNICODE_NORM_QC_NO},
+	{0xC6C3, UNICODE_NORM_QC_NO},
+	{0xC6C4, UNICODE_NORM_QC_NO},
+	{0xC6C5, UNICODE_NORM_QC_NO},
+	{0xC6C6, UNICODE_NORM_QC_NO},
+	{0xC6C7, UNICODE_NORM_QC_NO},
+	{0xC6C8, UNICODE_NORM_QC_NO},
+	{0xC6C9, UNICODE_NORM_QC_NO},
+	{0xC6CA, UNICODE_NORM_QC_NO},
+	{0xC6CB, UNICODE_NORM_QC_NO},
+	{0xC6CC, UNICODE_NORM_QC_NO},
+	{0xC6CD, UNICODE_NORM_QC_NO},
+	{0xC6CE, UNICODE_NORM_QC_NO},
+	{0xC6CF, UNICODE_NORM_QC_NO},
+	{0xC6D0, UNICODE_NORM_QC_NO},
+	{0xC6D1, UNICODE_NORM_QC_NO},
+	{0xC6D2, UNICODE_NORM_QC_NO},
+	{0xC6D3, UNICODE_NORM_QC_NO},
+	{0xC6D4, UNICODE_NORM_QC_NO},
+	{0xC6D5, UNICODE_NORM_QC_NO},
+	{0xC6D6, UNICODE_NORM_QC_NO},
+	{0xC6D7, UNICODE_NORM_QC_NO},
+	{0xC6D8, UNICODE_NORM_QC_NO},
+	{0xC6D9, UNICODE_NORM_QC_NO},
+	{0xC6DA, UNICODE_NORM_QC_NO},
+	{0xC6DB, UNICODE_NORM_QC_NO},
+	{0xC6DC, UNICODE_NORM_QC_NO},
+	{0xC6DD, UNICODE_NORM_QC_NO},
+	{0xC6DE, UNICODE_NORM_QC_NO},
+	{0xC6DF, UNICODE_NORM_QC_NO},
+	{0xC6E0, UNICODE_NORM_QC_NO},
+	{0xC6E1, UNICODE_NORM_QC_NO},
+	{0xC6E2, UNICODE_NORM_QC_NO},
+	{0xC6E3, UNICODE_NORM_QC_NO},
+	{0xC6E4, UNICODE_NORM_QC_NO},
+	{0xC6E5, UNICODE_NORM_QC_NO},
+	{0xC6E6, UNICODE_NORM_QC_NO},
+	{0xC6E7, UNICODE_NORM_QC_NO},
+	{0xC6E8, UNICODE_NORM_QC_NO},
+	{0xC6E9, UNICODE_NORM_QC_NO},
+	{0xC6EA, UNICODE_NORM_QC_NO},
+	{0xC6EB, UNICODE_NORM_QC_NO},
+	{0xC6EC, UNICODE_NORM_QC_NO},
+	{0xC6ED, UNICODE_NORM_QC_NO},
+	{0xC6EE, UNICODE_NORM_QC_NO},
+	{0xC6EF, UNICODE_NORM_QC_NO},
+	{0xC6F0, UNICODE_NORM_QC_NO},
+	{0xC6F1, UNICODE_NORM_QC_NO},
+	{0xC6F2, UNICODE_NORM_QC_NO},
+	{0xC6F3, UNICODE_NORM_QC_NO},
+	{0xC6F4, UNICODE_NORM_QC_NO},
+	{0xC6F5, UNICODE_NORM_QC_NO},
+	{0xC6F6, UNICODE_NORM_QC_NO},
+	{0xC6F7, UNICODE_NORM_QC_NO},
+	{0xC6F8, UNICODE_NORM_QC_NO},
+	{0xC6F9, UNICODE_NORM_QC_NO},
+	{0xC6FA, UNICODE_NORM_QC_NO},
+	{0xC6FB, UNICODE_NORM_QC_NO},
+	{0xC6FC, UNICODE_NORM_QC_NO},
+	{0xC6FD, UNICODE_NORM_QC_NO},
+	{0xC6FE, UNICODE_NORM_QC_NO},
+	{0xC6FF, UNICODE_NORM_QC_NO},
+	{0xC700, UNICODE_NORM_QC_NO},
+	{0xC701, UNICODE_NORM_QC_NO},
+	{0xC702, UNICODE_NORM_QC_NO},
+	{0xC703, UNICODE_NORM_QC_NO},
+	{0xC704, UNICODE_NORM_QC_NO},
+	{0xC705, UNICODE_NORM_QC_NO},
+	{0xC706, UNICODE_NORM_QC_NO},
+	{0xC707, UNICODE_NORM_QC_NO},
+	{0xC708, UNICODE_NORM_QC_NO},
+	{0xC709, UNICODE_NORM_QC_NO},
+	{0xC70A, UNICODE_NORM_QC_NO},
+	{0xC70B, UNICODE_NORM_QC_NO},
+	{0xC70C, UNICODE_NORM_QC_NO},
+	{0xC70D, UNICODE_NORM_QC_NO},
+	{0xC70E, UNICODE_NORM_QC_NO},
+	{0xC70F, UNICODE_NORM_QC_NO},
+	{0xC710, UNICODE_NORM_QC_NO},
+	{0xC711, UNICODE_NORM_QC_NO},
+	{0xC712, UNICODE_NORM_QC_NO},
+	{0xC713, UNICODE_NORM_QC_NO},
+	{0xC714, UNICODE_NORM_QC_NO},
+	{0xC715, UNICODE_NORM_QC_NO},
+	{0xC716, UNICODE_NORM_QC_NO},
+	{0xC717, UNICODE_NORM_QC_NO},
+	{0xC718, UNICODE_NORM_QC_NO},
+	{0xC719, UNICODE_NORM_QC_NO},
+	{0xC71A, UNICODE_NORM_QC_NO},
+	{0xC71B, UNICODE_NORM_QC_NO},
+	{0xC71C, UNICODE_NORM_QC_NO},
+	{0xC71D, UNICODE_NORM_QC_NO},
+	{0xC71E, UNICODE_NORM_QC_NO},
+	{0xC71F, UNICODE_NORM_QC_NO},
+	{0xC720, UNICODE_NORM_QC_NO},
+	{0xC721, UNICODE_NORM_QC_NO},
+	{0xC722, UNICODE_NORM_QC_NO},
+	{0xC723, UNICODE_NORM_QC_NO},
+	{0xC724, UNICODE_NORM_QC_NO},
+	{0xC725, UNICODE_NORM_QC_NO},
+	{0xC726, UNICODE_NORM_QC_NO},
+	{0xC727, UNICODE_NORM_QC_NO},
+	{0xC728, UNICODE_NORM_QC_NO},
+	{0xC729, UNICODE_NORM_QC_NO},
+	{0xC72A, UNICODE_NORM_QC_NO},
+	{0xC72B, UNICODE_NORM_QC_NO},
+	{0xC72C, UNICODE_NORM_QC_NO},
+	{0xC72D, UNICODE_NORM_QC_NO},
+	{0xC72E, UNICODE_NORM_QC_NO},
+	{0xC72F, UNICODE_NORM_QC_NO},
+	{0xC730, UNICODE_NORM_QC_NO},
+	{0xC731, UNICODE_NORM_QC_NO},
+	{0xC732, UNICODE_NORM_QC_NO},
+	{0xC733, UNICODE_NORM_QC_NO},
+	{0xC734, UNICODE_NORM_QC_NO},
+	{0xC735, UNICODE_NORM_QC_NO},
+	{0xC736, UNICODE_NORM_QC_NO},
+	{0xC737, UNICODE_NORM_QC_NO},
+	{0xC738, UNICODE_NORM_QC_NO},
+	{0xC739, UNICODE_NORM_QC_NO},
+	{0xC73A, UNICODE_NORM_QC_NO},
+	{0xC73B, UNICODE_NORM_QC_NO},
+	{0xC73C, UNICODE_NORM_QC_NO},
+	{0xC73D, UNICODE_NORM_QC_NO},
+	{0xC73E, UNICODE_NORM_QC_NO},
+	{0xC73F, UNICODE_NORM_QC_NO},
+	{0xC740, UNICODE_NORM_QC_NO},
+	{0xC741, UNICODE_NORM_QC_NO},
+	{0xC742, UNICODE_NORM_QC_NO},
+	{0xC743, UNICODE_NORM_QC_NO},
+	{0xC744, UNICODE_NORM_QC_NO},
+	{0xC745, UNICODE_NORM_QC_NO},
+	{0xC746, UNICODE_NORM_QC_NO},
+	{0xC747, UNICODE_NORM_QC_NO},
+	{0xC748, UNICODE_NORM_QC_NO},
+	{0xC749, UNICODE_NORM_QC_NO},
+	{0xC74A, UNICODE_NORM_QC_NO},
+	{0xC74B, UNICODE_NORM_QC_NO},
+	{0xC74C, UNICODE_NORM_QC_NO},
+	{0xC74D, UNICODE_NORM_QC_NO},
+	{0xC74E, UNICODE_NORM_QC_NO},
+	{0xC74F, UNICODE_NORM_QC_NO},
+	{0xC750, UNICODE_NORM_QC_NO},
+	{0xC751, UNICODE_NORM_QC_NO},
+	{0xC752, UNICODE_NORM_QC_NO},
+	{0xC753, UNICODE_NORM_QC_NO},
+	{0xC754, UNICODE_NORM_QC_NO},
+	{0xC755, UNICODE_NORM_QC_NO},
+	{0xC756, UNICODE_NORM_QC_NO},
+	{0xC757, UNICODE_NORM_QC_NO},
+	{0xC758, UNICODE_NORM_QC_NO},
+	{0xC759, UNICODE_NORM_QC_NO},
+	{0xC75A, UNICODE_NORM_QC_NO},
+	{0xC75B, UNICODE_NORM_QC_NO},
+	{0xC75C, UNICODE_NORM_QC_NO},
+	{0xC75D, UNICODE_NORM_QC_NO},
+	{0xC75E, UNICODE_NORM_QC_NO},
+	{0xC75F, UNICODE_NORM_QC_NO},
+	{0xC760, UNICODE_NORM_QC_NO},
+	{0xC761, UNICODE_NORM_QC_NO},
+	{0xC762, UNICODE_NORM_QC_NO},
+	{0xC763, UNICODE_NORM_QC_NO},
+	{0xC764, UNICODE_NORM_QC_NO},
+	{0xC765, UNICODE_NORM_QC_NO},
+	{0xC766, UNICODE_NORM_QC_NO},
+	{0xC767, UNICODE_NORM_QC_NO},
+	{0xC768, UNICODE_NORM_QC_NO},
+	{0xC769, UNICODE_NORM_QC_NO},
+	{0xC76A, UNICODE_NORM_QC_NO},
+	{0xC76B, UNICODE_NORM_QC_NO},
+	{0xC76C, UNICODE_NORM_QC_NO},
+	{0xC76D, UNICODE_NORM_QC_NO},
+	{0xC76E, UNICODE_NORM_QC_NO},
+	{0xC76F, UNICODE_NORM_QC_NO},
+	{0xC770, UNICODE_NORM_QC_NO},
+	{0xC771, UNICODE_NORM_QC_NO},
+	{0xC772, UNICODE_NORM_QC_NO},
+	{0xC773, UNICODE_NORM_QC_NO},
+	{0xC774, UNICODE_NORM_QC_NO},
+	{0xC775, UNICODE_NORM_QC_NO},
+	{0xC776, UNICODE_NORM_QC_NO},
+	{0xC777, UNICODE_NORM_QC_NO},
+	{0xC778, UNICODE_NORM_QC_NO},
+	{0xC779, UNICODE_NORM_QC_NO},
+	{0xC77A, UNICODE_NORM_QC_NO},
+	{0xC77B, UNICODE_NORM_QC_NO},
+	{0xC77C, UNICODE_NORM_QC_NO},
+	{0xC77D, UNICODE_NORM_QC_NO},
+	{0xC77E, UNICODE_NORM_QC_NO},
+	{0xC77F, UNICODE_NORM_QC_NO},
+	{0xC780, UNICODE_NORM_QC_NO},
+	{0xC781, UNICODE_NORM_QC_NO},
+	{0xC782, UNICODE_NORM_QC_NO},
+	{0xC783, UNICODE_NORM_QC_NO},
+	{0xC784, UNICODE_NORM_QC_NO},
+	{0xC785, UNICODE_NORM_QC_NO},
+	{0xC786, UNICODE_NORM_QC_NO},
+	{0xC787, UNICODE_NORM_QC_NO},
+	{0xC788, UNICODE_NORM_QC_NO},
+	{0xC789, UNICODE_NORM_QC_NO},
+	{0xC78A, UNICODE_NORM_QC_NO},
+	{0xC78B, UNICODE_NORM_QC_NO},
+	{0xC78C, UNICODE_NORM_QC_NO},
+	{0xC78D, UNICODE_NORM_QC_NO},
+	{0xC78E, UNICODE_NORM_QC_NO},
+	{0xC78F, UNICODE_NORM_QC_NO},
+	{0xC790, UNICODE_NORM_QC_NO},
+	{0xC791, UNICODE_NORM_QC_NO},
+	{0xC792, UNICODE_NORM_QC_NO},
+	{0xC793, UNICODE_NORM_QC_NO},
+	{0xC794, UNICODE_NORM_QC_NO},
+	{0xC795, UNICODE_NORM_QC_NO},
+	{0xC796, UNICODE_NORM_QC_NO},
+	{0xC797, UNICODE_NORM_QC_NO},
+	{0xC798, UNICODE_NORM_QC_NO},
+	{0xC799, UNICODE_NORM_QC_NO},
+	{0xC79A, UNICODE_NORM_QC_NO},
+	{0xC79B, UNICODE_NORM_QC_NO},
+	{0xC79C, UNICODE_NORM_QC_NO},
+	{0xC79D, UNICODE_NORM_QC_NO},
+	{0xC79E, UNICODE_NORM_QC_NO},
+	{0xC79F, UNICODE_NORM_QC_NO},
+	{0xC7A0, UNICODE_NORM_QC_NO},
+	{0xC7A1, UNICODE_NORM_QC_NO},
+	{0xC7A2, UNICODE_NORM_QC_NO},
+	{0xC7A3, UNICODE_NORM_QC_NO},
+	{0xC7A4, UNICODE_NORM_QC_NO},
+	{0xC7A5, UNICODE_NORM_QC_NO},
+	{0xC7A6, UNICODE_NORM_QC_NO},
+	{0xC7A7, UNICODE_NORM_QC_NO},
+	{0xC7A8, UNICODE_NORM_QC_NO},
+	{0xC7A9, UNICODE_NORM_QC_NO},
+	{0xC7AA, UNICODE_NORM_QC_NO},
+	{0xC7AB, UNICODE_NORM_QC_NO},
+	{0xC7AC, UNICODE_NORM_QC_NO},
+	{0xC7AD, UNICODE_NORM_QC_NO},
+	{0xC7AE, UNICODE_NORM_QC_NO},
+	{0xC7AF, UNICODE_NORM_QC_NO},
+	{0xC7B0, UNICODE_NORM_QC_NO},
+	{0xC7B1, UNICODE_NORM_QC_NO},
+	{0xC7B2, UNICODE_NORM_QC_NO},
+	{0xC7B3, UNICODE_NORM_QC_NO},
+	{0xC7B4, UNICODE_NORM_QC_NO},
+	{0xC7B5, UNICODE_NORM_QC_NO},
+	{0xC7B6, UNICODE_NORM_QC_NO},
+	{0xC7B7, UNICODE_NORM_QC_NO},
+	{0xC7B8, UNICODE_NORM_QC_NO},
+	{0xC7B9, UNICODE_NORM_QC_NO},
+	{0xC7BA, UNICODE_NORM_QC_NO},
+	{0xC7BB, UNICODE_NORM_QC_NO},
+	{0xC7BC, UNICODE_NORM_QC_NO},
+	{0xC7BD, UNICODE_NORM_QC_NO},
+	{0xC7BE, UNICODE_NORM_QC_NO},
+	{0xC7BF, UNICODE_NORM_QC_NO},
+	{0xC7C0, UNICODE_NORM_QC_NO},
+	{0xC7C1, UNICODE_NORM_QC_NO},
+	{0xC7C2, UNICODE_NORM_QC_NO},
+	{0xC7C3, UNICODE_NORM_QC_NO},
+	{0xC7C4, UNICODE_NORM_QC_NO},
+	{0xC7C5, UNICODE_NORM_QC_NO},
+	{0xC7C6, UNICODE_NORM_QC_NO},
+	{0xC7C7, UNICODE_NORM_QC_NO},
+	{0xC7C8, UNICODE_NORM_QC_NO},
+	{0xC7C9, UNICODE_NORM_QC_NO},
+	{0xC7CA, UNICODE_NORM_QC_NO},
+	{0xC7CB, UNICODE_NORM_QC_NO},
+	{0xC7CC, UNICODE_NORM_QC_NO},
+	{0xC7CD, UNICODE_NORM_QC_NO},
+	{0xC7CE, UNICODE_NORM_QC_NO},
+	{0xC7CF, UNICODE_NORM_QC_NO},
+	{0xC7D0, UNICODE_NORM_QC_NO},
+	{0xC7D1, UNICODE_NORM_QC_NO},
+	{0xC7D2, UNICODE_NORM_QC_NO},
+	{0xC7D3, UNICODE_NORM_QC_NO},
+	{0xC7D4, UNICODE_NORM_QC_NO},
+	{0xC7D5, UNICODE_NORM_QC_NO},
+	{0xC7D6, UNICODE_NORM_QC_NO},
+	{0xC7D7, UNICODE_NORM_QC_NO},
+	{0xC7D8, UNICODE_NORM_QC_NO},
+	{0xC7D9, UNICODE_NORM_QC_NO},
+	{0xC7DA, UNICODE_NORM_QC_NO},
+	{0xC7DB, UNICODE_NORM_QC_NO},
+	{0xC7DC, UNICODE_NORM_QC_NO},
+	{0xC7DD, UNICODE_NORM_QC_NO},
+	{0xC7DE, UNICODE_NORM_QC_NO},
+	{0xC7DF, UNICODE_NORM_QC_NO},
+	{0xC7E0, UNICODE_NORM_QC_NO},
+	{0xC7E1, UNICODE_NORM_QC_NO},
+	{0xC7E2, UNICODE_NORM_QC_NO},
+	{0xC7E3, UNICODE_NORM_QC_NO},
+	{0xC7E4, UNICODE_NORM_QC_NO},
+	{0xC7E5, UNICODE_NORM_QC_NO},
+	{0xC7E6, UNICODE_NORM_QC_NO},
+	{0xC7E7, UNICODE_NORM_QC_NO},
+	{0xC7E8, UNICODE_NORM_QC_NO},
+	{0xC7E9, UNICODE_NORM_QC_NO},
+	{0xC7EA, UNICODE_NORM_QC_NO},
+	{0xC7EB, UNICODE_NORM_QC_NO},
+	{0xC7EC, UNICODE_NORM_QC_NO},
+	{0xC7ED, UNICODE_NORM_QC_NO},
+	{0xC7EE, UNICODE_NORM_QC_NO},
+	{0xC7EF, UNICODE_NORM_QC_NO},
+	{0xC7F0, UNICODE_NORM_QC_NO},
+	{0xC7F1, UNICODE_NORM_QC_NO},
+	{0xC7F2, UNICODE_NORM_QC_NO},
+	{0xC7F3, UNICODE_NORM_QC_NO},
+	{0xC7F4, UNICODE_NORM_QC_NO},
+	{0xC7F5, UNICODE_NORM_QC_NO},
+	{0xC7F6, UNICODE_NORM_QC_NO},
+	{0xC7F7, UNICODE_NORM_QC_NO},
+	{0xC7F8, UNICODE_NORM_QC_NO},
+	{0xC7F9, UNICODE_NORM_QC_NO},
+	{0xC7FA, UNICODE_NORM_QC_NO},
+	{0xC7FB, UNICODE_NORM_QC_NO},
+	{0xC7FC, UNICODE_NORM_QC_NO},
+	{0xC7FD, UNICODE_NORM_QC_NO},
+	{0xC7FE, UNICODE_NORM_QC_NO},
+	{0xC7FF, UNICODE_NORM_QC_NO},
+	{0xC800, UNICODE_NORM_QC_NO},
+	{0xC801, UNICODE_NORM_QC_NO},
+	{0xC802, UNICODE_NORM_QC_NO},
+	{0xC803, UNICODE_NORM_QC_NO},
+	{0xC804, UNICODE_NORM_QC_NO},
+	{0xC805, UNICODE_NORM_QC_NO},
+	{0xC806, UNICODE_NORM_QC_NO},
+	{0xC807, UNICODE_NORM_QC_NO},
+	{0xC808, UNICODE_NORM_QC_NO},
+	{0xC809, UNICODE_NORM_QC_NO},
+	{0xC80A, UNICODE_NORM_QC_NO},
+	{0xC80B, UNICODE_NORM_QC_NO},
+	{0xC80C, UNICODE_NORM_QC_NO},
+	{0xC80D, UNICODE_NORM_QC_NO},
+	{0xC80E, UNICODE_NORM_QC_NO},
+	{0xC80F, UNICODE_NORM_QC_NO},
+	{0xC810, UNICODE_NORM_QC_NO},
+	{0xC811, UNICODE_NORM_QC_NO},
+	{0xC812, UNICODE_NORM_QC_NO},
+	{0xC813, UNICODE_NORM_QC_NO},
+	{0xC814, UNICODE_NORM_QC_NO},
+	{0xC815, UNICODE_NORM_QC_NO},
+	{0xC816, UNICODE_NORM_QC_NO},
+	{0xC817, UNICODE_NORM_QC_NO},
+	{0xC818, UNICODE_NORM_QC_NO},
+	{0xC819, UNICODE_NORM_QC_NO},
+	{0xC81A, UNICODE_NORM_QC_NO},
+	{0xC81B, UNICODE_NORM_QC_NO},
+	{0xC81C, UNICODE_NORM_QC_NO},
+	{0xC81D, UNICODE_NORM_QC_NO},
+	{0xC81E, UNICODE_NORM_QC_NO},
+	{0xC81F, UNICODE_NORM_QC_NO},
+	{0xC820, UNICODE_NORM_QC_NO},
+	{0xC821, UNICODE_NORM_QC_NO},
+	{0xC822, UNICODE_NORM_QC_NO},
+	{0xC823, UNICODE_NORM_QC_NO},
+	{0xC824, UNICODE_NORM_QC_NO},
+	{0xC825, UNICODE_NORM_QC_NO},
+	{0xC826, UNICODE_NORM_QC_NO},
+	{0xC827, UNICODE_NORM_QC_NO},
+	{0xC828, UNICODE_NORM_QC_NO},
+	{0xC829, UNICODE_NORM_QC_NO},
+	{0xC82A, UNICODE_NORM_QC_NO},
+	{0xC82B, UNICODE_NORM_QC_NO},
+	{0xC82C, UNICODE_NORM_QC_NO},
+	{0xC82D, UNICODE_NORM_QC_NO},
+	{0xC82E, UNICODE_NORM_QC_NO},
+	{0xC82F, UNICODE_NORM_QC_NO},
+	{0xC830, UNICODE_NORM_QC_NO},
+	{0xC831, UNICODE_NORM_QC_NO},
+	{0xC832, UNICODE_NORM_QC_NO},
+	{0xC833, UNICODE_NORM_QC_NO},
+	{0xC834, UNICODE_NORM_QC_NO},
+	{0xC835, UNICODE_NORM_QC_NO},
+	{0xC836, UNICODE_NORM_QC_NO},
+	{0xC837, UNICODE_NORM_QC_NO},
+	{0xC838, UNICODE_NORM_QC_NO},
+	{0xC839, UNICODE_NORM_QC_NO},
+	{0xC83A, UNICODE_NORM_QC_NO},
+	{0xC83B, UNICODE_NORM_QC_NO},
+	{0xC83C, UNICODE_NORM_QC_NO},
+	{0xC83D, UNICODE_NORM_QC_NO},
+	{0xC83E, UNICODE_NORM_QC_NO},
+	{0xC83F, UNICODE_NORM_QC_NO},
+	{0xC840, UNICODE_NORM_QC_NO},
+	{0xC841, UNICODE_NORM_QC_NO},
+	{0xC842, UNICODE_NORM_QC_NO},
+	{0xC843, UNICODE_NORM_QC_NO},
+	{0xC844, UNICODE_NORM_QC_NO},
+	{0xC845, UNICODE_NORM_QC_NO},
+	{0xC846, UNICODE_NORM_QC_NO},
+	{0xC847, UNICODE_NORM_QC_NO},
+	{0xC848, UNICODE_NORM_QC_NO},
+	{0xC849, UNICODE_NORM_QC_NO},
+	{0xC84A, UNICODE_NORM_QC_NO},
+	{0xC84B, UNICODE_NORM_QC_NO},
+	{0xC84C, UNICODE_NORM_QC_NO},
+	{0xC84D, UNICODE_NORM_QC_NO},
+	{0xC84E, UNICODE_NORM_QC_NO},
+	{0xC84F, UNICODE_NORM_QC_NO},
+	{0xC850, UNICODE_NORM_QC_NO},
+	{0xC851, UNICODE_NORM_QC_NO},
+	{0xC852, UNICODE_NORM_QC_NO},
+	{0xC853, UNICODE_NORM_QC_NO},
+	{0xC854, UNICODE_NORM_QC_NO},
+	{0xC855, UNICODE_NORM_QC_NO},
+	{0xC856, UNICODE_NORM_QC_NO},
+	{0xC857, UNICODE_NORM_QC_NO},
+	{0xC858, UNICODE_NORM_QC_NO},
+	{0xC859, UNICODE_NORM_QC_NO},
+	{0xC85A, UNICODE_NORM_QC_NO},
+	{0xC85B, UNICODE_NORM_QC_NO},
+	{0xC85C, UNICODE_NORM_QC_NO},
+	{0xC85D, UNICODE_NORM_QC_NO},
+	{0xC85E, UNICODE_NORM_QC_NO},
+	{0xC85F, UNICODE_NORM_QC_NO},
+	{0xC860, UNICODE_NORM_QC_NO},
+	{0xC861, UNICODE_NORM_QC_NO},
+	{0xC862, UNICODE_NORM_QC_NO},
+	{0xC863, UNICODE_NORM_QC_NO},
+	{0xC864, UNICODE_NORM_QC_NO},
+	{0xC865, UNICODE_NORM_QC_NO},
+	{0xC866, UNICODE_NORM_QC_NO},
+	{0xC867, UNICODE_NORM_QC_NO},
+	{0xC868, UNICODE_NORM_QC_NO},
+	{0xC869, UNICODE_NORM_QC_NO},
+	{0xC86A, UNICODE_NORM_QC_NO},
+	{0xC86B, UNICODE_NORM_QC_NO},
+	{0xC86C, UNICODE_NORM_QC_NO},
+	{0xC86D, UNICODE_NORM_QC_NO},
+	{0xC86E, UNICODE_NORM_QC_NO},
+	{0xC86F, UNICODE_NORM_QC_NO},
+	{0xC870, UNICODE_NORM_QC_NO},
+	{0xC871, UNICODE_NORM_QC_NO},
+	{0xC872, UNICODE_NORM_QC_NO},
+	{0xC873, UNICODE_NORM_QC_NO},
+	{0xC874, UNICODE_NORM_QC_NO},
+	{0xC875, UNICODE_NORM_QC_NO},
+	{0xC876, UNICODE_NORM_QC_NO},
+	{0xC877, UNICODE_NORM_QC_NO},
+	{0xC878, UNICODE_NORM_QC_NO},
+	{0xC879, UNICODE_NORM_QC_NO},
+	{0xC87A, UNICODE_NORM_QC_NO},
+	{0xC87B, UNICODE_NORM_QC_NO},
+	{0xC87C, UNICODE_NORM_QC_NO},
+	{0xC87D, UNICODE_NORM_QC_NO},
+	{0xC87E, UNICODE_NORM_QC_NO},
+	{0xC87F, UNICODE_NORM_QC_NO},
+	{0xC880, UNICODE_NORM_QC_NO},
+	{0xC881, UNICODE_NORM_QC_NO},
+	{0xC882, UNICODE_NORM_QC_NO},
+	{0xC883, UNICODE_NORM_QC_NO},
+	{0xC884, UNICODE_NORM_QC_NO},
+	{0xC885, UNICODE_NORM_QC_NO},
+	{0xC886, UNICODE_NORM_QC_NO},
+	{0xC887, UNICODE_NORM_QC_NO},
+	{0xC888, UNICODE_NORM_QC_NO},
+	{0xC889, UNICODE_NORM_QC_NO},
+	{0xC88A, UNICODE_NORM_QC_NO},
+	{0xC88B, UNICODE_NORM_QC_NO},
+	{0xC88C, UNICODE_NORM_QC_NO},
+	{0xC88D, UNICODE_NORM_QC_NO},
+	{0xC88E, UNICODE_NORM_QC_NO},
+	{0xC88F, UNICODE_NORM_QC_NO},
+	{0xC890, UNICODE_NORM_QC_NO},
+	{0xC891, UNICODE_NORM_QC_NO},
+	{0xC892, UNICODE_NORM_QC_NO},
+	{0xC893, UNICODE_NORM_QC_NO},
+	{0xC894, UNICODE_NORM_QC_NO},
+	{0xC895, UNICODE_NORM_QC_NO},
+	{0xC896, UNICODE_NORM_QC_NO},
+	{0xC897, UNICODE_NORM_QC_NO},
+	{0xC898, UNICODE_NORM_QC_NO},
+	{0xC899, UNICODE_NORM_QC_NO},
+	{0xC89A, UNICODE_NORM_QC_NO},
+	{0xC89B, UNICODE_NORM_QC_NO},
+	{0xC89C, UNICODE_NORM_QC_NO},
+	{0xC89D, UNICODE_NORM_QC_NO},
+	{0xC89E, UNICODE_NORM_QC_NO},
+	{0xC89F, UNICODE_NORM_QC_NO},
+	{0xC8A0, UNICODE_NORM_QC_NO},
+	{0xC8A1, UNICODE_NORM_QC_NO},
+	{0xC8A2, UNICODE_NORM_QC_NO},
+	{0xC8A3, UNICODE_NORM_QC_NO},
+	{0xC8A4, UNICODE_NORM_QC_NO},
+	{0xC8A5, UNICODE_NORM_QC_NO},
+	{0xC8A6, UNICODE_NORM_QC_NO},
+	{0xC8A7, UNICODE_NORM_QC_NO},
+	{0xC8A8, UNICODE_NORM_QC_NO},
+	{0xC8A9, UNICODE_NORM_QC_NO},
+	{0xC8AA, UNICODE_NORM_QC_NO},
+	{0xC8AB, UNICODE_NORM_QC_NO},
+	{0xC8AC, UNICODE_NORM_QC_NO},
+	{0xC8AD, UNICODE_NORM_QC_NO},
+	{0xC8AE, UNICODE_NORM_QC_NO},
+	{0xC8AF, UNICODE_NORM_QC_NO},
+	{0xC8B0, UNICODE_NORM_QC_NO},
+	{0xC8B1, UNICODE_NORM_QC_NO},
+	{0xC8B2, UNICODE_NORM_QC_NO},
+	{0xC8B3, UNICODE_NORM_QC_NO},
+	{0xC8B4, UNICODE_NORM_QC_NO},
+	{0xC8B5, UNICODE_NORM_QC_NO},
+	{0xC8B6, UNICODE_NORM_QC_NO},
+	{0xC8B7, UNICODE_NORM_QC_NO},
+	{0xC8B8, UNICODE_NORM_QC_NO},
+	{0xC8B9, UNICODE_NORM_QC_NO},
+	{0xC8BA, UNICODE_NORM_QC_NO},
+	{0xC8BB, UNICODE_NORM_QC_NO},
+	{0xC8BC, UNICODE_NORM_QC_NO},
+	{0xC8BD, UNICODE_NORM_QC_NO},
+	{0xC8BE, UNICODE_NORM_QC_NO},
+	{0xC8BF, UNICODE_NORM_QC_NO},
+	{0xC8C0, UNICODE_NORM_QC_NO},
+	{0xC8C1, UNICODE_NORM_QC_NO},
+	{0xC8C2, UNICODE_NORM_QC_NO},
+	{0xC8C3, UNICODE_NORM_QC_NO},
+	{0xC8C4, UNICODE_NORM_QC_NO},
+	{0xC8C5, UNICODE_NORM_QC_NO},
+	{0xC8C6, UNICODE_NORM_QC_NO},
+	{0xC8C7, UNICODE_NORM_QC_NO},
+	{0xC8C8, UNICODE_NORM_QC_NO},
+	{0xC8C9, UNICODE_NORM_QC_NO},
+	{0xC8CA, UNICODE_NORM_QC_NO},
+	{0xC8CB, UNICODE_NORM_QC_NO},
+	{0xC8CC, UNICODE_NORM_QC_NO},
+	{0xC8CD, UNICODE_NORM_QC_NO},
+	{0xC8CE, UNICODE_NORM_QC_NO},
+	{0xC8CF, UNICODE_NORM_QC_NO},
+	{0xC8D0, UNICODE_NORM_QC_NO},
+	{0xC8D1, UNICODE_NORM_QC_NO},
+	{0xC8D2, UNICODE_NORM_QC_NO},
+	{0xC8D3, UNICODE_NORM_QC_NO},
+	{0xC8D4, UNICODE_NORM_QC_NO},
+	{0xC8D5, UNICODE_NORM_QC_NO},
+	{0xC8D6, UNICODE_NORM_QC_NO},
+	{0xC8D7, UNICODE_NORM_QC_NO},
+	{0xC8D8, UNICODE_NORM_QC_NO},
+	{0xC8D9, UNICODE_NORM_QC_NO},
+	{0xC8DA, UNICODE_NORM_QC_NO},
+	{0xC8DB, UNICODE_NORM_QC_NO},
+	{0xC8DC, UNICODE_NORM_QC_NO},
+	{0xC8DD, UNICODE_NORM_QC_NO},
+	{0xC8DE, UNICODE_NORM_QC_NO},
+	{0xC8DF, UNICODE_NORM_QC_NO},
+	{0xC8E0, UNICODE_NORM_QC_NO},
+	{0xC8E1, UNICODE_NORM_QC_NO},
+	{0xC8E2, UNICODE_NORM_QC_NO},
+	{0xC8E3, UNICODE_NORM_QC_NO},
+	{0xC8E4, UNICODE_NORM_QC_NO},
+	{0xC8E5, UNICODE_NORM_QC_NO},
+	{0xC8E6, UNICODE_NORM_QC_NO},
+	{0xC8E7, UNICODE_NORM_QC_NO},
+	{0xC8E8, UNICODE_NORM_QC_NO},
+	{0xC8E9, UNICODE_NORM_QC_NO},
+	{0xC8EA, UNICODE_NORM_QC_NO},
+	{0xC8EB, UNICODE_NORM_QC_NO},
+	{0xC8EC, UNICODE_NORM_QC_NO},
+	{0xC8ED, UNICODE_NORM_QC_NO},
+	{0xC8EE, UNICODE_NORM_QC_NO},
+	{0xC8EF, UNICODE_NORM_QC_NO},
+	{0xC8F0, UNICODE_NORM_QC_NO},
+	{0xC8F1, UNICODE_NORM_QC_NO},
+	{0xC8F2, UNICODE_NORM_QC_NO},
+	{0xC8F3, UNICODE_NORM_QC_NO},
+	{0xC8F4, UNICODE_NORM_QC_NO},
+	{0xC8F5, UNICODE_NORM_QC_NO},
+	{0xC8F6, UNICODE_NORM_QC_NO},
+	{0xC8F7, UNICODE_NORM_QC_NO},
+	{0xC8F8, UNICODE_NORM_QC_NO},
+	{0xC8F9, UNICODE_NORM_QC_NO},
+	{0xC8FA, UNICODE_NORM_QC_NO},
+	{0xC8FB, UNICODE_NORM_QC_NO},
+	{0xC8FC, UNICODE_NORM_QC_NO},
+	{0xC8FD, UNICODE_NORM_QC_NO},
+	{0xC8FE, UNICODE_NORM_QC_NO},
+	{0xC8FF, UNICODE_NORM_QC_NO},
+	{0xC900, UNICODE_NORM_QC_NO},
+	{0xC901, UNICODE_NORM_QC_NO},
+	{0xC902, UNICODE_NORM_QC_NO},
+	{0xC903, UNICODE_NORM_QC_NO},
+	{0xC904, UNICODE_NORM_QC_NO},
+	{0xC905, UNICODE_NORM_QC_NO},
+	{0xC906, UNICODE_NORM_QC_NO},
+	{0xC907, UNICODE_NORM_QC_NO},
+	{0xC908, UNICODE_NORM_QC_NO},
+	{0xC909, UNICODE_NORM_QC_NO},
+	{0xC90A, UNICODE_NORM_QC_NO},
+	{0xC90B, UNICODE_NORM_QC_NO},
+	{0xC90C, UNICODE_NORM_QC_NO},
+	{0xC90D, UNICODE_NORM_QC_NO},
+	{0xC90E, UNICODE_NORM_QC_NO},
+	{0xC90F, UNICODE_NORM_QC_NO},
+	{0xC910, UNICODE_NORM_QC_NO},
+	{0xC911, UNICODE_NORM_QC_NO},
+	{0xC912, UNICODE_NORM_QC_NO},
+	{0xC913, UNICODE_NORM_QC_NO},
+	{0xC914, UNICODE_NORM_QC_NO},
+	{0xC915, UNICODE_NORM_QC_NO},
+	{0xC916, UNICODE_NORM_QC_NO},
+	{0xC917, UNICODE_NORM_QC_NO},
+	{0xC918, UNICODE_NORM_QC_NO},
+	{0xC919, UNICODE_NORM_QC_NO},
+	{0xC91A, UNICODE_NORM_QC_NO},
+	{0xC91B, UNICODE_NORM_QC_NO},
+	{0xC91C, UNICODE_NORM_QC_NO},
+	{0xC91D, UNICODE_NORM_QC_NO},
+	{0xC91E, UNICODE_NORM_QC_NO},
+	{0xC91F, UNICODE_NORM_QC_NO},
+	{0xC920, UNICODE_NORM_QC_NO},
+	{0xC921, UNICODE_NORM_QC_NO},
+	{0xC922, UNICODE_NORM_QC_NO},
+	{0xC923, UNICODE_NORM_QC_NO},
+	{0xC924, UNICODE_NORM_QC_NO},
+	{0xC925, UNICODE_NORM_QC_NO},
+	{0xC926, UNICODE_NORM_QC_NO},
+	{0xC927, UNICODE_NORM_QC_NO},
+	{0xC928, UNICODE_NORM_QC_NO},
+	{0xC929, UNICODE_NORM_QC_NO},
+	{0xC92A, UNICODE_NORM_QC_NO},
+	{0xC92B, UNICODE_NORM_QC_NO},
+	{0xC92C, UNICODE_NORM_QC_NO},
+	{0xC92D, UNICODE_NORM_QC_NO},
+	{0xC92E, UNICODE_NORM_QC_NO},
+	{0xC92F, UNICODE_NORM_QC_NO},
+	{0xC930, UNICODE_NORM_QC_NO},
+	{0xC931, UNICODE_NORM_QC_NO},
+	{0xC932, UNICODE_NORM_QC_NO},
+	{0xC933, UNICODE_NORM_QC_NO},
+	{0xC934, UNICODE_NORM_QC_NO},
+	{0xC935, UNICODE_NORM_QC_NO},
+	{0xC936, UNICODE_NORM_QC_NO},
+	{0xC937, UNICODE_NORM_QC_NO},
+	{0xC938, UNICODE_NORM_QC_NO},
+	{0xC939, UNICODE_NORM_QC_NO},
+	{0xC93A, UNICODE_NORM_QC_NO},
+	{0xC93B, UNICODE_NORM_QC_NO},
+	{0xC93C, UNICODE_NORM_QC_NO},
+	{0xC93D, UNICODE_NORM_QC_NO},
+	{0xC93E, UNICODE_NORM_QC_NO},
+	{0xC93F, UNICODE_NORM_QC_NO},
+	{0xC940, UNICODE_NORM_QC_NO},
+	{0xC941, UNICODE_NORM_QC_NO},
+	{0xC942, UNICODE_NORM_QC_NO},
+	{0xC943, UNICODE_NORM_QC_NO},
+	{0xC944, UNICODE_NORM_QC_NO},
+	{0xC945, UNICODE_NORM_QC_NO},
+	{0xC946, UNICODE_NORM_QC_NO},
+	{0xC947, UNICODE_NORM_QC_NO},
+	{0xC948, UNICODE_NORM_QC_NO},
+	{0xC949, UNICODE_NORM_QC_NO},
+	{0xC94A, UNICODE_NORM_QC_NO},
+	{0xC94B, UNICODE_NORM_QC_NO},
+	{0xC94C, UNICODE_NORM_QC_NO},
+	{0xC94D, UNICODE_NORM_QC_NO},
+	{0xC94E, UNICODE_NORM_QC_NO},
+	{0xC94F, UNICODE_NORM_QC_NO},
+	{0xC950, UNICODE_NORM_QC_NO},
+	{0xC951, UNICODE_NORM_QC_NO},
+	{0xC952, UNICODE_NORM_QC_NO},
+	{0xC953, UNICODE_NORM_QC_NO},
+	{0xC954, UNICODE_NORM_QC_NO},
+	{0xC955, UNICODE_NORM_QC_NO},
+	{0xC956, UNICODE_NORM_QC_NO},
+	{0xC957, UNICODE_NORM_QC_NO},
+	{0xC958, UNICODE_NORM_QC_NO},
+	{0xC959, UNICODE_NORM_QC_NO},
+	{0xC95A, UNICODE_NORM_QC_NO},
+	{0xC95B, UNICODE_NORM_QC_NO},
+	{0xC95C, UNICODE_NORM_QC_NO},
+	{0xC95D, UNICODE_NORM_QC_NO},
+	{0xC95E, UNICODE_NORM_QC_NO},
+	{0xC95F, UNICODE_NORM_QC_NO},
+	{0xC960, UNICODE_NORM_QC_NO},
+	{0xC961, UNICODE_NORM_QC_NO},
+	{0xC962, UNICODE_NORM_QC_NO},
+	{0xC963, UNICODE_NORM_QC_NO},
+	{0xC964, UNICODE_NORM_QC_NO},
+	{0xC965, UNICODE_NORM_QC_NO},
+	{0xC966, UNICODE_NORM_QC_NO},
+	{0xC967, UNICODE_NORM_QC_NO},
+	{0xC968, UNICODE_NORM_QC_NO},
+	{0xC969, UNICODE_NORM_QC_NO},
+	{0xC96A, UNICODE_NORM_QC_NO},
+	{0xC96B, UNICODE_NORM_QC_NO},
+	{0xC96C, UNICODE_NORM_QC_NO},
+	{0xC96D, UNICODE_NORM_QC_NO},
+	{0xC96E, UNICODE_NORM_QC_NO},
+	{0xC96F, UNICODE_NORM_QC_NO},
+	{0xC970, UNICODE_NORM_QC_NO},
+	{0xC971, UNICODE_NORM_QC_NO},
+	{0xC972, UNICODE_NORM_QC_NO},
+	{0xC973, UNICODE_NORM_QC_NO},
+	{0xC974, UNICODE_NORM_QC_NO},
+	{0xC975, UNICODE_NORM_QC_NO},
+	{0xC976, UNICODE_NORM_QC_NO},
+	{0xC977, UNICODE_NORM_QC_NO},
+	{0xC978, UNICODE_NORM_QC_NO},
+	{0xC979, UNICODE_NORM_QC_NO},
+	{0xC97A, UNICODE_NORM_QC_NO},
+	{0xC97B, UNICODE_NORM_QC_NO},
+	{0xC97C, UNICODE_NORM_QC_NO},
+	{0xC97D, UNICODE_NORM_QC_NO},
+	{0xC97E, UNICODE_NORM_QC_NO},
+	{0xC97F, UNICODE_NORM_QC_NO},
+	{0xC980, UNICODE_NORM_QC_NO},
+	{0xC981, UNICODE_NORM_QC_NO},
+	{0xC982, UNICODE_NORM_QC_NO},
+	{0xC983, UNICODE_NORM_QC_NO},
+	{0xC984, UNICODE_NORM_QC_NO},
+	{0xC985, UNICODE_NORM_QC_NO},
+	{0xC986, UNICODE_NORM_QC_NO},
+	{0xC987, UNICODE_NORM_QC_NO},
+	{0xC988, UNICODE_NORM_QC_NO},
+	{0xC989, UNICODE_NORM_QC_NO},
+	{0xC98A, UNICODE_NORM_QC_NO},
+	{0xC98B, UNICODE_NORM_QC_NO},
+	{0xC98C, UNICODE_NORM_QC_NO},
+	{0xC98D, UNICODE_NORM_QC_NO},
+	{0xC98E, UNICODE_NORM_QC_NO},
+	{0xC98F, UNICODE_NORM_QC_NO},
+	{0xC990, UNICODE_NORM_QC_NO},
+	{0xC991, UNICODE_NORM_QC_NO},
+	{0xC992, UNICODE_NORM_QC_NO},
+	{0xC993, UNICODE_NORM_QC_NO},
+	{0xC994, UNICODE_NORM_QC_NO},
+	{0xC995, UNICODE_NORM_QC_NO},
+	{0xC996, UNICODE_NORM_QC_NO},
+	{0xC997, UNICODE_NORM_QC_NO},
+	{0xC998, UNICODE_NORM_QC_NO},
+	{0xC999, UNICODE_NORM_QC_NO},
+	{0xC99A, UNICODE_NORM_QC_NO},
+	{0xC99B, UNICODE_NORM_QC_NO},
+	{0xC99C, UNICODE_NORM_QC_NO},
+	{0xC99D, UNICODE_NORM_QC_NO},
+	{0xC99E, UNICODE_NORM_QC_NO},
+	{0xC99F, UNICODE_NORM_QC_NO},
+	{0xC9A0, UNICODE_NORM_QC_NO},
+	{0xC9A1, UNICODE_NORM_QC_NO},
+	{0xC9A2, UNICODE_NORM_QC_NO},
+	{0xC9A3, UNICODE_NORM_QC_NO},
+	{0xC9A4, UNICODE_NORM_QC_NO},
+	{0xC9A5, UNICODE_NORM_QC_NO},
+	{0xC9A6, UNICODE_NORM_QC_NO},
+	{0xC9A7, UNICODE_NORM_QC_NO},
+	{0xC9A8, UNICODE_NORM_QC_NO},
+	{0xC9A9, UNICODE_NORM_QC_NO},
+	{0xC9AA, UNICODE_NORM_QC_NO},
+	{0xC9AB, UNICODE_NORM_QC_NO},
+	{0xC9AC, UNICODE_NORM_QC_NO},
+	{0xC9AD, UNICODE_NORM_QC_NO},
+	{0xC9AE, UNICODE_NORM_QC_NO},
+	{0xC9AF, UNICODE_NORM_QC_NO},
+	{0xC9B0, UNICODE_NORM_QC_NO},
+	{0xC9B1, UNICODE_NORM_QC_NO},
+	{0xC9B2, UNICODE_NORM_QC_NO},
+	{0xC9B3, UNICODE_NORM_QC_NO},
+	{0xC9B4, UNICODE_NORM_QC_NO},
+	{0xC9B5, UNICODE_NORM_QC_NO},
+	{0xC9B6, UNICODE_NORM_QC_NO},
+	{0xC9B7, UNICODE_NORM_QC_NO},
+	{0xC9B8, UNICODE_NORM_QC_NO},
+	{0xC9B9, UNICODE_NORM_QC_NO},
+	{0xC9BA, UNICODE_NORM_QC_NO},
+	{0xC9BB, UNICODE_NORM_QC_NO},
+	{0xC9BC, UNICODE_NORM_QC_NO},
+	{0xC9BD, UNICODE_NORM_QC_NO},
+	{0xC9BE, UNICODE_NORM_QC_NO},
+	{0xC9BF, UNICODE_NORM_QC_NO},
+	{0xC9C0, UNICODE_NORM_QC_NO},
+	{0xC9C1, UNICODE_NORM_QC_NO},
+	{0xC9C2, UNICODE_NORM_QC_NO},
+	{0xC9C3, UNICODE_NORM_QC_NO},
+	{0xC9C4, UNICODE_NORM_QC_NO},
+	{0xC9C5, UNICODE_NORM_QC_NO},
+	{0xC9C6, UNICODE_NORM_QC_NO},
+	{0xC9C7, UNICODE_NORM_QC_NO},
+	{0xC9C8, UNICODE_NORM_QC_NO},
+	{0xC9C9, UNICODE_NORM_QC_NO},
+	{0xC9CA, UNICODE_NORM_QC_NO},
+	{0xC9CB, UNICODE_NORM_QC_NO},
+	{0xC9CC, UNICODE_NORM_QC_NO},
+	{0xC9CD, UNICODE_NORM_QC_NO},
+	{0xC9CE, UNICODE_NORM_QC_NO},
+	{0xC9CF, UNICODE_NORM_QC_NO},
+	{0xC9D0, UNICODE_NORM_QC_NO},
+	{0xC9D1, UNICODE_NORM_QC_NO},
+	{0xC9D2, UNICODE_NORM_QC_NO},
+	{0xC9D3, UNICODE_NORM_QC_NO},
+	{0xC9D4, UNICODE_NORM_QC_NO},
+	{0xC9D5, UNICODE_NORM_QC_NO},
+	{0xC9D6, UNICODE_NORM_QC_NO},
+	{0xC9D7, UNICODE_NORM_QC_NO},
+	{0xC9D8, UNICODE_NORM_QC_NO},
+	{0xC9D9, UNICODE_NORM_QC_NO},
+	{0xC9DA, UNICODE_NORM_QC_NO},
+	{0xC9DB, UNICODE_NORM_QC_NO},
+	{0xC9DC, UNICODE_NORM_QC_NO},
+	{0xC9DD, UNICODE_NORM_QC_NO},
+	{0xC9DE, UNICODE_NORM_QC_NO},
+	{0xC9DF, UNICODE_NORM_QC_NO},
+	{0xC9E0, UNICODE_NORM_QC_NO},
+	{0xC9E1, UNICODE_NORM_QC_NO},
+	{0xC9E2, UNICODE_NORM_QC_NO},
+	{0xC9E3, UNICODE_NORM_QC_NO},
+	{0xC9E4, UNICODE_NORM_QC_NO},
+	{0xC9E5, UNICODE_NORM_QC_NO},
+	{0xC9E6, UNICODE_NORM_QC_NO},
+	{0xC9E7, UNICODE_NORM_QC_NO},
+	{0xC9E8, UNICODE_NORM_QC_NO},
+	{0xC9E9, UNICODE_NORM_QC_NO},
+	{0xC9EA, UNICODE_NORM_QC_NO},
+	{0xC9EB, UNICODE_NORM_QC_NO},
+	{0xC9EC, UNICODE_NORM_QC_NO},
+	{0xC9ED, UNICODE_NORM_QC_NO},
+	{0xC9EE, UNICODE_NORM_QC_NO},
+	{0xC9EF, UNICODE_NORM_QC_NO},
+	{0xC9F0, UNICODE_NORM_QC_NO},
+	{0xC9F1, UNICODE_NORM_QC_NO},
+	{0xC9F2, UNICODE_NORM_QC_NO},
+	{0xC9F3, UNICODE_NORM_QC_NO},
+	{0xC9F4, UNICODE_NORM_QC_NO},
+	{0xC9F5, UNICODE_NORM_QC_NO},
+	{0xC9F6, UNICODE_NORM_QC_NO},
+	{0xC9F7, UNICODE_NORM_QC_NO},
+	{0xC9F8, UNICODE_NORM_QC_NO},
+	{0xC9F9, UNICODE_NORM_QC_NO},
+	{0xC9FA, UNICODE_NORM_QC_NO},
+	{0xC9FB, UNICODE_NORM_QC_NO},
+	{0xC9FC, UNICODE_NORM_QC_NO},
+	{0xC9FD, UNICODE_NORM_QC_NO},
+	{0xC9FE, UNICODE_NORM_QC_NO},
+	{0xC9FF, UNICODE_NORM_QC_NO},
+	{0xCA00, UNICODE_NORM_QC_NO},
+	{0xCA01, UNICODE_NORM_QC_NO},
+	{0xCA02, UNICODE_NORM_QC_NO},
+	{0xCA03, UNICODE_NORM_QC_NO},
+	{0xCA04, UNICODE_NORM_QC_NO},
+	{0xCA05, UNICODE_NORM_QC_NO},
+	{0xCA06, UNICODE_NORM_QC_NO},
+	{0xCA07, UNICODE_NORM_QC_NO},
+	{0xCA08, UNICODE_NORM_QC_NO},
+	{0xCA09, UNICODE_NORM_QC_NO},
+	{0xCA0A, UNICODE_NORM_QC_NO},
+	{0xCA0B, UNICODE_NORM_QC_NO},
+	{0xCA0C, UNICODE_NORM_QC_NO},
+	{0xCA0D, UNICODE_NORM_QC_NO},
+	{0xCA0E, UNICODE_NORM_QC_NO},
+	{0xCA0F, UNICODE_NORM_QC_NO},
+	{0xCA10, UNICODE_NORM_QC_NO},
+	{0xCA11, UNICODE_NORM_QC_NO},
+	{0xCA12, UNICODE_NORM_QC_NO},
+	{0xCA13, UNICODE_NORM_QC_NO},
+	{0xCA14, UNICODE_NORM_QC_NO},
+	{0xCA15, UNICODE_NORM_QC_NO},
+	{0xCA16, UNICODE_NORM_QC_NO},
+	{0xCA17, UNICODE_NORM_QC_NO},
+	{0xCA18, UNICODE_NORM_QC_NO},
+	{0xCA19, UNICODE_NORM_QC_NO},
+	{0xCA1A, UNICODE_NORM_QC_NO},
+	{0xCA1B, UNICODE_NORM_QC_NO},
+	{0xCA1C, UNICODE_NORM_QC_NO},
+	{0xCA1D, UNICODE_NORM_QC_NO},
+	{0xCA1E, UNICODE_NORM_QC_NO},
+	{0xCA1F, UNICODE_NORM_QC_NO},
+	{0xCA20, UNICODE_NORM_QC_NO},
+	{0xCA21, UNICODE_NORM_QC_NO},
+	{0xCA22, UNICODE_NORM_QC_NO},
+	{0xCA23, UNICODE_NORM_QC_NO},
+	{0xCA24, UNICODE_NORM_QC_NO},
+	{0xCA25, UNICODE_NORM_QC_NO},
+	{0xCA26, UNICODE_NORM_QC_NO},
+	{0xCA27, UNICODE_NORM_QC_NO},
+	{0xCA28, UNICODE_NORM_QC_NO},
+	{0xCA29, UNICODE_NORM_QC_NO},
+	{0xCA2A, UNICODE_NORM_QC_NO},
+	{0xCA2B, UNICODE_NORM_QC_NO},
+	{0xCA2C, UNICODE_NORM_QC_NO},
+	{0xCA2D, UNICODE_NORM_QC_NO},
+	{0xCA2E, UNICODE_NORM_QC_NO},
+	{0xCA2F, UNICODE_NORM_QC_NO},
+	{0xCA30, UNICODE_NORM_QC_NO},
+	{0xCA31, UNICODE_NORM_QC_NO},
+	{0xCA32, UNICODE_NORM_QC_NO},
+	{0xCA33, UNICODE_NORM_QC_NO},
+	{0xCA34, UNICODE_NORM_QC_NO},
+	{0xCA35, UNICODE_NORM_QC_NO},
+	{0xCA36, UNICODE_NORM_QC_NO},
+	{0xCA37, UNICODE_NORM_QC_NO},
+	{0xCA38, UNICODE_NORM_QC_NO},
+	{0xCA39, UNICODE_NORM_QC_NO},
+	{0xCA3A, UNICODE_NORM_QC_NO},
+	{0xCA3B, UNICODE_NORM_QC_NO},
+	{0xCA3C, UNICODE_NORM_QC_NO},
+	{0xCA3D, UNICODE_NORM_QC_NO},
+	{0xCA3E, UNICODE_NORM_QC_NO},
+	{0xCA3F, UNICODE_NORM_QC_NO},
+	{0xCA40, UNICODE_NORM_QC_NO},
+	{0xCA41, UNICODE_NORM_QC_NO},
+	{0xCA42, UNICODE_NORM_QC_NO},
+	{0xCA43, UNICODE_NORM_QC_NO},
+	{0xCA44, UNICODE_NORM_QC_NO},
+	{0xCA45, UNICODE_NORM_QC_NO},
+	{0xCA46, UNICODE_NORM_QC_NO},
+	{0xCA47, UNICODE_NORM_QC_NO},
+	{0xCA48, UNICODE_NORM_QC_NO},
+	{0xCA49, UNICODE_NORM_QC_NO},
+	{0xCA4A, UNICODE_NORM_QC_NO},
+	{0xCA4B, UNICODE_NORM_QC_NO},
+	{0xCA4C, UNICODE_NORM_QC_NO},
+	{0xCA4D, UNICODE_NORM_QC_NO},
+	{0xCA4E, UNICODE_NORM_QC_NO},
+	{0xCA4F, UNICODE_NORM_QC_NO},
+	{0xCA50, UNICODE_NORM_QC_NO},
+	{0xCA51, UNICODE_NORM_QC_NO},
+	{0xCA52, UNICODE_NORM_QC_NO},
+	{0xCA53, UNICODE_NORM_QC_NO},
+	{0xCA54, UNICODE_NORM_QC_NO},
+	{0xCA55, UNICODE_NORM_QC_NO},
+	{0xCA56, UNICODE_NORM_QC_NO},
+	{0xCA57, UNICODE_NORM_QC_NO},
+	{0xCA58, UNICODE_NORM_QC_NO},
+	{0xCA59, UNICODE_NORM_QC_NO},
+	{0xCA5A, UNICODE_NORM_QC_NO},
+	{0xCA5B, UNICODE_NORM_QC_NO},
+	{0xCA5C, UNICODE_NORM_QC_NO},
+	{0xCA5D, UNICODE_NORM_QC_NO},
+	{0xCA5E, UNICODE_NORM_QC_NO},
+	{0xCA5F, UNICODE_NORM_QC_NO},
+	{0xCA60, UNICODE_NORM_QC_NO},
+	{0xCA61, UNICODE_NORM_QC_NO},
+	{0xCA62, UNICODE_NORM_QC_NO},
+	{0xCA63, UNICODE_NORM_QC_NO},
+	{0xCA64, UNICODE_NORM_QC_NO},
+	{0xCA65, UNICODE_NORM_QC_NO},
+	{0xCA66, UNICODE_NORM_QC_NO},
+	{0xCA67, UNICODE_NORM_QC_NO},
+	{0xCA68, UNICODE_NORM_QC_NO},
+	{0xCA69, UNICODE_NORM_QC_NO},
+	{0xCA6A, UNICODE_NORM_QC_NO},
+	{0xCA6B, UNICODE_NORM_QC_NO},
+	{0xCA6C, UNICODE_NORM_QC_NO},
+	{0xCA6D, UNICODE_NORM_QC_NO},
+	{0xCA6E, UNICODE_NORM_QC_NO},
+	{0xCA6F, UNICODE_NORM_QC_NO},
+	{0xCA70, UNICODE_NORM_QC_NO},
+	{0xCA71, UNICODE_NORM_QC_NO},
+	{0xCA72, UNICODE_NORM_QC_NO},
+	{0xCA73, UNICODE_NORM_QC_NO},
+	{0xCA74, UNICODE_NORM_QC_NO},
+	{0xCA75, UNICODE_NORM_QC_NO},
+	{0xCA76, UNICODE_NORM_QC_NO},
+	{0xCA77, UNICODE_NORM_QC_NO},
+	{0xCA78, UNICODE_NORM_QC_NO},
+	{0xCA79, UNICODE_NORM_QC_NO},
+	{0xCA7A, UNICODE_NORM_QC_NO},
+	{0xCA7B, UNICODE_NORM_QC_NO},
+	{0xCA7C, UNICODE_NORM_QC_NO},
+	{0xCA7D, UNICODE_NORM_QC_NO},
+	{0xCA7E, UNICODE_NORM_QC_NO},
+	{0xCA7F, UNICODE_NORM_QC_NO},
+	{0xCA80, UNICODE_NORM_QC_NO},
+	{0xCA81, UNICODE_NORM_QC_NO},
+	{0xCA82, UNICODE_NORM_QC_NO},
+	{0xCA83, UNICODE_NORM_QC_NO},
+	{0xCA84, UNICODE_NORM_QC_NO},
+	{0xCA85, UNICODE_NORM_QC_NO},
+	{0xCA86, UNICODE_NORM_QC_NO},
+	{0xCA87, UNICODE_NORM_QC_NO},
+	{0xCA88, UNICODE_NORM_QC_NO},
+	{0xCA89, UNICODE_NORM_QC_NO},
+	{0xCA8A, UNICODE_NORM_QC_NO},
+	{0xCA8B, UNICODE_NORM_QC_NO},
+	{0xCA8C, UNICODE_NORM_QC_NO},
+	{0xCA8D, UNICODE_NORM_QC_NO},
+	{0xCA8E, UNICODE_NORM_QC_NO},
+	{0xCA8F, UNICODE_NORM_QC_NO},
+	{0xCA90, UNICODE_NORM_QC_NO},
+	{0xCA91, UNICODE_NORM_QC_NO},
+	{0xCA92, UNICODE_NORM_QC_NO},
+	{0xCA93, UNICODE_NORM_QC_NO},
+	{0xCA94, UNICODE_NORM_QC_NO},
+	{0xCA95, UNICODE_NORM_QC_NO},
+	{0xCA96, UNICODE_NORM_QC_NO},
+	{0xCA97, UNICODE_NORM_QC_NO},
+	{0xCA98, UNICODE_NORM_QC_NO},
+	{0xCA99, UNICODE_NORM_QC_NO},
+	{0xCA9A, UNICODE_NORM_QC_NO},
+	{0xCA9B, UNICODE_NORM_QC_NO},
+	{0xCA9C, UNICODE_NORM_QC_NO},
+	{0xCA9D, UNICODE_NORM_QC_NO},
+	{0xCA9E, UNICODE_NORM_QC_NO},
+	{0xCA9F, UNICODE_NORM_QC_NO},
+	{0xCAA0, UNICODE_NORM_QC_NO},
+	{0xCAA1, UNICODE_NORM_QC_NO},
+	{0xCAA2, UNICODE_NORM_QC_NO},
+	{0xCAA3, UNICODE_NORM_QC_NO},
+	{0xCAA4, UNICODE_NORM_QC_NO},
+	{0xCAA5, UNICODE_NORM_QC_NO},
+	{0xCAA6, UNICODE_NORM_QC_NO},
+	{0xCAA7, UNICODE_NORM_QC_NO},
+	{0xCAA8, UNICODE_NORM_QC_NO},
+	{0xCAA9, UNICODE_NORM_QC_NO},
+	{0xCAAA, UNICODE_NORM_QC_NO},
+	{0xCAAB, UNICODE_NORM_QC_NO},
+	{0xCAAC, UNICODE_NORM_QC_NO},
+	{0xCAAD, UNICODE_NORM_QC_NO},
+	{0xCAAE, UNICODE_NORM_QC_NO},
+	{0xCAAF, UNICODE_NORM_QC_NO},
+	{0xCAB0, UNICODE_NORM_QC_NO},
+	{0xCAB1, UNICODE_NORM_QC_NO},
+	{0xCAB2, UNICODE_NORM_QC_NO},
+	{0xCAB3, UNICODE_NORM_QC_NO},
+	{0xCAB4, UNICODE_NORM_QC_NO},
+	{0xCAB5, UNICODE_NORM_QC_NO},
+	{0xCAB6, UNICODE_NORM_QC_NO},
+	{0xCAB7, UNICODE_NORM_QC_NO},
+	{0xCAB8, UNICODE_NORM_QC_NO},
+	{0xCAB9, UNICODE_NORM_QC_NO},
+	{0xCABA, UNICODE_NORM_QC_NO},
+	{0xCABB, UNICODE_NORM_QC_NO},
+	{0xCABC, UNICODE_NORM_QC_NO},
+	{0xCABD, UNICODE_NORM_QC_NO},
+	{0xCABE, UNICODE_NORM_QC_NO},
+	{0xCABF, UNICODE_NORM_QC_NO},
+	{0xCAC0, UNICODE_NORM_QC_NO},
+	{0xCAC1, UNICODE_NORM_QC_NO},
+	{0xCAC2, UNICODE_NORM_QC_NO},
+	{0xCAC3, UNICODE_NORM_QC_NO},
+	{0xCAC4, UNICODE_NORM_QC_NO},
+	{0xCAC5, UNICODE_NORM_QC_NO},
+	{0xCAC6, UNICODE_NORM_QC_NO},
+	{0xCAC7, UNICODE_NORM_QC_NO},
+	{0xCAC8, UNICODE_NORM_QC_NO},
+	{0xCAC9, UNICODE_NORM_QC_NO},
+	{0xCACA, UNICODE_NORM_QC_NO},
+	{0xCACB, UNICODE_NORM_QC_NO},
+	{0xCACC, UNICODE_NORM_QC_NO},
+	{0xCACD, UNICODE_NORM_QC_NO},
+	{0xCACE, UNICODE_NORM_QC_NO},
+	{0xCACF, UNICODE_NORM_QC_NO},
+	{0xCAD0, UNICODE_NORM_QC_NO},
+	{0xCAD1, UNICODE_NORM_QC_NO},
+	{0xCAD2, UNICODE_NORM_QC_NO},
+	{0xCAD3, UNICODE_NORM_QC_NO},
+	{0xCAD4, UNICODE_NORM_QC_NO},
+	{0xCAD5, UNICODE_NORM_QC_NO},
+	{0xCAD6, UNICODE_NORM_QC_NO},
+	{0xCAD7, UNICODE_NORM_QC_NO},
+	{0xCAD8, UNICODE_NORM_QC_NO},
+	{0xCAD9, UNICODE_NORM_QC_NO},
+	{0xCADA, UNICODE_NORM_QC_NO},
+	{0xCADB, UNICODE_NORM_QC_NO},
+	{0xCADC, UNICODE_NORM_QC_NO},
+	{0xCADD, UNICODE_NORM_QC_NO},
+	{0xCADE, UNICODE_NORM_QC_NO},
+	{0xCADF, UNICODE_NORM_QC_NO},
+	{0xCAE0, UNICODE_NORM_QC_NO},
+	{0xCAE1, UNICODE_NORM_QC_NO},
+	{0xCAE2, UNICODE_NORM_QC_NO},
+	{0xCAE3, UNICODE_NORM_QC_NO},
+	{0xCAE4, UNICODE_NORM_QC_NO},
+	{0xCAE5, UNICODE_NORM_QC_NO},
+	{0xCAE6, UNICODE_NORM_QC_NO},
+	{0xCAE7, UNICODE_NORM_QC_NO},
+	{0xCAE8, UNICODE_NORM_QC_NO},
+	{0xCAE9, UNICODE_NORM_QC_NO},
+	{0xCAEA, UNICODE_NORM_QC_NO},
+	{0xCAEB, UNICODE_NORM_QC_NO},
+	{0xCAEC, UNICODE_NORM_QC_NO},
+	{0xCAED, UNICODE_NORM_QC_NO},
+	{0xCAEE, UNICODE_NORM_QC_NO},
+	{0xCAEF, UNICODE_NORM_QC_NO},
+	{0xCAF0, UNICODE_NORM_QC_NO},
+	{0xCAF1, UNICODE_NORM_QC_NO},
+	{0xCAF2, UNICODE_NORM_QC_NO},
+	{0xCAF3, UNICODE_NORM_QC_NO},
+	{0xCAF4, UNICODE_NORM_QC_NO},
+	{0xCAF5, UNICODE_NORM_QC_NO},
+	{0xCAF6, UNICODE_NORM_QC_NO},
+	{0xCAF7, UNICODE_NORM_QC_NO},
+	{0xCAF8, UNICODE_NORM_QC_NO},
+	{0xCAF9, UNICODE_NORM_QC_NO},
+	{0xCAFA, UNICODE_NORM_QC_NO},
+	{0xCAFB, UNICODE_NORM_QC_NO},
+	{0xCAFC, UNICODE_NORM_QC_NO},
+	{0xCAFD, UNICODE_NORM_QC_NO},
+	{0xCAFE, UNICODE_NORM_QC_NO},
+	{0xCAFF, UNICODE_NORM_QC_NO},
+	{0xCB00, UNICODE_NORM_QC_NO},
+	{0xCB01, UNICODE_NORM_QC_NO},
+	{0xCB02, UNICODE_NORM_QC_NO},
+	{0xCB03, UNICODE_NORM_QC_NO},
+	{0xCB04, UNICODE_NORM_QC_NO},
+	{0xCB05, UNICODE_NORM_QC_NO},
+	{0xCB06, UNICODE_NORM_QC_NO},
+	{0xCB07, UNICODE_NORM_QC_NO},
+	{0xCB08, UNICODE_NORM_QC_NO},
+	{0xCB09, UNICODE_NORM_QC_NO},
+	{0xCB0A, UNICODE_NORM_QC_NO},
+	{0xCB0B, UNICODE_NORM_QC_NO},
+	{0xCB0C, UNICODE_NORM_QC_NO},
+	{0xCB0D, UNICODE_NORM_QC_NO},
+	{0xCB0E, UNICODE_NORM_QC_NO},
+	{0xCB0F, UNICODE_NORM_QC_NO},
+	{0xCB10, UNICODE_NORM_QC_NO},
+	{0xCB11, UNICODE_NORM_QC_NO},
+	{0xCB12, UNICODE_NORM_QC_NO},
+	{0xCB13, UNICODE_NORM_QC_NO},
+	{0xCB14, UNICODE_NORM_QC_NO},
+	{0xCB15, UNICODE_NORM_QC_NO},
+	{0xCB16, UNICODE_NORM_QC_NO},
+	{0xCB17, UNICODE_NORM_QC_NO},
+	{0xCB18, UNICODE_NORM_QC_NO},
+	{0xCB19, UNICODE_NORM_QC_NO},
+	{0xCB1A, UNICODE_NORM_QC_NO},
+	{0xCB1B, UNICODE_NORM_QC_NO},
+	{0xCB1C, UNICODE_NORM_QC_NO},
+	{0xCB1D, UNICODE_NORM_QC_NO},
+	{0xCB1E, UNICODE_NORM_QC_NO},
+	{0xCB1F, UNICODE_NORM_QC_NO},
+	{0xCB20, UNICODE_NORM_QC_NO},
+	{0xCB21, UNICODE_NORM_QC_NO},
+	{0xCB22, UNICODE_NORM_QC_NO},
+	{0xCB23, UNICODE_NORM_QC_NO},
+	{0xCB24, UNICODE_NORM_QC_NO},
+	{0xCB25, UNICODE_NORM_QC_NO},
+	{0xCB26, UNICODE_NORM_QC_NO},
+	{0xCB27, UNICODE_NORM_QC_NO},
+	{0xCB28, UNICODE_NORM_QC_NO},
+	{0xCB29, UNICODE_NORM_QC_NO},
+	{0xCB2A, UNICODE_NORM_QC_NO},
+	{0xCB2B, UNICODE_NORM_QC_NO},
+	{0xCB2C, UNICODE_NORM_QC_NO},
+	{0xCB2D, UNICODE_NORM_QC_NO},
+	{0xCB2E, UNICODE_NORM_QC_NO},
+	{0xCB2F, UNICODE_NORM_QC_NO},
+	{0xCB30, UNICODE_NORM_QC_NO},
+	{0xCB31, UNICODE_NORM_QC_NO},
+	{0xCB32, UNICODE_NORM_QC_NO},
+	{0xCB33, UNICODE_NORM_QC_NO},
+	{0xCB34, UNICODE_NORM_QC_NO},
+	{0xCB35, UNICODE_NORM_QC_NO},
+	{0xCB36, UNICODE_NORM_QC_NO},
+	{0xCB37, UNICODE_NORM_QC_NO},
+	{0xCB38, UNICODE_NORM_QC_NO},
+	{0xCB39, UNICODE_NORM_QC_NO},
+	{0xCB3A, UNICODE_NORM_QC_NO},
+	{0xCB3B, UNICODE_NORM_QC_NO},
+	{0xCB3C, UNICODE_NORM_QC_NO},
+	{0xCB3D, UNICODE_NORM_QC_NO},
+	{0xCB3E, UNICODE_NORM_QC_NO},
+	{0xCB3F, UNICODE_NORM_QC_NO},
+	{0xCB40, UNICODE_NORM_QC_NO},
+	{0xCB41, UNICODE_NORM_QC_NO},
+	{0xCB42, UNICODE_NORM_QC_NO},
+	{0xCB43, UNICODE_NORM_QC_NO},
+	{0xCB44, UNICODE_NORM_QC_NO},
+	{0xCB45, UNICODE_NORM_QC_NO},
+	{0xCB46, UNICODE_NORM_QC_NO},
+	{0xCB47, UNICODE_NORM_QC_NO},
+	{0xCB48, UNICODE_NORM_QC_NO},
+	{0xCB49, UNICODE_NORM_QC_NO},
+	{0xCB4A, UNICODE_NORM_QC_NO},
+	{0xCB4B, UNICODE_NORM_QC_NO},
+	{0xCB4C, UNICODE_NORM_QC_NO},
+	{0xCB4D, UNICODE_NORM_QC_NO},
+	{0xCB4E, UNICODE_NORM_QC_NO},
+	{0xCB4F, UNICODE_NORM_QC_NO},
+	{0xCB50, UNICODE_NORM_QC_NO},
+	{0xCB51, UNICODE_NORM_QC_NO},
+	{0xCB52, UNICODE_NORM_QC_NO},
+	{0xCB53, UNICODE_NORM_QC_NO},
+	{0xCB54, UNICODE_NORM_QC_NO},
+	{0xCB55, UNICODE_NORM_QC_NO},
+	{0xCB56, UNICODE_NORM_QC_NO},
+	{0xCB57, UNICODE_NORM_QC_NO},
+	{0xCB58, UNICODE_NORM_QC_NO},
+	{0xCB59, UNICODE_NORM_QC_NO},
+	{0xCB5A, UNICODE_NORM_QC_NO},
+	{0xCB5B, UNICODE_NORM_QC_NO},
+	{0xCB5C, UNICODE_NORM_QC_NO},
+	{0xCB5D, UNICODE_NORM_QC_NO},
+	{0xCB5E, UNICODE_NORM_QC_NO},
+	{0xCB5F, UNICODE_NORM_QC_NO},
+	{0xCB60, UNICODE_NORM_QC_NO},
+	{0xCB61, UNICODE_NORM_QC_NO},
+	{0xCB62, UNICODE_NORM_QC_NO},
+	{0xCB63, UNICODE_NORM_QC_NO},
+	{0xCB64, UNICODE_NORM_QC_NO},
+	{0xCB65, UNICODE_NORM_QC_NO},
+	{0xCB66, UNICODE_NORM_QC_NO},
+	{0xCB67, UNICODE_NORM_QC_NO},
+	{0xCB68, UNICODE_NORM_QC_NO},
+	{0xCB69, UNICODE_NORM_QC_NO},
+	{0xCB6A, UNICODE_NORM_QC_NO},
+	{0xCB6B, UNICODE_NORM_QC_NO},
+	{0xCB6C, UNICODE_NORM_QC_NO},
+	{0xCB6D, UNICODE_NORM_QC_NO},
+	{0xCB6E, UNICODE_NORM_QC_NO},
+	{0xCB6F, UNICODE_NORM_QC_NO},
+	{0xCB70, UNICODE_NORM_QC_NO},
+	{0xCB71, UNICODE_NORM_QC_NO},
+	{0xCB72, UNICODE_NORM_QC_NO},
+	{0xCB73, UNICODE_NORM_QC_NO},
+	{0xCB74, UNICODE_NORM_QC_NO},
+	{0xCB75, UNICODE_NORM_QC_NO},
+	{0xCB76, UNICODE_NORM_QC_NO},
+	{0xCB77, UNICODE_NORM_QC_NO},
+	{0xCB78, UNICODE_NORM_QC_NO},
+	{0xCB79, UNICODE_NORM_QC_NO},
+	{0xCB7A, UNICODE_NORM_QC_NO},
+	{0xCB7B, UNICODE_NORM_QC_NO},
+	{0xCB7C, UNICODE_NORM_QC_NO},
+	{0xCB7D, UNICODE_NORM_QC_NO},
+	{0xCB7E, UNICODE_NORM_QC_NO},
+	{0xCB7F, UNICODE_NORM_QC_NO},
+	{0xCB80, UNICODE_NORM_QC_NO},
+	{0xCB81, UNICODE_NORM_QC_NO},
+	{0xCB82, UNICODE_NORM_QC_NO},
+	{0xCB83, UNICODE_NORM_QC_NO},
+	{0xCB84, UNICODE_NORM_QC_NO},
+	{0xCB85, UNICODE_NORM_QC_NO},
+	{0xCB86, UNICODE_NORM_QC_NO},
+	{0xCB87, UNICODE_NORM_QC_NO},
+	{0xCB88, UNICODE_NORM_QC_NO},
+	{0xCB89, UNICODE_NORM_QC_NO},
+	{0xCB8A, UNICODE_NORM_QC_NO},
+	{0xCB8B, UNICODE_NORM_QC_NO},
+	{0xCB8C, UNICODE_NORM_QC_NO},
+	{0xCB8D, UNICODE_NORM_QC_NO},
+	{0xCB8E, UNICODE_NORM_QC_NO},
+	{0xCB8F, UNICODE_NORM_QC_NO},
+	{0xCB90, UNICODE_NORM_QC_NO},
+	{0xCB91, UNICODE_NORM_QC_NO},
+	{0xCB92, UNICODE_NORM_QC_NO},
+	{0xCB93, UNICODE_NORM_QC_NO},
+	{0xCB94, UNICODE_NORM_QC_NO},
+	{0xCB95, UNICODE_NORM_QC_NO},
+	{0xCB96, UNICODE_NORM_QC_NO},
+	{0xCB97, UNICODE_NORM_QC_NO},
+	{0xCB98, UNICODE_NORM_QC_NO},
+	{0xCB99, UNICODE_NORM_QC_NO},
+	{0xCB9A, UNICODE_NORM_QC_NO},
+	{0xCB9B, UNICODE_NORM_QC_NO},
+	{0xCB9C, UNICODE_NORM_QC_NO},
+	{0xCB9D, UNICODE_NORM_QC_NO},
+	{0xCB9E, UNICODE_NORM_QC_NO},
+	{0xCB9F, UNICODE_NORM_QC_NO},
+	{0xCBA0, UNICODE_NORM_QC_NO},
+	{0xCBA1, UNICODE_NORM_QC_NO},
+	{0xCBA2, UNICODE_NORM_QC_NO},
+	{0xCBA3, UNICODE_NORM_QC_NO},
+	{0xCBA4, UNICODE_NORM_QC_NO},
+	{0xCBA5, UNICODE_NORM_QC_NO},
+	{0xCBA6, UNICODE_NORM_QC_NO},
+	{0xCBA7, UNICODE_NORM_QC_NO},
+	{0xCBA8, UNICODE_NORM_QC_NO},
+	{0xCBA9, UNICODE_NORM_QC_NO},
+	{0xCBAA, UNICODE_NORM_QC_NO},
+	{0xCBAB, UNICODE_NORM_QC_NO},
+	{0xCBAC, UNICODE_NORM_QC_NO},
+	{0xCBAD, UNICODE_NORM_QC_NO},
+	{0xCBAE, UNICODE_NORM_QC_NO},
+	{0xCBAF, UNICODE_NORM_QC_NO},
+	{0xCBB0, UNICODE_NORM_QC_NO},
+	{0xCBB1, UNICODE_NORM_QC_NO},
+	{0xCBB2, UNICODE_NORM_QC_NO},
+	{0xCBB3, UNICODE_NORM_QC_NO},
+	{0xCBB4, UNICODE_NORM_QC_NO},
+	{0xCBB5, UNICODE_NORM_QC_NO},
+	{0xCBB6, UNICODE_NORM_QC_NO},
+	{0xCBB7, UNICODE_NORM_QC_NO},
+	{0xCBB8, UNICODE_NORM_QC_NO},
+	{0xCBB9, UNICODE_NORM_QC_NO},
+	{0xCBBA, UNICODE_NORM_QC_NO},
+	{0xCBBB, UNICODE_NORM_QC_NO},
+	{0xCBBC, UNICODE_NORM_QC_NO},
+	{0xCBBD, UNICODE_NORM_QC_NO},
+	{0xCBBE, UNICODE_NORM_QC_NO},
+	{0xCBBF, UNICODE_NORM_QC_NO},
+	{0xCBC0, UNICODE_NORM_QC_NO},
+	{0xCBC1, UNICODE_NORM_QC_NO},
+	{0xCBC2, UNICODE_NORM_QC_NO},
+	{0xCBC3, UNICODE_NORM_QC_NO},
+	{0xCBC4, UNICODE_NORM_QC_NO},
+	{0xCBC5, UNICODE_NORM_QC_NO},
+	{0xCBC6, UNICODE_NORM_QC_NO},
+	{0xCBC7, UNICODE_NORM_QC_NO},
+	{0xCBC8, UNICODE_NORM_QC_NO},
+	{0xCBC9, UNICODE_NORM_QC_NO},
+	{0xCBCA, UNICODE_NORM_QC_NO},
+	{0xCBCB, UNICODE_NORM_QC_NO},
+	{0xCBCC, UNICODE_NORM_QC_NO},
+	{0xCBCD, UNICODE_NORM_QC_NO},
+	{0xCBCE, UNICODE_NORM_QC_NO},
+	{0xCBCF, UNICODE_NORM_QC_NO},
+	{0xCBD0, UNICODE_NORM_QC_NO},
+	{0xCBD1, UNICODE_NORM_QC_NO},
+	{0xCBD2, UNICODE_NORM_QC_NO},
+	{0xCBD3, UNICODE_NORM_QC_NO},
+	{0xCBD4, UNICODE_NORM_QC_NO},
+	{0xCBD5, UNICODE_NORM_QC_NO},
+	{0xCBD6, UNICODE_NORM_QC_NO},
+	{0xCBD7, UNICODE_NORM_QC_NO},
+	{0xCBD8, UNICODE_NORM_QC_NO},
+	{0xCBD9, UNICODE_NORM_QC_NO},
+	{0xCBDA, UNICODE_NORM_QC_NO},
+	{0xCBDB, UNICODE_NORM_QC_NO},
+	{0xCBDC, UNICODE_NORM_QC_NO},
+	{0xCBDD, UNICODE_NORM_QC_NO},
+	{0xCBDE, UNICODE_NORM_QC_NO},
+	{0xCBDF, UNICODE_NORM_QC_NO},
+	{0xCBE0, UNICODE_NORM_QC_NO},
+	{0xCBE1, UNICODE_NORM_QC_NO},
+	{0xCBE2, UNICODE_NORM_QC_NO},
+	{0xCBE3, UNICODE_NORM_QC_NO},
+	{0xCBE4, UNICODE_NORM_QC_NO},
+	{0xCBE5, UNICODE_NORM_QC_NO},
+	{0xCBE6, UNICODE_NORM_QC_NO},
+	{0xCBE7, UNICODE_NORM_QC_NO},
+	{0xCBE8, UNICODE_NORM_QC_NO},
+	{0xCBE9, UNICODE_NORM_QC_NO},
+	{0xCBEA, UNICODE_NORM_QC_NO},
+	{0xCBEB, UNICODE_NORM_QC_NO},
+	{0xCBEC, UNICODE_NORM_QC_NO},
+	{0xCBED, UNICODE_NORM_QC_NO},
+	{0xCBEE, UNICODE_NORM_QC_NO},
+	{0xCBEF, UNICODE_NORM_QC_NO},
+	{0xCBF0, UNICODE_NORM_QC_NO},
+	{0xCBF1, UNICODE_NORM_QC_NO},
+	{0xCBF2, UNICODE_NORM_QC_NO},
+	{0xCBF3, UNICODE_NORM_QC_NO},
+	{0xCBF4, UNICODE_NORM_QC_NO},
+	{0xCBF5, UNICODE_NORM_QC_NO},
+	{0xCBF6, UNICODE_NORM_QC_NO},
+	{0xCBF7, UNICODE_NORM_QC_NO},
+	{0xCBF8, UNICODE_NORM_QC_NO},
+	{0xCBF9, UNICODE_NORM_QC_NO},
+	{0xCBFA, UNICODE_NORM_QC_NO},
+	{0xCBFB, UNICODE_NORM_QC_NO},
+	{0xCBFC, UNICODE_NORM_QC_NO},
+	{0xCBFD, UNICODE_NORM_QC_NO},
+	{0xCBFE, UNICODE_NORM_QC_NO},
+	{0xCBFF, UNICODE_NORM_QC_NO},
+	{0xCC00, UNICODE_NORM_QC_NO},
+	{0xCC01, UNICODE_NORM_QC_NO},
+	{0xCC02, UNICODE_NORM_QC_NO},
+	{0xCC03, UNICODE_NORM_QC_NO},
+	{0xCC04, UNICODE_NORM_QC_NO},
+	{0xCC05, UNICODE_NORM_QC_NO},
+	{0xCC06, UNICODE_NORM_QC_NO},
+	{0xCC07, UNICODE_NORM_QC_NO},
+	{0xCC08, UNICODE_NORM_QC_NO},
+	{0xCC09, UNICODE_NORM_QC_NO},
+	{0xCC0A, UNICODE_NORM_QC_NO},
+	{0xCC0B, UNICODE_NORM_QC_NO},
+	{0xCC0C, UNICODE_NORM_QC_NO},
+	{0xCC0D, UNICODE_NORM_QC_NO},
+	{0xCC0E, UNICODE_NORM_QC_NO},
+	{0xCC0F, UNICODE_NORM_QC_NO},
+	{0xCC10, UNICODE_NORM_QC_NO},
+	{0xCC11, UNICODE_NORM_QC_NO},
+	{0xCC12, UNICODE_NORM_QC_NO},
+	{0xCC13, UNICODE_NORM_QC_NO},
+	{0xCC14, UNICODE_NORM_QC_NO},
+	{0xCC15, UNICODE_NORM_QC_NO},
+	{0xCC16, UNICODE_NORM_QC_NO},
+	{0xCC17, UNICODE_NORM_QC_NO},
+	{0xCC18, UNICODE_NORM_QC_NO},
+	{0xCC19, UNICODE_NORM_QC_NO},
+	{0xCC1A, UNICODE_NORM_QC_NO},
+	{0xCC1B, UNICODE_NORM_QC_NO},
+	{0xCC1C, UNICODE_NORM_QC_NO},
+	{0xCC1D, UNICODE_NORM_QC_NO},
+	{0xCC1E, UNICODE_NORM_QC_NO},
+	{0xCC1F, UNICODE_NORM_QC_NO},
+	{0xCC20, UNICODE_NORM_QC_NO},
+	{0xCC21, UNICODE_NORM_QC_NO},
+	{0xCC22, UNICODE_NORM_QC_NO},
+	{0xCC23, UNICODE_NORM_QC_NO},
+	{0xCC24, UNICODE_NORM_QC_NO},
+	{0xCC25, UNICODE_NORM_QC_NO},
+	{0xCC26, UNICODE_NORM_QC_NO},
+	{0xCC27, UNICODE_NORM_QC_NO},
+	{0xCC28, UNICODE_NORM_QC_NO},
+	{0xCC29, UNICODE_NORM_QC_NO},
+	{0xCC2A, UNICODE_NORM_QC_NO},
+	{0xCC2B, UNICODE_NORM_QC_NO},
+	{0xCC2C, UNICODE_NORM_QC_NO},
+	{0xCC2D, UNICODE_NORM_QC_NO},
+	{0xCC2E, UNICODE_NORM_QC_NO},
+	{0xCC2F, UNICODE_NORM_QC_NO},
+	{0xCC30, UNICODE_NORM_QC_NO},
+	{0xCC31, UNICODE_NORM_QC_NO},
+	{0xCC32, UNICODE_NORM_QC_NO},
+	{0xCC33, UNICODE_NORM_QC_NO},
+	{0xCC34, UNICODE_NORM_QC_NO},
+	{0xCC35, UNICODE_NORM_QC_NO},
+	{0xCC36, UNICODE_NORM_QC_NO},
+	{0xCC37, UNICODE_NORM_QC_NO},
+	{0xCC38, UNICODE_NORM_QC_NO},
+	{0xCC39, UNICODE_NORM_QC_NO},
+	{0xCC3A, UNICODE_NORM_QC_NO},
+	{0xCC3B, UNICODE_NORM_QC_NO},
+	{0xCC3C, UNICODE_NORM_QC_NO},
+	{0xCC3D, UNICODE_NORM_QC_NO},
+	{0xCC3E, UNICODE_NORM_QC_NO},
+	{0xCC3F, UNICODE_NORM_QC_NO},
+	{0xCC40, UNICODE_NORM_QC_NO},
+	{0xCC41, UNICODE_NORM_QC_NO},
+	{0xCC42, UNICODE_NORM_QC_NO},
+	{0xCC43, UNICODE_NORM_QC_NO},
+	{0xCC44, UNICODE_NORM_QC_NO},
+	{0xCC45, UNICODE_NORM_QC_NO},
+	{0xCC46, UNICODE_NORM_QC_NO},
+	{0xCC47, UNICODE_NORM_QC_NO},
+	{0xCC48, UNICODE_NORM_QC_NO},
+	{0xCC49, UNICODE_NORM_QC_NO},
+	{0xCC4A, UNICODE_NORM_QC_NO},
+	{0xCC4B, UNICODE_NORM_QC_NO},
+	{0xCC4C, UNICODE_NORM_QC_NO},
+	{0xCC4D, UNICODE_NORM_QC_NO},
+	{0xCC4E, UNICODE_NORM_QC_NO},
+	{0xCC4F, UNICODE_NORM_QC_NO},
+	{0xCC50, UNICODE_NORM_QC_NO},
+	{0xCC51, UNICODE_NORM_QC_NO},
+	{0xCC52, UNICODE_NORM_QC_NO},
+	{0xCC53, UNICODE_NORM_QC_NO},
+	{0xCC54, UNICODE_NORM_QC_NO},
+	{0xCC55, UNICODE_NORM_QC_NO},
+	{0xCC56, UNICODE_NORM_QC_NO},
+	{0xCC57, UNICODE_NORM_QC_NO},
+	{0xCC58, UNICODE_NORM_QC_NO},
+	{0xCC59, UNICODE_NORM_QC_NO},
+	{0xCC5A, UNICODE_NORM_QC_NO},
+	{0xCC5B, UNICODE_NORM_QC_NO},
+	{0xCC5C, UNICODE_NORM_QC_NO},
+	{0xCC5D, UNICODE_NORM_QC_NO},
+	{0xCC5E, UNICODE_NORM_QC_NO},
+	{0xCC5F, UNICODE_NORM_QC_NO},
+	{0xCC60, UNICODE_NORM_QC_NO},
+	{0xCC61, UNICODE_NORM_QC_NO},
+	{0xCC62, UNICODE_NORM_QC_NO},
+	{0xCC63, UNICODE_NORM_QC_NO},
+	{0xCC64, UNICODE_NORM_QC_NO},
+	{0xCC65, UNICODE_NORM_QC_NO},
+	{0xCC66, UNICODE_NORM_QC_NO},
+	{0xCC67, UNICODE_NORM_QC_NO},
+	{0xCC68, UNICODE_NORM_QC_NO},
+	{0xCC69, UNICODE_NORM_QC_NO},
+	{0xCC6A, UNICODE_NORM_QC_NO},
+	{0xCC6B, UNICODE_NORM_QC_NO},
+	{0xCC6C, UNICODE_NORM_QC_NO},
+	{0xCC6D, UNICODE_NORM_QC_NO},
+	{0xCC6E, UNICODE_NORM_QC_NO},
+	{0xCC6F, UNICODE_NORM_QC_NO},
+	{0xCC70, UNICODE_NORM_QC_NO},
+	{0xCC71, UNICODE_NORM_QC_NO},
+	{0xCC72, UNICODE_NORM_QC_NO},
+	{0xCC73, UNICODE_NORM_QC_NO},
+	{0xCC74, UNICODE_NORM_QC_NO},
+	{0xCC75, UNICODE_NORM_QC_NO},
+	{0xCC76, UNICODE_NORM_QC_NO},
+	{0xCC77, UNICODE_NORM_QC_NO},
+	{0xCC78, UNICODE_NORM_QC_NO},
+	{0xCC79, UNICODE_NORM_QC_NO},
+	{0xCC7A, UNICODE_NORM_QC_NO},
+	{0xCC7B, UNICODE_NORM_QC_NO},
+	{0xCC7C, UNICODE_NORM_QC_NO},
+	{0xCC7D, UNICODE_NORM_QC_NO},
+	{0xCC7E, UNICODE_NORM_QC_NO},
+	{0xCC7F, UNICODE_NORM_QC_NO},
+	{0xCC80, UNICODE_NORM_QC_NO},
+	{0xCC81, UNICODE_NORM_QC_NO},
+	{0xCC82, UNICODE_NORM_QC_NO},
+	{0xCC83, UNICODE_NORM_QC_NO},
+	{0xCC84, UNICODE_NORM_QC_NO},
+	{0xCC85, UNICODE_NORM_QC_NO},
+	{0xCC86, UNICODE_NORM_QC_NO},
+	{0xCC87, UNICODE_NORM_QC_NO},
+	{0xCC88, UNICODE_NORM_QC_NO},
+	{0xCC89, UNICODE_NORM_QC_NO},
+	{0xCC8A, UNICODE_NORM_QC_NO},
+	{0xCC8B, UNICODE_NORM_QC_NO},
+	{0xCC8C, UNICODE_NORM_QC_NO},
+	{0xCC8D, UNICODE_NORM_QC_NO},
+	{0xCC8E, UNICODE_NORM_QC_NO},
+	{0xCC8F, UNICODE_NORM_QC_NO},
+	{0xCC90, UNICODE_NORM_QC_NO},
+	{0xCC91, UNICODE_NORM_QC_NO},
+	{0xCC92, UNICODE_NORM_QC_NO},
+	{0xCC93, UNICODE_NORM_QC_NO},
+	{0xCC94, UNICODE_NORM_QC_NO},
+	{0xCC95, UNICODE_NORM_QC_NO},
+	{0xCC96, UNICODE_NORM_QC_NO},
+	{0xCC97, UNICODE_NORM_QC_NO},
+	{0xCC98, UNICODE_NORM_QC_NO},
+	{0xCC99, UNICODE_NORM_QC_NO},
+	{0xCC9A, UNICODE_NORM_QC_NO},
+	{0xCC9B, UNICODE_NORM_QC_NO},
+	{0xCC9C, UNICODE_NORM_QC_NO},
+	{0xCC9D, UNICODE_NORM_QC_NO},
+	{0xCC9E, UNICODE_NORM_QC_NO},
+	{0xCC9F, UNICODE_NORM_QC_NO},
+	{0xCCA0, UNICODE_NORM_QC_NO},
+	{0xCCA1, UNICODE_NORM_QC_NO},
+	{0xCCA2, UNICODE_NORM_QC_NO},
+	{0xCCA3, UNICODE_NORM_QC_NO},
+	{0xCCA4, UNICODE_NORM_QC_NO},
+	{0xCCA5, UNICODE_NORM_QC_NO},
+	{0xCCA6, UNICODE_NORM_QC_NO},
+	{0xCCA7, UNICODE_NORM_QC_NO},
+	{0xCCA8, UNICODE_NORM_QC_NO},
+	{0xCCA9, UNICODE_NORM_QC_NO},
+	{0xCCAA, UNICODE_NORM_QC_NO},
+	{0xCCAB, UNICODE_NORM_QC_NO},
+	{0xCCAC, UNICODE_NORM_QC_NO},
+	{0xCCAD, UNICODE_NORM_QC_NO},
+	{0xCCAE, UNICODE_NORM_QC_NO},
+	{0xCCAF, UNICODE_NORM_QC_NO},
+	{0xCCB0, UNICODE_NORM_QC_NO},
+	{0xCCB1, UNICODE_NORM_QC_NO},
+	{0xCCB2, UNICODE_NORM_QC_NO},
+	{0xCCB3, UNICODE_NORM_QC_NO},
+	{0xCCB4, UNICODE_NORM_QC_NO},
+	{0xCCB5, UNICODE_NORM_QC_NO},
+	{0xCCB6, UNICODE_NORM_QC_NO},
+	{0xCCB7, UNICODE_NORM_QC_NO},
+	{0xCCB8, UNICODE_NORM_QC_NO},
+	{0xCCB9, UNICODE_NORM_QC_NO},
+	{0xCCBA, UNICODE_NORM_QC_NO},
+	{0xCCBB, UNICODE_NORM_QC_NO},
+	{0xCCBC, UNICODE_NORM_QC_NO},
+	{0xCCBD, UNICODE_NORM_QC_NO},
+	{0xCCBE, UNICODE_NORM_QC_NO},
+	{0xCCBF, UNICODE_NORM_QC_NO},
+	{0xCCC0, UNICODE_NORM_QC_NO},
+	{0xCCC1, UNICODE_NORM_QC_NO},
+	{0xCCC2, UNICODE_NORM_QC_NO},
+	{0xCCC3, UNICODE_NORM_QC_NO},
+	{0xCCC4, UNICODE_NORM_QC_NO},
+	{0xCCC5, UNICODE_NORM_QC_NO},
+	{0xCCC6, UNICODE_NORM_QC_NO},
+	{0xCCC7, UNICODE_NORM_QC_NO},
+	{0xCCC8, UNICODE_NORM_QC_NO},
+	{0xCCC9, UNICODE_NORM_QC_NO},
+	{0xCCCA, UNICODE_NORM_QC_NO},
+	{0xCCCB, UNICODE_NORM_QC_NO},
+	{0xCCCC, UNICODE_NORM_QC_NO},
+	{0xCCCD, UNICODE_NORM_QC_NO},
+	{0xCCCE, UNICODE_NORM_QC_NO},
+	{0xCCCF, UNICODE_NORM_QC_NO},
+	{0xCCD0, UNICODE_NORM_QC_NO},
+	{0xCCD1, UNICODE_NORM_QC_NO},
+	{0xCCD2, UNICODE_NORM_QC_NO},
+	{0xCCD3, UNICODE_NORM_QC_NO},
+	{0xCCD4, UNICODE_NORM_QC_NO},
+	{0xCCD5, UNICODE_NORM_QC_NO},
+	{0xCCD6, UNICODE_NORM_QC_NO},
+	{0xCCD7, UNICODE_NORM_QC_NO},
+	{0xCCD8, UNICODE_NORM_QC_NO},
+	{0xCCD9, UNICODE_NORM_QC_NO},
+	{0xCCDA, UNICODE_NORM_QC_NO},
+	{0xCCDB, UNICODE_NORM_QC_NO},
+	{0xCCDC, UNICODE_NORM_QC_NO},
+	{0xCCDD, UNICODE_NORM_QC_NO},
+	{0xCCDE, UNICODE_NORM_QC_NO},
+	{0xCCDF, UNICODE_NORM_QC_NO},
+	{0xCCE0, UNICODE_NORM_QC_NO},
+	{0xCCE1, UNICODE_NORM_QC_NO},
+	{0xCCE2, UNICODE_NORM_QC_NO},
+	{0xCCE3, UNICODE_NORM_QC_NO},
+	{0xCCE4, UNICODE_NORM_QC_NO},
+	{0xCCE5, UNICODE_NORM_QC_NO},
+	{0xCCE6, UNICODE_NORM_QC_NO},
+	{0xCCE7, UNICODE_NORM_QC_NO},
+	{0xCCE8, UNICODE_NORM_QC_NO},
+	{0xCCE9, UNICODE_NORM_QC_NO},
+	{0xCCEA, UNICODE_NORM_QC_NO},
+	{0xCCEB, UNICODE_NORM_QC_NO},
+	{0xCCEC, UNICODE_NORM_QC_NO},
+	{0xCCED, UNICODE_NORM_QC_NO},
+	{0xCCEE, UNICODE_NORM_QC_NO},
+	{0xCCEF, UNICODE_NORM_QC_NO},
+	{0xCCF0, UNICODE_NORM_QC_NO},
+	{0xCCF1, UNICODE_NORM_QC_NO},
+	{0xCCF2, UNICODE_NORM_QC_NO},
+	{0xCCF3, UNICODE_NORM_QC_NO},
+	{0xCCF4, UNICODE_NORM_QC_NO},
+	{0xCCF5, UNICODE_NORM_QC_NO},
+	{0xCCF6, UNICODE_NORM_QC_NO},
+	{0xCCF7, UNICODE_NORM_QC_NO},
+	{0xCCF8, UNICODE_NORM_QC_NO},
+	{0xCCF9, UNICODE_NORM_QC_NO},
+	{0xCCFA, UNICODE_NORM_QC_NO},
+	{0xCCFB, UNICODE_NORM_QC_NO},
+	{0xCCFC, UNICODE_NORM_QC_NO},
+	{0xCCFD, UNICODE_NORM_QC_NO},
+	{0xCCFE, UNICODE_NORM_QC_NO},
+	{0xCCFF, UNICODE_NORM_QC_NO},
+	{0xCD00, UNICODE_NORM_QC_NO},
+	{0xCD01, UNICODE_NORM_QC_NO},
+	{0xCD02, UNICODE_NORM_QC_NO},
+	{0xCD03, UNICODE_NORM_QC_NO},
+	{0xCD04, UNICODE_NORM_QC_NO},
+	{0xCD05, UNICODE_NORM_QC_NO},
+	{0xCD06, UNICODE_NORM_QC_NO},
+	{0xCD07, UNICODE_NORM_QC_NO},
+	{0xCD08, UNICODE_NORM_QC_NO},
+	{0xCD09, UNICODE_NORM_QC_NO},
+	{0xCD0A, UNICODE_NORM_QC_NO},
+	{0xCD0B, UNICODE_NORM_QC_NO},
+	{0xCD0C, UNICODE_NORM_QC_NO},
+	{0xCD0D, UNICODE_NORM_QC_NO},
+	{0xCD0E, UNICODE_NORM_QC_NO},
+	{0xCD0F, UNICODE_NORM_QC_NO},
+	{0xCD10, UNICODE_NORM_QC_NO},
+	{0xCD11, UNICODE_NORM_QC_NO},
+	{0xCD12, UNICODE_NORM_QC_NO},
+	{0xCD13, UNICODE_NORM_QC_NO},
+	{0xCD14, UNICODE_NORM_QC_NO},
+	{0xCD15, UNICODE_NORM_QC_NO},
+	{0xCD16, UNICODE_NORM_QC_NO},
+	{0xCD17, UNICODE_NORM_QC_NO},
+	{0xCD18, UNICODE_NORM_QC_NO},
+	{0xCD19, UNICODE_NORM_QC_NO},
+	{0xCD1A, UNICODE_NORM_QC_NO},
+	{0xCD1B, UNICODE_NORM_QC_NO},
+	{0xCD1C, UNICODE_NORM_QC_NO},
+	{0xCD1D, UNICODE_NORM_QC_NO},
+	{0xCD1E, UNICODE_NORM_QC_NO},
+	{0xCD1F, UNICODE_NORM_QC_NO},
+	{0xCD20, UNICODE_NORM_QC_NO},
+	{0xCD21, UNICODE_NORM_QC_NO},
+	{0xCD22, UNICODE_NORM_QC_NO},
+	{0xCD23, UNICODE_NORM_QC_NO},
+	{0xCD24, UNICODE_NORM_QC_NO},
+	{0xCD25, UNICODE_NORM_QC_NO},
+	{0xCD26, UNICODE_NORM_QC_NO},
+	{0xCD27, UNICODE_NORM_QC_NO},
+	{0xCD28, UNICODE_NORM_QC_NO},
+	{0xCD29, UNICODE_NORM_QC_NO},
+	{0xCD2A, UNICODE_NORM_QC_NO},
+	{0xCD2B, UNICODE_NORM_QC_NO},
+	{0xCD2C, UNICODE_NORM_QC_NO},
+	{0xCD2D, UNICODE_NORM_QC_NO},
+	{0xCD2E, UNICODE_NORM_QC_NO},
+	{0xCD2F, UNICODE_NORM_QC_NO},
+	{0xCD30, UNICODE_NORM_QC_NO},
+	{0xCD31, UNICODE_NORM_QC_NO},
+	{0xCD32, UNICODE_NORM_QC_NO},
+	{0xCD33, UNICODE_NORM_QC_NO},
+	{0xCD34, UNICODE_NORM_QC_NO},
+	{0xCD35, UNICODE_NORM_QC_NO},
+	{0xCD36, UNICODE_NORM_QC_NO},
+	{0xCD37, UNICODE_NORM_QC_NO},
+	{0xCD38, UNICODE_NORM_QC_NO},
+	{0xCD39, UNICODE_NORM_QC_NO},
+	{0xCD3A, UNICODE_NORM_QC_NO},
+	{0xCD3B, UNICODE_NORM_QC_NO},
+	{0xCD3C, UNICODE_NORM_QC_NO},
+	{0xCD3D, UNICODE_NORM_QC_NO},
+	{0xCD3E, UNICODE_NORM_QC_NO},
+	{0xCD3F, UNICODE_NORM_QC_NO},
+	{0xCD40, UNICODE_NORM_QC_NO},
+	{0xCD41, UNICODE_NORM_QC_NO},
+	{0xCD42, UNICODE_NORM_QC_NO},
+	{0xCD43, UNICODE_NORM_QC_NO},
+	{0xCD44, UNICODE_NORM_QC_NO},
+	{0xCD45, UNICODE_NORM_QC_NO},
+	{0xCD46, UNICODE_NORM_QC_NO},
+	{0xCD47, UNICODE_NORM_QC_NO},
+	{0xCD48, UNICODE_NORM_QC_NO},
+	{0xCD49, UNICODE_NORM_QC_NO},
+	{0xCD4A, UNICODE_NORM_QC_NO},
+	{0xCD4B, UNICODE_NORM_QC_NO},
+	{0xCD4C, UNICODE_NORM_QC_NO},
+	{0xCD4D, UNICODE_NORM_QC_NO},
+	{0xCD4E, UNICODE_NORM_QC_NO},
+	{0xCD4F, UNICODE_NORM_QC_NO},
+	{0xCD50, UNICODE_NORM_QC_NO},
+	{0xCD51, UNICODE_NORM_QC_NO},
+	{0xCD52, UNICODE_NORM_QC_NO},
+	{0xCD53, UNICODE_NORM_QC_NO},
+	{0xCD54, UNICODE_NORM_QC_NO},
+	{0xCD55, UNICODE_NORM_QC_NO},
+	{0xCD56, UNICODE_NORM_QC_NO},
+	{0xCD57, UNICODE_NORM_QC_NO},
+	{0xCD58, UNICODE_NORM_QC_NO},
+	{0xCD59, UNICODE_NORM_QC_NO},
+	{0xCD5A, UNICODE_NORM_QC_NO},
+	{0xCD5B, UNICODE_NORM_QC_NO},
+	{0xCD5C, UNICODE_NORM_QC_NO},
+	{0xCD5D, UNICODE_NORM_QC_NO},
+	{0xCD5E, UNICODE_NORM_QC_NO},
+	{0xCD5F, UNICODE_NORM_QC_NO},
+	{0xCD60, UNICODE_NORM_QC_NO},
+	{0xCD61, UNICODE_NORM_QC_NO},
+	{0xCD62, UNICODE_NORM_QC_NO},
+	{0xCD63, UNICODE_NORM_QC_NO},
+	{0xCD64, UNICODE_NORM_QC_NO},
+	{0xCD65, UNICODE_NORM_QC_NO},
+	{0xCD66, UNICODE_NORM_QC_NO},
+	{0xCD67, UNICODE_NORM_QC_NO},
+	{0xCD68, UNICODE_NORM_QC_NO},
+	{0xCD69, UNICODE_NORM_QC_NO},
+	{0xCD6A, UNICODE_NORM_QC_NO},
+	{0xCD6B, UNICODE_NORM_QC_NO},
+	{0xCD6C, UNICODE_NORM_QC_NO},
+	{0xCD6D, UNICODE_NORM_QC_NO},
+	{0xCD6E, UNICODE_NORM_QC_NO},
+	{0xCD6F, UNICODE_NORM_QC_NO},
+	{0xCD70, UNICODE_NORM_QC_NO},
+	{0xCD71, UNICODE_NORM_QC_NO},
+	{0xCD72, UNICODE_NORM_QC_NO},
+	{0xCD73, UNICODE_NORM_QC_NO},
+	{0xCD74, UNICODE_NORM_QC_NO},
+	{0xCD75, UNICODE_NORM_QC_NO},
+	{0xCD76, UNICODE_NORM_QC_NO},
+	{0xCD77, UNICODE_NORM_QC_NO},
+	{0xCD78, UNICODE_NORM_QC_NO},
+	{0xCD79, UNICODE_NORM_QC_NO},
+	{0xCD7A, UNICODE_NORM_QC_NO},
+	{0xCD7B, UNICODE_NORM_QC_NO},
+	{0xCD7C, UNICODE_NORM_QC_NO},
+	{0xCD7D, UNICODE_NORM_QC_NO},
+	{0xCD7E, UNICODE_NORM_QC_NO},
+	{0xCD7F, UNICODE_NORM_QC_NO},
+	{0xCD80, UNICODE_NORM_QC_NO},
+	{0xCD81, UNICODE_NORM_QC_NO},
+	{0xCD82, UNICODE_NORM_QC_NO},
+	{0xCD83, UNICODE_NORM_QC_NO},
+	{0xCD84, UNICODE_NORM_QC_NO},
+	{0xCD85, UNICODE_NORM_QC_NO},
+	{0xCD86, UNICODE_NORM_QC_NO},
+	{0xCD87, UNICODE_NORM_QC_NO},
+	{0xCD88, UNICODE_NORM_QC_NO},
+	{0xCD89, UNICODE_NORM_QC_NO},
+	{0xCD8A, UNICODE_NORM_QC_NO},
+	{0xCD8B, UNICODE_NORM_QC_NO},
+	{0xCD8C, UNICODE_NORM_QC_NO},
+	{0xCD8D, UNICODE_NORM_QC_NO},
+	{0xCD8E, UNICODE_NORM_QC_NO},
+	{0xCD8F, UNICODE_NORM_QC_NO},
+	{0xCD90, UNICODE_NORM_QC_NO},
+	{0xCD91, UNICODE_NORM_QC_NO},
+	{0xCD92, UNICODE_NORM_QC_NO},
+	{0xCD93, UNICODE_NORM_QC_NO},
+	{0xCD94, UNICODE_NORM_QC_NO},
+	{0xCD95, UNICODE_NORM_QC_NO},
+	{0xCD96, UNICODE_NORM_QC_NO},
+	{0xCD97, UNICODE_NORM_QC_NO},
+	{0xCD98, UNICODE_NORM_QC_NO},
+	{0xCD99, UNICODE_NORM_QC_NO},
+	{0xCD9A, UNICODE_NORM_QC_NO},
+	{0xCD9B, UNICODE_NORM_QC_NO},
+	{0xCD9C, UNICODE_NORM_QC_NO},
+	{0xCD9D, UNICODE_NORM_QC_NO},
+	{0xCD9E, UNICODE_NORM_QC_NO},
+	{0xCD9F, UNICODE_NORM_QC_NO},
+	{0xCDA0, UNICODE_NORM_QC_NO},
+	{0xCDA1, UNICODE_NORM_QC_NO},
+	{0xCDA2, UNICODE_NORM_QC_NO},
+	{0xCDA3, UNICODE_NORM_QC_NO},
+	{0xCDA4, UNICODE_NORM_QC_NO},
+	{0xCDA5, UNICODE_NORM_QC_NO},
+	{0xCDA6, UNICODE_NORM_QC_NO},
+	{0xCDA7, UNICODE_NORM_QC_NO},
+	{0xCDA8, UNICODE_NORM_QC_NO},
+	{0xCDA9, UNICODE_NORM_QC_NO},
+	{0xCDAA, UNICODE_NORM_QC_NO},
+	{0xCDAB, UNICODE_NORM_QC_NO},
+	{0xCDAC, UNICODE_NORM_QC_NO},
+	{0xCDAD, UNICODE_NORM_QC_NO},
+	{0xCDAE, UNICODE_NORM_QC_NO},
+	{0xCDAF, UNICODE_NORM_QC_NO},
+	{0xCDB0, UNICODE_NORM_QC_NO},
+	{0xCDB1, UNICODE_NORM_QC_NO},
+	{0xCDB2, UNICODE_NORM_QC_NO},
+	{0xCDB3, UNICODE_NORM_QC_NO},
+	{0xCDB4, UNICODE_NORM_QC_NO},
+	{0xCDB5, UNICODE_NORM_QC_NO},
+	{0xCDB6, UNICODE_NORM_QC_NO},
+	{0xCDB7, UNICODE_NORM_QC_NO},
+	{0xCDB8, UNICODE_NORM_QC_NO},
+	{0xCDB9, UNICODE_NORM_QC_NO},
+	{0xCDBA, UNICODE_NORM_QC_NO},
+	{0xCDBB, UNICODE_NORM_QC_NO},
+	{0xCDBC, UNICODE_NORM_QC_NO},
+	{0xCDBD, UNICODE_NORM_QC_NO},
+	{0xCDBE, UNICODE_NORM_QC_NO},
+	{0xCDBF, UNICODE_NORM_QC_NO},
+	{0xCDC0, UNICODE_NORM_QC_NO},
+	{0xCDC1, UNICODE_NORM_QC_NO},
+	{0xCDC2, UNICODE_NORM_QC_NO},
+	{0xCDC3, UNICODE_NORM_QC_NO},
+	{0xCDC4, UNICODE_NORM_QC_NO},
+	{0xCDC5, UNICODE_NORM_QC_NO},
+	{0xCDC6, UNICODE_NORM_QC_NO},
+	{0xCDC7, UNICODE_NORM_QC_NO},
+	{0xCDC8, UNICODE_NORM_QC_NO},
+	{0xCDC9, UNICODE_NORM_QC_NO},
+	{0xCDCA, UNICODE_NORM_QC_NO},
+	{0xCDCB, UNICODE_NORM_QC_NO},
+	{0xCDCC, UNICODE_NORM_QC_NO},
+	{0xCDCD, UNICODE_NORM_QC_NO},
+	{0xCDCE, UNICODE_NORM_QC_NO},
+	{0xCDCF, UNICODE_NORM_QC_NO},
+	{0xCDD0, UNICODE_NORM_QC_NO},
+	{0xCDD1, UNICODE_NORM_QC_NO},
+	{0xCDD2, UNICODE_NORM_QC_NO},
+	{0xCDD3, UNICODE_NORM_QC_NO},
+	{0xCDD4, UNICODE_NORM_QC_NO},
+	{0xCDD5, UNICODE_NORM_QC_NO},
+	{0xCDD6, UNICODE_NORM_QC_NO},
+	{0xCDD7, UNICODE_NORM_QC_NO},
+	{0xCDD8, UNICODE_NORM_QC_NO},
+	{0xCDD9, UNICODE_NORM_QC_NO},
+	{0xCDDA, UNICODE_NORM_QC_NO},
+	{0xCDDB, UNICODE_NORM_QC_NO},
+	{0xCDDC, UNICODE_NORM_QC_NO},
+	{0xCDDD, UNICODE_NORM_QC_NO},
+	{0xCDDE, UNICODE_NORM_QC_NO},
+	{0xCDDF, UNICODE_NORM_QC_NO},
+	{0xCDE0, UNICODE_NORM_QC_NO},
+	{0xCDE1, UNICODE_NORM_QC_NO},
+	{0xCDE2, UNICODE_NORM_QC_NO},
+	{0xCDE3, UNICODE_NORM_QC_NO},
+	{0xCDE4, UNICODE_NORM_QC_NO},
+	{0xCDE5, UNICODE_NORM_QC_NO},
+	{0xCDE6, UNICODE_NORM_QC_NO},
+	{0xCDE7, UNICODE_NORM_QC_NO},
+	{0xCDE8, UNICODE_NORM_QC_NO},
+	{0xCDE9, UNICODE_NORM_QC_NO},
+	{0xCDEA, UNICODE_NORM_QC_NO},
+	{0xCDEB, UNICODE_NORM_QC_NO},
+	{0xCDEC, UNICODE_NORM_QC_NO},
+	{0xCDED, UNICODE_NORM_QC_NO},
+	{0xCDEE, UNICODE_NORM_QC_NO},
+	{0xCDEF, UNICODE_NORM_QC_NO},
+	{0xCDF0, UNICODE_NORM_QC_NO},
+	{0xCDF1, UNICODE_NORM_QC_NO},
+	{0xCDF2, UNICODE_NORM_QC_NO},
+	{0xCDF3, UNICODE_NORM_QC_NO},
+	{0xCDF4, UNICODE_NORM_QC_NO},
+	{0xCDF5, UNICODE_NORM_QC_NO},
+	{0xCDF6, UNICODE_NORM_QC_NO},
+	{0xCDF7, UNICODE_NORM_QC_NO},
+	{0xCDF8, UNICODE_NORM_QC_NO},
+	{0xCDF9, UNICODE_NORM_QC_NO},
+	{0xCDFA, UNICODE_NORM_QC_NO},
+	{0xCDFB, UNICODE_NORM_QC_NO},
+	{0xCDFC, UNICODE_NORM_QC_NO},
+	{0xCDFD, UNICODE_NORM_QC_NO},
+	{0xCDFE, UNICODE_NORM_QC_NO},
+	{0xCDFF, UNICODE_NORM_QC_NO},
+	{0xCE00, UNICODE_NORM_QC_NO},
+	{0xCE01, UNICODE_NORM_QC_NO},
+	{0xCE02, UNICODE_NORM_QC_NO},
+	{0xCE03, UNICODE_NORM_QC_NO},
+	{0xCE04, UNICODE_NORM_QC_NO},
+	{0xCE05, UNICODE_NORM_QC_NO},
+	{0xCE06, UNICODE_NORM_QC_NO},
+	{0xCE07, UNICODE_NORM_QC_NO},
+	{0xCE08, UNICODE_NORM_QC_NO},
+	{0xCE09, UNICODE_NORM_QC_NO},
+	{0xCE0A, UNICODE_NORM_QC_NO},
+	{0xCE0B, UNICODE_NORM_QC_NO},
+	{0xCE0C, UNICODE_NORM_QC_NO},
+	{0xCE0D, UNICODE_NORM_QC_NO},
+	{0xCE0E, UNICODE_NORM_QC_NO},
+	{0xCE0F, UNICODE_NORM_QC_NO},
+	{0xCE10, UNICODE_NORM_QC_NO},
+	{0xCE11, UNICODE_NORM_QC_NO},
+	{0xCE12, UNICODE_NORM_QC_NO},
+	{0xCE13, UNICODE_NORM_QC_NO},
+	{0xCE14, UNICODE_NORM_QC_NO},
+	{0xCE15, UNICODE_NORM_QC_NO},
+	{0xCE16, UNICODE_NORM_QC_NO},
+	{0xCE17, UNICODE_NORM_QC_NO},
+	{0xCE18, UNICODE_NORM_QC_NO},
+	{0xCE19, UNICODE_NORM_QC_NO},
+	{0xCE1A, UNICODE_NORM_QC_NO},
+	{0xCE1B, UNICODE_NORM_QC_NO},
+	{0xCE1C, UNICODE_NORM_QC_NO},
+	{0xCE1D, UNICODE_NORM_QC_NO},
+	{0xCE1E, UNICODE_NORM_QC_NO},
+	{0xCE1F, UNICODE_NORM_QC_NO},
+	{0xCE20, UNICODE_NORM_QC_NO},
+	{0xCE21, UNICODE_NORM_QC_NO},
+	{0xCE22, UNICODE_NORM_QC_NO},
+	{0xCE23, UNICODE_NORM_QC_NO},
+	{0xCE24, UNICODE_NORM_QC_NO},
+	{0xCE25, UNICODE_NORM_QC_NO},
+	{0xCE26, UNICODE_NORM_QC_NO},
+	{0xCE27, UNICODE_NORM_QC_NO},
+	{0xCE28, UNICODE_NORM_QC_NO},
+	{0xCE29, UNICODE_NORM_QC_NO},
+	{0xCE2A, UNICODE_NORM_QC_NO},
+	{0xCE2B, UNICODE_NORM_QC_NO},
+	{0xCE2C, UNICODE_NORM_QC_NO},
+	{0xCE2D, UNICODE_NORM_QC_NO},
+	{0xCE2E, UNICODE_NORM_QC_NO},
+	{0xCE2F, UNICODE_NORM_QC_NO},
+	{0xCE30, UNICODE_NORM_QC_NO},
+	{0xCE31, UNICODE_NORM_QC_NO},
+	{0xCE32, UNICODE_NORM_QC_NO},
+	{0xCE33, UNICODE_NORM_QC_NO},
+	{0xCE34, UNICODE_NORM_QC_NO},
+	{0xCE35, UNICODE_NORM_QC_NO},
+	{0xCE36, UNICODE_NORM_QC_NO},
+	{0xCE37, UNICODE_NORM_QC_NO},
+	{0xCE38, UNICODE_NORM_QC_NO},
+	{0xCE39, UNICODE_NORM_QC_NO},
+	{0xCE3A, UNICODE_NORM_QC_NO},
+	{0xCE3B, UNICODE_NORM_QC_NO},
+	{0xCE3C, UNICODE_NORM_QC_NO},
+	{0xCE3D, UNICODE_NORM_QC_NO},
+	{0xCE3E, UNICODE_NORM_QC_NO},
+	{0xCE3F, UNICODE_NORM_QC_NO},
+	{0xCE40, UNICODE_NORM_QC_NO},
+	{0xCE41, UNICODE_NORM_QC_NO},
+	{0xCE42, UNICODE_NORM_QC_NO},
+	{0xCE43, UNICODE_NORM_QC_NO},
+	{0xCE44, UNICODE_NORM_QC_NO},
+	{0xCE45, UNICODE_NORM_QC_NO},
+	{0xCE46, UNICODE_NORM_QC_NO},
+	{0xCE47, UNICODE_NORM_QC_NO},
+	{0xCE48, UNICODE_NORM_QC_NO},
+	{0xCE49, UNICODE_NORM_QC_NO},
+	{0xCE4A, UNICODE_NORM_QC_NO},
+	{0xCE4B, UNICODE_NORM_QC_NO},
+	{0xCE4C, UNICODE_NORM_QC_NO},
+	{0xCE4D, UNICODE_NORM_QC_NO},
+	{0xCE4E, UNICODE_NORM_QC_NO},
+	{0xCE4F, UNICODE_NORM_QC_NO},
+	{0xCE50, UNICODE_NORM_QC_NO},
+	{0xCE51, UNICODE_NORM_QC_NO},
+	{0xCE52, UNICODE_NORM_QC_NO},
+	{0xCE53, UNICODE_NORM_QC_NO},
+	{0xCE54, UNICODE_NORM_QC_NO},
+	{0xCE55, UNICODE_NORM_QC_NO},
+	{0xCE56, UNICODE_NORM_QC_NO},
+	{0xCE57, UNICODE_NORM_QC_NO},
+	{0xCE58, UNICODE_NORM_QC_NO},
+	{0xCE59, UNICODE_NORM_QC_NO},
+	{0xCE5A, UNICODE_NORM_QC_NO},
+	{0xCE5B, UNICODE_NORM_QC_NO},
+	{0xCE5C, UNICODE_NORM_QC_NO},
+	{0xCE5D, UNICODE_NORM_QC_NO},
+	{0xCE5E, UNICODE_NORM_QC_NO},
+	{0xCE5F, UNICODE_NORM_QC_NO},
+	{0xCE60, UNICODE_NORM_QC_NO},
+	{0xCE61, UNICODE_NORM_QC_NO},
+	{0xCE62, UNICODE_NORM_QC_NO},
+	{0xCE63, UNICODE_NORM_QC_NO},
+	{0xCE64, UNICODE_NORM_QC_NO},
+	{0xCE65, UNICODE_NORM_QC_NO},
+	{0xCE66, UNICODE_NORM_QC_NO},
+	{0xCE67, UNICODE_NORM_QC_NO},
+	{0xCE68, UNICODE_NORM_QC_NO},
+	{0xCE69, UNICODE_NORM_QC_NO},
+	{0xCE6A, UNICODE_NORM_QC_NO},
+	{0xCE6B, UNICODE_NORM_QC_NO},
+	{0xCE6C, UNICODE_NORM_QC_NO},
+	{0xCE6D, UNICODE_NORM_QC_NO},
+	{0xCE6E, UNICODE_NORM_QC_NO},
+	{0xCE6F, UNICODE_NORM_QC_NO},
+	{0xCE70, UNICODE_NORM_QC_NO},
+	{0xCE71, UNICODE_NORM_QC_NO},
+	{0xCE72, UNICODE_NORM_QC_NO},
+	{0xCE73, UNICODE_NORM_QC_NO},
+	{0xCE74, UNICODE_NORM_QC_NO},
+	{0xCE75, UNICODE_NORM_QC_NO},
+	{0xCE76, UNICODE_NORM_QC_NO},
+	{0xCE77, UNICODE_NORM_QC_NO},
+	{0xCE78, UNICODE_NORM_QC_NO},
+	{0xCE79, UNICODE_NORM_QC_NO},
+	{0xCE7A, UNICODE_NORM_QC_NO},
+	{0xCE7B, UNICODE_NORM_QC_NO},
+	{0xCE7C, UNICODE_NORM_QC_NO},
+	{0xCE7D, UNICODE_NORM_QC_NO},
+	{0xCE7E, UNICODE_NORM_QC_NO},
+	{0xCE7F, UNICODE_NORM_QC_NO},
+	{0xCE80, UNICODE_NORM_QC_NO},
+	{0xCE81, UNICODE_NORM_QC_NO},
+	{0xCE82, UNICODE_NORM_QC_NO},
+	{0xCE83, UNICODE_NORM_QC_NO},
+	{0xCE84, UNICODE_NORM_QC_NO},
+	{0xCE85, UNICODE_NORM_QC_NO},
+	{0xCE86, UNICODE_NORM_QC_NO},
+	{0xCE87, UNICODE_NORM_QC_NO},
+	{0xCE88, UNICODE_NORM_QC_NO},
+	{0xCE89, UNICODE_NORM_QC_NO},
+	{0xCE8A, UNICODE_NORM_QC_NO},
+	{0xCE8B, UNICODE_NORM_QC_NO},
+	{0xCE8C, UNICODE_NORM_QC_NO},
+	{0xCE8D, UNICODE_NORM_QC_NO},
+	{0xCE8E, UNICODE_NORM_QC_NO},
+	{0xCE8F, UNICODE_NORM_QC_NO},
+	{0xCE90, UNICODE_NORM_QC_NO},
+	{0xCE91, UNICODE_NORM_QC_NO},
+	{0xCE92, UNICODE_NORM_QC_NO},
+	{0xCE93, UNICODE_NORM_QC_NO},
+	{0xCE94, UNICODE_NORM_QC_NO},
+	{0xCE95, UNICODE_NORM_QC_NO},
+	{0xCE96, UNICODE_NORM_QC_NO},
+	{0xCE97, UNICODE_NORM_QC_NO},
+	{0xCE98, UNICODE_NORM_QC_NO},
+	{0xCE99, UNICODE_NORM_QC_NO},
+	{0xCE9A, UNICODE_NORM_QC_NO},
+	{0xCE9B, UNICODE_NORM_QC_NO},
+	{0xCE9C, UNICODE_NORM_QC_NO},
+	{0xCE9D, UNICODE_NORM_QC_NO},
+	{0xCE9E, UNICODE_NORM_QC_NO},
+	{0xCE9F, UNICODE_NORM_QC_NO},
+	{0xCEA0, UNICODE_NORM_QC_NO},
+	{0xCEA1, UNICODE_NORM_QC_NO},
+	{0xCEA2, UNICODE_NORM_QC_NO},
+	{0xCEA3, UNICODE_NORM_QC_NO},
+	{0xCEA4, UNICODE_NORM_QC_NO},
+	{0xCEA5, UNICODE_NORM_QC_NO},
+	{0xCEA6, UNICODE_NORM_QC_NO},
+	{0xCEA7, UNICODE_NORM_QC_NO},
+	{0xCEA8, UNICODE_NORM_QC_NO},
+	{0xCEA9, UNICODE_NORM_QC_NO},
+	{0xCEAA, UNICODE_NORM_QC_NO},
+	{0xCEAB, UNICODE_NORM_QC_NO},
+	{0xCEAC, UNICODE_NORM_QC_NO},
+	{0xCEAD, UNICODE_NORM_QC_NO},
+	{0xCEAE, UNICODE_NORM_QC_NO},
+	{0xCEAF, UNICODE_NORM_QC_NO},
+	{0xCEB0, UNICODE_NORM_QC_NO},
+	{0xCEB1, UNICODE_NORM_QC_NO},
+	{0xCEB2, UNICODE_NORM_QC_NO},
+	{0xCEB3, UNICODE_NORM_QC_NO},
+	{0xCEB4, UNICODE_NORM_QC_NO},
+	{0xCEB5, UNICODE_NORM_QC_NO},
+	{0xCEB6, UNICODE_NORM_QC_NO},
+	{0xCEB7, UNICODE_NORM_QC_NO},
+	{0xCEB8, UNICODE_NORM_QC_NO},
+	{0xCEB9, UNICODE_NORM_QC_NO},
+	{0xCEBA, UNICODE_NORM_QC_NO},
+	{0xCEBB, UNICODE_NORM_QC_NO},
+	{0xCEBC, UNICODE_NORM_QC_NO},
+	{0xCEBD, UNICODE_NORM_QC_NO},
+	{0xCEBE, UNICODE_NORM_QC_NO},
+	{0xCEBF, UNICODE_NORM_QC_NO},
+	{0xCEC0, UNICODE_NORM_QC_NO},
+	{0xCEC1, UNICODE_NORM_QC_NO},
+	{0xCEC2, UNICODE_NORM_QC_NO},
+	{0xCEC3, UNICODE_NORM_QC_NO},
+	{0xCEC4, UNICODE_NORM_QC_NO},
+	{0xCEC5, UNICODE_NORM_QC_NO},
+	{0xCEC6, UNICODE_NORM_QC_NO},
+	{0xCEC7, UNICODE_NORM_QC_NO},
+	{0xCEC8, UNICODE_NORM_QC_NO},
+	{0xCEC9, UNICODE_NORM_QC_NO},
+	{0xCECA, UNICODE_NORM_QC_NO},
+	{0xCECB, UNICODE_NORM_QC_NO},
+	{0xCECC, UNICODE_NORM_QC_NO},
+	{0xCECD, UNICODE_NORM_QC_NO},
+	{0xCECE, UNICODE_NORM_QC_NO},
+	{0xCECF, UNICODE_NORM_QC_NO},
+	{0xCED0, UNICODE_NORM_QC_NO},
+	{0xCED1, UNICODE_NORM_QC_NO},
+	{0xCED2, UNICODE_NORM_QC_NO},
+	{0xCED3, UNICODE_NORM_QC_NO},
+	{0xCED4, UNICODE_NORM_QC_NO},
+	{0xCED5, UNICODE_NORM_QC_NO},
+	{0xCED6, UNICODE_NORM_QC_NO},
+	{0xCED7, UNICODE_NORM_QC_NO},
+	{0xCED8, UNICODE_NORM_QC_NO},
+	{0xCED9, UNICODE_NORM_QC_NO},
+	{0xCEDA, UNICODE_NORM_QC_NO},
+	{0xCEDB, UNICODE_NORM_QC_NO},
+	{0xCEDC, UNICODE_NORM_QC_NO},
+	{0xCEDD, UNICODE_NORM_QC_NO},
+	{0xCEDE, UNICODE_NORM_QC_NO},
+	{0xCEDF, UNICODE_NORM_QC_NO},
+	{0xCEE0, UNICODE_NORM_QC_NO},
+	{0xCEE1, UNICODE_NORM_QC_NO},
+	{0xCEE2, UNICODE_NORM_QC_NO},
+	{0xCEE3, UNICODE_NORM_QC_NO},
+	{0xCEE4, UNICODE_NORM_QC_NO},
+	{0xCEE5, UNICODE_NORM_QC_NO},
+	{0xCEE6, UNICODE_NORM_QC_NO},
+	{0xCEE7, UNICODE_NORM_QC_NO},
+	{0xCEE8, UNICODE_NORM_QC_NO},
+	{0xCEE9, UNICODE_NORM_QC_NO},
+	{0xCEEA, UNICODE_NORM_QC_NO},
+	{0xCEEB, UNICODE_NORM_QC_NO},
+	{0xCEEC, UNICODE_NORM_QC_NO},
+	{0xCEED, UNICODE_NORM_QC_NO},
+	{0xCEEE, UNICODE_NORM_QC_NO},
+	{0xCEEF, UNICODE_NORM_QC_NO},
+	{0xCEF0, UNICODE_NORM_QC_NO},
+	{0xCEF1, UNICODE_NORM_QC_NO},
+	{0xCEF2, UNICODE_NORM_QC_NO},
+	{0xCEF3, UNICODE_NORM_QC_NO},
+	{0xCEF4, UNICODE_NORM_QC_NO},
+	{0xCEF5, UNICODE_NORM_QC_NO},
+	{0xCEF6, UNICODE_NORM_QC_NO},
+	{0xCEF7, UNICODE_NORM_QC_NO},
+	{0xCEF8, UNICODE_NORM_QC_NO},
+	{0xCEF9, UNICODE_NORM_QC_NO},
+	{0xCEFA, UNICODE_NORM_QC_NO},
+	{0xCEFB, UNICODE_NORM_QC_NO},
+	{0xCEFC, UNICODE_NORM_QC_NO},
+	{0xCEFD, UNICODE_NORM_QC_NO},
+	{0xCEFE, UNICODE_NORM_QC_NO},
+	{0xCEFF, UNICODE_NORM_QC_NO},
+	{0xCF00, UNICODE_NORM_QC_NO},
+	{0xCF01, UNICODE_NORM_QC_NO},
+	{0xCF02, UNICODE_NORM_QC_NO},
+	{0xCF03, UNICODE_NORM_QC_NO},
+	{0xCF04, UNICODE_NORM_QC_NO},
+	{0xCF05, UNICODE_NORM_QC_NO},
+	{0xCF06, UNICODE_NORM_QC_NO},
+	{0xCF07, UNICODE_NORM_QC_NO},
+	{0xCF08, UNICODE_NORM_QC_NO},
+	{0xCF09, UNICODE_NORM_QC_NO},
+	{0xCF0A, UNICODE_NORM_QC_NO},
+	{0xCF0B, UNICODE_NORM_QC_NO},
+	{0xCF0C, UNICODE_NORM_QC_NO},
+	{0xCF0D, UNICODE_NORM_QC_NO},
+	{0xCF0E, UNICODE_NORM_QC_NO},
+	{0xCF0F, UNICODE_NORM_QC_NO},
+	{0xCF10, UNICODE_NORM_QC_NO},
+	{0xCF11, UNICODE_NORM_QC_NO},
+	{0xCF12, UNICODE_NORM_QC_NO},
+	{0xCF13, UNICODE_NORM_QC_NO},
+	{0xCF14, UNICODE_NORM_QC_NO},
+	{0xCF15, UNICODE_NORM_QC_NO},
+	{0xCF16, UNICODE_NORM_QC_NO},
+	{0xCF17, UNICODE_NORM_QC_NO},
+	{0xCF18, UNICODE_NORM_QC_NO},
+	{0xCF19, UNICODE_NORM_QC_NO},
+	{0xCF1A, UNICODE_NORM_QC_NO},
+	{0xCF1B, UNICODE_NORM_QC_NO},
+	{0xCF1C, UNICODE_NORM_QC_NO},
+	{0xCF1D, UNICODE_NORM_QC_NO},
+	{0xCF1E, UNICODE_NORM_QC_NO},
+	{0xCF1F, UNICODE_NORM_QC_NO},
+	{0xCF20, UNICODE_NORM_QC_NO},
+	{0xCF21, UNICODE_NORM_QC_NO},
+	{0xCF22, UNICODE_NORM_QC_NO},
+	{0xCF23, UNICODE_NORM_QC_NO},
+	{0xCF24, UNICODE_NORM_QC_NO},
+	{0xCF25, UNICODE_NORM_QC_NO},
+	{0xCF26, UNICODE_NORM_QC_NO},
+	{0xCF27, UNICODE_NORM_QC_NO},
+	{0xCF28, UNICODE_NORM_QC_NO},
+	{0xCF29, UNICODE_NORM_QC_NO},
+	{0xCF2A, UNICODE_NORM_QC_NO},
+	{0xCF2B, UNICODE_NORM_QC_NO},
+	{0xCF2C, UNICODE_NORM_QC_NO},
+	{0xCF2D, UNICODE_NORM_QC_NO},
+	{0xCF2E, UNICODE_NORM_QC_NO},
+	{0xCF2F, UNICODE_NORM_QC_NO},
+	{0xCF30, UNICODE_NORM_QC_NO},
+	{0xCF31, UNICODE_NORM_QC_NO},
+	{0xCF32, UNICODE_NORM_QC_NO},
+	{0xCF33, UNICODE_NORM_QC_NO},
+	{0xCF34, UNICODE_NORM_QC_NO},
+	{0xCF35, UNICODE_NORM_QC_NO},
+	{0xCF36, UNICODE_NORM_QC_NO},
+	{0xCF37, UNICODE_NORM_QC_NO},
+	{0xCF38, UNICODE_NORM_QC_NO},
+	{0xCF39, UNICODE_NORM_QC_NO},
+	{0xCF3A, UNICODE_NORM_QC_NO},
+	{0xCF3B, UNICODE_NORM_QC_NO},
+	{0xCF3C, UNICODE_NORM_QC_NO},
+	{0xCF3D, UNICODE_NORM_QC_NO},
+	{0xCF3E, UNICODE_NORM_QC_NO},
+	{0xCF3F, UNICODE_NORM_QC_NO},
+	{0xCF40, UNICODE_NORM_QC_NO},
+	{0xCF41, UNICODE_NORM_QC_NO},
+	{0xCF42, UNICODE_NORM_QC_NO},
+	{0xCF43, UNICODE_NORM_QC_NO},
+	{0xCF44, UNICODE_NORM_QC_NO},
+	{0xCF45, UNICODE_NORM_QC_NO},
+	{0xCF46, UNICODE_NORM_QC_NO},
+	{0xCF47, UNICODE_NORM_QC_NO},
+	{0xCF48, UNICODE_NORM_QC_NO},
+	{0xCF49, UNICODE_NORM_QC_NO},
+	{0xCF4A, UNICODE_NORM_QC_NO},
+	{0xCF4B, UNICODE_NORM_QC_NO},
+	{0xCF4C, UNICODE_NORM_QC_NO},
+	{0xCF4D, UNICODE_NORM_QC_NO},
+	{0xCF4E, UNICODE_NORM_QC_NO},
+	{0xCF4F, UNICODE_NORM_QC_NO},
+	{0xCF50, UNICODE_NORM_QC_NO},
+	{0xCF51, UNICODE_NORM_QC_NO},
+	{0xCF52, UNICODE_NORM_QC_NO},
+	{0xCF53, UNICODE_NORM_QC_NO},
+	{0xCF54, UNICODE_NORM_QC_NO},
+	{0xCF55, UNICODE_NORM_QC_NO},
+	{0xCF56, UNICODE_NORM_QC_NO},
+	{0xCF57, UNICODE_NORM_QC_NO},
+	{0xCF58, UNICODE_NORM_QC_NO},
+	{0xCF59, UNICODE_NORM_QC_NO},
+	{0xCF5A, UNICODE_NORM_QC_NO},
+	{0xCF5B, UNICODE_NORM_QC_NO},
+	{0xCF5C, UNICODE_NORM_QC_NO},
+	{0xCF5D, UNICODE_NORM_QC_NO},
+	{0xCF5E, UNICODE_NORM_QC_NO},
+	{0xCF5F, UNICODE_NORM_QC_NO},
+	{0xCF60, UNICODE_NORM_QC_NO},
+	{0xCF61, UNICODE_NORM_QC_NO},
+	{0xCF62, UNICODE_NORM_QC_NO},
+	{0xCF63, UNICODE_NORM_QC_NO},
+	{0xCF64, UNICODE_NORM_QC_NO},
+	{0xCF65, UNICODE_NORM_QC_NO},
+	{0xCF66, UNICODE_NORM_QC_NO},
+	{0xCF67, UNICODE_NORM_QC_NO},
+	{0xCF68, UNICODE_NORM_QC_NO},
+	{0xCF69, UNICODE_NORM_QC_NO},
+	{0xCF6A, UNICODE_NORM_QC_NO},
+	{0xCF6B, UNICODE_NORM_QC_NO},
+	{0xCF6C, UNICODE_NORM_QC_NO},
+	{0xCF6D, UNICODE_NORM_QC_NO},
+	{0xCF6E, UNICODE_NORM_QC_NO},
+	{0xCF6F, UNICODE_NORM_QC_NO},
+	{0xCF70, UNICODE_NORM_QC_NO},
+	{0xCF71, UNICODE_NORM_QC_NO},
+	{0xCF72, UNICODE_NORM_QC_NO},
+	{0xCF73, UNICODE_NORM_QC_NO},
+	{0xCF74, UNICODE_NORM_QC_NO},
+	{0xCF75, UNICODE_NORM_QC_NO},
+	{0xCF76, UNICODE_NORM_QC_NO},
+	{0xCF77, UNICODE_NORM_QC_NO},
+	{0xCF78, UNICODE_NORM_QC_NO},
+	{0xCF79, UNICODE_NORM_QC_NO},
+	{0xCF7A, UNICODE_NORM_QC_NO},
+	{0xCF7B, UNICODE_NORM_QC_NO},
+	{0xCF7C, UNICODE_NORM_QC_NO},
+	{0xCF7D, UNICODE_NORM_QC_NO},
+	{0xCF7E, UNICODE_NORM_QC_NO},
+	{0xCF7F, UNICODE_NORM_QC_NO},
+	{0xCF80, UNICODE_NORM_QC_NO},
+	{0xCF81, UNICODE_NORM_QC_NO},
+	{0xCF82, UNICODE_NORM_QC_NO},
+	{0xCF83, UNICODE_NORM_QC_NO},
+	{0xCF84, UNICODE_NORM_QC_NO},
+	{0xCF85, UNICODE_NORM_QC_NO},
+	{0xCF86, UNICODE_NORM_QC_NO},
+	{0xCF87, UNICODE_NORM_QC_NO},
+	{0xCF88, UNICODE_NORM_QC_NO},
+	{0xCF89, UNICODE_NORM_QC_NO},
+	{0xCF8A, UNICODE_NORM_QC_NO},
+	{0xCF8B, UNICODE_NORM_QC_NO},
+	{0xCF8C, UNICODE_NORM_QC_NO},
+	{0xCF8D, UNICODE_NORM_QC_NO},
+	{0xCF8E, UNICODE_NORM_QC_NO},
+	{0xCF8F, UNICODE_NORM_QC_NO},
+	{0xCF90, UNICODE_NORM_QC_NO},
+	{0xCF91, UNICODE_NORM_QC_NO},
+	{0xCF92, UNICODE_NORM_QC_NO},
+	{0xCF93, UNICODE_NORM_QC_NO},
+	{0xCF94, UNICODE_NORM_QC_NO},
+	{0xCF95, UNICODE_NORM_QC_NO},
+	{0xCF96, UNICODE_NORM_QC_NO},
+	{0xCF97, UNICODE_NORM_QC_NO},
+	{0xCF98, UNICODE_NORM_QC_NO},
+	{0xCF99, UNICODE_NORM_QC_NO},
+	{0xCF9A, UNICODE_NORM_QC_NO},
+	{0xCF9B, UNICODE_NORM_QC_NO},
+	{0xCF9C, UNICODE_NORM_QC_NO},
+	{0xCF9D, UNICODE_NORM_QC_NO},
+	{0xCF9E, UNICODE_NORM_QC_NO},
+	{0xCF9F, UNICODE_NORM_QC_NO},
+	{0xCFA0, UNICODE_NORM_QC_NO},
+	{0xCFA1, UNICODE_NORM_QC_NO},
+	{0xCFA2, UNICODE_NORM_QC_NO},
+	{0xCFA3, UNICODE_NORM_QC_NO},
+	{0xCFA4, UNICODE_NORM_QC_NO},
+	{0xCFA5, UNICODE_NORM_QC_NO},
+	{0xCFA6, UNICODE_NORM_QC_NO},
+	{0xCFA7, UNICODE_NORM_QC_NO},
+	{0xCFA8, UNICODE_NORM_QC_NO},
+	{0xCFA9, UNICODE_NORM_QC_NO},
+	{0xCFAA, UNICODE_NORM_QC_NO},
+	{0xCFAB, UNICODE_NORM_QC_NO},
+	{0xCFAC, UNICODE_NORM_QC_NO},
+	{0xCFAD, UNICODE_NORM_QC_NO},
+	{0xCFAE, UNICODE_NORM_QC_NO},
+	{0xCFAF, UNICODE_NORM_QC_NO},
+	{0xCFB0, UNICODE_NORM_QC_NO},
+	{0xCFB1, UNICODE_NORM_QC_NO},
+	{0xCFB2, UNICODE_NORM_QC_NO},
+	{0xCFB3, UNICODE_NORM_QC_NO},
+	{0xCFB4, UNICODE_NORM_QC_NO},
+	{0xCFB5, UNICODE_NORM_QC_NO},
+	{0xCFB6, UNICODE_NORM_QC_NO},
+	{0xCFB7, UNICODE_NORM_QC_NO},
+	{0xCFB8, UNICODE_NORM_QC_NO},
+	{0xCFB9, UNICODE_NORM_QC_NO},
+	{0xCFBA, UNICODE_NORM_QC_NO},
+	{0xCFBB, UNICODE_NORM_QC_NO},
+	{0xCFBC, UNICODE_NORM_QC_NO},
+	{0xCFBD, UNICODE_NORM_QC_NO},
+	{0xCFBE, UNICODE_NORM_QC_NO},
+	{0xCFBF, UNICODE_NORM_QC_NO},
+	{0xCFC0, UNICODE_NORM_QC_NO},
+	{0xCFC1, UNICODE_NORM_QC_NO},
+	{0xCFC2, UNICODE_NORM_QC_NO},
+	{0xCFC3, UNICODE_NORM_QC_NO},
+	{0xCFC4, UNICODE_NORM_QC_NO},
+	{0xCFC5, UNICODE_NORM_QC_NO},
+	{0xCFC6, UNICODE_NORM_QC_NO},
+	{0xCFC7, UNICODE_NORM_QC_NO},
+	{0xCFC8, UNICODE_NORM_QC_NO},
+	{0xCFC9, UNICODE_NORM_QC_NO},
+	{0xCFCA, UNICODE_NORM_QC_NO},
+	{0xCFCB, UNICODE_NORM_QC_NO},
+	{0xCFCC, UNICODE_NORM_QC_NO},
+	{0xCFCD, UNICODE_NORM_QC_NO},
+	{0xCFCE, UNICODE_NORM_QC_NO},
+	{0xCFCF, UNICODE_NORM_QC_NO},
+	{0xCFD0, UNICODE_NORM_QC_NO},
+	{0xCFD1, UNICODE_NORM_QC_NO},
+	{0xCFD2, UNICODE_NORM_QC_NO},
+	{0xCFD3, UNICODE_NORM_QC_NO},
+	{0xCFD4, UNICODE_NORM_QC_NO},
+	{0xCFD5, UNICODE_NORM_QC_NO},
+	{0xCFD6, UNICODE_NORM_QC_NO},
+	{0xCFD7, UNICODE_NORM_QC_NO},
+	{0xCFD8, UNICODE_NORM_QC_NO},
+	{0xCFD9, UNICODE_NORM_QC_NO},
+	{0xCFDA, UNICODE_NORM_QC_NO},
+	{0xCFDB, UNICODE_NORM_QC_NO},
+	{0xCFDC, UNICODE_NORM_QC_NO},
+	{0xCFDD, UNICODE_NORM_QC_NO},
+	{0xCFDE, UNICODE_NORM_QC_NO},
+	{0xCFDF, UNICODE_NORM_QC_NO},
+	{0xCFE0, UNICODE_NORM_QC_NO},
+	{0xCFE1, UNICODE_NORM_QC_NO},
+	{0xCFE2, UNICODE_NORM_QC_NO},
+	{0xCFE3, UNICODE_NORM_QC_NO},
+	{0xCFE4, UNICODE_NORM_QC_NO},
+	{0xCFE5, UNICODE_NORM_QC_NO},
+	{0xCFE6, UNICODE_NORM_QC_NO},
+	{0xCFE7, UNICODE_NORM_QC_NO},
+	{0xCFE8, UNICODE_NORM_QC_NO},
+	{0xCFE9, UNICODE_NORM_QC_NO},
+	{0xCFEA, UNICODE_NORM_QC_NO},
+	{0xCFEB, UNICODE_NORM_QC_NO},
+	{0xCFEC, UNICODE_NORM_QC_NO},
+	{0xCFED, UNICODE_NORM_QC_NO},
+	{0xCFEE, UNICODE_NORM_QC_NO},
+	{0xCFEF, UNICODE_NORM_QC_NO},
+	{0xCFF0, UNICODE_NORM_QC_NO},
+	{0xCFF1, UNICODE_NORM_QC_NO},
+	{0xCFF2, UNICODE_NORM_QC_NO},
+	{0xCFF3, UNICODE_NORM_QC_NO},
+	{0xCFF4, UNICODE_NORM_QC_NO},
+	{0xCFF5, UNICODE_NORM_QC_NO},
+	{0xCFF6, UNICODE_NORM_QC_NO},
+	{0xCFF7, UNICODE_NORM_QC_NO},
+	{0xCFF8, UNICODE_NORM_QC_NO},
+	{0xCFF9, UNICODE_NORM_QC_NO},
+	{0xCFFA, UNICODE_NORM_QC_NO},
+	{0xCFFB, UNICODE_NORM_QC_NO},
+	{0xCFFC, UNICODE_NORM_QC_NO},
+	{0xCFFD, UNICODE_NORM_QC_NO},
+	{0xCFFE, UNICODE_NORM_QC_NO},
+	{0xCFFF, UNICODE_NORM_QC_NO},
+	{0xD000, UNICODE_NORM_QC_NO},
+	{0xD001, UNICODE_NORM_QC_NO},
+	{0xD002, UNICODE_NORM_QC_NO},
+	{0xD003, UNICODE_NORM_QC_NO},
+	{0xD004, UNICODE_NORM_QC_NO},
+	{0xD005, UNICODE_NORM_QC_NO},
+	{0xD006, UNICODE_NORM_QC_NO},
+	{0xD007, UNICODE_NORM_QC_NO},
+	{0xD008, UNICODE_NORM_QC_NO},
+	{0xD009, UNICODE_NORM_QC_NO},
+	{0xD00A, UNICODE_NORM_QC_NO},
+	{0xD00B, UNICODE_NORM_QC_NO},
+	{0xD00C, UNICODE_NORM_QC_NO},
+	{0xD00D, UNICODE_NORM_QC_NO},
+	{0xD00E, UNICODE_NORM_QC_NO},
+	{0xD00F, UNICODE_NORM_QC_NO},
+	{0xD010, UNICODE_NORM_QC_NO},
+	{0xD011, UNICODE_NORM_QC_NO},
+	{0xD012, UNICODE_NORM_QC_NO},
+	{0xD013, UNICODE_NORM_QC_NO},
+	{0xD014, UNICODE_NORM_QC_NO},
+	{0xD015, UNICODE_NORM_QC_NO},
+	{0xD016, UNICODE_NORM_QC_NO},
+	{0xD017, UNICODE_NORM_QC_NO},
+	{0xD018, UNICODE_NORM_QC_NO},
+	{0xD019, UNICODE_NORM_QC_NO},
+	{0xD01A, UNICODE_NORM_QC_NO},
+	{0xD01B, UNICODE_NORM_QC_NO},
+	{0xD01C, UNICODE_NORM_QC_NO},
+	{0xD01D, UNICODE_NORM_QC_NO},
+	{0xD01E, UNICODE_NORM_QC_NO},
+	{0xD01F, UNICODE_NORM_QC_NO},
+	{0xD020, UNICODE_NORM_QC_NO},
+	{0xD021, UNICODE_NORM_QC_NO},
+	{0xD022, UNICODE_NORM_QC_NO},
+	{0xD023, UNICODE_NORM_QC_NO},
+	{0xD024, UNICODE_NORM_QC_NO},
+	{0xD025, UNICODE_NORM_QC_NO},
+	{0xD026, UNICODE_NORM_QC_NO},
+	{0xD027, UNICODE_NORM_QC_NO},
+	{0xD028, UNICODE_NORM_QC_NO},
+	{0xD029, UNICODE_NORM_QC_NO},
+	{0xD02A, UNICODE_NORM_QC_NO},
+	{0xD02B, UNICODE_NORM_QC_NO},
+	{0xD02C, UNICODE_NORM_QC_NO},
+	{0xD02D, UNICODE_NORM_QC_NO},
+	{0xD02E, UNICODE_NORM_QC_NO},
+	{0xD02F, UNICODE_NORM_QC_NO},
+	{0xD030, UNICODE_NORM_QC_NO},
+	{0xD031, UNICODE_NORM_QC_NO},
+	{0xD032, UNICODE_NORM_QC_NO},
+	{0xD033, UNICODE_NORM_QC_NO},
+	{0xD034, UNICODE_NORM_QC_NO},
+	{0xD035, UNICODE_NORM_QC_NO},
+	{0xD036, UNICODE_NORM_QC_NO},
+	{0xD037, UNICODE_NORM_QC_NO},
+	{0xD038, UNICODE_NORM_QC_NO},
+	{0xD039, UNICODE_NORM_QC_NO},
+	{0xD03A, UNICODE_NORM_QC_NO},
+	{0xD03B, UNICODE_NORM_QC_NO},
+	{0xD03C, UNICODE_NORM_QC_NO},
+	{0xD03D, UNICODE_NORM_QC_NO},
+	{0xD03E, UNICODE_NORM_QC_NO},
+	{0xD03F, UNICODE_NORM_QC_NO},
+	{0xD040, UNICODE_NORM_QC_NO},
+	{0xD041, UNICODE_NORM_QC_NO},
+	{0xD042, UNICODE_NORM_QC_NO},
+	{0xD043, UNICODE_NORM_QC_NO},
+	{0xD044, UNICODE_NORM_QC_NO},
+	{0xD045, UNICODE_NORM_QC_NO},
+	{0xD046, UNICODE_NORM_QC_NO},
+	{0xD047, UNICODE_NORM_QC_NO},
+	{0xD048, UNICODE_NORM_QC_NO},
+	{0xD049, UNICODE_NORM_QC_NO},
+	{0xD04A, UNICODE_NORM_QC_NO},
+	{0xD04B, UNICODE_NORM_QC_NO},
+	{0xD04C, UNICODE_NORM_QC_NO},
+	{0xD04D, UNICODE_NORM_QC_NO},
+	{0xD04E, UNICODE_NORM_QC_NO},
+	{0xD04F, UNICODE_NORM_QC_NO},
+	{0xD050, UNICODE_NORM_QC_NO},
+	{0xD051, UNICODE_NORM_QC_NO},
+	{0xD052, UNICODE_NORM_QC_NO},
+	{0xD053, UNICODE_NORM_QC_NO},
+	{0xD054, UNICODE_NORM_QC_NO},
+	{0xD055, UNICODE_NORM_QC_NO},
+	{0xD056, UNICODE_NORM_QC_NO},
+	{0xD057, UNICODE_NORM_QC_NO},
+	{0xD058, UNICODE_NORM_QC_NO},
+	{0xD059, UNICODE_NORM_QC_NO},
+	{0xD05A, UNICODE_NORM_QC_NO},
+	{0xD05B, UNICODE_NORM_QC_NO},
+	{0xD05C, UNICODE_NORM_QC_NO},
+	{0xD05D, UNICODE_NORM_QC_NO},
+	{0xD05E, UNICODE_NORM_QC_NO},
+	{0xD05F, UNICODE_NORM_QC_NO},
+	{0xD060, UNICODE_NORM_QC_NO},
+	{0xD061, UNICODE_NORM_QC_NO},
+	{0xD062, UNICODE_NORM_QC_NO},
+	{0xD063, UNICODE_NORM_QC_NO},
+	{0xD064, UNICODE_NORM_QC_NO},
+	{0xD065, UNICODE_NORM_QC_NO},
+	{0xD066, UNICODE_NORM_QC_NO},
+	{0xD067, UNICODE_NORM_QC_NO},
+	{0xD068, UNICODE_NORM_QC_NO},
+	{0xD069, UNICODE_NORM_QC_NO},
+	{0xD06A, UNICODE_NORM_QC_NO},
+	{0xD06B, UNICODE_NORM_QC_NO},
+	{0xD06C, UNICODE_NORM_QC_NO},
+	{0xD06D, UNICODE_NORM_QC_NO},
+	{0xD06E, UNICODE_NORM_QC_NO},
+	{0xD06F, UNICODE_NORM_QC_NO},
+	{0xD070, UNICODE_NORM_QC_NO},
+	{0xD071, UNICODE_NORM_QC_NO},
+	{0xD072, UNICODE_NORM_QC_NO},
+	{0xD073, UNICODE_NORM_QC_NO},
+	{0xD074, UNICODE_NORM_QC_NO},
+	{0xD075, UNICODE_NORM_QC_NO},
+	{0xD076, UNICODE_NORM_QC_NO},
+	{0xD077, UNICODE_NORM_QC_NO},
+	{0xD078, UNICODE_NORM_QC_NO},
+	{0xD079, UNICODE_NORM_QC_NO},
+	{0xD07A, UNICODE_NORM_QC_NO},
+	{0xD07B, UNICODE_NORM_QC_NO},
+	{0xD07C, UNICODE_NORM_QC_NO},
+	{0xD07D, UNICODE_NORM_QC_NO},
+	{0xD07E, UNICODE_NORM_QC_NO},
+	{0xD07F, UNICODE_NORM_QC_NO},
+	{0xD080, UNICODE_NORM_QC_NO},
+	{0xD081, UNICODE_NORM_QC_NO},
+	{0xD082, UNICODE_NORM_QC_NO},
+	{0xD083, UNICODE_NORM_QC_NO},
+	{0xD084, UNICODE_NORM_QC_NO},
+	{0xD085, UNICODE_NORM_QC_NO},
+	{0xD086, UNICODE_NORM_QC_NO},
+	{0xD087, UNICODE_NORM_QC_NO},
+	{0xD088, UNICODE_NORM_QC_NO},
+	{0xD089, UNICODE_NORM_QC_NO},
+	{0xD08A, UNICODE_NORM_QC_NO},
+	{0xD08B, UNICODE_NORM_QC_NO},
+	{0xD08C, UNICODE_NORM_QC_NO},
+	{0xD08D, UNICODE_NORM_QC_NO},
+	{0xD08E, UNICODE_NORM_QC_NO},
+	{0xD08F, UNICODE_NORM_QC_NO},
+	{0xD090, UNICODE_NORM_QC_NO},
+	{0xD091, UNICODE_NORM_QC_NO},
+	{0xD092, UNICODE_NORM_QC_NO},
+	{0xD093, UNICODE_NORM_QC_NO},
+	{0xD094, UNICODE_NORM_QC_NO},
+	{0xD095, UNICODE_NORM_QC_NO},
+	{0xD096, UNICODE_NORM_QC_NO},
+	{0xD097, UNICODE_NORM_QC_NO},
+	{0xD098, UNICODE_NORM_QC_NO},
+	{0xD099, UNICODE_NORM_QC_NO},
+	{0xD09A, UNICODE_NORM_QC_NO},
+	{0xD09B, UNICODE_NORM_QC_NO},
+	{0xD09C, UNICODE_NORM_QC_NO},
+	{0xD09D, UNICODE_NORM_QC_NO},
+	{0xD09E, UNICODE_NORM_QC_NO},
+	{0xD09F, UNICODE_NORM_QC_NO},
+	{0xD0A0, UNICODE_NORM_QC_NO},
+	{0xD0A1, UNICODE_NORM_QC_NO},
+	{0xD0A2, UNICODE_NORM_QC_NO},
+	{0xD0A3, UNICODE_NORM_QC_NO},
+	{0xD0A4, UNICODE_NORM_QC_NO},
+	{0xD0A5, UNICODE_NORM_QC_NO},
+	{0xD0A6, UNICODE_NORM_QC_NO},
+	{0xD0A7, UNICODE_NORM_QC_NO},
+	{0xD0A8, UNICODE_NORM_QC_NO},
+	{0xD0A9, UNICODE_NORM_QC_NO},
+	{0xD0AA, UNICODE_NORM_QC_NO},
+	{0xD0AB, UNICODE_NORM_QC_NO},
+	{0xD0AC, UNICODE_NORM_QC_NO},
+	{0xD0AD, UNICODE_NORM_QC_NO},
+	{0xD0AE, UNICODE_NORM_QC_NO},
+	{0xD0AF, UNICODE_NORM_QC_NO},
+	{0xD0B0, UNICODE_NORM_QC_NO},
+	{0xD0B1, UNICODE_NORM_QC_NO},
+	{0xD0B2, UNICODE_NORM_QC_NO},
+	{0xD0B3, UNICODE_NORM_QC_NO},
+	{0xD0B4, UNICODE_NORM_QC_NO},
+	{0xD0B5, UNICODE_NORM_QC_NO},
+	{0xD0B6, UNICODE_NORM_QC_NO},
+	{0xD0B7, UNICODE_NORM_QC_NO},
+	{0xD0B8, UNICODE_NORM_QC_NO},
+	{0xD0B9, UNICODE_NORM_QC_NO},
+	{0xD0BA, UNICODE_NORM_QC_NO},
+	{0xD0BB, UNICODE_NORM_QC_NO},
+	{0xD0BC, UNICODE_NORM_QC_NO},
+	{0xD0BD, UNICODE_NORM_QC_NO},
+	{0xD0BE, UNICODE_NORM_QC_NO},
+	{0xD0BF, UNICODE_NORM_QC_NO},
+	{0xD0C0, UNICODE_NORM_QC_NO},
+	{0xD0C1, UNICODE_NORM_QC_NO},
+	{0xD0C2, UNICODE_NORM_QC_NO},
+	{0xD0C3, UNICODE_NORM_QC_NO},
+	{0xD0C4, UNICODE_NORM_QC_NO},
+	{0xD0C5, UNICODE_NORM_QC_NO},
+	{0xD0C6, UNICODE_NORM_QC_NO},
+	{0xD0C7, UNICODE_NORM_QC_NO},
+	{0xD0C8, UNICODE_NORM_QC_NO},
+	{0xD0C9, UNICODE_NORM_QC_NO},
+	{0xD0CA, UNICODE_NORM_QC_NO},
+	{0xD0CB, UNICODE_NORM_QC_NO},
+	{0xD0CC, UNICODE_NORM_QC_NO},
+	{0xD0CD, UNICODE_NORM_QC_NO},
+	{0xD0CE, UNICODE_NORM_QC_NO},
+	{0xD0CF, UNICODE_NORM_QC_NO},
+	{0xD0D0, UNICODE_NORM_QC_NO},
+	{0xD0D1, UNICODE_NORM_QC_NO},
+	{0xD0D2, UNICODE_NORM_QC_NO},
+	{0xD0D3, UNICODE_NORM_QC_NO},
+	{0xD0D4, UNICODE_NORM_QC_NO},
+	{0xD0D5, UNICODE_NORM_QC_NO},
+	{0xD0D6, UNICODE_NORM_QC_NO},
+	{0xD0D7, UNICODE_NORM_QC_NO},
+	{0xD0D8, UNICODE_NORM_QC_NO},
+	{0xD0D9, UNICODE_NORM_QC_NO},
+	{0xD0DA, UNICODE_NORM_QC_NO},
+	{0xD0DB, UNICODE_NORM_QC_NO},
+	{0xD0DC, UNICODE_NORM_QC_NO},
+	{0xD0DD, UNICODE_NORM_QC_NO},
+	{0xD0DE, UNICODE_NORM_QC_NO},
+	{0xD0DF, UNICODE_NORM_QC_NO},
+	{0xD0E0, UNICODE_NORM_QC_NO},
+	{0xD0E1, UNICODE_NORM_QC_NO},
+	{0xD0E2, UNICODE_NORM_QC_NO},
+	{0xD0E3, UNICODE_NORM_QC_NO},
+	{0xD0E4, UNICODE_NORM_QC_NO},
+	{0xD0E5, UNICODE_NORM_QC_NO},
+	{0xD0E6, UNICODE_NORM_QC_NO},
+	{0xD0E7, UNICODE_NORM_QC_NO},
+	{0xD0E8, UNICODE_NORM_QC_NO},
+	{0xD0E9, UNICODE_NORM_QC_NO},
+	{0xD0EA, UNICODE_NORM_QC_NO},
+	{0xD0EB, UNICODE_NORM_QC_NO},
+	{0xD0EC, UNICODE_NORM_QC_NO},
+	{0xD0ED, UNICODE_NORM_QC_NO},
+	{0xD0EE, UNICODE_NORM_QC_NO},
+	{0xD0EF, UNICODE_NORM_QC_NO},
+	{0xD0F0, UNICODE_NORM_QC_NO},
+	{0xD0F1, UNICODE_NORM_QC_NO},
+	{0xD0F2, UNICODE_NORM_QC_NO},
+	{0xD0F3, UNICODE_NORM_QC_NO},
+	{0xD0F4, UNICODE_NORM_QC_NO},
+	{0xD0F5, UNICODE_NORM_QC_NO},
+	{0xD0F6, UNICODE_NORM_QC_NO},
+	{0xD0F7, UNICODE_NORM_QC_NO},
+	{0xD0F8, UNICODE_NORM_QC_NO},
+	{0xD0F9, UNICODE_NORM_QC_NO},
+	{0xD0FA, UNICODE_NORM_QC_NO},
+	{0xD0FB, UNICODE_NORM_QC_NO},
+	{0xD0FC, UNICODE_NORM_QC_NO},
+	{0xD0FD, UNICODE_NORM_QC_NO},
+	{0xD0FE, UNICODE_NORM_QC_NO},
+	{0xD0FF, UNICODE_NORM_QC_NO},
+	{0xD100, UNICODE_NORM_QC_NO},
+	{0xD101, UNICODE_NORM_QC_NO},
+	{0xD102, UNICODE_NORM_QC_NO},
+	{0xD103, UNICODE_NORM_QC_NO},
+	{0xD104, UNICODE_NORM_QC_NO},
+	{0xD105, UNICODE_NORM_QC_NO},
+	{0xD106, UNICODE_NORM_QC_NO},
+	{0xD107, UNICODE_NORM_QC_NO},
+	{0xD108, UNICODE_NORM_QC_NO},
+	{0xD109, UNICODE_NORM_QC_NO},
+	{0xD10A, UNICODE_NORM_QC_NO},
+	{0xD10B, UNICODE_NORM_QC_NO},
+	{0xD10C, UNICODE_NORM_QC_NO},
+	{0xD10D, UNICODE_NORM_QC_NO},
+	{0xD10E, UNICODE_NORM_QC_NO},
+	{0xD10F, UNICODE_NORM_QC_NO},
+	{0xD110, UNICODE_NORM_QC_NO},
+	{0xD111, UNICODE_NORM_QC_NO},
+	{0xD112, UNICODE_NORM_QC_NO},
+	{0xD113, UNICODE_NORM_QC_NO},
+	{0xD114, UNICODE_NORM_QC_NO},
+	{0xD115, UNICODE_NORM_QC_NO},
+	{0xD116, UNICODE_NORM_QC_NO},
+	{0xD117, UNICODE_NORM_QC_NO},
+	{0xD118, UNICODE_NORM_QC_NO},
+	{0xD119, UNICODE_NORM_QC_NO},
+	{0xD11A, UNICODE_NORM_QC_NO},
+	{0xD11B, UNICODE_NORM_QC_NO},
+	{0xD11C, UNICODE_NORM_QC_NO},
+	{0xD11D, UNICODE_NORM_QC_NO},
+	{0xD11E, UNICODE_NORM_QC_NO},
+	{0xD11F, UNICODE_NORM_QC_NO},
+	{0xD120, UNICODE_NORM_QC_NO},
+	{0xD121, UNICODE_NORM_QC_NO},
+	{0xD122, UNICODE_NORM_QC_NO},
+	{0xD123, UNICODE_NORM_QC_NO},
+	{0xD124, UNICODE_NORM_QC_NO},
+	{0xD125, UNICODE_NORM_QC_NO},
+	{0xD126, UNICODE_NORM_QC_NO},
+	{0xD127, UNICODE_NORM_QC_NO},
+	{0xD128, UNICODE_NORM_QC_NO},
+	{0xD129, UNICODE_NORM_QC_NO},
+	{0xD12A, UNICODE_NORM_QC_NO},
+	{0xD12B, UNICODE_NORM_QC_NO},
+	{0xD12C, UNICODE_NORM_QC_NO},
+	{0xD12D, UNICODE_NORM_QC_NO},
+	{0xD12E, UNICODE_NORM_QC_NO},
+	{0xD12F, UNICODE_NORM_QC_NO},
+	{0xD130, UNICODE_NORM_QC_NO},
+	{0xD131, UNICODE_NORM_QC_NO},
+	{0xD132, UNICODE_NORM_QC_NO},
+	{0xD133, UNICODE_NORM_QC_NO},
+	{0xD134, UNICODE_NORM_QC_NO},
+	{0xD135, UNICODE_NORM_QC_NO},
+	{0xD136, UNICODE_NORM_QC_NO},
+	{0xD137, UNICODE_NORM_QC_NO},
+	{0xD138, UNICODE_NORM_QC_NO},
+	{0xD139, UNICODE_NORM_QC_NO},
+	{0xD13A, UNICODE_NORM_QC_NO},
+	{0xD13B, UNICODE_NORM_QC_NO},
+	{0xD13C, UNICODE_NORM_QC_NO},
+	{0xD13D, UNICODE_NORM_QC_NO},
+	{0xD13E, UNICODE_NORM_QC_NO},
+	{0xD13F, UNICODE_NORM_QC_NO},
+	{0xD140, UNICODE_NORM_QC_NO},
+	{0xD141, UNICODE_NORM_QC_NO},
+	{0xD142, UNICODE_NORM_QC_NO},
+	{0xD143, UNICODE_NORM_QC_NO},
+	{0xD144, UNICODE_NORM_QC_NO},
+	{0xD145, UNICODE_NORM_QC_NO},
+	{0xD146, UNICODE_NORM_QC_NO},
+	{0xD147, UNICODE_NORM_QC_NO},
+	{0xD148, UNICODE_NORM_QC_NO},
+	{0xD149, UNICODE_NORM_QC_NO},
+	{0xD14A, UNICODE_NORM_QC_NO},
+	{0xD14B, UNICODE_NORM_QC_NO},
+	{0xD14C, UNICODE_NORM_QC_NO},
+	{0xD14D, UNICODE_NORM_QC_NO},
+	{0xD14E, UNICODE_NORM_QC_NO},
+	{0xD14F, UNICODE_NORM_QC_NO},
+	{0xD150, UNICODE_NORM_QC_NO},
+	{0xD151, UNICODE_NORM_QC_NO},
+	{0xD152, UNICODE_NORM_QC_NO},
+	{0xD153, UNICODE_NORM_QC_NO},
+	{0xD154, UNICODE_NORM_QC_NO},
+	{0xD155, UNICODE_NORM_QC_NO},
+	{0xD156, UNICODE_NORM_QC_NO},
+	{0xD157, UNICODE_NORM_QC_NO},
+	{0xD158, UNICODE_NORM_QC_NO},
+	{0xD159, UNICODE_NORM_QC_NO},
+	{0xD15A, UNICODE_NORM_QC_NO},
+	{0xD15B, UNICODE_NORM_QC_NO},
+	{0xD15C, UNICODE_NORM_QC_NO},
+	{0xD15D, UNICODE_NORM_QC_NO},
+	{0xD15E, UNICODE_NORM_QC_NO},
+	{0xD15F, UNICODE_NORM_QC_NO},
+	{0xD160, UNICODE_NORM_QC_NO},
+	{0xD161, UNICODE_NORM_QC_NO},
+	{0xD162, UNICODE_NORM_QC_NO},
+	{0xD163, UNICODE_NORM_QC_NO},
+	{0xD164, UNICODE_NORM_QC_NO},
+	{0xD165, UNICODE_NORM_QC_NO},
+	{0xD166, UNICODE_NORM_QC_NO},
+	{0xD167, UNICODE_NORM_QC_NO},
+	{0xD168, UNICODE_NORM_QC_NO},
+	{0xD169, UNICODE_NORM_QC_NO},
+	{0xD16A, UNICODE_NORM_QC_NO},
+	{0xD16B, UNICODE_NORM_QC_NO},
+	{0xD16C, UNICODE_NORM_QC_NO},
+	{0xD16D, UNICODE_NORM_QC_NO},
+	{0xD16E, UNICODE_NORM_QC_NO},
+	{0xD16F, UNICODE_NORM_QC_NO},
+	{0xD170, UNICODE_NORM_QC_NO},
+	{0xD171, UNICODE_NORM_QC_NO},
+	{0xD172, UNICODE_NORM_QC_NO},
+	{0xD173, UNICODE_NORM_QC_NO},
+	{0xD174, UNICODE_NORM_QC_NO},
+	{0xD175, UNICODE_NORM_QC_NO},
+	{0xD176, UNICODE_NORM_QC_NO},
+	{0xD177, UNICODE_NORM_QC_NO},
+	{0xD178, UNICODE_NORM_QC_NO},
+	{0xD179, UNICODE_NORM_QC_NO},
+	{0xD17A, UNICODE_NORM_QC_NO},
+	{0xD17B, UNICODE_NORM_QC_NO},
+	{0xD17C, UNICODE_NORM_QC_NO},
+	{0xD17D, UNICODE_NORM_QC_NO},
+	{0xD17E, UNICODE_NORM_QC_NO},
+	{0xD17F, UNICODE_NORM_QC_NO},
+	{0xD180, UNICODE_NORM_QC_NO},
+	{0xD181, UNICODE_NORM_QC_NO},
+	{0xD182, UNICODE_NORM_QC_NO},
+	{0xD183, UNICODE_NORM_QC_NO},
+	{0xD184, UNICODE_NORM_QC_NO},
+	{0xD185, UNICODE_NORM_QC_NO},
+	{0xD186, UNICODE_NORM_QC_NO},
+	{0xD187, UNICODE_NORM_QC_NO},
+	{0xD188, UNICODE_NORM_QC_NO},
+	{0xD189, UNICODE_NORM_QC_NO},
+	{0xD18A, UNICODE_NORM_QC_NO},
+	{0xD18B, UNICODE_NORM_QC_NO},
+	{0xD18C, UNICODE_NORM_QC_NO},
+	{0xD18D, UNICODE_NORM_QC_NO},
+	{0xD18E, UNICODE_NORM_QC_NO},
+	{0xD18F, UNICODE_NORM_QC_NO},
+	{0xD190, UNICODE_NORM_QC_NO},
+	{0xD191, UNICODE_NORM_QC_NO},
+	{0xD192, UNICODE_NORM_QC_NO},
+	{0xD193, UNICODE_NORM_QC_NO},
+	{0xD194, UNICODE_NORM_QC_NO},
+	{0xD195, UNICODE_NORM_QC_NO},
+	{0xD196, UNICODE_NORM_QC_NO},
+	{0xD197, UNICODE_NORM_QC_NO},
+	{0xD198, UNICODE_NORM_QC_NO},
+	{0xD199, UNICODE_NORM_QC_NO},
+	{0xD19A, UNICODE_NORM_QC_NO},
+	{0xD19B, UNICODE_NORM_QC_NO},
+	{0xD19C, UNICODE_NORM_QC_NO},
+	{0xD19D, UNICODE_NORM_QC_NO},
+	{0xD19E, UNICODE_NORM_QC_NO},
+	{0xD19F, UNICODE_NORM_QC_NO},
+	{0xD1A0, UNICODE_NORM_QC_NO},
+	{0xD1A1, UNICODE_NORM_QC_NO},
+	{0xD1A2, UNICODE_NORM_QC_NO},
+	{0xD1A3, UNICODE_NORM_QC_NO},
+	{0xD1A4, UNICODE_NORM_QC_NO},
+	{0xD1A5, UNICODE_NORM_QC_NO},
+	{0xD1A6, UNICODE_NORM_QC_NO},
+	{0xD1A7, UNICODE_NORM_QC_NO},
+	{0xD1A8, UNICODE_NORM_QC_NO},
+	{0xD1A9, UNICODE_NORM_QC_NO},
+	{0xD1AA, UNICODE_NORM_QC_NO},
+	{0xD1AB, UNICODE_NORM_QC_NO},
+	{0xD1AC, UNICODE_NORM_QC_NO},
+	{0xD1AD, UNICODE_NORM_QC_NO},
+	{0xD1AE, UNICODE_NORM_QC_NO},
+	{0xD1AF, UNICODE_NORM_QC_NO},
+	{0xD1B0, UNICODE_NORM_QC_NO},
+	{0xD1B1, UNICODE_NORM_QC_NO},
+	{0xD1B2, UNICODE_NORM_QC_NO},
+	{0xD1B3, UNICODE_NORM_QC_NO},
+	{0xD1B4, UNICODE_NORM_QC_NO},
+	{0xD1B5, UNICODE_NORM_QC_NO},
+	{0xD1B6, UNICODE_NORM_QC_NO},
+	{0xD1B7, UNICODE_NORM_QC_NO},
+	{0xD1B8, UNICODE_NORM_QC_NO},
+	{0xD1B9, UNICODE_NORM_QC_NO},
+	{0xD1BA, UNICODE_NORM_QC_NO},
+	{0xD1BB, UNICODE_NORM_QC_NO},
+	{0xD1BC, UNICODE_NORM_QC_NO},
+	{0xD1BD, UNICODE_NORM_QC_NO},
+	{0xD1BE, UNICODE_NORM_QC_NO},
+	{0xD1BF, UNICODE_NORM_QC_NO},
+	{0xD1C0, UNICODE_NORM_QC_NO},
+	{0xD1C1, UNICODE_NORM_QC_NO},
+	{0xD1C2, UNICODE_NORM_QC_NO},
+	{0xD1C3, UNICODE_NORM_QC_NO},
+	{0xD1C4, UNICODE_NORM_QC_NO},
+	{0xD1C5, UNICODE_NORM_QC_NO},
+	{0xD1C6, UNICODE_NORM_QC_NO},
+	{0xD1C7, UNICODE_NORM_QC_NO},
+	{0xD1C8, UNICODE_NORM_QC_NO},
+	{0xD1C9, UNICODE_NORM_QC_NO},
+	{0xD1CA, UNICODE_NORM_QC_NO},
+	{0xD1CB, UNICODE_NORM_QC_NO},
+	{0xD1CC, UNICODE_NORM_QC_NO},
+	{0xD1CD, UNICODE_NORM_QC_NO},
+	{0xD1CE, UNICODE_NORM_QC_NO},
+	{0xD1CF, UNICODE_NORM_QC_NO},
+	{0xD1D0, UNICODE_NORM_QC_NO},
+	{0xD1D1, UNICODE_NORM_QC_NO},
+	{0xD1D2, UNICODE_NORM_QC_NO},
+	{0xD1D3, UNICODE_NORM_QC_NO},
+	{0xD1D4, UNICODE_NORM_QC_NO},
+	{0xD1D5, UNICODE_NORM_QC_NO},
+	{0xD1D6, UNICODE_NORM_QC_NO},
+	{0xD1D7, UNICODE_NORM_QC_NO},
+	{0xD1D8, UNICODE_NORM_QC_NO},
+	{0xD1D9, UNICODE_NORM_QC_NO},
+	{0xD1DA, UNICODE_NORM_QC_NO},
+	{0xD1DB, UNICODE_NORM_QC_NO},
+	{0xD1DC, UNICODE_NORM_QC_NO},
+	{0xD1DD, UNICODE_NORM_QC_NO},
+	{0xD1DE, UNICODE_NORM_QC_NO},
+	{0xD1DF, UNICODE_NORM_QC_NO},
+	{0xD1E0, UNICODE_NORM_QC_NO},
+	{0xD1E1, UNICODE_NORM_QC_NO},
+	{0xD1E2, UNICODE_NORM_QC_NO},
+	{0xD1E3, UNICODE_NORM_QC_NO},
+	{0xD1E4, UNICODE_NORM_QC_NO},
+	{0xD1E5, UNICODE_NORM_QC_NO},
+	{0xD1E6, UNICODE_NORM_QC_NO},
+	{0xD1E7, UNICODE_NORM_QC_NO},
+	{0xD1E8, UNICODE_NORM_QC_NO},
+	{0xD1E9, UNICODE_NORM_QC_NO},
+	{0xD1EA, UNICODE_NORM_QC_NO},
+	{0xD1EB, UNICODE_NORM_QC_NO},
+	{0xD1EC, UNICODE_NORM_QC_NO},
+	{0xD1ED, UNICODE_NORM_QC_NO},
+	{0xD1EE, UNICODE_NORM_QC_NO},
+	{0xD1EF, UNICODE_NORM_QC_NO},
+	{0xD1F0, UNICODE_NORM_QC_NO},
+	{0xD1F1, UNICODE_NORM_QC_NO},
+	{0xD1F2, UNICODE_NORM_QC_NO},
+	{0xD1F3, UNICODE_NORM_QC_NO},
+	{0xD1F4, UNICODE_NORM_QC_NO},
+	{0xD1F5, UNICODE_NORM_QC_NO},
+	{0xD1F6, UNICODE_NORM_QC_NO},
+	{0xD1F7, UNICODE_NORM_QC_NO},
+	{0xD1F8, UNICODE_NORM_QC_NO},
+	{0xD1F9, UNICODE_NORM_QC_NO},
+	{0xD1FA, UNICODE_NORM_QC_NO},
+	{0xD1FB, UNICODE_NORM_QC_NO},
+	{0xD1FC, UNICODE_NORM_QC_NO},
+	{0xD1FD, UNICODE_NORM_QC_NO},
+	{0xD1FE, UNICODE_NORM_QC_NO},
+	{0xD1FF, UNICODE_NORM_QC_NO},
+	{0xD200, UNICODE_NORM_QC_NO},
+	{0xD201, UNICODE_NORM_QC_NO},
+	{0xD202, UNICODE_NORM_QC_NO},
+	{0xD203, UNICODE_NORM_QC_NO},
+	{0xD204, UNICODE_NORM_QC_NO},
+	{0xD205, UNICODE_NORM_QC_NO},
+	{0xD206, UNICODE_NORM_QC_NO},
+	{0xD207, UNICODE_NORM_QC_NO},
+	{0xD208, UNICODE_NORM_QC_NO},
+	{0xD209, UNICODE_NORM_QC_NO},
+	{0xD20A, UNICODE_NORM_QC_NO},
+	{0xD20B, UNICODE_NORM_QC_NO},
+	{0xD20C, UNICODE_NORM_QC_NO},
+	{0xD20D, UNICODE_NORM_QC_NO},
+	{0xD20E, UNICODE_NORM_QC_NO},
+	{0xD20F, UNICODE_NORM_QC_NO},
+	{0xD210, UNICODE_NORM_QC_NO},
+	{0xD211, UNICODE_NORM_QC_NO},
+	{0xD212, UNICODE_NORM_QC_NO},
+	{0xD213, UNICODE_NORM_QC_NO},
+	{0xD214, UNICODE_NORM_QC_NO},
+	{0xD215, UNICODE_NORM_QC_NO},
+	{0xD216, UNICODE_NORM_QC_NO},
+	{0xD217, UNICODE_NORM_QC_NO},
+	{0xD218, UNICODE_NORM_QC_NO},
+	{0xD219, UNICODE_NORM_QC_NO},
+	{0xD21A, UNICODE_NORM_QC_NO},
+	{0xD21B, UNICODE_NORM_QC_NO},
+	{0xD21C, UNICODE_NORM_QC_NO},
+	{0xD21D, UNICODE_NORM_QC_NO},
+	{0xD21E, UNICODE_NORM_QC_NO},
+	{0xD21F, UNICODE_NORM_QC_NO},
+	{0xD220, UNICODE_NORM_QC_NO},
+	{0xD221, UNICODE_NORM_QC_NO},
+	{0xD222, UNICODE_NORM_QC_NO},
+	{0xD223, UNICODE_NORM_QC_NO},
+	{0xD224, UNICODE_NORM_QC_NO},
+	{0xD225, UNICODE_NORM_QC_NO},
+	{0xD226, UNICODE_NORM_QC_NO},
+	{0xD227, UNICODE_NORM_QC_NO},
+	{0xD228, UNICODE_NORM_QC_NO},
+	{0xD229, UNICODE_NORM_QC_NO},
+	{0xD22A, UNICODE_NORM_QC_NO},
+	{0xD22B, UNICODE_NORM_QC_NO},
+	{0xD22C, UNICODE_NORM_QC_NO},
+	{0xD22D, UNICODE_NORM_QC_NO},
+	{0xD22E, UNICODE_NORM_QC_NO},
+	{0xD22F, UNICODE_NORM_QC_NO},
+	{0xD230, UNICODE_NORM_QC_NO},
+	{0xD231, UNICODE_NORM_QC_NO},
+	{0xD232, UNICODE_NORM_QC_NO},
+	{0xD233, UNICODE_NORM_QC_NO},
+	{0xD234, UNICODE_NORM_QC_NO},
+	{0xD235, UNICODE_NORM_QC_NO},
+	{0xD236, UNICODE_NORM_QC_NO},
+	{0xD237, UNICODE_NORM_QC_NO},
+	{0xD238, UNICODE_NORM_QC_NO},
+	{0xD239, UNICODE_NORM_QC_NO},
+	{0xD23A, UNICODE_NORM_QC_NO},
+	{0xD23B, UNICODE_NORM_QC_NO},
+	{0xD23C, UNICODE_NORM_QC_NO},
+	{0xD23D, UNICODE_NORM_QC_NO},
+	{0xD23E, UNICODE_NORM_QC_NO},
+	{0xD23F, UNICODE_NORM_QC_NO},
+	{0xD240, UNICODE_NORM_QC_NO},
+	{0xD241, UNICODE_NORM_QC_NO},
+	{0xD242, UNICODE_NORM_QC_NO},
+	{0xD243, UNICODE_NORM_QC_NO},
+	{0xD244, UNICODE_NORM_QC_NO},
+	{0xD245, UNICODE_NORM_QC_NO},
+	{0xD246, UNICODE_NORM_QC_NO},
+	{0xD247, UNICODE_NORM_QC_NO},
+	{0xD248, UNICODE_NORM_QC_NO},
+	{0xD249, UNICODE_NORM_QC_NO},
+	{0xD24A, UNICODE_NORM_QC_NO},
+	{0xD24B, UNICODE_NORM_QC_NO},
+	{0xD24C, UNICODE_NORM_QC_NO},
+	{0xD24D, UNICODE_NORM_QC_NO},
+	{0xD24E, UNICODE_NORM_QC_NO},
+	{0xD24F, UNICODE_NORM_QC_NO},
+	{0xD250, UNICODE_NORM_QC_NO},
+	{0xD251, UNICODE_NORM_QC_NO},
+	{0xD252, UNICODE_NORM_QC_NO},
+	{0xD253, UNICODE_NORM_QC_NO},
+	{0xD254, UNICODE_NORM_QC_NO},
+	{0xD255, UNICODE_NORM_QC_NO},
+	{0xD256, UNICODE_NORM_QC_NO},
+	{0xD257, UNICODE_NORM_QC_NO},
+	{0xD258, UNICODE_NORM_QC_NO},
+	{0xD259, UNICODE_NORM_QC_NO},
+	{0xD25A, UNICODE_NORM_QC_NO},
+	{0xD25B, UNICODE_NORM_QC_NO},
+	{0xD25C, UNICODE_NORM_QC_NO},
+	{0xD25D, UNICODE_NORM_QC_NO},
+	{0xD25E, UNICODE_NORM_QC_NO},
+	{0xD25F, UNICODE_NORM_QC_NO},
+	{0xD260, UNICODE_NORM_QC_NO},
+	{0xD261, UNICODE_NORM_QC_NO},
+	{0xD262, UNICODE_NORM_QC_NO},
+	{0xD263, UNICODE_NORM_QC_NO},
+	{0xD264, UNICODE_NORM_QC_NO},
+	{0xD265, UNICODE_NORM_QC_NO},
+	{0xD266, UNICODE_NORM_QC_NO},
+	{0xD267, UNICODE_NORM_QC_NO},
+	{0xD268, UNICODE_NORM_QC_NO},
+	{0xD269, UNICODE_NORM_QC_NO},
+	{0xD26A, UNICODE_NORM_QC_NO},
+	{0xD26B, UNICODE_NORM_QC_NO},
+	{0xD26C, UNICODE_NORM_QC_NO},
+	{0xD26D, UNICODE_NORM_QC_NO},
+	{0xD26E, UNICODE_NORM_QC_NO},
+	{0xD26F, UNICODE_NORM_QC_NO},
+	{0xD270, UNICODE_NORM_QC_NO},
+	{0xD271, UNICODE_NORM_QC_NO},
+	{0xD272, UNICODE_NORM_QC_NO},
+	{0xD273, UNICODE_NORM_QC_NO},
+	{0xD274, UNICODE_NORM_QC_NO},
+	{0xD275, UNICODE_NORM_QC_NO},
+	{0xD276, UNICODE_NORM_QC_NO},
+	{0xD277, UNICODE_NORM_QC_NO},
+	{0xD278, UNICODE_NORM_QC_NO},
+	{0xD279, UNICODE_NORM_QC_NO},
+	{0xD27A, UNICODE_NORM_QC_NO},
+	{0xD27B, UNICODE_NORM_QC_NO},
+	{0xD27C, UNICODE_NORM_QC_NO},
+	{0xD27D, UNICODE_NORM_QC_NO},
+	{0xD27E, UNICODE_NORM_QC_NO},
+	{0xD27F, UNICODE_NORM_QC_NO},
+	{0xD280, UNICODE_NORM_QC_NO},
+	{0xD281, UNICODE_NORM_QC_NO},
+	{0xD282, UNICODE_NORM_QC_NO},
+	{0xD283, UNICODE_NORM_QC_NO},
+	{0xD284, UNICODE_NORM_QC_NO},
+	{0xD285, UNICODE_NORM_QC_NO},
+	{0xD286, UNICODE_NORM_QC_NO},
+	{0xD287, UNICODE_NORM_QC_NO},
+	{0xD288, UNICODE_NORM_QC_NO},
+	{0xD289, UNICODE_NORM_QC_NO},
+	{0xD28A, UNICODE_NORM_QC_NO},
+	{0xD28B, UNICODE_NORM_QC_NO},
+	{0xD28C, UNICODE_NORM_QC_NO},
+	{0xD28D, UNICODE_NORM_QC_NO},
+	{0xD28E, UNICODE_NORM_QC_NO},
+	{0xD28F, UNICODE_NORM_QC_NO},
+	{0xD290, UNICODE_NORM_QC_NO},
+	{0xD291, UNICODE_NORM_QC_NO},
+	{0xD292, UNICODE_NORM_QC_NO},
+	{0xD293, UNICODE_NORM_QC_NO},
+	{0xD294, UNICODE_NORM_QC_NO},
+	{0xD295, UNICODE_NORM_QC_NO},
+	{0xD296, UNICODE_NORM_QC_NO},
+	{0xD297, UNICODE_NORM_QC_NO},
+	{0xD298, UNICODE_NORM_QC_NO},
+	{0xD299, UNICODE_NORM_QC_NO},
+	{0xD29A, UNICODE_NORM_QC_NO},
+	{0xD29B, UNICODE_NORM_QC_NO},
+	{0xD29C, UNICODE_NORM_QC_NO},
+	{0xD29D, UNICODE_NORM_QC_NO},
+	{0xD29E, UNICODE_NORM_QC_NO},
+	{0xD29F, UNICODE_NORM_QC_NO},
+	{0xD2A0, UNICODE_NORM_QC_NO},
+	{0xD2A1, UNICODE_NORM_QC_NO},
+	{0xD2A2, UNICODE_NORM_QC_NO},
+	{0xD2A3, UNICODE_NORM_QC_NO},
+	{0xD2A4, UNICODE_NORM_QC_NO},
+	{0xD2A5, UNICODE_NORM_QC_NO},
+	{0xD2A6, UNICODE_NORM_QC_NO},
+	{0xD2A7, UNICODE_NORM_QC_NO},
+	{0xD2A8, UNICODE_NORM_QC_NO},
+	{0xD2A9, UNICODE_NORM_QC_NO},
+	{0xD2AA, UNICODE_NORM_QC_NO},
+	{0xD2AB, UNICODE_NORM_QC_NO},
+	{0xD2AC, UNICODE_NORM_QC_NO},
+	{0xD2AD, UNICODE_NORM_QC_NO},
+	{0xD2AE, UNICODE_NORM_QC_NO},
+	{0xD2AF, UNICODE_NORM_QC_NO},
+	{0xD2B0, UNICODE_NORM_QC_NO},
+	{0xD2B1, UNICODE_NORM_QC_NO},
+	{0xD2B2, UNICODE_NORM_QC_NO},
+	{0xD2B3, UNICODE_NORM_QC_NO},
+	{0xD2B4, UNICODE_NORM_QC_NO},
+	{0xD2B5, UNICODE_NORM_QC_NO},
+	{0xD2B6, UNICODE_NORM_QC_NO},
+	{0xD2B7, UNICODE_NORM_QC_NO},
+	{0xD2B8, UNICODE_NORM_QC_NO},
+	{0xD2B9, UNICODE_NORM_QC_NO},
+	{0xD2BA, UNICODE_NORM_QC_NO},
+	{0xD2BB, UNICODE_NORM_QC_NO},
+	{0xD2BC, UNICODE_NORM_QC_NO},
+	{0xD2BD, UNICODE_NORM_QC_NO},
+	{0xD2BE, UNICODE_NORM_QC_NO},
+	{0xD2BF, UNICODE_NORM_QC_NO},
+	{0xD2C0, UNICODE_NORM_QC_NO},
+	{0xD2C1, UNICODE_NORM_QC_NO},
+	{0xD2C2, UNICODE_NORM_QC_NO},
+	{0xD2C3, UNICODE_NORM_QC_NO},
+	{0xD2C4, UNICODE_NORM_QC_NO},
+	{0xD2C5, UNICODE_NORM_QC_NO},
+	{0xD2C6, UNICODE_NORM_QC_NO},
+	{0xD2C7, UNICODE_NORM_QC_NO},
+	{0xD2C8, UNICODE_NORM_QC_NO},
+	{0xD2C9, UNICODE_NORM_QC_NO},
+	{0xD2CA, UNICODE_NORM_QC_NO},
+	{0xD2CB, UNICODE_NORM_QC_NO},
+	{0xD2CC, UNICODE_NORM_QC_NO},
+	{0xD2CD, UNICODE_NORM_QC_NO},
+	{0xD2CE, UNICODE_NORM_QC_NO},
+	{0xD2CF, UNICODE_NORM_QC_NO},
+	{0xD2D0, UNICODE_NORM_QC_NO},
+	{0xD2D1, UNICODE_NORM_QC_NO},
+	{0xD2D2, UNICODE_NORM_QC_NO},
+	{0xD2D3, UNICODE_NORM_QC_NO},
+	{0xD2D4, UNICODE_NORM_QC_NO},
+	{0xD2D5, UNICODE_NORM_QC_NO},
+	{0xD2D6, UNICODE_NORM_QC_NO},
+	{0xD2D7, UNICODE_NORM_QC_NO},
+	{0xD2D8, UNICODE_NORM_QC_NO},
+	{0xD2D9, UNICODE_NORM_QC_NO},
+	{0xD2DA, UNICODE_NORM_QC_NO},
+	{0xD2DB, UNICODE_NORM_QC_NO},
+	{0xD2DC, UNICODE_NORM_QC_NO},
+	{0xD2DD, UNICODE_NORM_QC_NO},
+	{0xD2DE, UNICODE_NORM_QC_NO},
+	{0xD2DF, UNICODE_NORM_QC_NO},
+	{0xD2E0, UNICODE_NORM_QC_NO},
+	{0xD2E1, UNICODE_NORM_QC_NO},
+	{0xD2E2, UNICODE_NORM_QC_NO},
+	{0xD2E3, UNICODE_NORM_QC_NO},
+	{0xD2E4, UNICODE_NORM_QC_NO},
+	{0xD2E5, UNICODE_NORM_QC_NO},
+	{0xD2E6, UNICODE_NORM_QC_NO},
+	{0xD2E7, UNICODE_NORM_QC_NO},
+	{0xD2E8, UNICODE_NORM_QC_NO},
+	{0xD2E9, UNICODE_NORM_QC_NO},
+	{0xD2EA, UNICODE_NORM_QC_NO},
+	{0xD2EB, UNICODE_NORM_QC_NO},
+	{0xD2EC, UNICODE_NORM_QC_NO},
+	{0xD2ED, UNICODE_NORM_QC_NO},
+	{0xD2EE, UNICODE_NORM_QC_NO},
+	{0xD2EF, UNICODE_NORM_QC_NO},
+	{0xD2F0, UNICODE_NORM_QC_NO},
+	{0xD2F1, UNICODE_NORM_QC_NO},
+	{0xD2F2, UNICODE_NORM_QC_NO},
+	{0xD2F3, UNICODE_NORM_QC_NO},
+	{0xD2F4, UNICODE_NORM_QC_NO},
+	{0xD2F5, UNICODE_NORM_QC_NO},
+	{0xD2F6, UNICODE_NORM_QC_NO},
+	{0xD2F7, UNICODE_NORM_QC_NO},
+	{0xD2F8, UNICODE_NORM_QC_NO},
+	{0xD2F9, UNICODE_NORM_QC_NO},
+	{0xD2FA, UNICODE_NORM_QC_NO},
+	{0xD2FB, UNICODE_NORM_QC_NO},
+	{0xD2FC, UNICODE_NORM_QC_NO},
+	{0xD2FD, UNICODE_NORM_QC_NO},
+	{0xD2FE, UNICODE_NORM_QC_NO},
+	{0xD2FF, UNICODE_NORM_QC_NO},
+	{0xD300, UNICODE_NORM_QC_NO},
+	{0xD301, UNICODE_NORM_QC_NO},
+	{0xD302, UNICODE_NORM_QC_NO},
+	{0xD303, UNICODE_NORM_QC_NO},
+	{0xD304, UNICODE_NORM_QC_NO},
+	{0xD305, UNICODE_NORM_QC_NO},
+	{0xD306, UNICODE_NORM_QC_NO},
+	{0xD307, UNICODE_NORM_QC_NO},
+	{0xD308, UNICODE_NORM_QC_NO},
+	{0xD309, UNICODE_NORM_QC_NO},
+	{0xD30A, UNICODE_NORM_QC_NO},
+	{0xD30B, UNICODE_NORM_QC_NO},
+	{0xD30C, UNICODE_NORM_QC_NO},
+	{0xD30D, UNICODE_NORM_QC_NO},
+	{0xD30E, UNICODE_NORM_QC_NO},
+	{0xD30F, UNICODE_NORM_QC_NO},
+	{0xD310, UNICODE_NORM_QC_NO},
+	{0xD311, UNICODE_NORM_QC_NO},
+	{0xD312, UNICODE_NORM_QC_NO},
+	{0xD313, UNICODE_NORM_QC_NO},
+	{0xD314, UNICODE_NORM_QC_NO},
+	{0xD315, UNICODE_NORM_QC_NO},
+	{0xD316, UNICODE_NORM_QC_NO},
+	{0xD317, UNICODE_NORM_QC_NO},
+	{0xD318, UNICODE_NORM_QC_NO},
+	{0xD319, UNICODE_NORM_QC_NO},
+	{0xD31A, UNICODE_NORM_QC_NO},
+	{0xD31B, UNICODE_NORM_QC_NO},
+	{0xD31C, UNICODE_NORM_QC_NO},
+	{0xD31D, UNICODE_NORM_QC_NO},
+	{0xD31E, UNICODE_NORM_QC_NO},
+	{0xD31F, UNICODE_NORM_QC_NO},
+	{0xD320, UNICODE_NORM_QC_NO},
+	{0xD321, UNICODE_NORM_QC_NO},
+	{0xD322, UNICODE_NORM_QC_NO},
+	{0xD323, UNICODE_NORM_QC_NO},
+	{0xD324, UNICODE_NORM_QC_NO},
+	{0xD325, UNICODE_NORM_QC_NO},
+	{0xD326, UNICODE_NORM_QC_NO},
+	{0xD327, UNICODE_NORM_QC_NO},
+	{0xD328, UNICODE_NORM_QC_NO},
+	{0xD329, UNICODE_NORM_QC_NO},
+	{0xD32A, UNICODE_NORM_QC_NO},
+	{0xD32B, UNICODE_NORM_QC_NO},
+	{0xD32C, UNICODE_NORM_QC_NO},
+	{0xD32D, UNICODE_NORM_QC_NO},
+	{0xD32E, UNICODE_NORM_QC_NO},
+	{0xD32F, UNICODE_NORM_QC_NO},
+	{0xD330, UNICODE_NORM_QC_NO},
+	{0xD331, UNICODE_NORM_QC_NO},
+	{0xD332, UNICODE_NORM_QC_NO},
+	{0xD333, UNICODE_NORM_QC_NO},
+	{0xD334, UNICODE_NORM_QC_NO},
+	{0xD335, UNICODE_NORM_QC_NO},
+	{0xD336, UNICODE_NORM_QC_NO},
+	{0xD337, UNICODE_NORM_QC_NO},
+	{0xD338, UNICODE_NORM_QC_NO},
+	{0xD339, UNICODE_NORM_QC_NO},
+	{0xD33A, UNICODE_NORM_QC_NO},
+	{0xD33B, UNICODE_NORM_QC_NO},
+	{0xD33C, UNICODE_NORM_QC_NO},
+	{0xD33D, UNICODE_NORM_QC_NO},
+	{0xD33E, UNICODE_NORM_QC_NO},
+	{0xD33F, UNICODE_NORM_QC_NO},
+	{0xD340, UNICODE_NORM_QC_NO},
+	{0xD341, UNICODE_NORM_QC_NO},
+	{0xD342, UNICODE_NORM_QC_NO},
+	{0xD343, UNICODE_NORM_QC_NO},
+	{0xD344, UNICODE_NORM_QC_NO},
+	{0xD345, UNICODE_NORM_QC_NO},
+	{0xD346, UNICODE_NORM_QC_NO},
+	{0xD347, UNICODE_NORM_QC_NO},
+	{0xD348, UNICODE_NORM_QC_NO},
+	{0xD349, UNICODE_NORM_QC_NO},
+	{0xD34A, UNICODE_NORM_QC_NO},
+	{0xD34B, UNICODE_NORM_QC_NO},
+	{0xD34C, UNICODE_NORM_QC_NO},
+	{0xD34D, UNICODE_NORM_QC_NO},
+	{0xD34E, UNICODE_NORM_QC_NO},
+	{0xD34F, UNICODE_NORM_QC_NO},
+	{0xD350, UNICODE_NORM_QC_NO},
+	{0xD351, UNICODE_NORM_QC_NO},
+	{0xD352, UNICODE_NORM_QC_NO},
+	{0xD353, UNICODE_NORM_QC_NO},
+	{0xD354, UNICODE_NORM_QC_NO},
+	{0xD355, UNICODE_NORM_QC_NO},
+	{0xD356, UNICODE_NORM_QC_NO},
+	{0xD357, UNICODE_NORM_QC_NO},
+	{0xD358, UNICODE_NORM_QC_NO},
+	{0xD359, UNICODE_NORM_QC_NO},
+	{0xD35A, UNICODE_NORM_QC_NO},
+	{0xD35B, UNICODE_NORM_QC_NO},
+	{0xD35C, UNICODE_NORM_QC_NO},
+	{0xD35D, UNICODE_NORM_QC_NO},
+	{0xD35E, UNICODE_NORM_QC_NO},
+	{0xD35F, UNICODE_NORM_QC_NO},
+	{0xD360, UNICODE_NORM_QC_NO},
+	{0xD361, UNICODE_NORM_QC_NO},
+	{0xD362, UNICODE_NORM_QC_NO},
+	{0xD363, UNICODE_NORM_QC_NO},
+	{0xD364, UNICODE_NORM_QC_NO},
+	{0xD365, UNICODE_NORM_QC_NO},
+	{0xD366, UNICODE_NORM_QC_NO},
+	{0xD367, UNICODE_NORM_QC_NO},
+	{0xD368, UNICODE_NORM_QC_NO},
+	{0xD369, UNICODE_NORM_QC_NO},
+	{0xD36A, UNICODE_NORM_QC_NO},
+	{0xD36B, UNICODE_NORM_QC_NO},
+	{0xD36C, UNICODE_NORM_QC_NO},
+	{0xD36D, UNICODE_NORM_QC_NO},
+	{0xD36E, UNICODE_NORM_QC_NO},
+	{0xD36F, UNICODE_NORM_QC_NO},
+	{0xD370, UNICODE_NORM_QC_NO},
+	{0xD371, UNICODE_NORM_QC_NO},
+	{0xD372, UNICODE_NORM_QC_NO},
+	{0xD373, UNICODE_NORM_QC_NO},
+	{0xD374, UNICODE_NORM_QC_NO},
+	{0xD375, UNICODE_NORM_QC_NO},
+	{0xD376, UNICODE_NORM_QC_NO},
+	{0xD377, UNICODE_NORM_QC_NO},
+	{0xD378, UNICODE_NORM_QC_NO},
+	{0xD379, UNICODE_NORM_QC_NO},
+	{0xD37A, UNICODE_NORM_QC_NO},
+	{0xD37B, UNICODE_NORM_QC_NO},
+	{0xD37C, UNICODE_NORM_QC_NO},
+	{0xD37D, UNICODE_NORM_QC_NO},
+	{0xD37E, UNICODE_NORM_QC_NO},
+	{0xD37F, UNICODE_NORM_QC_NO},
+	{0xD380, UNICODE_NORM_QC_NO},
+	{0xD381, UNICODE_NORM_QC_NO},
+	{0xD382, UNICODE_NORM_QC_NO},
+	{0xD383, UNICODE_NORM_QC_NO},
+	{0xD384, UNICODE_NORM_QC_NO},
+	{0xD385, UNICODE_NORM_QC_NO},
+	{0xD386, UNICODE_NORM_QC_NO},
+	{0xD387, UNICODE_NORM_QC_NO},
+	{0xD388, UNICODE_NORM_QC_NO},
+	{0xD389, UNICODE_NORM_QC_NO},
+	{0xD38A, UNICODE_NORM_QC_NO},
+	{0xD38B, UNICODE_NORM_QC_NO},
+	{0xD38C, UNICODE_NORM_QC_NO},
+	{0xD38D, UNICODE_NORM_QC_NO},
+	{0xD38E, UNICODE_NORM_QC_NO},
+	{0xD38F, UNICODE_NORM_QC_NO},
+	{0xD390, UNICODE_NORM_QC_NO},
+	{0xD391, UNICODE_NORM_QC_NO},
+	{0xD392, UNICODE_NORM_QC_NO},
+	{0xD393, UNICODE_NORM_QC_NO},
+	{0xD394, UNICODE_NORM_QC_NO},
+	{0xD395, UNICODE_NORM_QC_NO},
+	{0xD396, UNICODE_NORM_QC_NO},
+	{0xD397, UNICODE_NORM_QC_NO},
+	{0xD398, UNICODE_NORM_QC_NO},
+	{0xD399, UNICODE_NORM_QC_NO},
+	{0xD39A, UNICODE_NORM_QC_NO},
+	{0xD39B, UNICODE_NORM_QC_NO},
+	{0xD39C, UNICODE_NORM_QC_NO},
+	{0xD39D, UNICODE_NORM_QC_NO},
+	{0xD39E, UNICODE_NORM_QC_NO},
+	{0xD39F, UNICODE_NORM_QC_NO},
+	{0xD3A0, UNICODE_NORM_QC_NO},
+	{0xD3A1, UNICODE_NORM_QC_NO},
+	{0xD3A2, UNICODE_NORM_QC_NO},
+	{0xD3A3, UNICODE_NORM_QC_NO},
+	{0xD3A4, UNICODE_NORM_QC_NO},
+	{0xD3A5, UNICODE_NORM_QC_NO},
+	{0xD3A6, UNICODE_NORM_QC_NO},
+	{0xD3A7, UNICODE_NORM_QC_NO},
+	{0xD3A8, UNICODE_NORM_QC_NO},
+	{0xD3A9, UNICODE_NORM_QC_NO},
+	{0xD3AA, UNICODE_NORM_QC_NO},
+	{0xD3AB, UNICODE_NORM_QC_NO},
+	{0xD3AC, UNICODE_NORM_QC_NO},
+	{0xD3AD, UNICODE_NORM_QC_NO},
+	{0xD3AE, UNICODE_NORM_QC_NO},
+	{0xD3AF, UNICODE_NORM_QC_NO},
+	{0xD3B0, UNICODE_NORM_QC_NO},
+	{0xD3B1, UNICODE_NORM_QC_NO},
+	{0xD3B2, UNICODE_NORM_QC_NO},
+	{0xD3B3, UNICODE_NORM_QC_NO},
+	{0xD3B4, UNICODE_NORM_QC_NO},
+	{0xD3B5, UNICODE_NORM_QC_NO},
+	{0xD3B6, UNICODE_NORM_QC_NO},
+	{0xD3B7, UNICODE_NORM_QC_NO},
+	{0xD3B8, UNICODE_NORM_QC_NO},
+	{0xD3B9, UNICODE_NORM_QC_NO},
+	{0xD3BA, UNICODE_NORM_QC_NO},
+	{0xD3BB, UNICODE_NORM_QC_NO},
+	{0xD3BC, UNICODE_NORM_QC_NO},
+	{0xD3BD, UNICODE_NORM_QC_NO},
+	{0xD3BE, UNICODE_NORM_QC_NO},
+	{0xD3BF, UNICODE_NORM_QC_NO},
+	{0xD3C0, UNICODE_NORM_QC_NO},
+	{0xD3C1, UNICODE_NORM_QC_NO},
+	{0xD3C2, UNICODE_NORM_QC_NO},
+	{0xD3C3, UNICODE_NORM_QC_NO},
+	{0xD3C4, UNICODE_NORM_QC_NO},
+	{0xD3C5, UNICODE_NORM_QC_NO},
+	{0xD3C6, UNICODE_NORM_QC_NO},
+	{0xD3C7, UNICODE_NORM_QC_NO},
+	{0xD3C8, UNICODE_NORM_QC_NO},
+	{0xD3C9, UNICODE_NORM_QC_NO},
+	{0xD3CA, UNICODE_NORM_QC_NO},
+	{0xD3CB, UNICODE_NORM_QC_NO},
+	{0xD3CC, UNICODE_NORM_QC_NO},
+	{0xD3CD, UNICODE_NORM_QC_NO},
+	{0xD3CE, UNICODE_NORM_QC_NO},
+	{0xD3CF, UNICODE_NORM_QC_NO},
+	{0xD3D0, UNICODE_NORM_QC_NO},
+	{0xD3D1, UNICODE_NORM_QC_NO},
+	{0xD3D2, UNICODE_NORM_QC_NO},
+	{0xD3D3, UNICODE_NORM_QC_NO},
+	{0xD3D4, UNICODE_NORM_QC_NO},
+	{0xD3D5, UNICODE_NORM_QC_NO},
+	{0xD3D6, UNICODE_NORM_QC_NO},
+	{0xD3D7, UNICODE_NORM_QC_NO},
+	{0xD3D8, UNICODE_NORM_QC_NO},
+	{0xD3D9, UNICODE_NORM_QC_NO},
+	{0xD3DA, UNICODE_NORM_QC_NO},
+	{0xD3DB, UNICODE_NORM_QC_NO},
+	{0xD3DC, UNICODE_NORM_QC_NO},
+	{0xD3DD, UNICODE_NORM_QC_NO},
+	{0xD3DE, UNICODE_NORM_QC_NO},
+	{0xD3DF, UNICODE_NORM_QC_NO},
+	{0xD3E0, UNICODE_NORM_QC_NO},
+	{0xD3E1, UNICODE_NORM_QC_NO},
+	{0xD3E2, UNICODE_NORM_QC_NO},
+	{0xD3E3, UNICODE_NORM_QC_NO},
+	{0xD3E4, UNICODE_NORM_QC_NO},
+	{0xD3E5, UNICODE_NORM_QC_NO},
+	{0xD3E6, UNICODE_NORM_QC_NO},
+	{0xD3E7, UNICODE_NORM_QC_NO},
+	{0xD3E8, UNICODE_NORM_QC_NO},
+	{0xD3E9, UNICODE_NORM_QC_NO},
+	{0xD3EA, UNICODE_NORM_QC_NO},
+	{0xD3EB, UNICODE_NORM_QC_NO},
+	{0xD3EC, UNICODE_NORM_QC_NO},
+	{0xD3ED, UNICODE_NORM_QC_NO},
+	{0xD3EE, UNICODE_NORM_QC_NO},
+	{0xD3EF, UNICODE_NORM_QC_NO},
+	{0xD3F0, UNICODE_NORM_QC_NO},
+	{0xD3F1, UNICODE_NORM_QC_NO},
+	{0xD3F2, UNICODE_NORM_QC_NO},
+	{0xD3F3, UNICODE_NORM_QC_NO},
+	{0xD3F4, UNICODE_NORM_QC_NO},
+	{0xD3F5, UNICODE_NORM_QC_NO},
+	{0xD3F6, UNICODE_NORM_QC_NO},
+	{0xD3F7, UNICODE_NORM_QC_NO},
+	{0xD3F8, UNICODE_NORM_QC_NO},
+	{0xD3F9, UNICODE_NORM_QC_NO},
+	{0xD3FA, UNICODE_NORM_QC_NO},
+	{0xD3FB, UNICODE_NORM_QC_NO},
+	{0xD3FC, UNICODE_NORM_QC_NO},
+	{0xD3FD, UNICODE_NORM_QC_NO},
+	{0xD3FE, UNICODE_NORM_QC_NO},
+	{0xD3FF, UNICODE_NORM_QC_NO},
+	{0xD400, UNICODE_NORM_QC_NO},
+	{0xD401, UNICODE_NORM_QC_NO},
+	{0xD402, UNICODE_NORM_QC_NO},
+	{0xD403, UNICODE_NORM_QC_NO},
+	{0xD404, UNICODE_NORM_QC_NO},
+	{0xD405, UNICODE_NORM_QC_NO},
+	{0xD406, UNICODE_NORM_QC_NO},
+	{0xD407, UNICODE_NORM_QC_NO},
+	{0xD408, UNICODE_NORM_QC_NO},
+	{0xD409, UNICODE_NORM_QC_NO},
+	{0xD40A, UNICODE_NORM_QC_NO},
+	{0xD40B, UNICODE_NORM_QC_NO},
+	{0xD40C, UNICODE_NORM_QC_NO},
+	{0xD40D, UNICODE_NORM_QC_NO},
+	{0xD40E, UNICODE_NORM_QC_NO},
+	{0xD40F, UNICODE_NORM_QC_NO},
+	{0xD410, UNICODE_NORM_QC_NO},
+	{0xD411, UNICODE_NORM_QC_NO},
+	{0xD412, UNICODE_NORM_QC_NO},
+	{0xD413, UNICODE_NORM_QC_NO},
+	{0xD414, UNICODE_NORM_QC_NO},
+	{0xD415, UNICODE_NORM_QC_NO},
+	{0xD416, UNICODE_NORM_QC_NO},
+	{0xD417, UNICODE_NORM_QC_NO},
+	{0xD418, UNICODE_NORM_QC_NO},
+	{0xD419, UNICODE_NORM_QC_NO},
+	{0xD41A, UNICODE_NORM_QC_NO},
+	{0xD41B, UNICODE_NORM_QC_NO},
+	{0xD41C, UNICODE_NORM_QC_NO},
+	{0xD41D, UNICODE_NORM_QC_NO},
+	{0xD41E, UNICODE_NORM_QC_NO},
+	{0xD41F, UNICODE_NORM_QC_NO},
+	{0xD420, UNICODE_NORM_QC_NO},
+	{0xD421, UNICODE_NORM_QC_NO},
+	{0xD422, UNICODE_NORM_QC_NO},
+	{0xD423, UNICODE_NORM_QC_NO},
+	{0xD424, UNICODE_NORM_QC_NO},
+	{0xD425, UNICODE_NORM_QC_NO},
+	{0xD426, UNICODE_NORM_QC_NO},
+	{0xD427, UNICODE_NORM_QC_NO},
+	{0xD428, UNICODE_NORM_QC_NO},
+	{0xD429, UNICODE_NORM_QC_NO},
+	{0xD42A, UNICODE_NORM_QC_NO},
+	{0xD42B, UNICODE_NORM_QC_NO},
+	{0xD42C, UNICODE_NORM_QC_NO},
+	{0xD42D, UNICODE_NORM_QC_NO},
+	{0xD42E, UNICODE_NORM_QC_NO},
+	{0xD42F, UNICODE_NORM_QC_NO},
+	{0xD430, UNICODE_NORM_QC_NO},
+	{0xD431, UNICODE_NORM_QC_NO},
+	{0xD432, UNICODE_NORM_QC_NO},
+	{0xD433, UNICODE_NORM_QC_NO},
+	{0xD434, UNICODE_NORM_QC_NO},
+	{0xD435, UNICODE_NORM_QC_NO},
+	{0xD436, UNICODE_NORM_QC_NO},
+	{0xD437, UNICODE_NORM_QC_NO},
+	{0xD438, UNICODE_NORM_QC_NO},
+	{0xD439, UNICODE_NORM_QC_NO},
+	{0xD43A, UNICODE_NORM_QC_NO},
+	{0xD43B, UNICODE_NORM_QC_NO},
+	{0xD43C, UNICODE_NORM_QC_NO},
+	{0xD43D, UNICODE_NORM_QC_NO},
+	{0xD43E, UNICODE_NORM_QC_NO},
+	{0xD43F, UNICODE_NORM_QC_NO},
+	{0xD440, UNICODE_NORM_QC_NO},
+	{0xD441, UNICODE_NORM_QC_NO},
+	{0xD442, UNICODE_NORM_QC_NO},
+	{0xD443, UNICODE_NORM_QC_NO},
+	{0xD444, UNICODE_NORM_QC_NO},
+	{0xD445, UNICODE_NORM_QC_NO},
+	{0xD446, UNICODE_NORM_QC_NO},
+	{0xD447, UNICODE_NORM_QC_NO},
+	{0xD448, UNICODE_NORM_QC_NO},
+	{0xD449, UNICODE_NORM_QC_NO},
+	{0xD44A, UNICODE_NORM_QC_NO},
+	{0xD44B, UNICODE_NORM_QC_NO},
+	{0xD44C, UNICODE_NORM_QC_NO},
+	{0xD44D, UNICODE_NORM_QC_NO},
+	{0xD44E, UNICODE_NORM_QC_NO},
+	{0xD44F, UNICODE_NORM_QC_NO},
+	{0xD450, UNICODE_NORM_QC_NO},
+	{0xD451, UNICODE_NORM_QC_NO},
+	{0xD452, UNICODE_NORM_QC_NO},
+	{0xD453, UNICODE_NORM_QC_NO},
+	{0xD454, UNICODE_NORM_QC_NO},
+	{0xD455, UNICODE_NORM_QC_NO},
+	{0xD456, UNICODE_NORM_QC_NO},
+	{0xD457, UNICODE_NORM_QC_NO},
+	{0xD458, UNICODE_NORM_QC_NO},
+	{0xD459, UNICODE_NORM_QC_NO},
+	{0xD45A, UNICODE_NORM_QC_NO},
+	{0xD45B, UNICODE_NORM_QC_NO},
+	{0xD45C, UNICODE_NORM_QC_NO},
+	{0xD45D, UNICODE_NORM_QC_NO},
+	{0xD45E, UNICODE_NORM_QC_NO},
+	{0xD45F, UNICODE_NORM_QC_NO},
+	{0xD460, UNICODE_NORM_QC_NO},
+	{0xD461, UNICODE_NORM_QC_NO},
+	{0xD462, UNICODE_NORM_QC_NO},
+	{0xD463, UNICODE_NORM_QC_NO},
+	{0xD464, UNICODE_NORM_QC_NO},
+	{0xD465, UNICODE_NORM_QC_NO},
+	{0xD466, UNICODE_NORM_QC_NO},
+	{0xD467, UNICODE_NORM_QC_NO},
+	{0xD468, UNICODE_NORM_QC_NO},
+	{0xD469, UNICODE_NORM_QC_NO},
+	{0xD46A, UNICODE_NORM_QC_NO},
+	{0xD46B, UNICODE_NORM_QC_NO},
+	{0xD46C, UNICODE_NORM_QC_NO},
+	{0xD46D, UNICODE_NORM_QC_NO},
+	{0xD46E, UNICODE_NORM_QC_NO},
+	{0xD46F, UNICODE_NORM_QC_NO},
+	{0xD470, UNICODE_NORM_QC_NO},
+	{0xD471, UNICODE_NORM_QC_NO},
+	{0xD472, UNICODE_NORM_QC_NO},
+	{0xD473, UNICODE_NORM_QC_NO},
+	{0xD474, UNICODE_NORM_QC_NO},
+	{0xD475, UNICODE_NORM_QC_NO},
+	{0xD476, UNICODE_NORM_QC_NO},
+	{0xD477, UNICODE_NORM_QC_NO},
+	{0xD478, UNICODE_NORM_QC_NO},
+	{0xD479, UNICODE_NORM_QC_NO},
+	{0xD47A, UNICODE_NORM_QC_NO},
+	{0xD47B, UNICODE_NORM_QC_NO},
+	{0xD47C, UNICODE_NORM_QC_NO},
+	{0xD47D, UNICODE_NORM_QC_NO},
+	{0xD47E, UNICODE_NORM_QC_NO},
+	{0xD47F, UNICODE_NORM_QC_NO},
+	{0xD480, UNICODE_NORM_QC_NO},
+	{0xD481, UNICODE_NORM_QC_NO},
+	{0xD482, UNICODE_NORM_QC_NO},
+	{0xD483, UNICODE_NORM_QC_NO},
+	{0xD484, UNICODE_NORM_QC_NO},
+	{0xD485, UNICODE_NORM_QC_NO},
+	{0xD486, UNICODE_NORM_QC_NO},
+	{0xD487, UNICODE_NORM_QC_NO},
+	{0xD488, UNICODE_NORM_QC_NO},
+	{0xD489, UNICODE_NORM_QC_NO},
+	{0xD48A, UNICODE_NORM_QC_NO},
+	{0xD48B, UNICODE_NORM_QC_NO},
+	{0xD48C, UNICODE_NORM_QC_NO},
+	{0xD48D, UNICODE_NORM_QC_NO},
+	{0xD48E, UNICODE_NORM_QC_NO},
+	{0xD48F, UNICODE_NORM_QC_NO},
+	{0xD490, UNICODE_NORM_QC_NO},
+	{0xD491, UNICODE_NORM_QC_NO},
+	{0xD492, UNICODE_NORM_QC_NO},
+	{0xD493, UNICODE_NORM_QC_NO},
+	{0xD494, UNICODE_NORM_QC_NO},
+	{0xD495, UNICODE_NORM_QC_NO},
+	{0xD496, UNICODE_NORM_QC_NO},
+	{0xD497, UNICODE_NORM_QC_NO},
+	{0xD498, UNICODE_NORM_QC_NO},
+	{0xD499, UNICODE_NORM_QC_NO},
+	{0xD49A, UNICODE_NORM_QC_NO},
+	{0xD49B, UNICODE_NORM_QC_NO},
+	{0xD49C, UNICODE_NORM_QC_NO},
+	{0xD49D, UNICODE_NORM_QC_NO},
+	{0xD49E, UNICODE_NORM_QC_NO},
+	{0xD49F, UNICODE_NORM_QC_NO},
+	{0xD4A0, UNICODE_NORM_QC_NO},
+	{0xD4A1, UNICODE_NORM_QC_NO},
+	{0xD4A2, UNICODE_NORM_QC_NO},
+	{0xD4A3, UNICODE_NORM_QC_NO},
+	{0xD4A4, UNICODE_NORM_QC_NO},
+	{0xD4A5, UNICODE_NORM_QC_NO},
+	{0xD4A6, UNICODE_NORM_QC_NO},
+	{0xD4A7, UNICODE_NORM_QC_NO},
+	{0xD4A8, UNICODE_NORM_QC_NO},
+	{0xD4A9, UNICODE_NORM_QC_NO},
+	{0xD4AA, UNICODE_NORM_QC_NO},
+	{0xD4AB, UNICODE_NORM_QC_NO},
+	{0xD4AC, UNICODE_NORM_QC_NO},
+	{0xD4AD, UNICODE_NORM_QC_NO},
+	{0xD4AE, UNICODE_NORM_QC_NO},
+	{0xD4AF, UNICODE_NORM_QC_NO},
+	{0xD4B0, UNICODE_NORM_QC_NO},
+	{0xD4B1, UNICODE_NORM_QC_NO},
+	{0xD4B2, UNICODE_NORM_QC_NO},
+	{0xD4B3, UNICODE_NORM_QC_NO},
+	{0xD4B4, UNICODE_NORM_QC_NO},
+	{0xD4B5, UNICODE_NORM_QC_NO},
+	{0xD4B6, UNICODE_NORM_QC_NO},
+	{0xD4B7, UNICODE_NORM_QC_NO},
+	{0xD4B8, UNICODE_NORM_QC_NO},
+	{0xD4B9, UNICODE_NORM_QC_NO},
+	{0xD4BA, UNICODE_NORM_QC_NO},
+	{0xD4BB, UNICODE_NORM_QC_NO},
+	{0xD4BC, UNICODE_NORM_QC_NO},
+	{0xD4BD, UNICODE_NORM_QC_NO},
+	{0xD4BE, UNICODE_NORM_QC_NO},
+	{0xD4BF, UNICODE_NORM_QC_NO},
+	{0xD4C0, UNICODE_NORM_QC_NO},
+	{0xD4C1, UNICODE_NORM_QC_NO},
+	{0xD4C2, UNICODE_NORM_QC_NO},
+	{0xD4C3, UNICODE_NORM_QC_NO},
+	{0xD4C4, UNICODE_NORM_QC_NO},
+	{0xD4C5, UNICODE_NORM_QC_NO},
+	{0xD4C6, UNICODE_NORM_QC_NO},
+	{0xD4C7, UNICODE_NORM_QC_NO},
+	{0xD4C8, UNICODE_NORM_QC_NO},
+	{0xD4C9, UNICODE_NORM_QC_NO},
+	{0xD4CA, UNICODE_NORM_QC_NO},
+	{0xD4CB, UNICODE_NORM_QC_NO},
+	{0xD4CC, UNICODE_NORM_QC_NO},
+	{0xD4CD, UNICODE_NORM_QC_NO},
+	{0xD4CE, UNICODE_NORM_QC_NO},
+	{0xD4CF, UNICODE_NORM_QC_NO},
+	{0xD4D0, UNICODE_NORM_QC_NO},
+	{0xD4D1, UNICODE_NORM_QC_NO},
+	{0xD4D2, UNICODE_NORM_QC_NO},
+	{0xD4D3, UNICODE_NORM_QC_NO},
+	{0xD4D4, UNICODE_NORM_QC_NO},
+	{0xD4D5, UNICODE_NORM_QC_NO},
+	{0xD4D6, UNICODE_NORM_QC_NO},
+	{0xD4D7, UNICODE_NORM_QC_NO},
+	{0xD4D8, UNICODE_NORM_QC_NO},
+	{0xD4D9, UNICODE_NORM_QC_NO},
+	{0xD4DA, UNICODE_NORM_QC_NO},
+	{0xD4DB, UNICODE_NORM_QC_NO},
+	{0xD4DC, UNICODE_NORM_QC_NO},
+	{0xD4DD, UNICODE_NORM_QC_NO},
+	{0xD4DE, UNICODE_NORM_QC_NO},
+	{0xD4DF, UNICODE_NORM_QC_NO},
+	{0xD4E0, UNICODE_NORM_QC_NO},
+	{0xD4E1, UNICODE_NORM_QC_NO},
+	{0xD4E2, UNICODE_NORM_QC_NO},
+	{0xD4E3, UNICODE_NORM_QC_NO},
+	{0xD4E4, UNICODE_NORM_QC_NO},
+	{0xD4E5, UNICODE_NORM_QC_NO},
+	{0xD4E6, UNICODE_NORM_QC_NO},
+	{0xD4E7, UNICODE_NORM_QC_NO},
+	{0xD4E8, UNICODE_NORM_QC_NO},
+	{0xD4E9, UNICODE_NORM_QC_NO},
+	{0xD4EA, UNICODE_NORM_QC_NO},
+	{0xD4EB, UNICODE_NORM_QC_NO},
+	{0xD4EC, UNICODE_NORM_QC_NO},
+	{0xD4ED, UNICODE_NORM_QC_NO},
+	{0xD4EE, UNICODE_NORM_QC_NO},
+	{0xD4EF, UNICODE_NORM_QC_NO},
+	{0xD4F0, UNICODE_NORM_QC_NO},
+	{0xD4F1, UNICODE_NORM_QC_NO},
+	{0xD4F2, UNICODE_NORM_QC_NO},
+	{0xD4F3, UNICODE_NORM_QC_NO},
+	{0xD4F4, UNICODE_NORM_QC_NO},
+	{0xD4F5, UNICODE_NORM_QC_NO},
+	{0xD4F6, UNICODE_NORM_QC_NO},
+	{0xD4F7, UNICODE_NORM_QC_NO},
+	{0xD4F8, UNICODE_NORM_QC_NO},
+	{0xD4F9, UNICODE_NORM_QC_NO},
+	{0xD4FA, UNICODE_NORM_QC_NO},
+	{0xD4FB, UNICODE_NORM_QC_NO},
+	{0xD4FC, UNICODE_NORM_QC_NO},
+	{0xD4FD, UNICODE_NORM_QC_NO},
+	{0xD4FE, UNICODE_NORM_QC_NO},
+	{0xD4FF, UNICODE_NORM_QC_NO},
+	{0xD500, UNICODE_NORM_QC_NO},
+	{0xD501, UNICODE_NORM_QC_NO},
+	{0xD502, UNICODE_NORM_QC_NO},
+	{0xD503, UNICODE_NORM_QC_NO},
+	{0xD504, UNICODE_NORM_QC_NO},
+	{0xD505, UNICODE_NORM_QC_NO},
+	{0xD506, UNICODE_NORM_QC_NO},
+	{0xD507, UNICODE_NORM_QC_NO},
+	{0xD508, UNICODE_NORM_QC_NO},
+	{0xD509, UNICODE_NORM_QC_NO},
+	{0xD50A, UNICODE_NORM_QC_NO},
+	{0xD50B, UNICODE_NORM_QC_NO},
+	{0xD50C, UNICODE_NORM_QC_NO},
+	{0xD50D, UNICODE_NORM_QC_NO},
+	{0xD50E, UNICODE_NORM_QC_NO},
+	{0xD50F, UNICODE_NORM_QC_NO},
+	{0xD510, UNICODE_NORM_QC_NO},
+	{0xD511, UNICODE_NORM_QC_NO},
+	{0xD512, UNICODE_NORM_QC_NO},
+	{0xD513, UNICODE_NORM_QC_NO},
+	{0xD514, UNICODE_NORM_QC_NO},
+	{0xD515, UNICODE_NORM_QC_NO},
+	{0xD516, UNICODE_NORM_QC_NO},
+	{0xD517, UNICODE_NORM_QC_NO},
+	{0xD518, UNICODE_NORM_QC_NO},
+	{0xD519, UNICODE_NORM_QC_NO},
+	{0xD51A, UNICODE_NORM_QC_NO},
+	{0xD51B, UNICODE_NORM_QC_NO},
+	{0xD51C, UNICODE_NORM_QC_NO},
+	{0xD51D, UNICODE_NORM_QC_NO},
+	{0xD51E, UNICODE_NORM_QC_NO},
+	{0xD51F, UNICODE_NORM_QC_NO},
+	{0xD520, UNICODE_NORM_QC_NO},
+	{0xD521, UNICODE_NORM_QC_NO},
+	{0xD522, UNICODE_NORM_QC_NO},
+	{0xD523, UNICODE_NORM_QC_NO},
+	{0xD524, UNICODE_NORM_QC_NO},
+	{0xD525, UNICODE_NORM_QC_NO},
+	{0xD526, UNICODE_NORM_QC_NO},
+	{0xD527, UNICODE_NORM_QC_NO},
+	{0xD528, UNICODE_NORM_QC_NO},
+	{0xD529, UNICODE_NORM_QC_NO},
+	{0xD52A, UNICODE_NORM_QC_NO},
+	{0xD52B, UNICODE_NORM_QC_NO},
+	{0xD52C, UNICODE_NORM_QC_NO},
+	{0xD52D, UNICODE_NORM_QC_NO},
+	{0xD52E, UNICODE_NORM_QC_NO},
+	{0xD52F, UNICODE_NORM_QC_NO},
+	{0xD530, UNICODE_NORM_QC_NO},
+	{0xD531, UNICODE_NORM_QC_NO},
+	{0xD532, UNICODE_NORM_QC_NO},
+	{0xD533, UNICODE_NORM_QC_NO},
+	{0xD534, UNICODE_NORM_QC_NO},
+	{0xD535, UNICODE_NORM_QC_NO},
+	{0xD536, UNICODE_NORM_QC_NO},
+	{0xD537, UNICODE_NORM_QC_NO},
+	{0xD538, UNICODE_NORM_QC_NO},
+	{0xD539, UNICODE_NORM_QC_NO},
+	{0xD53A, UNICODE_NORM_QC_NO},
+	{0xD53B, UNICODE_NORM_QC_NO},
+	{0xD53C, UNICODE_NORM_QC_NO},
+	{0xD53D, UNICODE_NORM_QC_NO},
+	{0xD53E, UNICODE_NORM_QC_NO},
+	{0xD53F, UNICODE_NORM_QC_NO},
+	{0xD540, UNICODE_NORM_QC_NO},
+	{0xD541, UNICODE_NORM_QC_NO},
+	{0xD542, UNICODE_NORM_QC_NO},
+	{0xD543, UNICODE_NORM_QC_NO},
+	{0xD544, UNICODE_NORM_QC_NO},
+	{0xD545, UNICODE_NORM_QC_NO},
+	{0xD546, UNICODE_NORM_QC_NO},
+	{0xD547, UNICODE_NORM_QC_NO},
+	{0xD548, UNICODE_NORM_QC_NO},
+	{0xD549, UNICODE_NORM_QC_NO},
+	{0xD54A, UNICODE_NORM_QC_NO},
+	{0xD54B, UNICODE_NORM_QC_NO},
+	{0xD54C, UNICODE_NORM_QC_NO},
+	{0xD54D, UNICODE_NORM_QC_NO},
+	{0xD54E, UNICODE_NORM_QC_NO},
+	{0xD54F, UNICODE_NORM_QC_NO},
+	{0xD550, UNICODE_NORM_QC_NO},
+	{0xD551, UNICODE_NORM_QC_NO},
+	{0xD552, UNICODE_NORM_QC_NO},
+	{0xD553, UNICODE_NORM_QC_NO},
+	{0xD554, UNICODE_NORM_QC_NO},
+	{0xD555, UNICODE_NORM_QC_NO},
+	{0xD556, UNICODE_NORM_QC_NO},
+	{0xD557, UNICODE_NORM_QC_NO},
+	{0xD558, UNICODE_NORM_QC_NO},
+	{0xD559, UNICODE_NORM_QC_NO},
+	{0xD55A, UNICODE_NORM_QC_NO},
+	{0xD55B, UNICODE_NORM_QC_NO},
+	{0xD55C, UNICODE_NORM_QC_NO},
+	{0xD55D, UNICODE_NORM_QC_NO},
+	{0xD55E, UNICODE_NORM_QC_NO},
+	{0xD55F, UNICODE_NORM_QC_NO},
+	{0xD560, UNICODE_NORM_QC_NO},
+	{0xD561, UNICODE_NORM_QC_NO},
+	{0xD562, UNICODE_NORM_QC_NO},
+	{0xD563, UNICODE_NORM_QC_NO},
+	{0xD564, UNICODE_NORM_QC_NO},
+	{0xD565, UNICODE_NORM_QC_NO},
+	{0xD566, UNICODE_NORM_QC_NO},
+	{0xD567, UNICODE_NORM_QC_NO},
+	{0xD568, UNICODE_NORM_QC_NO},
+	{0xD569, UNICODE_NORM_QC_NO},
+	{0xD56A, UNICODE_NORM_QC_NO},
+	{0xD56B, UNICODE_NORM_QC_NO},
+	{0xD56C, UNICODE_NORM_QC_NO},
+	{0xD56D, UNICODE_NORM_QC_NO},
+	{0xD56E, UNICODE_NORM_QC_NO},
+	{0xD56F, UNICODE_NORM_QC_NO},
+	{0xD570, UNICODE_NORM_QC_NO},
+	{0xD571, UNICODE_NORM_QC_NO},
+	{0xD572, UNICODE_NORM_QC_NO},
+	{0xD573, UNICODE_NORM_QC_NO},
+	{0xD574, UNICODE_NORM_QC_NO},
+	{0xD575, UNICODE_NORM_QC_NO},
+	{0xD576, UNICODE_NORM_QC_NO},
+	{0xD577, UNICODE_NORM_QC_NO},
+	{0xD578, UNICODE_NORM_QC_NO},
+	{0xD579, UNICODE_NORM_QC_NO},
+	{0xD57A, UNICODE_NORM_QC_NO},
+	{0xD57B, UNICODE_NORM_QC_NO},
+	{0xD57C, UNICODE_NORM_QC_NO},
+	{0xD57D, UNICODE_NORM_QC_NO},
+	{0xD57E, UNICODE_NORM_QC_NO},
+	{0xD57F, UNICODE_NORM_QC_NO},
+	{0xD580, UNICODE_NORM_QC_NO},
+	{0xD581, UNICODE_NORM_QC_NO},
+	{0xD582, UNICODE_NORM_QC_NO},
+	{0xD583, UNICODE_NORM_QC_NO},
+	{0xD584, UNICODE_NORM_QC_NO},
+	{0xD585, UNICODE_NORM_QC_NO},
+	{0xD586, UNICODE_NORM_QC_NO},
+	{0xD587, UNICODE_NORM_QC_NO},
+	{0xD588, UNICODE_NORM_QC_NO},
+	{0xD589, UNICODE_NORM_QC_NO},
+	{0xD58A, UNICODE_NORM_QC_NO},
+	{0xD58B, UNICODE_NORM_QC_NO},
+	{0xD58C, UNICODE_NORM_QC_NO},
+	{0xD58D, UNICODE_NORM_QC_NO},
+	{0xD58E, UNICODE_NORM_QC_NO},
+	{0xD58F, UNICODE_NORM_QC_NO},
+	{0xD590, UNICODE_NORM_QC_NO},
+	{0xD591, UNICODE_NORM_QC_NO},
+	{0xD592, UNICODE_NORM_QC_NO},
+	{0xD593, UNICODE_NORM_QC_NO},
+	{0xD594, UNICODE_NORM_QC_NO},
+	{0xD595, UNICODE_NORM_QC_NO},
+	{0xD596, UNICODE_NORM_QC_NO},
+	{0xD597, UNICODE_NORM_QC_NO},
+	{0xD598, UNICODE_NORM_QC_NO},
+	{0xD599, UNICODE_NORM_QC_NO},
+	{0xD59A, UNICODE_NORM_QC_NO},
+	{0xD59B, UNICODE_NORM_QC_NO},
+	{0xD59C, UNICODE_NORM_QC_NO},
+	{0xD59D, UNICODE_NORM_QC_NO},
+	{0xD59E, UNICODE_NORM_QC_NO},
+	{0xD59F, UNICODE_NORM_QC_NO},
+	{0xD5A0, UNICODE_NORM_QC_NO},
+	{0xD5A1, UNICODE_NORM_QC_NO},
+	{0xD5A2, UNICODE_NORM_QC_NO},
+	{0xD5A3, UNICODE_NORM_QC_NO},
+	{0xD5A4, UNICODE_NORM_QC_NO},
+	{0xD5A5, UNICODE_NORM_QC_NO},
+	{0xD5A6, UNICODE_NORM_QC_NO},
+	{0xD5A7, UNICODE_NORM_QC_NO},
+	{0xD5A8, UNICODE_NORM_QC_NO},
+	{0xD5A9, UNICODE_NORM_QC_NO},
+	{0xD5AA, UNICODE_NORM_QC_NO},
+	{0xD5AB, UNICODE_NORM_QC_NO},
+	{0xD5AC, UNICODE_NORM_QC_NO},
+	{0xD5AD, UNICODE_NORM_QC_NO},
+	{0xD5AE, UNICODE_NORM_QC_NO},
+	{0xD5AF, UNICODE_NORM_QC_NO},
+	{0xD5B0, UNICODE_NORM_QC_NO},
+	{0xD5B1, UNICODE_NORM_QC_NO},
+	{0xD5B2, UNICODE_NORM_QC_NO},
+	{0xD5B3, UNICODE_NORM_QC_NO},
+	{0xD5B4, UNICODE_NORM_QC_NO},
+	{0xD5B5, UNICODE_NORM_QC_NO},
+	{0xD5B6, UNICODE_NORM_QC_NO},
+	{0xD5B7, UNICODE_NORM_QC_NO},
+	{0xD5B8, UNICODE_NORM_QC_NO},
+	{0xD5B9, UNICODE_NORM_QC_NO},
+	{0xD5BA, UNICODE_NORM_QC_NO},
+	{0xD5BB, UNICODE_NORM_QC_NO},
+	{0xD5BC, UNICODE_NORM_QC_NO},
+	{0xD5BD, UNICODE_NORM_QC_NO},
+	{0xD5BE, UNICODE_NORM_QC_NO},
+	{0xD5BF, UNICODE_NORM_QC_NO},
+	{0xD5C0, UNICODE_NORM_QC_NO},
+	{0xD5C1, UNICODE_NORM_QC_NO},
+	{0xD5C2, UNICODE_NORM_QC_NO},
+	{0xD5C3, UNICODE_NORM_QC_NO},
+	{0xD5C4, UNICODE_NORM_QC_NO},
+	{0xD5C5, UNICODE_NORM_QC_NO},
+	{0xD5C6, UNICODE_NORM_QC_NO},
+	{0xD5C7, UNICODE_NORM_QC_NO},
+	{0xD5C8, UNICODE_NORM_QC_NO},
+	{0xD5C9, UNICODE_NORM_QC_NO},
+	{0xD5CA, UNICODE_NORM_QC_NO},
+	{0xD5CB, UNICODE_NORM_QC_NO},
+	{0xD5CC, UNICODE_NORM_QC_NO},
+	{0xD5CD, UNICODE_NORM_QC_NO},
+	{0xD5CE, UNICODE_NORM_QC_NO},
+	{0xD5CF, UNICODE_NORM_QC_NO},
+	{0xD5D0, UNICODE_NORM_QC_NO},
+	{0xD5D1, UNICODE_NORM_QC_NO},
+	{0xD5D2, UNICODE_NORM_QC_NO},
+	{0xD5D3, UNICODE_NORM_QC_NO},
+	{0xD5D4, UNICODE_NORM_QC_NO},
+	{0xD5D5, UNICODE_NORM_QC_NO},
+	{0xD5D6, UNICODE_NORM_QC_NO},
+	{0xD5D7, UNICODE_NORM_QC_NO},
+	{0xD5D8, UNICODE_NORM_QC_NO},
+	{0xD5D9, UNICODE_NORM_QC_NO},
+	{0xD5DA, UNICODE_NORM_QC_NO},
+	{0xD5DB, UNICODE_NORM_QC_NO},
+	{0xD5DC, UNICODE_NORM_QC_NO},
+	{0xD5DD, UNICODE_NORM_QC_NO},
+	{0xD5DE, UNICODE_NORM_QC_NO},
+	{0xD5DF, UNICODE_NORM_QC_NO},
+	{0xD5E0, UNICODE_NORM_QC_NO},
+	{0xD5E1, UNICODE_NORM_QC_NO},
+	{0xD5E2, UNICODE_NORM_QC_NO},
+	{0xD5E3, UNICODE_NORM_QC_NO},
+	{0xD5E4, UNICODE_NORM_QC_NO},
+	{0xD5E5, UNICODE_NORM_QC_NO},
+	{0xD5E6, UNICODE_NORM_QC_NO},
+	{0xD5E7, UNICODE_NORM_QC_NO},
+	{0xD5E8, UNICODE_NORM_QC_NO},
+	{0xD5E9, UNICODE_NORM_QC_NO},
+	{0xD5EA, UNICODE_NORM_QC_NO},
+	{0xD5EB, UNICODE_NORM_QC_NO},
+	{0xD5EC, UNICODE_NORM_QC_NO},
+	{0xD5ED, UNICODE_NORM_QC_NO},
+	{0xD5EE, UNICODE_NORM_QC_NO},
+	{0xD5EF, UNICODE_NORM_QC_NO},
+	{0xD5F0, UNICODE_NORM_QC_NO},
+	{0xD5F1, UNICODE_NORM_QC_NO},
+	{0xD5F2, UNICODE_NORM_QC_NO},
+	{0xD5F3, UNICODE_NORM_QC_NO},
+	{0xD5F4, UNICODE_NORM_QC_NO},
+	{0xD5F5, UNICODE_NORM_QC_NO},
+	{0xD5F6, UNICODE_NORM_QC_NO},
+	{0xD5F7, UNICODE_NORM_QC_NO},
+	{0xD5F8, UNICODE_NORM_QC_NO},
+	{0xD5F9, UNICODE_NORM_QC_NO},
+	{0xD5FA, UNICODE_NORM_QC_NO},
+	{0xD5FB, UNICODE_NORM_QC_NO},
+	{0xD5FC, UNICODE_NORM_QC_NO},
+	{0xD5FD, UNICODE_NORM_QC_NO},
+	{0xD5FE, UNICODE_NORM_QC_NO},
+	{0xD5FF, UNICODE_NORM_QC_NO},
+	{0xD600, UNICODE_NORM_QC_NO},
+	{0xD601, UNICODE_NORM_QC_NO},
+	{0xD602, UNICODE_NORM_QC_NO},
+	{0xD603, UNICODE_NORM_QC_NO},
+	{0xD604, UNICODE_NORM_QC_NO},
+	{0xD605, UNICODE_NORM_QC_NO},
+	{0xD606, UNICODE_NORM_QC_NO},
+	{0xD607, UNICODE_NORM_QC_NO},
+	{0xD608, UNICODE_NORM_QC_NO},
+	{0xD609, UNICODE_NORM_QC_NO},
+	{0xD60A, UNICODE_NORM_QC_NO},
+	{0xD60B, UNICODE_NORM_QC_NO},
+	{0xD60C, UNICODE_NORM_QC_NO},
+	{0xD60D, UNICODE_NORM_QC_NO},
+	{0xD60E, UNICODE_NORM_QC_NO},
+	{0xD60F, UNICODE_NORM_QC_NO},
+	{0xD610, UNICODE_NORM_QC_NO},
+	{0xD611, UNICODE_NORM_QC_NO},
+	{0xD612, UNICODE_NORM_QC_NO},
+	{0xD613, UNICODE_NORM_QC_NO},
+	{0xD614, UNICODE_NORM_QC_NO},
+	{0xD615, UNICODE_NORM_QC_NO},
+	{0xD616, UNICODE_NORM_QC_NO},
+	{0xD617, UNICODE_NORM_QC_NO},
+	{0xD618, UNICODE_NORM_QC_NO},
+	{0xD619, UNICODE_NORM_QC_NO},
+	{0xD61A, UNICODE_NORM_QC_NO},
+	{0xD61B, UNICODE_NORM_QC_NO},
+	{0xD61C, UNICODE_NORM_QC_NO},
+	{0xD61D, UNICODE_NORM_QC_NO},
+	{0xD61E, UNICODE_NORM_QC_NO},
+	{0xD61F, UNICODE_NORM_QC_NO},
+	{0xD620, UNICODE_NORM_QC_NO},
+	{0xD621, UNICODE_NORM_QC_NO},
+	{0xD622, UNICODE_NORM_QC_NO},
+	{0xD623, UNICODE_NORM_QC_NO},
+	{0xD624, UNICODE_NORM_QC_NO},
+	{0xD625, UNICODE_NORM_QC_NO},
+	{0xD626, UNICODE_NORM_QC_NO},
+	{0xD627, UNICODE_NORM_QC_NO},
+	{0xD628, UNICODE_NORM_QC_NO},
+	{0xD629, UNICODE_NORM_QC_NO},
+	{0xD62A, UNICODE_NORM_QC_NO},
+	{0xD62B, UNICODE_NORM_QC_NO},
+	{0xD62C, UNICODE_NORM_QC_NO},
+	{0xD62D, UNICODE_NORM_QC_NO},
+	{0xD62E, UNICODE_NORM_QC_NO},
+	{0xD62F, UNICODE_NORM_QC_NO},
+	{0xD630, UNICODE_NORM_QC_NO},
+	{0xD631, UNICODE_NORM_QC_NO},
+	{0xD632, UNICODE_NORM_QC_NO},
+	{0xD633, UNICODE_NORM_QC_NO},
+	{0xD634, UNICODE_NORM_QC_NO},
+	{0xD635, UNICODE_NORM_QC_NO},
+	{0xD636, UNICODE_NORM_QC_NO},
+	{0xD637, UNICODE_NORM_QC_NO},
+	{0xD638, UNICODE_NORM_QC_NO},
+	{0xD639, UNICODE_NORM_QC_NO},
+	{0xD63A, UNICODE_NORM_QC_NO},
+	{0xD63B, UNICODE_NORM_QC_NO},
+	{0xD63C, UNICODE_NORM_QC_NO},
+	{0xD63D, UNICODE_NORM_QC_NO},
+	{0xD63E, UNICODE_NORM_QC_NO},
+	{0xD63F, UNICODE_NORM_QC_NO},
+	{0xD640, UNICODE_NORM_QC_NO},
+	{0xD641, UNICODE_NORM_QC_NO},
+	{0xD642, UNICODE_NORM_QC_NO},
+	{0xD643, UNICODE_NORM_QC_NO},
+	{0xD644, UNICODE_NORM_QC_NO},
+	{0xD645, UNICODE_NORM_QC_NO},
+	{0xD646, UNICODE_NORM_QC_NO},
+	{0xD647, UNICODE_NORM_QC_NO},
+	{0xD648, UNICODE_NORM_QC_NO},
+	{0xD649, UNICODE_NORM_QC_NO},
+	{0xD64A, UNICODE_NORM_QC_NO},
+	{0xD64B, UNICODE_NORM_QC_NO},
+	{0xD64C, UNICODE_NORM_QC_NO},
+	{0xD64D, UNICODE_NORM_QC_NO},
+	{0xD64E, UNICODE_NORM_QC_NO},
+	{0xD64F, UNICODE_NORM_QC_NO},
+	{0xD650, UNICODE_NORM_QC_NO},
+	{0xD651, UNICODE_NORM_QC_NO},
+	{0xD652, UNICODE_NORM_QC_NO},
+	{0xD653, UNICODE_NORM_QC_NO},
+	{0xD654, UNICODE_NORM_QC_NO},
+	{0xD655, UNICODE_NORM_QC_NO},
+	{0xD656, UNICODE_NORM_QC_NO},
+	{0xD657, UNICODE_NORM_QC_NO},
+	{0xD658, UNICODE_NORM_QC_NO},
+	{0xD659, UNICODE_NORM_QC_NO},
+	{0xD65A, UNICODE_NORM_QC_NO},
+	{0xD65B, UNICODE_NORM_QC_NO},
+	{0xD65C, UNICODE_NORM_QC_NO},
+	{0xD65D, UNICODE_NORM_QC_NO},
+	{0xD65E, UNICODE_NORM_QC_NO},
+	{0xD65F, UNICODE_NORM_QC_NO},
+	{0xD660, UNICODE_NORM_QC_NO},
+	{0xD661, UNICODE_NORM_QC_NO},
+	{0xD662, UNICODE_NORM_QC_NO},
+	{0xD663, UNICODE_NORM_QC_NO},
+	{0xD664, UNICODE_NORM_QC_NO},
+	{0xD665, UNICODE_NORM_QC_NO},
+	{0xD666, UNICODE_NORM_QC_NO},
+	{0xD667, UNICODE_NORM_QC_NO},
+	{0xD668, UNICODE_NORM_QC_NO},
+	{0xD669, UNICODE_NORM_QC_NO},
+	{0xD66A, UNICODE_NORM_QC_NO},
+	{0xD66B, UNICODE_NORM_QC_NO},
+	{0xD66C, UNICODE_NORM_QC_NO},
+	{0xD66D, UNICODE_NORM_QC_NO},
+	{0xD66E, UNICODE_NORM_QC_NO},
+	{0xD66F, UNICODE_NORM_QC_NO},
+	{0xD670, UNICODE_NORM_QC_NO},
+	{0xD671, UNICODE_NORM_QC_NO},
+	{0xD672, UNICODE_NORM_QC_NO},
+	{0xD673, UNICODE_NORM_QC_NO},
+	{0xD674, UNICODE_NORM_QC_NO},
+	{0xD675, UNICODE_NORM_QC_NO},
+	{0xD676, UNICODE_NORM_QC_NO},
+	{0xD677, UNICODE_NORM_QC_NO},
+	{0xD678, UNICODE_NORM_QC_NO},
+	{0xD679, UNICODE_NORM_QC_NO},
+	{0xD67A, UNICODE_NORM_QC_NO},
+	{0xD67B, UNICODE_NORM_QC_NO},
+	{0xD67C, UNICODE_NORM_QC_NO},
+	{0xD67D, UNICODE_NORM_QC_NO},
+	{0xD67E, UNICODE_NORM_QC_NO},
+	{0xD67F, UNICODE_NORM_QC_NO},
+	{0xD680, UNICODE_NORM_QC_NO},
+	{0xD681, UNICODE_NORM_QC_NO},
+	{0xD682, UNICODE_NORM_QC_NO},
+	{0xD683, UNICODE_NORM_QC_NO},
+	{0xD684, UNICODE_NORM_QC_NO},
+	{0xD685, UNICODE_NORM_QC_NO},
+	{0xD686, UNICODE_NORM_QC_NO},
+	{0xD687, UNICODE_NORM_QC_NO},
+	{0xD688, UNICODE_NORM_QC_NO},
+	{0xD689, UNICODE_NORM_QC_NO},
+	{0xD68A, UNICODE_NORM_QC_NO},
+	{0xD68B, UNICODE_NORM_QC_NO},
+	{0xD68C, UNICODE_NORM_QC_NO},
+	{0xD68D, UNICODE_NORM_QC_NO},
+	{0xD68E, UNICODE_NORM_QC_NO},
+	{0xD68F, UNICODE_NORM_QC_NO},
+	{0xD690, UNICODE_NORM_QC_NO},
+	{0xD691, UNICODE_NORM_QC_NO},
+	{0xD692, UNICODE_NORM_QC_NO},
+	{0xD693, UNICODE_NORM_QC_NO},
+	{0xD694, UNICODE_NORM_QC_NO},
+	{0xD695, UNICODE_NORM_QC_NO},
+	{0xD696, UNICODE_NORM_QC_NO},
+	{0xD697, UNICODE_NORM_QC_NO},
+	{0xD698, UNICODE_NORM_QC_NO},
+	{0xD699, UNICODE_NORM_QC_NO},
+	{0xD69A, UNICODE_NORM_QC_NO},
+	{0xD69B, UNICODE_NORM_QC_NO},
+	{0xD69C, UNICODE_NORM_QC_NO},
+	{0xD69D, UNICODE_NORM_QC_NO},
+	{0xD69E, UNICODE_NORM_QC_NO},
+	{0xD69F, UNICODE_NORM_QC_NO},
+	{0xD6A0, UNICODE_NORM_QC_NO},
+	{0xD6A1, UNICODE_NORM_QC_NO},
+	{0xD6A2, UNICODE_NORM_QC_NO},
+	{0xD6A3, UNICODE_NORM_QC_NO},
+	{0xD6A4, UNICODE_NORM_QC_NO},
+	{0xD6A5, UNICODE_NORM_QC_NO},
+	{0xD6A6, UNICODE_NORM_QC_NO},
+	{0xD6A7, UNICODE_NORM_QC_NO},
+	{0xD6A8, UNICODE_NORM_QC_NO},
+	{0xD6A9, UNICODE_NORM_QC_NO},
+	{0xD6AA, UNICODE_NORM_QC_NO},
+	{0xD6AB, UNICODE_NORM_QC_NO},
+	{0xD6AC, UNICODE_NORM_QC_NO},
+	{0xD6AD, UNICODE_NORM_QC_NO},
+	{0xD6AE, UNICODE_NORM_QC_NO},
+	{0xD6AF, UNICODE_NORM_QC_NO},
+	{0xD6B0, UNICODE_NORM_QC_NO},
+	{0xD6B1, UNICODE_NORM_QC_NO},
+	{0xD6B2, UNICODE_NORM_QC_NO},
+	{0xD6B3, UNICODE_NORM_QC_NO},
+	{0xD6B4, UNICODE_NORM_QC_NO},
+	{0xD6B5, UNICODE_NORM_QC_NO},
+	{0xD6B6, UNICODE_NORM_QC_NO},
+	{0xD6B7, UNICODE_NORM_QC_NO},
+	{0xD6B8, UNICODE_NORM_QC_NO},
+	{0xD6B9, UNICODE_NORM_QC_NO},
+	{0xD6BA, UNICODE_NORM_QC_NO},
+	{0xD6BB, UNICODE_NORM_QC_NO},
+	{0xD6BC, UNICODE_NORM_QC_NO},
+	{0xD6BD, UNICODE_NORM_QC_NO},
+	{0xD6BE, UNICODE_NORM_QC_NO},
+	{0xD6BF, UNICODE_NORM_QC_NO},
+	{0xD6C0, UNICODE_NORM_QC_NO},
+	{0xD6C1, UNICODE_NORM_QC_NO},
+	{0xD6C2, UNICODE_NORM_QC_NO},
+	{0xD6C3, UNICODE_NORM_QC_NO},
+	{0xD6C4, UNICODE_NORM_QC_NO},
+	{0xD6C5, UNICODE_NORM_QC_NO},
+	{0xD6C6, UNICODE_NORM_QC_NO},
+	{0xD6C7, UNICODE_NORM_QC_NO},
+	{0xD6C8, UNICODE_NORM_QC_NO},
+	{0xD6C9, UNICODE_NORM_QC_NO},
+	{0xD6CA, UNICODE_NORM_QC_NO},
+	{0xD6CB, UNICODE_NORM_QC_NO},
+	{0xD6CC, UNICODE_NORM_QC_NO},
+	{0xD6CD, UNICODE_NORM_QC_NO},
+	{0xD6CE, UNICODE_NORM_QC_NO},
+	{0xD6CF, UNICODE_NORM_QC_NO},
+	{0xD6D0, UNICODE_NORM_QC_NO},
+	{0xD6D1, UNICODE_NORM_QC_NO},
+	{0xD6D2, UNICODE_NORM_QC_NO},
+	{0xD6D3, UNICODE_NORM_QC_NO},
+	{0xD6D4, UNICODE_NORM_QC_NO},
+	{0xD6D5, UNICODE_NORM_QC_NO},
+	{0xD6D6, UNICODE_NORM_QC_NO},
+	{0xD6D7, UNICODE_NORM_QC_NO},
+	{0xD6D8, UNICODE_NORM_QC_NO},
+	{0xD6D9, UNICODE_NORM_QC_NO},
+	{0xD6DA, UNICODE_NORM_QC_NO},
+	{0xD6DB, UNICODE_NORM_QC_NO},
+	{0xD6DC, UNICODE_NORM_QC_NO},
+	{0xD6DD, UNICODE_NORM_QC_NO},
+	{0xD6DE, UNICODE_NORM_QC_NO},
+	{0xD6DF, UNICODE_NORM_QC_NO},
+	{0xD6E0, UNICODE_NORM_QC_NO},
+	{0xD6E1, UNICODE_NORM_QC_NO},
+	{0xD6E2, UNICODE_NORM_QC_NO},
+	{0xD6E3, UNICODE_NORM_QC_NO},
+	{0xD6E4, UNICODE_NORM_QC_NO},
+	{0xD6E5, UNICODE_NORM_QC_NO},
+	{0xD6E6, UNICODE_NORM_QC_NO},
+	{0xD6E7, UNICODE_NORM_QC_NO},
+	{0xD6E8, UNICODE_NORM_QC_NO},
+	{0xD6E9, UNICODE_NORM_QC_NO},
+	{0xD6EA, UNICODE_NORM_QC_NO},
+	{0xD6EB, UNICODE_NORM_QC_NO},
+	{0xD6EC, UNICODE_NORM_QC_NO},
+	{0xD6ED, UNICODE_NORM_QC_NO},
+	{0xD6EE, UNICODE_NORM_QC_NO},
+	{0xD6EF, UNICODE_NORM_QC_NO},
+	{0xD6F0, UNICODE_NORM_QC_NO},
+	{0xD6F1, UNICODE_NORM_QC_NO},
+	{0xD6F2, UNICODE_NORM_QC_NO},
+	{0xD6F3, UNICODE_NORM_QC_NO},
+	{0xD6F4, UNICODE_NORM_QC_NO},
+	{0xD6F5, UNICODE_NORM_QC_NO},
+	{0xD6F6, UNICODE_NORM_QC_NO},
+	{0xD6F7, UNICODE_NORM_QC_NO},
+	{0xD6F8, UNICODE_NORM_QC_NO},
+	{0xD6F9, UNICODE_NORM_QC_NO},
+	{0xD6FA, UNICODE_NORM_QC_NO},
+	{0xD6FB, UNICODE_NORM_QC_NO},
+	{0xD6FC, UNICODE_NORM_QC_NO},
+	{0xD6FD, UNICODE_NORM_QC_NO},
+	{0xD6FE, UNICODE_NORM_QC_NO},
+	{0xD6FF, UNICODE_NORM_QC_NO},
+	{0xD700, UNICODE_NORM_QC_NO},
+	{0xD701, UNICODE_NORM_QC_NO},
+	{0xD702, UNICODE_NORM_QC_NO},
+	{0xD703, UNICODE_NORM_QC_NO},
+	{0xD704, UNICODE_NORM_QC_NO},
+	{0xD705, UNICODE_NORM_QC_NO},
+	{0xD706, UNICODE_NORM_QC_NO},
+	{0xD707, UNICODE_NORM_QC_NO},
+	{0xD708, UNICODE_NORM_QC_NO},
+	{0xD709, UNICODE_NORM_QC_NO},
+	{0xD70A, UNICODE_NORM_QC_NO},
+	{0xD70B, UNICODE_NORM_QC_NO},
+	{0xD70C, UNICODE_NORM_QC_NO},
+	{0xD70D, UNICODE_NORM_QC_NO},
+	{0xD70E, UNICODE_NORM_QC_NO},
+	{0xD70F, UNICODE_NORM_QC_NO},
+	{0xD710, UNICODE_NORM_QC_NO},
+	{0xD711, UNICODE_NORM_QC_NO},
+	{0xD712, UNICODE_NORM_QC_NO},
+	{0xD713, UNICODE_NORM_QC_NO},
+	{0xD714, UNICODE_NORM_QC_NO},
+	{0xD715, UNICODE_NORM_QC_NO},
+	{0xD716, UNICODE_NORM_QC_NO},
+	{0xD717, UNICODE_NORM_QC_NO},
+	{0xD718, UNICODE_NORM_QC_NO},
+	{0xD719, UNICODE_NORM_QC_NO},
+	{0xD71A, UNICODE_NORM_QC_NO},
+	{0xD71B, UNICODE_NORM_QC_NO},
+	{0xD71C, UNICODE_NORM_QC_NO},
+	{0xD71D, UNICODE_NORM_QC_NO},
+	{0xD71E, UNICODE_NORM_QC_NO},
+	{0xD71F, UNICODE_NORM_QC_NO},
+	{0xD720, UNICODE_NORM_QC_NO},
+	{0xD721, UNICODE_NORM_QC_NO},
+	{0xD722, UNICODE_NORM_QC_NO},
+	{0xD723, UNICODE_NORM_QC_NO},
+	{0xD724, UNICODE_NORM_QC_NO},
+	{0xD725, UNICODE_NORM_QC_NO},
+	{0xD726, UNICODE_NORM_QC_NO},
+	{0xD727, UNICODE_NORM_QC_NO},
+	{0xD728, UNICODE_NORM_QC_NO},
+	{0xD729, UNICODE_NORM_QC_NO},
+	{0xD72A, UNICODE_NORM_QC_NO},
+	{0xD72B, UNICODE_NORM_QC_NO},
+	{0xD72C, UNICODE_NORM_QC_NO},
+	{0xD72D, UNICODE_NORM_QC_NO},
+	{0xD72E, UNICODE_NORM_QC_NO},
+	{0xD72F, UNICODE_NORM_QC_NO},
+	{0xD730, UNICODE_NORM_QC_NO},
+	{0xD731, UNICODE_NORM_QC_NO},
+	{0xD732, UNICODE_NORM_QC_NO},
+	{0xD733, UNICODE_NORM_QC_NO},
+	{0xD734, UNICODE_NORM_QC_NO},
+	{0xD735, UNICODE_NORM_QC_NO},
+	{0xD736, UNICODE_NORM_QC_NO},
+	{0xD737, UNICODE_NORM_QC_NO},
+	{0xD738, UNICODE_NORM_QC_NO},
+	{0xD739, UNICODE_NORM_QC_NO},
+	{0xD73A, UNICODE_NORM_QC_NO},
+	{0xD73B, UNICODE_NORM_QC_NO},
+	{0xD73C, UNICODE_NORM_QC_NO},
+	{0xD73D, UNICODE_NORM_QC_NO},
+	{0xD73E, UNICODE_NORM_QC_NO},
+	{0xD73F, UNICODE_NORM_QC_NO},
+	{0xD740, UNICODE_NORM_QC_NO},
+	{0xD741, UNICODE_NORM_QC_NO},
+	{0xD742, UNICODE_NORM_QC_NO},
+	{0xD743, UNICODE_NORM_QC_NO},
+	{0xD744, UNICODE_NORM_QC_NO},
+	{0xD745, UNICODE_NORM_QC_NO},
+	{0xD746, UNICODE_NORM_QC_NO},
+	{0xD747, UNICODE_NORM_QC_NO},
+	{0xD748, UNICODE_NORM_QC_NO},
+	{0xD749, UNICODE_NORM_QC_NO},
+	{0xD74A, UNICODE_NORM_QC_NO},
+	{0xD74B, UNICODE_NORM_QC_NO},
+	{0xD74C, UNICODE_NORM_QC_NO},
+	{0xD74D, UNICODE_NORM_QC_NO},
+	{0xD74E, UNICODE_NORM_QC_NO},
+	{0xD74F, UNICODE_NORM_QC_NO},
+	{0xD750, UNICODE_NORM_QC_NO},
+	{0xD751, UNICODE_NORM_QC_NO},
+	{0xD752, UNICODE_NORM_QC_NO},
+	{0xD753, UNICODE_NORM_QC_NO},
+	{0xD754, UNICODE_NORM_QC_NO},
+	{0xD755, UNICODE_NORM_QC_NO},
+	{0xD756, UNICODE_NORM_QC_NO},
+	{0xD757, UNICODE_NORM_QC_NO},
+	{0xD758, UNICODE_NORM_QC_NO},
+	{0xD759, UNICODE_NORM_QC_NO},
+	{0xD75A, UNICODE_NORM_QC_NO},
+	{0xD75B, UNICODE_NORM_QC_NO},
+	{0xD75C, UNICODE_NORM_QC_NO},
+	{0xD75D, UNICODE_NORM_QC_NO},
+	{0xD75E, UNICODE_NORM_QC_NO},
+	{0xD75F, UNICODE_NORM_QC_NO},
+	{0xD760, UNICODE_NORM_QC_NO},
+	{0xD761, UNICODE_NORM_QC_NO},
+	{0xD762, UNICODE_NORM_QC_NO},
+	{0xD763, UNICODE_NORM_QC_NO},
+	{0xD764, UNICODE_NORM_QC_NO},
+	{0xD765, UNICODE_NORM_QC_NO},
+	{0xD766, UNICODE_NORM_QC_NO},
+	{0xD767, UNICODE_NORM_QC_NO},
+	{0xD768, UNICODE_NORM_QC_NO},
+	{0xD769, UNICODE_NORM_QC_NO},
+	{0xD76A, UNICODE_NORM_QC_NO},
+	{0xD76B, UNICODE_NORM_QC_NO},
+	{0xD76C, UNICODE_NORM_QC_NO},
+	{0xD76D, UNICODE_NORM_QC_NO},
+	{0xD76E, UNICODE_NORM_QC_NO},
+	{0xD76F, UNICODE_NORM_QC_NO},
+	{0xD770, UNICODE_NORM_QC_NO},
+	{0xD771, UNICODE_NORM_QC_NO},
+	{0xD772, UNICODE_NORM_QC_NO},
+	{0xD773, UNICODE_NORM_QC_NO},
+	{0xD774, UNICODE_NORM_QC_NO},
+	{0xD775, UNICODE_NORM_QC_NO},
+	{0xD776, UNICODE_NORM_QC_NO},
+	{0xD777, UNICODE_NORM_QC_NO},
+	{0xD778, UNICODE_NORM_QC_NO},
+	{0xD779, UNICODE_NORM_QC_NO},
+	{0xD77A, UNICODE_NORM_QC_NO},
+	{0xD77B, UNICODE_NORM_QC_NO},
+	{0xD77C, UNICODE_NORM_QC_NO},
+	{0xD77D, UNICODE_NORM_QC_NO},
+	{0xD77E, UNICODE_NORM_QC_NO},
+	{0xD77F, UNICODE_NORM_QC_NO},
+	{0xD780, UNICODE_NORM_QC_NO},
+	{0xD781, UNICODE_NORM_QC_NO},
+	{0xD782, UNICODE_NORM_QC_NO},
+	{0xD783, UNICODE_NORM_QC_NO},
+	{0xD784, UNICODE_NORM_QC_NO},
+	{0xD785, UNICODE_NORM_QC_NO},
+	{0xD786, UNICODE_NORM_QC_NO},
+	{0xD787, UNICODE_NORM_QC_NO},
+	{0xD788, UNICODE_NORM_QC_NO},
+	{0xD789, UNICODE_NORM_QC_NO},
+	{0xD78A, UNICODE_NORM_QC_NO},
+	{0xD78B, UNICODE_NORM_QC_NO},
+	{0xD78C, UNICODE_NORM_QC_NO},
+	{0xD78D, UNICODE_NORM_QC_NO},
+	{0xD78E, UNICODE_NORM_QC_NO},
+	{0xD78F, UNICODE_NORM_QC_NO},
+	{0xD790, UNICODE_NORM_QC_NO},
+	{0xD791, UNICODE_NORM_QC_NO},
+	{0xD792, UNICODE_NORM_QC_NO},
+	{0xD793, UNICODE_NORM_QC_NO},
+	{0xD794, UNICODE_NORM_QC_NO},
+	{0xD795, UNICODE_NORM_QC_NO},
+	{0xD796, UNICODE_NORM_QC_NO},
+	{0xD797, UNICODE_NORM_QC_NO},
+	{0xD798, UNICODE_NORM_QC_NO},
+	{0xD799, UNICODE_NORM_QC_NO},
+	{0xD79A, UNICODE_NORM_QC_NO},
+	{0xD79B, UNICODE_NORM_QC_NO},
+	{0xD79C, UNICODE_NORM_QC_NO},
+	{0xD79D, UNICODE_NORM_QC_NO},
+	{0xD79E, UNICODE_NORM_QC_NO},
+	{0xD79F, UNICODE_NORM_QC_NO},
+	{0xD7A0, UNICODE_NORM_QC_NO},
+	{0xD7A1, UNICODE_NORM_QC_NO},
+	{0xD7A2, UNICODE_NORM_QC_NO},
+	{0xD7A3, UNICODE_NORM_QC_NO},
+	{0xF900, UNICODE_NORM_QC_NO},
+	{0xF901, UNICODE_NORM_QC_NO},
+	{0xF902, UNICODE_NORM_QC_NO},
+	{0xF903, UNICODE_NORM_QC_NO},
+	{0xF904, UNICODE_NORM_QC_NO},
+	{0xF905, UNICODE_NORM_QC_NO},
+	{0xF906, UNICODE_NORM_QC_NO},
+	{0xF907, UNICODE_NORM_QC_NO},
+	{0xF908, UNICODE_NORM_QC_NO},
+	{0xF909, UNICODE_NORM_QC_NO},
+	{0xF90A, UNICODE_NORM_QC_NO},
+	{0xF90B, UNICODE_NORM_QC_NO},
+	{0xF90C, UNICODE_NORM_QC_NO},
+	{0xF90D, UNICODE_NORM_QC_NO},
+	{0xF90E, UNICODE_NORM_QC_NO},
+	{0xF90F, UNICODE_NORM_QC_NO},
+	{0xF910, UNICODE_NORM_QC_NO},
+	{0xF911, UNICODE_NORM_QC_NO},
+	{0xF912, UNICODE_NORM_QC_NO},
+	{0xF913, UNICODE_NORM_QC_NO},
+	{0xF914, UNICODE_NORM_QC_NO},
+	{0xF915, UNICODE_NORM_QC_NO},
+	{0xF916, UNICODE_NORM_QC_NO},
+	{0xF917, UNICODE_NORM_QC_NO},
+	{0xF918, UNICODE_NORM_QC_NO},
+	{0xF919, UNICODE_NORM_QC_NO},
+	{0xF91A, UNICODE_NORM_QC_NO},
+	{0xF91B, UNICODE_NORM_QC_NO},
+	{0xF91C, UNICODE_NORM_QC_NO},
+	{0xF91D, UNICODE_NORM_QC_NO},
+	{0xF91E, UNICODE_NORM_QC_NO},
+	{0xF91F, UNICODE_NORM_QC_NO},
+	{0xF920, UNICODE_NORM_QC_NO},
+	{0xF921, UNICODE_NORM_QC_NO},
+	{0xF922, UNICODE_NORM_QC_NO},
+	{0xF923, UNICODE_NORM_QC_NO},
+	{0xF924, UNICODE_NORM_QC_NO},
+	{0xF925, UNICODE_NORM_QC_NO},
+	{0xF926, UNICODE_NORM_QC_NO},
+	{0xF927, UNICODE_NORM_QC_NO},
+	{0xF928, UNICODE_NORM_QC_NO},
+	{0xF929, UNICODE_NORM_QC_NO},
+	{0xF92A, UNICODE_NORM_QC_NO},
+	{0xF92B, UNICODE_NORM_QC_NO},
+	{0xF92C, UNICODE_NORM_QC_NO},
+	{0xF92D, UNICODE_NORM_QC_NO},
+	{0xF92E, UNICODE_NORM_QC_NO},
+	{0xF92F, UNICODE_NORM_QC_NO},
+	{0xF930, UNICODE_NORM_QC_NO},
+	{0xF931, UNICODE_NORM_QC_NO},
+	{0xF932, UNICODE_NORM_QC_NO},
+	{0xF933, UNICODE_NORM_QC_NO},
+	{0xF934, UNICODE_NORM_QC_NO},
+	{0xF935, UNICODE_NORM_QC_NO},
+	{0xF936, UNICODE_NORM_QC_NO},
+	{0xF937, UNICODE_NORM_QC_NO},
+	{0xF938, UNICODE_NORM_QC_NO},
+	{0xF939, UNICODE_NORM_QC_NO},
+	{0xF93A, UNICODE_NORM_QC_NO},
+	{0xF93B, UNICODE_NORM_QC_NO},
+	{0xF93C, UNICODE_NORM_QC_NO},
+	{0xF93D, UNICODE_NORM_QC_NO},
+	{0xF93E, UNICODE_NORM_QC_NO},
+	{0xF93F, UNICODE_NORM_QC_NO},
+	{0xF940, UNICODE_NORM_QC_NO},
+	{0xF941, UNICODE_NORM_QC_NO},
+	{0xF942, UNICODE_NORM_QC_NO},
+	{0xF943, UNICODE_NORM_QC_NO},
+	{0xF944, UNICODE_NORM_QC_NO},
+	{0xF945, UNICODE_NORM_QC_NO},
+	{0xF946, UNICODE_NORM_QC_NO},
+	{0xF947, UNICODE_NORM_QC_NO},
+	{0xF948, UNICODE_NORM_QC_NO},
+	{0xF949, UNICODE_NORM_QC_NO},
+	{0xF94A, UNICODE_NORM_QC_NO},
+	{0xF94B, UNICODE_NORM_QC_NO},
+	{0xF94C, UNICODE_NORM_QC_NO},
+	{0xF94D, UNICODE_NORM_QC_NO},
+	{0xF94E, UNICODE_NORM_QC_NO},
+	{0xF94F, UNICODE_NORM_QC_NO},
+	{0xF950, UNICODE_NORM_QC_NO},
+	{0xF951, UNICODE_NORM_QC_NO},
+	{0xF952, UNICODE_NORM_QC_NO},
+	{0xF953, UNICODE_NORM_QC_NO},
+	{0xF954, UNICODE_NORM_QC_NO},
+	{0xF955, UNICODE_NORM_QC_NO},
+	{0xF956, UNICODE_NORM_QC_NO},
+	{0xF957, UNICODE_NORM_QC_NO},
+	{0xF958, UNICODE_NORM_QC_NO},
+	{0xF959, UNICODE_NORM_QC_NO},
+	{0xF95A, UNICODE_NORM_QC_NO},
+	{0xF95B, UNICODE_NORM_QC_NO},
+	{0xF95C, UNICODE_NORM_QC_NO},
+	{0xF95D, UNICODE_NORM_QC_NO},
+	{0xF95E, UNICODE_NORM_QC_NO},
+	{0xF95F, UNICODE_NORM_QC_NO},
+	{0xF960, UNICODE_NORM_QC_NO},
+	{0xF961, UNICODE_NORM_QC_NO},
+	{0xF962, UNICODE_NORM_QC_NO},
+	{0xF963, UNICODE_NORM_QC_NO},
+	{0xF964, UNICODE_NORM_QC_NO},
+	{0xF965, UNICODE_NORM_QC_NO},
+	{0xF966, UNICODE_NORM_QC_NO},
+	{0xF967, UNICODE_NORM_QC_NO},
+	{0xF968, UNICODE_NORM_QC_NO},
+	{0xF969, UNICODE_NORM_QC_NO},
+	{0xF96A, UNICODE_NORM_QC_NO},
+	{0xF96B, UNICODE_NORM_QC_NO},
+	{0xF96C, UNICODE_NORM_QC_NO},
+	{0xF96D, UNICODE_NORM_QC_NO},
+	{0xF96E, UNICODE_NORM_QC_NO},
+	{0xF96F, UNICODE_NORM_QC_NO},
+	{0xF970, UNICODE_NORM_QC_NO},
+	{0xF971, UNICODE_NORM_QC_NO},
+	{0xF972, UNICODE_NORM_QC_NO},
+	{0xF973, UNICODE_NORM_QC_NO},
+	{0xF974, UNICODE_NORM_QC_NO},
+	{0xF975, UNICODE_NORM_QC_NO},
+	{0xF976, UNICODE_NORM_QC_NO},
+	{0xF977, UNICODE_NORM_QC_NO},
+	{0xF978, UNICODE_NORM_QC_NO},
+	{0xF979, UNICODE_NORM_QC_NO},
+	{0xF97A, UNICODE_NORM_QC_NO},
+	{0xF97B, UNICODE_NORM_QC_NO},
+	{0xF97C, UNICODE_NORM_QC_NO},
+	{0xF97D, UNICODE_NORM_QC_NO},
+	{0xF97E, UNICODE_NORM_QC_NO},
+	{0xF97F, UNICODE_NORM_QC_NO},
+	{0xF980, UNICODE_NORM_QC_NO},
+	{0xF981, UNICODE_NORM_QC_NO},
+	{0xF982, UNICODE_NORM_QC_NO},
+	{0xF983, UNICODE_NORM_QC_NO},
+	{0xF984, UNICODE_NORM_QC_NO},
+	{0xF985, UNICODE_NORM_QC_NO},
+	{0xF986, UNICODE_NORM_QC_NO},
+	{0xF987, UNICODE_NORM_QC_NO},
+	{0xF988, UNICODE_NORM_QC_NO},
+	{0xF989, UNICODE_NORM_QC_NO},
+	{0xF98A, UNICODE_NORM_QC_NO},
+	{0xF98B, UNICODE_NORM_QC_NO},
+	{0xF98C, UNICODE_NORM_QC_NO},
+	{0xF98D, UNICODE_NORM_QC_NO},
+	{0xF98E, UNICODE_NORM_QC_NO},
+	{0xF98F, UNICODE_NORM_QC_NO},
+	{0xF990, UNICODE_NORM_QC_NO},
+	{0xF991, UNICODE_NORM_QC_NO},
+	{0xF992, UNICODE_NORM_QC_NO},
+	{0xF993, UNICODE_NORM_QC_NO},
+	{0xF994, UNICODE_NORM_QC_NO},
+	{0xF995, UNICODE_NORM_QC_NO},
+	{0xF996, UNICODE_NORM_QC_NO},
+	{0xF997, UNICODE_NORM_QC_NO},
+	{0xF998, UNICODE_NORM_QC_NO},
+	{0xF999, UNICODE_NORM_QC_NO},
+	{0xF99A, UNICODE_NORM_QC_NO},
+	{0xF99B, UNICODE_NORM_QC_NO},
+	{0xF99C, UNICODE_NORM_QC_NO},
+	{0xF99D, UNICODE_NORM_QC_NO},
+	{0xF99E, UNICODE_NORM_QC_NO},
+	{0xF99F, UNICODE_NORM_QC_NO},
+	{0xF9A0, UNICODE_NORM_QC_NO},
+	{0xF9A1, UNICODE_NORM_QC_NO},
+	{0xF9A2, UNICODE_NORM_QC_NO},
+	{0xF9A3, UNICODE_NORM_QC_NO},
+	{0xF9A4, UNICODE_NORM_QC_NO},
+	{0xF9A5, UNICODE_NORM_QC_NO},
+	{0xF9A6, UNICODE_NORM_QC_NO},
+	{0xF9A7, UNICODE_NORM_QC_NO},
+	{0xF9A8, UNICODE_NORM_QC_NO},
+	{0xF9A9, UNICODE_NORM_QC_NO},
+	{0xF9AA, UNICODE_NORM_QC_NO},
+	{0xF9AB, UNICODE_NORM_QC_NO},
+	{0xF9AC, UNICODE_NORM_QC_NO},
+	{0xF9AD, UNICODE_NORM_QC_NO},
+	{0xF9AE, UNICODE_NORM_QC_NO},
+	{0xF9AF, UNICODE_NORM_QC_NO},
+	{0xF9B0, UNICODE_NORM_QC_NO},
+	{0xF9B1, UNICODE_NORM_QC_NO},
+	{0xF9B2, UNICODE_NORM_QC_NO},
+	{0xF9B3, UNICODE_NORM_QC_NO},
+	{0xF9B4, UNICODE_NORM_QC_NO},
+	{0xF9B5, UNICODE_NORM_QC_NO},
+	{0xF9B6, UNICODE_NORM_QC_NO},
+	{0xF9B7, UNICODE_NORM_QC_NO},
+	{0xF9B8, UNICODE_NORM_QC_NO},
+	{0xF9B9, UNICODE_NORM_QC_NO},
+	{0xF9BA, UNICODE_NORM_QC_NO},
+	{0xF9BB, UNICODE_NORM_QC_NO},
+	{0xF9BC, UNICODE_NORM_QC_NO},
+	{0xF9BD, UNICODE_NORM_QC_NO},
+	{0xF9BE, UNICODE_NORM_QC_NO},
+	{0xF9BF, UNICODE_NORM_QC_NO},
+	{0xF9C0, UNICODE_NORM_QC_NO},
+	{0xF9C1, UNICODE_NORM_QC_NO},
+	{0xF9C2, UNICODE_NORM_QC_NO},
+	{0xF9C3, UNICODE_NORM_QC_NO},
+	{0xF9C4, UNICODE_NORM_QC_NO},
+	{0xF9C5, UNICODE_NORM_QC_NO},
+	{0xF9C6, UNICODE_NORM_QC_NO},
+	{0xF9C7, UNICODE_NORM_QC_NO},
+	{0xF9C8, UNICODE_NORM_QC_NO},
+	{0xF9C9, UNICODE_NORM_QC_NO},
+	{0xF9CA, UNICODE_NORM_QC_NO},
+	{0xF9CB, UNICODE_NORM_QC_NO},
+	{0xF9CC, UNICODE_NORM_QC_NO},
+	{0xF9CD, UNICODE_NORM_QC_NO},
+	{0xF9CE, UNICODE_NORM_QC_NO},
+	{0xF9CF, UNICODE_NORM_QC_NO},
+	{0xF9D0, UNICODE_NORM_QC_NO},
+	{0xF9D1, UNICODE_NORM_QC_NO},
+	{0xF9D2, UNICODE_NORM_QC_NO},
+	{0xF9D3, UNICODE_NORM_QC_NO},
+	{0xF9D4, UNICODE_NORM_QC_NO},
+	{0xF9D5, UNICODE_NORM_QC_NO},
+	{0xF9D6, UNICODE_NORM_QC_NO},
+	{0xF9D7, UNICODE_NORM_QC_NO},
+	{0xF9D8, UNICODE_NORM_QC_NO},
+	{0xF9D9, UNICODE_NORM_QC_NO},
+	{0xF9DA, UNICODE_NORM_QC_NO},
+	{0xF9DB, UNICODE_NORM_QC_NO},
+	{0xF9DC, UNICODE_NORM_QC_NO},
+	{0xF9DD, UNICODE_NORM_QC_NO},
+	{0xF9DE, UNICODE_NORM_QC_NO},
+	{0xF9DF, UNICODE_NORM_QC_NO},
+	{0xF9E0, UNICODE_NORM_QC_NO},
+	{0xF9E1, UNICODE_NORM_QC_NO},
+	{0xF9E2, UNICODE_NORM_QC_NO},
+	{0xF9E3, UNICODE_NORM_QC_NO},
+	{0xF9E4, UNICODE_NORM_QC_NO},
+	{0xF9E5, UNICODE_NORM_QC_NO},
+	{0xF9E6, UNICODE_NORM_QC_NO},
+	{0xF9E7, UNICODE_NORM_QC_NO},
+	{0xF9E8, UNICODE_NORM_QC_NO},
+	{0xF9E9, UNICODE_NORM_QC_NO},
+	{0xF9EA, UNICODE_NORM_QC_NO},
+	{0xF9EB, UNICODE_NORM_QC_NO},
+	{0xF9EC, UNICODE_NORM_QC_NO},
+	{0xF9ED, UNICODE_NORM_QC_NO},
+	{0xF9EE, UNICODE_NORM_QC_NO},
+	{0xF9EF, UNICODE_NORM_QC_NO},
+	{0xF9F0, UNICODE_NORM_QC_NO},
+	{0xF9F1, UNICODE_NORM_QC_NO},
+	{0xF9F2, UNICODE_NORM_QC_NO},
+	{0xF9F3, UNICODE_NORM_QC_NO},
+	{0xF9F4, UNICODE_NORM_QC_NO},
+	{0xF9F5, UNICODE_NORM_QC_NO},
+	{0xF9F6, UNICODE_NORM_QC_NO},
+	{0xF9F7, UNICODE_NORM_QC_NO},
+	{0xF9F8, UNICODE_NORM_QC_NO},
+	{0xF9F9, UNICODE_NORM_QC_NO},
+	{0xF9FA, UNICODE_NORM_QC_NO},
+	{0xF9FB, UNICODE_NORM_QC_NO},
+	{0xF9FC, UNICODE_NORM_QC_NO},
+	{0xF9FD, UNICODE_NORM_QC_NO},
+	{0xF9FE, UNICODE_NORM_QC_NO},
+	{0xF9FF, UNICODE_NORM_QC_NO},
+	{0xFA00, UNICODE_NORM_QC_NO},
+	{0xFA01, UNICODE_NORM_QC_NO},
+	{0xFA02, UNICODE_NORM_QC_NO},
+	{0xFA03, UNICODE_NORM_QC_NO},
+	{0xFA04, UNICODE_NORM_QC_NO},
+	{0xFA05, UNICODE_NORM_QC_NO},
+	{0xFA06, UNICODE_NORM_QC_NO},
+	{0xFA07, UNICODE_NORM_QC_NO},
+	{0xFA08, UNICODE_NORM_QC_NO},
+	{0xFA09, UNICODE_NORM_QC_NO},
+	{0xFA0A, UNICODE_NORM_QC_NO},
+	{0xFA0B, UNICODE_NORM_QC_NO},
+	{0xFA0C, UNICODE_NORM_QC_NO},
+	{0xFA0D, UNICODE_NORM_QC_NO},
+	{0xFA10, UNICODE_NORM_QC_NO},
+	{0xFA12, UNICODE_NORM_QC_NO},
+	{0xFA15, UNICODE_NORM_QC_NO},
+	{0xFA16, UNICODE_NORM_QC_NO},
+	{0xFA17, UNICODE_NORM_QC_NO},
+	{0xFA18, UNICODE_NORM_QC_NO},
+	{0xFA19, UNICODE_NORM_QC_NO},
+	{0xFA1A, UNICODE_NORM_QC_NO},
+	{0xFA1B, UNICODE_NORM_QC_NO},
+	{0xFA1C, UNICODE_NORM_QC_NO},
+	{0xFA1D, UNICODE_NORM_QC_NO},
+	{0xFA1E, UNICODE_NORM_QC_NO},
+	{0xFA20, UNICODE_NORM_QC_NO},
+	{0xFA22, UNICODE_NORM_QC_NO},
+	{0xFA25, UNICODE_NORM_QC_NO},
+	{0xFA26, UNICODE_NORM_QC_NO},
+	{0xFA2A, UNICODE_NORM_QC_NO},
+	{0xFA2B, UNICODE_NORM_QC_NO},
+	{0xFA2C, UNICODE_NORM_QC_NO},
+	{0xFA2D, UNICODE_NORM_QC_NO},
+	{0xFA2E, UNICODE_NORM_QC_NO},
+	{0xFA2F, UNICODE_NORM_QC_NO},
+	{0xFA30, UNICODE_NORM_QC_NO},
+	{0xFA31, UNICODE_NORM_QC_NO},
+	{0xFA32, UNICODE_NORM_QC_NO},
+	{0xFA33, UNICODE_NORM_QC_NO},
+	{0xFA34, UNICODE_NORM_QC_NO},
+	{0xFA35, UNICODE_NORM_QC_NO},
+	{0xFA36, UNICODE_NORM_QC_NO},
+	{0xFA37, UNICODE_NORM_QC_NO},
+	{0xFA38, UNICODE_NORM_QC_NO},
+	{0xFA39, UNICODE_NORM_QC_NO},
+	{0xFA3A, UNICODE_NORM_QC_NO},
+	{0xFA3B, UNICODE_NORM_QC_NO},
+	{0xFA3C, UNICODE_NORM_QC_NO},
+	{0xFA3D, UNICODE_NORM_QC_NO},
+	{0xFA3E, UNICODE_NORM_QC_NO},
+	{0xFA3F, UNICODE_NORM_QC_NO},
+	{0xFA40, UNICODE_NORM_QC_NO},
+	{0xFA41, UNICODE_NORM_QC_NO},
+	{0xFA42, UNICODE_NORM_QC_NO},
+	{0xFA43, UNICODE_NORM_QC_NO},
+	{0xFA44, UNICODE_NORM_QC_NO},
+	{0xFA45, UNICODE_NORM_QC_NO},
+	{0xFA46, UNICODE_NORM_QC_NO},
+	{0xFA47, UNICODE_NORM_QC_NO},
+	{0xFA48, UNICODE_NORM_QC_NO},
+	{0xFA49, UNICODE_NORM_QC_NO},
+	{0xFA4A, UNICODE_NORM_QC_NO},
+	{0xFA4B, UNICODE_NORM_QC_NO},
+	{0xFA4C, UNICODE_NORM_QC_NO},
+	{0xFA4D, UNICODE_NORM_QC_NO},
+	{0xFA4E, UNICODE_NORM_QC_NO},
+	{0xFA4F, UNICODE_NORM_QC_NO},
+	{0xFA50, UNICODE_NORM_QC_NO},
+	{0xFA51, UNICODE_NORM_QC_NO},
+	{0xFA52, UNICODE_NORM_QC_NO},
+	{0xFA53, UNICODE_NORM_QC_NO},
+	{0xFA54, UNICODE_NORM_QC_NO},
+	{0xFA55, UNICODE_NORM_QC_NO},
+	{0xFA56, UNICODE_NORM_QC_NO},
+	{0xFA57, UNICODE_NORM_QC_NO},
+	{0xFA58, UNICODE_NORM_QC_NO},
+	{0xFA59, UNICODE_NORM_QC_NO},
+	{0xFA5A, UNICODE_NORM_QC_NO},
+	{0xFA5B, UNICODE_NORM_QC_NO},
+	{0xFA5C, UNICODE_NORM_QC_NO},
+	{0xFA5D, UNICODE_NORM_QC_NO},
+	{0xFA5E, UNICODE_NORM_QC_NO},
+	{0xFA5F, UNICODE_NORM_QC_NO},
+	{0xFA60, UNICODE_NORM_QC_NO},
+	{0xFA61, UNICODE_NORM_QC_NO},
+	{0xFA62, UNICODE_NORM_QC_NO},
+	{0xFA63, UNICODE_NORM_QC_NO},
+	{0xFA64, UNICODE_NORM_QC_NO},
+	{0xFA65, UNICODE_NORM_QC_NO},
+	{0xFA66, UNICODE_NORM_QC_NO},
+	{0xFA67, UNICODE_NORM_QC_NO},
+	{0xFA68, UNICODE_NORM_QC_NO},
+	{0xFA69, UNICODE_NORM_QC_NO},
+	{0xFA6A, UNICODE_NORM_QC_NO},
+	{0xFA6B, UNICODE_NORM_QC_NO},
+	{0xFA6C, UNICODE_NORM_QC_NO},
+	{0xFA6D, UNICODE_NORM_QC_NO},
+	{0xFA70, UNICODE_NORM_QC_NO},
+	{0xFA71, UNICODE_NORM_QC_NO},
+	{0xFA72, UNICODE_NORM_QC_NO},
+	{0xFA73, UNICODE_NORM_QC_NO},
+	{0xFA74, UNICODE_NORM_QC_NO},
+	{0xFA75, UNICODE_NORM_QC_NO},
+	{0xFA76, UNICODE_NORM_QC_NO},
+	{0xFA77, UNICODE_NORM_QC_NO},
+	{0xFA78, UNICODE_NORM_QC_NO},
+	{0xFA79, UNICODE_NORM_QC_NO},
+	{0xFA7A, UNICODE_NORM_QC_NO},
+	{0xFA7B, UNICODE_NORM_QC_NO},
+	{0xFA7C, UNICODE_NORM_QC_NO},
+	{0xFA7D, UNICODE_NORM_QC_NO},
+	{0xFA7E, UNICODE_NORM_QC_NO},
+	{0xFA7F, UNICODE_NORM_QC_NO},
+	{0xFA80, UNICODE_NORM_QC_NO},
+	{0xFA81, UNICODE_NORM_QC_NO},
+	{0xFA82, UNICODE_NORM_QC_NO},
+	{0xFA83, UNICODE_NORM_QC_NO},
+	{0xFA84, UNICODE_NORM_QC_NO},
+	{0xFA85, UNICODE_NORM_QC_NO},
+	{0xFA86, UNICODE_NORM_QC_NO},
+	{0xFA87, UNICODE_NORM_QC_NO},
+	{0xFA88, UNICODE_NORM_QC_NO},
+	{0xFA89, UNICODE_NORM_QC_NO},
+	{0xFA8A, UNICODE_NORM_QC_NO},
+	{0xFA8B, UNICODE_NORM_QC_NO},
+	{0xFA8C, UNICODE_NORM_QC_NO},
+	{0xFA8D, UNICODE_NORM_QC_NO},
+	{0xFA8E, UNICODE_NORM_QC_NO},
+	{0xFA8F, UNICODE_NORM_QC_NO},
+	{0xFA90, UNICODE_NORM_QC_NO},
+	{0xFA91, UNICODE_NORM_QC_NO},
+	{0xFA92, UNICODE_NORM_QC_NO},
+	{0xFA93, UNICODE_NORM_QC_NO},
+	{0xFA94, UNICODE_NORM_QC_NO},
+	{0xFA95, UNICODE_NORM_QC_NO},
+	{0xFA96, UNICODE_NORM_QC_NO},
+	{0xFA97, UNICODE_NORM_QC_NO},
+	{0xFA98, UNICODE_NORM_QC_NO},
+	{0xFA99, UNICODE_NORM_QC_NO},
+	{0xFA9A, UNICODE_NORM_QC_NO},
+	{0xFA9B, UNICODE_NORM_QC_NO},
+	{0xFA9C, UNICODE_NORM_QC_NO},
+	{0xFA9D, UNICODE_NORM_QC_NO},
+	{0xFA9E, UNICODE_NORM_QC_NO},
+	{0xFA9F, UNICODE_NORM_QC_NO},
+	{0xFAA0, UNICODE_NORM_QC_NO},
+	{0xFAA1, UNICODE_NORM_QC_NO},
+	{0xFAA2, UNICODE_NORM_QC_NO},
+	{0xFAA3, UNICODE_NORM_QC_NO},
+	{0xFAA4, UNICODE_NORM_QC_NO},
+	{0xFAA5, UNICODE_NORM_QC_NO},
+	{0xFAA6, UNICODE_NORM_QC_NO},
+	{0xFAA7, UNICODE_NORM_QC_NO},
+	{0xFAA8, UNICODE_NORM_QC_NO},
+	{0xFAA9, UNICODE_NORM_QC_NO},
+	{0xFAAA, UNICODE_NORM_QC_NO},
+	{0xFAAB, UNICODE_NORM_QC_NO},
+	{0xFAAC, UNICODE_NORM_QC_NO},
+	{0xFAAD, UNICODE_NORM_QC_NO},
+	{0xFAAE, UNICODE_NORM_QC_NO},
+	{0xFAAF, UNICODE_NORM_QC_NO},
+	{0xFAB0, UNICODE_NORM_QC_NO},
+	{0xFAB1, UNICODE_NORM_QC_NO},
+	{0xFAB2, UNICODE_NORM_QC_NO},
+	{0xFAB3, UNICODE_NORM_QC_NO},
+	{0xFAB4, UNICODE_NORM_QC_NO},
+	{0xFAB5, UNICODE_NORM_QC_NO},
+	{0xFAB6, UNICODE_NORM_QC_NO},
+	{0xFAB7, UNICODE_NORM_QC_NO},
+	{0xFAB8, UNICODE_NORM_QC_NO},
+	{0xFAB9, UNICODE_NORM_QC_NO},
+	{0xFABA, UNICODE_NORM_QC_NO},
+	{0xFABB, UNICODE_NORM_QC_NO},
+	{0xFABC, UNICODE_NORM_QC_NO},
+	{0xFABD, UNICODE_NORM_QC_NO},
+	{0xFABE, UNICODE_NORM_QC_NO},
+	{0xFABF, UNICODE_NORM_QC_NO},
+	{0xFAC0, UNICODE_NORM_QC_NO},
+	{0xFAC1, UNICODE_NORM_QC_NO},
+	{0xFAC2, UNICODE_NORM_QC_NO},
+	{0xFAC3, UNICODE_NORM_QC_NO},
+	{0xFAC4, UNICODE_NORM_QC_NO},
+	{0xFAC5, UNICODE_NORM_QC_NO},
+	{0xFAC6, UNICODE_NORM_QC_NO},
+	{0xFAC7, UNICODE_NORM_QC_NO},
+	{0xFAC8, UNICODE_NORM_QC_NO},
+	{0xFAC9, UNICODE_NORM_QC_NO},
+	{0xFACA, UNICODE_NORM_QC_NO},
+	{0xFACB, UNICODE_NORM_QC_NO},
+	{0xFACC, UNICODE_NORM_QC_NO},
+	{0xFACD, UNICODE_NORM_QC_NO},
+	{0xFACE, UNICODE_NORM_QC_NO},
+	{0xFACF, UNICODE_NORM_QC_NO},
+	{0xFAD0, UNICODE_NORM_QC_NO},
+	{0xFAD1, UNICODE_NORM_QC_NO},
+	{0xFAD2, UNICODE_NORM_QC_NO},
+	{0xFAD3, UNICODE_NORM_QC_NO},
+	{0xFAD4, UNICODE_NORM_QC_NO},
+	{0xFAD5, UNICODE_NORM_QC_NO},
+	{0xFAD6, UNICODE_NORM_QC_NO},
+	{0xFAD7, UNICODE_NORM_QC_NO},
+	{0xFAD8, UNICODE_NORM_QC_NO},
+	{0xFAD9, UNICODE_NORM_QC_NO},
+	{0xFB00, UNICODE_NORM_QC_NO},
+	{0xFB01, UNICODE_NORM_QC_NO},
+	{0xFB02, UNICODE_NORM_QC_NO},
+	{0xFB03, UNICODE_NORM_QC_NO},
+	{0xFB04, UNICODE_NORM_QC_NO},
+	{0xFB05, UNICODE_NORM_QC_NO},
+	{0xFB06, UNICODE_NORM_QC_NO},
+	{0xFB13, UNICODE_NORM_QC_NO},
+	{0xFB14, UNICODE_NORM_QC_NO},
+	{0xFB15, UNICODE_NORM_QC_NO},
+	{0xFB16, UNICODE_NORM_QC_NO},
+	{0xFB17, UNICODE_NORM_QC_NO},
+	{0xFB1D, UNICODE_NORM_QC_NO},
+	{0xFB1F, UNICODE_NORM_QC_NO},
+	{0xFB20, UNICODE_NORM_QC_NO},
+	{0xFB21, UNICODE_NORM_QC_NO},
+	{0xFB22, UNICODE_NORM_QC_NO},
+	{0xFB23, UNICODE_NORM_QC_NO},
+	{0xFB24, UNICODE_NORM_QC_NO},
+	{0xFB25, UNICODE_NORM_QC_NO},
+	{0xFB26, UNICODE_NORM_QC_NO},
+	{0xFB27, UNICODE_NORM_QC_NO},
+	{0xFB28, UNICODE_NORM_QC_NO},
+	{0xFB29, UNICODE_NORM_QC_NO},
+	{0xFB2A, UNICODE_NORM_QC_NO},
+	{0xFB2B, UNICODE_NORM_QC_NO},
+	{0xFB2C, UNICODE_NORM_QC_NO},
+	{0xFB2D, UNICODE_NORM_QC_NO},
+	{0xFB2E, UNICODE_NORM_QC_NO},
+	{0xFB2F, UNICODE_NORM_QC_NO},
+	{0xFB30, UNICODE_NORM_QC_NO},
+	{0xFB31, UNICODE_NORM_QC_NO},
+	{0xFB32, UNICODE_NORM_QC_NO},
+	{0xFB33, UNICODE_NORM_QC_NO},
+	{0xFB34, UNICODE_NORM_QC_NO},
+	{0xFB35, UNICODE_NORM_QC_NO},
+	{0xFB36, UNICODE_NORM_QC_NO},
+	{0xFB38, UNICODE_NORM_QC_NO},
+	{0xFB39, UNICODE_NORM_QC_NO},
+	{0xFB3A, UNICODE_NORM_QC_NO},
+	{0xFB3B, UNICODE_NORM_QC_NO},
+	{0xFB3C, UNICODE_NORM_QC_NO},
+	{0xFB3E, UNICODE_NORM_QC_NO},
+	{0xFB40, UNICODE_NORM_QC_NO},
+	{0xFB41, UNICODE_NORM_QC_NO},
+	{0xFB43, UNICODE_NORM_QC_NO},
+	{0xFB44, UNICODE_NORM_QC_NO},
+	{0xFB46, UNICODE_NORM_QC_NO},
+	{0xFB47, UNICODE_NORM_QC_NO},
+	{0xFB48, UNICODE_NORM_QC_NO},
+	{0xFB49, UNICODE_NORM_QC_NO},
+	{0xFB4A, UNICODE_NORM_QC_NO},
+	{0xFB4B, UNICODE_NORM_QC_NO},
+	{0xFB4C, UNICODE_NORM_QC_NO},
+	{0xFB4D, UNICODE_NORM_QC_NO},
+	{0xFB4E, UNICODE_NORM_QC_NO},
+	{0xFB4F, UNICODE_NORM_QC_NO},
+	{0xFB50, UNICODE_NORM_QC_NO},
+	{0xFB51, UNICODE_NORM_QC_NO},
+	{0xFB52, UNICODE_NORM_QC_NO},
+	{0xFB53, UNICODE_NORM_QC_NO},
+	{0xFB54, UNICODE_NORM_QC_NO},
+	{0xFB55, UNICODE_NORM_QC_NO},
+	{0xFB56, UNICODE_NORM_QC_NO},
+	{0xFB57, UNICODE_NORM_QC_NO},
+	{0xFB58, UNICODE_NORM_QC_NO},
+	{0xFB59, UNICODE_NORM_QC_NO},
+	{0xFB5A, UNICODE_NORM_QC_NO},
+	{0xFB5B, UNICODE_NORM_QC_NO},
+	{0xFB5C, UNICODE_NORM_QC_NO},
+	{0xFB5D, UNICODE_NORM_QC_NO},
+	{0xFB5E, UNICODE_NORM_QC_NO},
+	{0xFB5F, UNICODE_NORM_QC_NO},
+	{0xFB60, UNICODE_NORM_QC_NO},
+	{0xFB61, UNICODE_NORM_QC_NO},
+	{0xFB62, UNICODE_NORM_QC_NO},
+	{0xFB63, UNICODE_NORM_QC_NO},
+	{0xFB64, UNICODE_NORM_QC_NO},
+	{0xFB65, UNICODE_NORM_QC_NO},
+	{0xFB66, UNICODE_NORM_QC_NO},
+	{0xFB67, UNICODE_NORM_QC_NO},
+	{0xFB68, UNICODE_NORM_QC_NO},
+	{0xFB69, UNICODE_NORM_QC_NO},
+	{0xFB6A, UNICODE_NORM_QC_NO},
+	{0xFB6B, UNICODE_NORM_QC_NO},
+	{0xFB6C, UNICODE_NORM_QC_NO},
+	{0xFB6D, UNICODE_NORM_QC_NO},
+	{0xFB6E, UNICODE_NORM_QC_NO},
+	{0xFB6F, UNICODE_NORM_QC_NO},
+	{0xFB70, UNICODE_NORM_QC_NO},
+	{0xFB71, UNICODE_NORM_QC_NO},
+	{0xFB72, UNICODE_NORM_QC_NO},
+	{0xFB73, UNICODE_NORM_QC_NO},
+	{0xFB74, UNICODE_NORM_QC_NO},
+	{0xFB75, UNICODE_NORM_QC_NO},
+	{0xFB76, UNICODE_NORM_QC_NO},
+	{0xFB77, UNICODE_NORM_QC_NO},
+	{0xFB78, UNICODE_NORM_QC_NO},
+	{0xFB79, UNICODE_NORM_QC_NO},
+	{0xFB7A, UNICODE_NORM_QC_NO},
+	{0xFB7B, UNICODE_NORM_QC_NO},
+	{0xFB7C, UNICODE_NORM_QC_NO},
+	{0xFB7D, UNICODE_NORM_QC_NO},
+	{0xFB7E, UNICODE_NORM_QC_NO},
+	{0xFB7F, UNICODE_NORM_QC_NO},
+	{0xFB80, UNICODE_NORM_QC_NO},
+	{0xFB81, UNICODE_NORM_QC_NO},
+	{0xFB82, UNICODE_NORM_QC_NO},
+	{0xFB83, UNICODE_NORM_QC_NO},
+	{0xFB84, UNICODE_NORM_QC_NO},
+	{0xFB85, UNICODE_NORM_QC_NO},
+	{0xFB86, UNICODE_NORM_QC_NO},
+	{0xFB87, UNICODE_NORM_QC_NO},
+	{0xFB88, UNICODE_NORM_QC_NO},
+	{0xFB89, UNICODE_NORM_QC_NO},
+	{0xFB8A, UNICODE_NORM_QC_NO},
+	{0xFB8B, UNICODE_NORM_QC_NO},
+	{0xFB8C, UNICODE_NORM_QC_NO},
+	{0xFB8D, UNICODE_NORM_QC_NO},
+	{0xFB8E, UNICODE_NORM_QC_NO},
+	{0xFB8F, UNICODE_NORM_QC_NO},
+	{0xFB90, UNICODE_NORM_QC_NO},
+	{0xFB91, UNICODE_NORM_QC_NO},
+	{0xFB92, UNICODE_NORM_QC_NO},
+	{0xFB93, UNICODE_NORM_QC_NO},
+	{0xFB94, UNICODE_NORM_QC_NO},
+	{0xFB95, UNICODE_NORM_QC_NO},
+	{0xFB96, UNICODE_NORM_QC_NO},
+	{0xFB97, UNICODE_NORM_QC_NO},
+	{0xFB98, UNICODE_NORM_QC_NO},
+	{0xFB99, UNICODE_NORM_QC_NO},
+	{0xFB9A, UNICODE_NORM_QC_NO},
+	{0xFB9B, UNICODE_NORM_QC_NO},
+	{0xFB9C, UNICODE_NORM_QC_NO},
+	{0xFB9D, UNICODE_NORM_QC_NO},
+	{0xFB9E, UNICODE_NORM_QC_NO},
+	{0xFB9F, UNICODE_NORM_QC_NO},
+	{0xFBA0, UNICODE_NORM_QC_NO},
+	{0xFBA1, UNICODE_NORM_QC_NO},
+	{0xFBA2, UNICODE_NORM_QC_NO},
+	{0xFBA3, UNICODE_NORM_QC_NO},
+	{0xFBA4, UNICODE_NORM_QC_NO},
+	{0xFBA5, UNICODE_NORM_QC_NO},
+	{0xFBA6, UNICODE_NORM_QC_NO},
+	{0xFBA7, UNICODE_NORM_QC_NO},
+	{0xFBA8, UNICODE_NORM_QC_NO},
+	{0xFBA9, UNICODE_NORM_QC_NO},
+	{0xFBAA, UNICODE_NORM_QC_NO},
+	{0xFBAB, UNICODE_NORM_QC_NO},
+	{0xFBAC, UNICODE_NORM_QC_NO},
+	{0xFBAD, UNICODE_NORM_QC_NO},
+	{0xFBAE, UNICODE_NORM_QC_NO},
+	{0xFBAF, UNICODE_NORM_QC_NO},
+	{0xFBB0, UNICODE_NORM_QC_NO},
+	{0xFBB1, UNICODE_NORM_QC_NO},
+	{0xFBD3, UNICODE_NORM_QC_NO},
+	{0xFBD4, UNICODE_NORM_QC_NO},
+	{0xFBD5, UNICODE_NORM_QC_NO},
+	{0xFBD6, UNICODE_NORM_QC_NO},
+	{0xFBD7, UNICODE_NORM_QC_NO},
+	{0xFBD8, UNICODE_NORM_QC_NO},
+	{0xFBD9, UNICODE_NORM_QC_NO},
+	{0xFBDA, UNICODE_NORM_QC_NO},
+	{0xFBDB, UNICODE_NORM_QC_NO},
+	{0xFBDC, UNICODE_NORM_QC_NO},
+	{0xFBDD, UNICODE_NORM_QC_NO},
+	{0xFBDE, UNICODE_NORM_QC_NO},
+	{0xFBDF, UNICODE_NORM_QC_NO},
+	{0xFBE0, UNICODE_NORM_QC_NO},
+	{0xFBE1, UNICODE_NORM_QC_NO},
+	{0xFBE2, UNICODE_NORM_QC_NO},
+	{0xFBE3, UNICODE_NORM_QC_NO},
+	{0xFBE4, UNICODE_NORM_QC_NO},
+	{0xFBE5, UNICODE_NORM_QC_NO},
+	{0xFBE6, UNICODE_NORM_QC_NO},
+	{0xFBE7, UNICODE_NORM_QC_NO},
+	{0xFBE8, UNICODE_NORM_QC_NO},
+	{0xFBE9, UNICODE_NORM_QC_NO},
+	{0xFBEA, UNICODE_NORM_QC_NO},
+	{0xFBEB, UNICODE_NORM_QC_NO},
+	{0xFBEC, UNICODE_NORM_QC_NO},
+	{0xFBED, UNICODE_NORM_QC_NO},
+	{0xFBEE, UNICODE_NORM_QC_NO},
+	{0xFBEF, UNICODE_NORM_QC_NO},
+	{0xFBF0, UNICODE_NORM_QC_NO},
+	{0xFBF1, UNICODE_NORM_QC_NO},
+	{0xFBF2, UNICODE_NORM_QC_NO},
+	{0xFBF3, UNICODE_NORM_QC_NO},
+	{0xFBF4, UNICODE_NORM_QC_NO},
+	{0xFBF5, UNICODE_NORM_QC_NO},
+	{0xFBF6, UNICODE_NORM_QC_NO},
+	{0xFBF7, UNICODE_NORM_QC_NO},
+	{0xFBF8, UNICODE_NORM_QC_NO},
+	{0xFBF9, UNICODE_NORM_QC_NO},
+	{0xFBFA, UNICODE_NORM_QC_NO},
+	{0xFBFB, UNICODE_NORM_QC_NO},
+	{0xFBFC, UNICODE_NORM_QC_NO},
+	{0xFBFD, UNICODE_NORM_QC_NO},
+	{0xFBFE, UNICODE_NORM_QC_NO},
+	{0xFBFF, UNICODE_NORM_QC_NO},
+	{0xFC00, UNICODE_NORM_QC_NO},
+	{0xFC01, UNICODE_NORM_QC_NO},
+	{0xFC02, UNICODE_NORM_QC_NO},
+	{0xFC03, UNICODE_NORM_QC_NO},
+	{0xFC04, UNICODE_NORM_QC_NO},
+	{0xFC05, UNICODE_NORM_QC_NO},
+	{0xFC06, UNICODE_NORM_QC_NO},
+	{0xFC07, UNICODE_NORM_QC_NO},
+	{0xFC08, UNICODE_NORM_QC_NO},
+	{0xFC09, UNICODE_NORM_QC_NO},
+	{0xFC0A, UNICODE_NORM_QC_NO},
+	{0xFC0B, UNICODE_NORM_QC_NO},
+	{0xFC0C, UNICODE_NORM_QC_NO},
+	{0xFC0D, UNICODE_NORM_QC_NO},
+	{0xFC0E, UNICODE_NORM_QC_NO},
+	{0xFC0F, UNICODE_NORM_QC_NO},
+	{0xFC10, UNICODE_NORM_QC_NO},
+	{0xFC11, UNICODE_NORM_QC_NO},
+	{0xFC12, UNICODE_NORM_QC_NO},
+	{0xFC13, UNICODE_NORM_QC_NO},
+	{0xFC14, UNICODE_NORM_QC_NO},
+	{0xFC15, UNICODE_NORM_QC_NO},
+	{0xFC16, UNICODE_NORM_QC_NO},
+	{0xFC17, UNICODE_NORM_QC_NO},
+	{0xFC18, UNICODE_NORM_QC_NO},
+	{0xFC19, UNICODE_NORM_QC_NO},
+	{0xFC1A, UNICODE_NORM_QC_NO},
+	{0xFC1B, UNICODE_NORM_QC_NO},
+	{0xFC1C, UNICODE_NORM_QC_NO},
+	{0xFC1D, UNICODE_NORM_QC_NO},
+	{0xFC1E, UNICODE_NORM_QC_NO},
+	{0xFC1F, UNICODE_NORM_QC_NO},
+	{0xFC20, UNICODE_NORM_QC_NO},
+	{0xFC21, UNICODE_NORM_QC_NO},
+	{0xFC22, UNICODE_NORM_QC_NO},
+	{0xFC23, UNICODE_NORM_QC_NO},
+	{0xFC24, UNICODE_NORM_QC_NO},
+	{0xFC25, UNICODE_NORM_QC_NO},
+	{0xFC26, UNICODE_NORM_QC_NO},
+	{0xFC27, UNICODE_NORM_QC_NO},
+	{0xFC28, UNICODE_NORM_QC_NO},
+	{0xFC29, UNICODE_NORM_QC_NO},
+	{0xFC2A, UNICODE_NORM_QC_NO},
+	{0xFC2B, UNICODE_NORM_QC_NO},
+	{0xFC2C, UNICODE_NORM_QC_NO},
+	{0xFC2D, UNICODE_NORM_QC_NO},
+	{0xFC2E, UNICODE_NORM_QC_NO},
+	{0xFC2F, UNICODE_NORM_QC_NO},
+	{0xFC30, UNICODE_NORM_QC_NO},
+	{0xFC31, UNICODE_NORM_QC_NO},
+	{0xFC32, UNICODE_NORM_QC_NO},
+	{0xFC33, UNICODE_NORM_QC_NO},
+	{0xFC34, UNICODE_NORM_QC_NO},
+	{0xFC35, UNICODE_NORM_QC_NO},
+	{0xFC36, UNICODE_NORM_QC_NO},
+	{0xFC37, UNICODE_NORM_QC_NO},
+	{0xFC38, UNICODE_NORM_QC_NO},
+	{0xFC39, UNICODE_NORM_QC_NO},
+	{0xFC3A, UNICODE_NORM_QC_NO},
+	{0xFC3B, UNICODE_NORM_QC_NO},
+	{0xFC3C, UNICODE_NORM_QC_NO},
+	{0xFC3D, UNICODE_NORM_QC_NO},
+	{0xFC3E, UNICODE_NORM_QC_NO},
+	{0xFC3F, UNICODE_NORM_QC_NO},
+	{0xFC40, UNICODE_NORM_QC_NO},
+	{0xFC41, UNICODE_NORM_QC_NO},
+	{0xFC42, UNICODE_NORM_QC_NO},
+	{0xFC43, UNICODE_NORM_QC_NO},
+	{0xFC44, UNICODE_NORM_QC_NO},
+	{0xFC45, UNICODE_NORM_QC_NO},
+	{0xFC46, UNICODE_NORM_QC_NO},
+	{0xFC47, UNICODE_NORM_QC_NO},
+	{0xFC48, UNICODE_NORM_QC_NO},
+	{0xFC49, UNICODE_NORM_QC_NO},
+	{0xFC4A, UNICODE_NORM_QC_NO},
+	{0xFC4B, UNICODE_NORM_QC_NO},
+	{0xFC4C, UNICODE_NORM_QC_NO},
+	{0xFC4D, UNICODE_NORM_QC_NO},
+	{0xFC4E, UNICODE_NORM_QC_NO},
+	{0xFC4F, UNICODE_NORM_QC_NO},
+	{0xFC50, UNICODE_NORM_QC_NO},
+	{0xFC51, UNICODE_NORM_QC_NO},
+	{0xFC52, UNICODE_NORM_QC_NO},
+	{0xFC53, UNICODE_NORM_QC_NO},
+	{0xFC54, UNICODE_NORM_QC_NO},
+	{0xFC55, UNICODE_NORM_QC_NO},
+	{0xFC56, UNICODE_NORM_QC_NO},
+	{0xFC57, UNICODE_NORM_QC_NO},
+	{0xFC58, UNICODE_NORM_QC_NO},
+	{0xFC59, UNICODE_NORM_QC_NO},
+	{0xFC5A, UNICODE_NORM_QC_NO},
+	{0xFC5B, UNICODE_NORM_QC_NO},
+	{0xFC5C, UNICODE_NORM_QC_NO},
+	{0xFC5D, UNICODE_NORM_QC_NO},
+	{0xFC5E, UNICODE_NORM_QC_NO},
+	{0xFC5F, UNICODE_NORM_QC_NO},
+	{0xFC60, UNICODE_NORM_QC_NO},
+	{0xFC61, UNICODE_NORM_QC_NO},
+	{0xFC62, UNICODE_NORM_QC_NO},
+	{0xFC63, UNICODE_NORM_QC_NO},
+	{0xFC64, UNICODE_NORM_QC_NO},
+	{0xFC65, UNICODE_NORM_QC_NO},
+	{0xFC66, UNICODE_NORM_QC_NO},
+	{0xFC67, UNICODE_NORM_QC_NO},
+	{0xFC68, UNICODE_NORM_QC_NO},
+	{0xFC69, UNICODE_NORM_QC_NO},
+	{0xFC6A, UNICODE_NORM_QC_NO},
+	{0xFC6B, UNICODE_NORM_QC_NO},
+	{0xFC6C, UNICODE_NORM_QC_NO},
+	{0xFC6D, UNICODE_NORM_QC_NO},
+	{0xFC6E, UNICODE_NORM_QC_NO},
+	{0xFC6F, UNICODE_NORM_QC_NO},
+	{0xFC70, UNICODE_NORM_QC_NO},
+	{0xFC71, UNICODE_NORM_QC_NO},
+	{0xFC72, UNICODE_NORM_QC_NO},
+	{0xFC73, UNICODE_NORM_QC_NO},
+	{0xFC74, UNICODE_NORM_QC_NO},
+	{0xFC75, UNICODE_NORM_QC_NO},
+	{0xFC76, UNICODE_NORM_QC_NO},
+	{0xFC77, UNICODE_NORM_QC_NO},
+	{0xFC78, UNICODE_NORM_QC_NO},
+	{0xFC79, UNICODE_NORM_QC_NO},
+	{0xFC7A, UNICODE_NORM_QC_NO},
+	{0xFC7B, UNICODE_NORM_QC_NO},
+	{0xFC7C, UNICODE_NORM_QC_NO},
+	{0xFC7D, UNICODE_NORM_QC_NO},
+	{0xFC7E, UNICODE_NORM_QC_NO},
+	{0xFC7F, UNICODE_NORM_QC_NO},
+	{0xFC80, UNICODE_NORM_QC_NO},
+	{0xFC81, UNICODE_NORM_QC_NO},
+	{0xFC82, UNICODE_NORM_QC_NO},
+	{0xFC83, UNICODE_NORM_QC_NO},
+	{0xFC84, UNICODE_NORM_QC_NO},
+	{0xFC85, UNICODE_NORM_QC_NO},
+	{0xFC86, UNICODE_NORM_QC_NO},
+	{0xFC87, UNICODE_NORM_QC_NO},
+	{0xFC88, UNICODE_NORM_QC_NO},
+	{0xFC89, UNICODE_NORM_QC_NO},
+	{0xFC8A, UNICODE_NORM_QC_NO},
+	{0xFC8B, UNICODE_NORM_QC_NO},
+	{0xFC8C, UNICODE_NORM_QC_NO},
+	{0xFC8D, UNICODE_NORM_QC_NO},
+	{0xFC8E, UNICODE_NORM_QC_NO},
+	{0xFC8F, UNICODE_NORM_QC_NO},
+	{0xFC90, UNICODE_NORM_QC_NO},
+	{0xFC91, UNICODE_NORM_QC_NO},
+	{0xFC92, UNICODE_NORM_QC_NO},
+	{0xFC93, UNICODE_NORM_QC_NO},
+	{0xFC94, UNICODE_NORM_QC_NO},
+	{0xFC95, UNICODE_NORM_QC_NO},
+	{0xFC96, UNICODE_NORM_QC_NO},
+	{0xFC97, UNICODE_NORM_QC_NO},
+	{0xFC98, UNICODE_NORM_QC_NO},
+	{0xFC99, UNICODE_NORM_QC_NO},
+	{0xFC9A, UNICODE_NORM_QC_NO},
+	{0xFC9B, UNICODE_NORM_QC_NO},
+	{0xFC9C, UNICODE_NORM_QC_NO},
+	{0xFC9D, UNICODE_NORM_QC_NO},
+	{0xFC9E, UNICODE_NORM_QC_NO},
+	{0xFC9F, UNICODE_NORM_QC_NO},
+	{0xFCA0, UNICODE_NORM_QC_NO},
+	{0xFCA1, UNICODE_NORM_QC_NO},
+	{0xFCA2, UNICODE_NORM_QC_NO},
+	{0xFCA3, UNICODE_NORM_QC_NO},
+	{0xFCA4, UNICODE_NORM_QC_NO},
+	{0xFCA5, UNICODE_NORM_QC_NO},
+	{0xFCA6, UNICODE_NORM_QC_NO},
+	{0xFCA7, UNICODE_NORM_QC_NO},
+	{0xFCA8, UNICODE_NORM_QC_NO},
+	{0xFCA9, UNICODE_NORM_QC_NO},
+	{0xFCAA, UNICODE_NORM_QC_NO},
+	{0xFCAB, UNICODE_NORM_QC_NO},
+	{0xFCAC, UNICODE_NORM_QC_NO},
+	{0xFCAD, UNICODE_NORM_QC_NO},
+	{0xFCAE, UNICODE_NORM_QC_NO},
+	{0xFCAF, UNICODE_NORM_QC_NO},
+	{0xFCB0, UNICODE_NORM_QC_NO},
+	{0xFCB1, UNICODE_NORM_QC_NO},
+	{0xFCB2, UNICODE_NORM_QC_NO},
+	{0xFCB3, UNICODE_NORM_QC_NO},
+	{0xFCB4, UNICODE_NORM_QC_NO},
+	{0xFCB5, UNICODE_NORM_QC_NO},
+	{0xFCB6, UNICODE_NORM_QC_NO},
+	{0xFCB7, UNICODE_NORM_QC_NO},
+	{0xFCB8, UNICODE_NORM_QC_NO},
+	{0xFCB9, UNICODE_NORM_QC_NO},
+	{0xFCBA, UNICODE_NORM_QC_NO},
+	{0xFCBB, UNICODE_NORM_QC_NO},
+	{0xFCBC, UNICODE_NORM_QC_NO},
+	{0xFCBD, UNICODE_NORM_QC_NO},
+	{0xFCBE, UNICODE_NORM_QC_NO},
+	{0xFCBF, UNICODE_NORM_QC_NO},
+	{0xFCC0, UNICODE_NORM_QC_NO},
+	{0xFCC1, UNICODE_NORM_QC_NO},
+	{0xFCC2, UNICODE_NORM_QC_NO},
+	{0xFCC3, UNICODE_NORM_QC_NO},
+	{0xFCC4, UNICODE_NORM_QC_NO},
+	{0xFCC5, UNICODE_NORM_QC_NO},
+	{0xFCC6, UNICODE_NORM_QC_NO},
+	{0xFCC7, UNICODE_NORM_QC_NO},
+	{0xFCC8, UNICODE_NORM_QC_NO},
+	{0xFCC9, UNICODE_NORM_QC_NO},
+	{0xFCCA, UNICODE_NORM_QC_NO},
+	{0xFCCB, UNICODE_NORM_QC_NO},
+	{0xFCCC, UNICODE_NORM_QC_NO},
+	{0xFCCD, UNICODE_NORM_QC_NO},
+	{0xFCCE, UNICODE_NORM_QC_NO},
+	{0xFCCF, UNICODE_NORM_QC_NO},
+	{0xFCD0, UNICODE_NORM_QC_NO},
+	{0xFCD1, UNICODE_NORM_QC_NO},
+	{0xFCD2, UNICODE_NORM_QC_NO},
+	{0xFCD3, UNICODE_NORM_QC_NO},
+	{0xFCD4, UNICODE_NORM_QC_NO},
+	{0xFCD5, UNICODE_NORM_QC_NO},
+	{0xFCD6, UNICODE_NORM_QC_NO},
+	{0xFCD7, UNICODE_NORM_QC_NO},
+	{0xFCD8, UNICODE_NORM_QC_NO},
+	{0xFCD9, UNICODE_NORM_QC_NO},
+	{0xFCDA, UNICODE_NORM_QC_NO},
+	{0xFCDB, UNICODE_NORM_QC_NO},
+	{0xFCDC, UNICODE_NORM_QC_NO},
+	{0xFCDD, UNICODE_NORM_QC_NO},
+	{0xFCDE, UNICODE_NORM_QC_NO},
+	{0xFCDF, UNICODE_NORM_QC_NO},
+	{0xFCE0, UNICODE_NORM_QC_NO},
+	{0xFCE1, UNICODE_NORM_QC_NO},
+	{0xFCE2, UNICODE_NORM_QC_NO},
+	{0xFCE3, UNICODE_NORM_QC_NO},
+	{0xFCE4, UNICODE_NORM_QC_NO},
+	{0xFCE5, UNICODE_NORM_QC_NO},
+	{0xFCE6, UNICODE_NORM_QC_NO},
+	{0xFCE7, UNICODE_NORM_QC_NO},
+	{0xFCE8, UNICODE_NORM_QC_NO},
+	{0xFCE9, UNICODE_NORM_QC_NO},
+	{0xFCEA, UNICODE_NORM_QC_NO},
+	{0xFCEB, UNICODE_NORM_QC_NO},
+	{0xFCEC, UNICODE_NORM_QC_NO},
+	{0xFCED, UNICODE_NORM_QC_NO},
+	{0xFCEE, UNICODE_NORM_QC_NO},
+	{0xFCEF, UNICODE_NORM_QC_NO},
+	{0xFCF0, UNICODE_NORM_QC_NO},
+	{0xFCF1, UNICODE_NORM_QC_NO},
+	{0xFCF2, UNICODE_NORM_QC_NO},
+	{0xFCF3, UNICODE_NORM_QC_NO},
+	{0xFCF4, UNICODE_NORM_QC_NO},
+	{0xFCF5, UNICODE_NORM_QC_NO},
+	{0xFCF6, UNICODE_NORM_QC_NO},
+	{0xFCF7, UNICODE_NORM_QC_NO},
+	{0xFCF8, UNICODE_NORM_QC_NO},
+	{0xFCF9, UNICODE_NORM_QC_NO},
+	{0xFCFA, UNICODE_NORM_QC_NO},
+	{0xFCFB, UNICODE_NORM_QC_NO},
+	{0xFCFC, UNICODE_NORM_QC_NO},
+	{0xFCFD, UNICODE_NORM_QC_NO},
+	{0xFCFE, UNICODE_NORM_QC_NO},
+	{0xFCFF, UNICODE_NORM_QC_NO},
+	{0xFD00, UNICODE_NORM_QC_NO},
+	{0xFD01, UNICODE_NORM_QC_NO},
+	{0xFD02, UNICODE_NORM_QC_NO},
+	{0xFD03, UNICODE_NORM_QC_NO},
+	{0xFD04, UNICODE_NORM_QC_NO},
+	{0xFD05, UNICODE_NORM_QC_NO},
+	{0xFD06, UNICODE_NORM_QC_NO},
+	{0xFD07, UNICODE_NORM_QC_NO},
+	{0xFD08, UNICODE_NORM_QC_NO},
+	{0xFD09, UNICODE_NORM_QC_NO},
+	{0xFD0A, UNICODE_NORM_QC_NO},
+	{0xFD0B, UNICODE_NORM_QC_NO},
+	{0xFD0C, UNICODE_NORM_QC_NO},
+	{0xFD0D, UNICODE_NORM_QC_NO},
+	{0xFD0E, UNICODE_NORM_QC_NO},
+	{0xFD0F, UNICODE_NORM_QC_NO},
+	{0xFD10, UNICODE_NORM_QC_NO},
+	{0xFD11, UNICODE_NORM_QC_NO},
+	{0xFD12, UNICODE_NORM_QC_NO},
+	{0xFD13, UNICODE_NORM_QC_NO},
+	{0xFD14, UNICODE_NORM_QC_NO},
+	{0xFD15, UNICODE_NORM_QC_NO},
+	{0xFD16, UNICODE_NORM_QC_NO},
+	{0xFD17, UNICODE_NORM_QC_NO},
+	{0xFD18, UNICODE_NORM_QC_NO},
+	{0xFD19, UNICODE_NORM_QC_NO},
+	{0xFD1A, UNICODE_NORM_QC_NO},
+	{0xFD1B, UNICODE_NORM_QC_NO},
+	{0xFD1C, UNICODE_NORM_QC_NO},
+	{0xFD1D, UNICODE_NORM_QC_NO},
+	{0xFD1E, UNICODE_NORM_QC_NO},
+	{0xFD1F, UNICODE_NORM_QC_NO},
+	{0xFD20, UNICODE_NORM_QC_NO},
+	{0xFD21, UNICODE_NORM_QC_NO},
+	{0xFD22, UNICODE_NORM_QC_NO},
+	{0xFD23, UNICODE_NORM_QC_NO},
+	{0xFD24, UNICODE_NORM_QC_NO},
+	{0xFD25, UNICODE_NORM_QC_NO},
+	{0xFD26, UNICODE_NORM_QC_NO},
+	{0xFD27, UNICODE_NORM_QC_NO},
+	{0xFD28, UNICODE_NORM_QC_NO},
+	{0xFD29, UNICODE_NORM_QC_NO},
+	{0xFD2A, UNICODE_NORM_QC_NO},
+	{0xFD2B, UNICODE_NORM_QC_NO},
+	{0xFD2C, UNICODE_NORM_QC_NO},
+	{0xFD2D, UNICODE_NORM_QC_NO},
+	{0xFD2E, UNICODE_NORM_QC_NO},
+	{0xFD2F, UNICODE_NORM_QC_NO},
+	{0xFD30, UNICODE_NORM_QC_NO},
+	{0xFD31, UNICODE_NORM_QC_NO},
+	{0xFD32, UNICODE_NORM_QC_NO},
+	{0xFD33, UNICODE_NORM_QC_NO},
+	{0xFD34, UNICODE_NORM_QC_NO},
+	{0xFD35, UNICODE_NORM_QC_NO},
+	{0xFD36, UNICODE_NORM_QC_NO},
+	{0xFD37, UNICODE_NORM_QC_NO},
+	{0xFD38, UNICODE_NORM_QC_NO},
+	{0xFD39, UNICODE_NORM_QC_NO},
+	{0xFD3A, UNICODE_NORM_QC_NO},
+	{0xFD3B, UNICODE_NORM_QC_NO},
+	{0xFD3C, UNICODE_NORM_QC_NO},
+	{0xFD3D, UNICODE_NORM_QC_NO},
+	{0xFD50, UNICODE_NORM_QC_NO},
+	{0xFD51, UNICODE_NORM_QC_NO},
+	{0xFD52, UNICODE_NORM_QC_NO},
+	{0xFD53, UNICODE_NORM_QC_NO},
+	{0xFD54, UNICODE_NORM_QC_NO},
+	{0xFD55, UNICODE_NORM_QC_NO},
+	{0xFD56, UNICODE_NORM_QC_NO},
+	{0xFD57, UNICODE_NORM_QC_NO},
+	{0xFD58, UNICODE_NORM_QC_NO},
+	{0xFD59, UNICODE_NORM_QC_NO},
+	{0xFD5A, UNICODE_NORM_QC_NO},
+	{0xFD5B, UNICODE_NORM_QC_NO},
+	{0xFD5C, UNICODE_NORM_QC_NO},
+	{0xFD5D, UNICODE_NORM_QC_NO},
+	{0xFD5E, UNICODE_NORM_QC_NO},
+	{0xFD5F, UNICODE_NORM_QC_NO},
+	{0xFD60, UNICODE_NORM_QC_NO},
+	{0xFD61, UNICODE_NORM_QC_NO},
+	{0xFD62, UNICODE_NORM_QC_NO},
+	{0xFD63, UNICODE_NORM_QC_NO},
+	{0xFD64, UNICODE_NORM_QC_NO},
+	{0xFD65, UNICODE_NORM_QC_NO},
+	{0xFD66, UNICODE_NORM_QC_NO},
+	{0xFD67, UNICODE_NORM_QC_NO},
+	{0xFD68, UNICODE_NORM_QC_NO},
+	{0xFD69, UNICODE_NORM_QC_NO},
+	{0xFD6A, UNICODE_NORM_QC_NO},
+	{0xFD6B, UNICODE_NORM_QC_NO},
+	{0xFD6C, UNICODE_NORM_QC_NO},
+	{0xFD6D, UNICODE_NORM_QC_NO},
+	{0xFD6E, UNICODE_NORM_QC_NO},
+	{0xFD6F, UNICODE_NORM_QC_NO},
+	{0xFD70, UNICODE_NORM_QC_NO},
+	{0xFD71, UNICODE_NORM_QC_NO},
+	{0xFD72, UNICODE_NORM_QC_NO},
+	{0xFD73, UNICODE_NORM_QC_NO},
+	{0xFD74, UNICODE_NORM_QC_NO},
+	{0xFD75, UNICODE_NORM_QC_NO},
+	{0xFD76, UNICODE_NORM_QC_NO},
+	{0xFD77, UNICODE_NORM_QC_NO},
+	{0xFD78, UNICODE_NORM_QC_NO},
+	{0xFD79, UNICODE_NORM_QC_NO},
+	{0xFD7A, UNICODE_NORM_QC_NO},
+	{0xFD7B, UNICODE_NORM_QC_NO},
+	{0xFD7C, UNICODE_NORM_QC_NO},
+	{0xFD7D, UNICODE_NORM_QC_NO},
+	{0xFD7E, UNICODE_NORM_QC_NO},
+	{0xFD7F, UNICODE_NORM_QC_NO},
+	{0xFD80, UNICODE_NORM_QC_NO},
+	{0xFD81, UNICODE_NORM_QC_NO},
+	{0xFD82, UNICODE_NORM_QC_NO},
+	{0xFD83, UNICODE_NORM_QC_NO},
+	{0xFD84, UNICODE_NORM_QC_NO},
+	{0xFD85, UNICODE_NORM_QC_NO},
+	{0xFD86, UNICODE_NORM_QC_NO},
+	{0xFD87, UNICODE_NORM_QC_NO},
+	{0xFD88, UNICODE_NORM_QC_NO},
+	{0xFD89, UNICODE_NORM_QC_NO},
+	{0xFD8A, UNICODE_NORM_QC_NO},
+	{0xFD8B, UNICODE_NORM_QC_NO},
+	{0xFD8C, UNICODE_NORM_QC_NO},
+	{0xFD8D, UNICODE_NORM_QC_NO},
+	{0xFD8E, UNICODE_NORM_QC_NO},
+	{0xFD8F, UNICODE_NORM_QC_NO},
+	{0xFD92, UNICODE_NORM_QC_NO},
+	{0xFD93, UNICODE_NORM_QC_NO},
+	{0xFD94, UNICODE_NORM_QC_NO},
+	{0xFD95, UNICODE_NORM_QC_NO},
+	{0xFD96, UNICODE_NORM_QC_NO},
+	{0xFD97, UNICODE_NORM_QC_NO},
+	{0xFD98, UNICODE_NORM_QC_NO},
+	{0xFD99, UNICODE_NORM_QC_NO},
+	{0xFD9A, UNICODE_NORM_QC_NO},
+	{0xFD9B, UNICODE_NORM_QC_NO},
+	{0xFD9C, UNICODE_NORM_QC_NO},
+	{0xFD9D, UNICODE_NORM_QC_NO},
+	{0xFD9E, UNICODE_NORM_QC_NO},
+	{0xFD9F, UNICODE_NORM_QC_NO},
+	{0xFDA0, UNICODE_NORM_QC_NO},
+	{0xFDA1, UNICODE_NORM_QC_NO},
+	{0xFDA2, UNICODE_NORM_QC_NO},
+	{0xFDA3, UNICODE_NORM_QC_NO},
+	{0xFDA4, UNICODE_NORM_QC_NO},
+	{0xFDA5, UNICODE_NORM_QC_NO},
+	{0xFDA6, UNICODE_NORM_QC_NO},
+	{0xFDA7, UNICODE_NORM_QC_NO},
+	{0xFDA8, UNICODE_NORM_QC_NO},
+	{0xFDA9, UNICODE_NORM_QC_NO},
+	{0xFDAA, UNICODE_NORM_QC_NO},
+	{0xFDAB, UNICODE_NORM_QC_NO},
+	{0xFDAC, UNICODE_NORM_QC_NO},
+	{0xFDAD, UNICODE_NORM_QC_NO},
+	{0xFDAE, UNICODE_NORM_QC_NO},
+	{0xFDAF, UNICODE_NORM_QC_NO},
+	{0xFDB0, UNICODE_NORM_QC_NO},
+	{0xFDB1, UNICODE_NORM_QC_NO},
+	{0xFDB2, UNICODE_NORM_QC_NO},
+	{0xFDB3, UNICODE_NORM_QC_NO},
+	{0xFDB4, UNICODE_NORM_QC_NO},
+	{0xFDB5, UNICODE_NORM_QC_NO},
+	{0xFDB6, UNICODE_NORM_QC_NO},
+	{0xFDB7, UNICODE_NORM_QC_NO},
+	{0xFDB8, UNICODE_NORM_QC_NO},
+	{0xFDB9, UNICODE_NORM_QC_NO},
+	{0xFDBA, UNICODE_NORM_QC_NO},
+	{0xFDBB, UNICODE_NORM_QC_NO},
+	{0xFDBC, UNICODE_NORM_QC_NO},
+	{0xFDBD, UNICODE_NORM_QC_NO},
+	{0xFDBE, UNICODE_NORM_QC_NO},
+	{0xFDBF, UNICODE_NORM_QC_NO},
+	{0xFDC0, UNICODE_NORM_QC_NO},
+	{0xFDC1, UNICODE_NORM_QC_NO},
+	{0xFDC2, UNICODE_NORM_QC_NO},
+	{0xFDC3, UNICODE_NORM_QC_NO},
+	{0xFDC4, UNICODE_NORM_QC_NO},
+	{0xFDC5, UNICODE_NORM_QC_NO},
+	{0xFDC6, UNICODE_NORM_QC_NO},
+	{0xFDC7, UNICODE_NORM_QC_NO},
+	{0xFDF0, UNICODE_NORM_QC_NO},
+	{0xFDF1, UNICODE_NORM_QC_NO},
+	{0xFDF2, UNICODE_NORM_QC_NO},
+	{0xFDF3, UNICODE_NORM_QC_NO},
+	{0xFDF4, UNICODE_NORM_QC_NO},
+	{0xFDF5, UNICODE_NORM_QC_NO},
+	{0xFDF6, UNICODE_NORM_QC_NO},
+	{0xFDF7, UNICODE_NORM_QC_NO},
+	{0xFDF8, UNICODE_NORM_QC_NO},
+	{0xFDF9, UNICODE_NORM_QC_NO},
+	{0xFDFA, UNICODE_NORM_QC_NO},
+	{0xFDFB, UNICODE_NORM_QC_NO},
+	{0xFDFC, UNICODE_NORM_QC_NO},
+	{0xFE10, UNICODE_NORM_QC_NO},
+	{0xFE11, UNICODE_NORM_QC_NO},
+	{0xFE12, UNICODE_NORM_QC_NO},
+	{0xFE13, UNICODE_NORM_QC_NO},
+	{0xFE14, UNICODE_NORM_QC_NO},
+	{0xFE15, UNICODE_NORM_QC_NO},
+	{0xFE16, UNICODE_NORM_QC_NO},
+	{0xFE17, UNICODE_NORM_QC_NO},
+	{0xFE18, UNICODE_NORM_QC_NO},
+	{0xFE19, UNICODE_NORM_QC_NO},
+	{0xFE30, UNICODE_NORM_QC_NO},
+	{0xFE31, UNICODE_NORM_QC_NO},
+	{0xFE32, UNICODE_NORM_QC_NO},
+	{0xFE33, UNICODE_NORM_QC_NO},
+	{0xFE34, UNICODE_NORM_QC_NO},
+	{0xFE35, UNICODE_NORM_QC_NO},
+	{0xFE36, UNICODE_NORM_QC_NO},
+	{0xFE37, UNICODE_NORM_QC_NO},
+	{0xFE38, UNICODE_NORM_QC_NO},
+	{0xFE39, UNICODE_NORM_QC_NO},
+	{0xFE3A, UNICODE_NORM_QC_NO},
+	{0xFE3B, UNICODE_NORM_QC_NO},
+	{0xFE3C, UNICODE_NORM_QC_NO},
+	{0xFE3D, UNICODE_NORM_QC_NO},
+	{0xFE3E, UNICODE_NORM_QC_NO},
+	{0xFE3F, UNICODE_NORM_QC_NO},
+	{0xFE40, UNICODE_NORM_QC_NO},
+	{0xFE41, UNICODE_NORM_QC_NO},
+	{0xFE42, UNICODE_NORM_QC_NO},
+	{0xFE43, UNICODE_NORM_QC_NO},
+	{0xFE44, UNICODE_NORM_QC_NO},
+	{0xFE47, UNICODE_NORM_QC_NO},
+	{0xFE48, UNICODE_NORM_QC_NO},
+	{0xFE49, UNICODE_NORM_QC_NO},
+	{0xFE4A, UNICODE_NORM_QC_NO},
+	{0xFE4B, UNICODE_NORM_QC_NO},
+	{0xFE4C, UNICODE_NORM_QC_NO},
+	{0xFE4D, UNICODE_NORM_QC_NO},
+	{0xFE4E, UNICODE_NORM_QC_NO},
+	{0xFE4F, UNICODE_NORM_QC_NO},
+	{0xFE50, UNICODE_NORM_QC_NO},
+	{0xFE51, UNICODE_NORM_QC_NO},
+	{0xFE52, UNICODE_NORM_QC_NO},
+	{0xFE54, UNICODE_NORM_QC_NO},
+	{0xFE55, UNICODE_NORM_QC_NO},
+	{0xFE56, UNICODE_NORM_QC_NO},
+	{0xFE57, UNICODE_NORM_QC_NO},
+	{0xFE58, UNICODE_NORM_QC_NO},
+	{0xFE59, UNICODE_NORM_QC_NO},
+	{0xFE5A, UNICODE_NORM_QC_NO},
+	{0xFE5B, UNICODE_NORM_QC_NO},
+	{0xFE5C, UNICODE_NORM_QC_NO},
+	{0xFE5D, UNICODE_NORM_QC_NO},
+	{0xFE5E, UNICODE_NORM_QC_NO},
+	{0xFE5F, UNICODE_NORM_QC_NO},
+	{0xFE60, UNICODE_NORM_QC_NO},
+	{0xFE61, UNICODE_NORM_QC_NO},
+	{0xFE62, UNICODE_NORM_QC_NO},
+	{0xFE63, UNICODE_NORM_QC_NO},
+	{0xFE64, UNICODE_NORM_QC_NO},
+	{0xFE65, UNICODE_NORM_QC_NO},
+	{0xFE66, UNICODE_NORM_QC_NO},
+	{0xFE68, UNICODE_NORM_QC_NO},
+	{0xFE69, UNICODE_NORM_QC_NO},
+	{0xFE6A, UNICODE_NORM_QC_NO},
+	{0xFE6B, UNICODE_NORM_QC_NO},
+	{0xFE70, UNICODE_NORM_QC_NO},
+	{0xFE71, UNICODE_NORM_QC_NO},
+	{0xFE72, UNICODE_NORM_QC_NO},
+	{0xFE74, UNICODE_NORM_QC_NO},
+	{0xFE76, UNICODE_NORM_QC_NO},
+	{0xFE77, UNICODE_NORM_QC_NO},
+	{0xFE78, UNICODE_NORM_QC_NO},
+	{0xFE79, UNICODE_NORM_QC_NO},
+	{0xFE7A, UNICODE_NORM_QC_NO},
+	{0xFE7B, UNICODE_NORM_QC_NO},
+	{0xFE7C, UNICODE_NORM_QC_NO},
+	{0xFE7D, UNICODE_NORM_QC_NO},
+	{0xFE7E, UNICODE_NORM_QC_NO},
+	{0xFE7F, UNICODE_NORM_QC_NO},
+	{0xFE80, UNICODE_NORM_QC_NO},
+	{0xFE81, UNICODE_NORM_QC_NO},
+	{0xFE82, UNICODE_NORM_QC_NO},
+	{0xFE83, UNICODE_NORM_QC_NO},
+	{0xFE84, UNICODE_NORM_QC_NO},
+	{0xFE85, UNICODE_NORM_QC_NO},
+	{0xFE86, UNICODE_NORM_QC_NO},
+	{0xFE87, UNICODE_NORM_QC_NO},
+	{0xFE88, UNICODE_NORM_QC_NO},
+	{0xFE89, UNICODE_NORM_QC_NO},
+	{0xFE8A, UNICODE_NORM_QC_NO},
+	{0xFE8B, UNICODE_NORM_QC_NO},
+	{0xFE8C, UNICODE_NORM_QC_NO},
+	{0xFE8D, UNICODE_NORM_QC_NO},
+	{0xFE8E, UNICODE_NORM_QC_NO},
+	{0xFE8F, UNICODE_NORM_QC_NO},
+	{0xFE90, UNICODE_NORM_QC_NO},
+	{0xFE91, UNICODE_NORM_QC_NO},
+	{0xFE92, UNICODE_NORM_QC_NO},
+	{0xFE93, UNICODE_NORM_QC_NO},
+	{0xFE94, UNICODE_NORM_QC_NO},
+	{0xFE95, UNICODE_NORM_QC_NO},
+	{0xFE96, UNICODE_NORM_QC_NO},
+	{0xFE97, UNICODE_NORM_QC_NO},
+	{0xFE98, UNICODE_NORM_QC_NO},
+	{0xFE99, UNICODE_NORM_QC_NO},
+	{0xFE9A, UNICODE_NORM_QC_NO},
+	{0xFE9B, UNICODE_NORM_QC_NO},
+	{0xFE9C, UNICODE_NORM_QC_NO},
+	{0xFE9D, UNICODE_NORM_QC_NO},
+	{0xFE9E, UNICODE_NORM_QC_NO},
+	{0xFE9F, UNICODE_NORM_QC_NO},
+	{0xFEA0, UNICODE_NORM_QC_NO},
+	{0xFEA1, UNICODE_NORM_QC_NO},
+	{0xFEA2, UNICODE_NORM_QC_NO},
+	{0xFEA3, UNICODE_NORM_QC_NO},
+	{0xFEA4, UNICODE_NORM_QC_NO},
+	{0xFEA5, UNICODE_NORM_QC_NO},
+	{0xFEA6, UNICODE_NORM_QC_NO},
+	{0xFEA7, UNICODE_NORM_QC_NO},
+	{0xFEA8, UNICODE_NORM_QC_NO},
+	{0xFEA9, UNICODE_NORM_QC_NO},
+	{0xFEAA, UNICODE_NORM_QC_NO},
+	{0xFEAB, UNICODE_NORM_QC_NO},
+	{0xFEAC, UNICODE_NORM_QC_NO},
+	{0xFEAD, UNICODE_NORM_QC_NO},
+	{0xFEAE, UNICODE_NORM_QC_NO},
+	{0xFEAF, UNICODE_NORM_QC_NO},
+	{0xFEB0, UNICODE_NORM_QC_NO},
+	{0xFEB1, UNICODE_NORM_QC_NO},
+	{0xFEB2, UNICODE_NORM_QC_NO},
+	{0xFEB3, UNICODE_NORM_QC_NO},
+	{0xFEB4, UNICODE_NORM_QC_NO},
+	{0xFEB5, UNICODE_NORM_QC_NO},
+	{0xFEB6, UNICODE_NORM_QC_NO},
+	{0xFEB7, UNICODE_NORM_QC_NO},
+	{0xFEB8, UNICODE_NORM_QC_NO},
+	{0xFEB9, UNICODE_NORM_QC_NO},
+	{0xFEBA, UNICODE_NORM_QC_NO},
+	{0xFEBB, UNICODE_NORM_QC_NO},
+	{0xFEBC, UNICODE_NORM_QC_NO},
+	{0xFEBD, UNICODE_NORM_QC_NO},
+	{0xFEBE, UNICODE_NORM_QC_NO},
+	{0xFEBF, UNICODE_NORM_QC_NO},
+	{0xFEC0, UNICODE_NORM_QC_NO},
+	{0xFEC1, UNICODE_NORM_QC_NO},
+	{0xFEC2, UNICODE_NORM_QC_NO},
+	{0xFEC3, UNICODE_NORM_QC_NO},
+	{0xFEC4, UNICODE_NORM_QC_NO},
+	{0xFEC5, UNICODE_NORM_QC_NO},
+	{0xFEC6, UNICODE_NORM_QC_NO},
+	{0xFEC7, UNICODE_NORM_QC_NO},
+	{0xFEC8, UNICODE_NORM_QC_NO},
+	{0xFEC9, UNICODE_NORM_QC_NO},
+	{0xFECA, UNICODE_NORM_QC_NO},
+	{0xFECB, UNICODE_NORM_QC_NO},
+	{0xFECC, UNICODE_NORM_QC_NO},
+	{0xFECD, UNICODE_NORM_QC_NO},
+	{0xFECE, UNICODE_NORM_QC_NO},
+	{0xFECF, UNICODE_NORM_QC_NO},
+	{0xFED0, UNICODE_NORM_QC_NO},
+	{0xFED1, UNICODE_NORM_QC_NO},
+	{0xFED2, UNICODE_NORM_QC_NO},
+	{0xFED3, UNICODE_NORM_QC_NO},
+	{0xFED4, UNICODE_NORM_QC_NO},
+	{0xFED5, UNICODE_NORM_QC_NO},
+	{0xFED6, UNICODE_NORM_QC_NO},
+	{0xFED7, UNICODE_NORM_QC_NO},
+	{0xFED8, UNICODE_NORM_QC_NO},
+	{0xFED9, UNICODE_NORM_QC_NO},
+	{0xFEDA, UNICODE_NORM_QC_NO},
+	{0xFEDB, UNICODE_NORM_QC_NO},
+	{0xFEDC, UNICODE_NORM_QC_NO},
+	{0xFEDD, UNICODE_NORM_QC_NO},
+	{0xFEDE, UNICODE_NORM_QC_NO},
+	{0xFEDF, UNICODE_NORM_QC_NO},
+	{0xFEE0, UNICODE_NORM_QC_NO},
+	{0xFEE1, UNICODE_NORM_QC_NO},
+	{0xFEE2, UNICODE_NORM_QC_NO},
+	{0xFEE3, UNICODE_NORM_QC_NO},
+	{0xFEE4, UNICODE_NORM_QC_NO},
+	{0xFEE5, UNICODE_NORM_QC_NO},
+	{0xFEE6, UNICODE_NORM_QC_NO},
+	{0xFEE7, UNICODE_NORM_QC_NO},
+	{0xFEE8, UNICODE_NORM_QC_NO},
+	{0xFEE9, UNICODE_NORM_QC_NO},
+	{0xFEEA, UNICODE_NORM_QC_NO},
+	{0xFEEB, UNICODE_NORM_QC_NO},
+	{0xFEEC, UNICODE_NORM_QC_NO},
+	{0xFEED, UNICODE_NORM_QC_NO},
+	{0xFEEE, UNICODE_NORM_QC_NO},
+	{0xFEEF, UNICODE_NORM_QC_NO},
+	{0xFEF0, UNICODE_NORM_QC_NO},
+	{0xFEF1, UNICODE_NORM_QC_NO},
+	{0xFEF2, UNICODE_NORM_QC_NO},
+	{0xFEF3, UNICODE_NORM_QC_NO},
+	{0xFEF4, UNICODE_NORM_QC_NO},
+	{0xFEF5, UNICODE_NORM_QC_NO},
+	{0xFEF6, UNICODE_NORM_QC_NO},
+	{0xFEF7, UNICODE_NORM_QC_NO},
+	{0xFEF8, UNICODE_NORM_QC_NO},
+	{0xFEF9, UNICODE_NORM_QC_NO},
+	{0xFEFA, UNICODE_NORM_QC_NO},
+	{0xFEFB, UNICODE_NORM_QC_NO},
+	{0xFEFC, UNICODE_NORM_QC_NO},
+	{0xFF01, UNICODE_NORM_QC_NO},
+	{0xFF02, UNICODE_NORM_QC_NO},
+	{0xFF03, UNICODE_NORM_QC_NO},
+	{0xFF04, UNICODE_NORM_QC_NO},
+	{0xFF05, UNICODE_NORM_QC_NO},
+	{0xFF06, UNICODE_NORM_QC_NO},
+	{0xFF07, UNICODE_NORM_QC_NO},
+	{0xFF08, UNICODE_NORM_QC_NO},
+	{0xFF09, UNICODE_NORM_QC_NO},
+	{0xFF0A, UNICODE_NORM_QC_NO},
+	{0xFF0B, UNICODE_NORM_QC_NO},
+	{0xFF0C, UNICODE_NORM_QC_NO},
+	{0xFF0D, UNICODE_NORM_QC_NO},
+	{0xFF0E, UNICODE_NORM_QC_NO},
+	{0xFF0F, UNICODE_NORM_QC_NO},
+	{0xFF10, UNICODE_NORM_QC_NO},
+	{0xFF11, UNICODE_NORM_QC_NO},
+	{0xFF12, UNICODE_NORM_QC_NO},
+	{0xFF13, UNICODE_NORM_QC_NO},
+	{0xFF14, UNICODE_NORM_QC_NO},
+	{0xFF15, UNICODE_NORM_QC_NO},
+	{0xFF16, UNICODE_NORM_QC_NO},
+	{0xFF17, UNICODE_NORM_QC_NO},
+	{0xFF18, UNICODE_NORM_QC_NO},
+	{0xFF19, UNICODE_NORM_QC_NO},
+	{0xFF1A, UNICODE_NORM_QC_NO},
+	{0xFF1B, UNICODE_NORM_QC_NO},
+	{0xFF1C, UNICODE_NORM_QC_NO},
+	{0xFF1D, UNICODE_NORM_QC_NO},
+	{0xFF1E, UNICODE_NORM_QC_NO},
+	{0xFF1F, UNICODE_NORM_QC_NO},
+	{0xFF20, UNICODE_NORM_QC_NO},
+	{0xFF21, UNICODE_NORM_QC_NO},
+	{0xFF22, UNICODE_NORM_QC_NO},
+	{0xFF23, UNICODE_NORM_QC_NO},
+	{0xFF24, UNICODE_NORM_QC_NO},
+	{0xFF25, UNICODE_NORM_QC_NO},
+	{0xFF26, UNICODE_NORM_QC_NO},
+	{0xFF27, UNICODE_NORM_QC_NO},
+	{0xFF28, UNICODE_NORM_QC_NO},
+	{0xFF29, UNICODE_NORM_QC_NO},
+	{0xFF2A, UNICODE_NORM_QC_NO},
+	{0xFF2B, UNICODE_NORM_QC_NO},
+	{0xFF2C, UNICODE_NORM_QC_NO},
+	{0xFF2D, UNICODE_NORM_QC_NO},
+	{0xFF2E, UNICODE_NORM_QC_NO},
+	{0xFF2F, UNICODE_NORM_QC_NO},
+	{0xFF30, UNICODE_NORM_QC_NO},
+	{0xFF31, UNICODE_NORM_QC_NO},
+	{0xFF32, UNICODE_NORM_QC_NO},
+	{0xFF33, UNICODE_NORM_QC_NO},
+	{0xFF34, UNICODE_NORM_QC_NO},
+	{0xFF35, UNICODE_NORM_QC_NO},
+	{0xFF36, UNICODE_NORM_QC_NO},
+	{0xFF37, UNICODE_NORM_QC_NO},
+	{0xFF38, UNICODE_NORM_QC_NO},
+	{0xFF39, UNICODE_NORM_QC_NO},
+	{0xFF3A, UNICODE_NORM_QC_NO},
+	{0xFF3B, UNICODE_NORM_QC_NO},
+	{0xFF3C, UNICODE_NORM_QC_NO},
+	{0xFF3D, UNICODE_NORM_QC_NO},
+	{0xFF3E, UNICODE_NORM_QC_NO},
+	{0xFF3F, UNICODE_NORM_QC_NO},
+	{0xFF40, UNICODE_NORM_QC_NO},
+	{0xFF41, UNICODE_NORM_QC_NO},
+	{0xFF42, UNICODE_NORM_QC_NO},
+	{0xFF43, UNICODE_NORM_QC_NO},
+	{0xFF44, UNICODE_NORM_QC_NO},
+	{0xFF45, UNICODE_NORM_QC_NO},
+	{0xFF46, UNICODE_NORM_QC_NO},
+	{0xFF47, UNICODE_NORM_QC_NO},
+	{0xFF48, UNICODE_NORM_QC_NO},
+	{0xFF49, UNICODE_NORM_QC_NO},
+	{0xFF4A, UNICODE_NORM_QC_NO},
+	{0xFF4B, UNICODE_NORM_QC_NO},
+	{0xFF4C, UNICODE_NORM_QC_NO},
+	{0xFF4D, UNICODE_NORM_QC_NO},
+	{0xFF4E, UNICODE_NORM_QC_NO},
+	{0xFF4F, UNICODE_NORM_QC_NO},
+	{0xFF50, UNICODE_NORM_QC_NO},
+	{0xFF51, UNICODE_NORM_QC_NO},
+	{0xFF52, UNICODE_NORM_QC_NO},
+	{0xFF53, UNICODE_NORM_QC_NO},
+	{0xFF54, UNICODE_NORM_QC_NO},
+	{0xFF55, UNICODE_NORM_QC_NO},
+	{0xFF56, UNICODE_NORM_QC_NO},
+	{0xFF57, UNICODE_NORM_QC_NO},
+	{0xFF58, UNICODE_NORM_QC_NO},
+	{0xFF59, UNICODE_NORM_QC_NO},
+	{0xFF5A, UNICODE_NORM_QC_NO},
+	{0xFF5B, UNICODE_NORM_QC_NO},
+	{0xFF5C, UNICODE_NORM_QC_NO},
+	{0xFF5D, UNICODE_NORM_QC_NO},
+	{0xFF5E, UNICODE_NORM_QC_NO},
+	{0xFF5F, UNICODE_NORM_QC_NO},
+	{0xFF60, UNICODE_NORM_QC_NO},
+	{0xFF61, UNICODE_NORM_QC_NO},
+	{0xFF62, UNICODE_NORM_QC_NO},
+	{0xFF63, UNICODE_NORM_QC_NO},
+	{0xFF64, UNICODE_NORM_QC_NO},
+	{0xFF65, UNICODE_NORM_QC_NO},
+	{0xFF66, UNICODE_NORM_QC_NO},
+	{0xFF67, UNICODE_NORM_QC_NO},
+	{0xFF68, UNICODE_NORM_QC_NO},
+	{0xFF69, UNICODE_NORM_QC_NO},
+	{0xFF6A, UNICODE_NORM_QC_NO},
+	{0xFF6B, UNICODE_NORM_QC_NO},
+	{0xFF6C, UNICODE_NORM_QC_NO},
+	{0xFF6D, UNICODE_NORM_QC_NO},
+	{0xFF6E, UNICODE_NORM_QC_NO},
+	{0xFF6F, UNICODE_NORM_QC_NO},
+	{0xFF70, UNICODE_NORM_QC_NO},
+	{0xFF71, UNICODE_NORM_QC_NO},
+	{0xFF72, UNICODE_NORM_QC_NO},
+	{0xFF73, UNICODE_NORM_QC_NO},
+	{0xFF74, UNICODE_NORM_QC_NO},
+	{0xFF75, UNICODE_NORM_QC_NO},
+	{0xFF76, UNICODE_NORM_QC_NO},
+	{0xFF77, UNICODE_NORM_QC_NO},
+	{0xFF78, UNICODE_NORM_QC_NO},
+	{0xFF79, UNICODE_NORM_QC_NO},
+	{0xFF7A, UNICODE_NORM_QC_NO},
+	{0xFF7B, UNICODE_NORM_QC_NO},
+	{0xFF7C, UNICODE_NORM_QC_NO},
+	{0xFF7D, UNICODE_NORM_QC_NO},
+	{0xFF7E, UNICODE_NORM_QC_NO},
+	{0xFF7F, UNICODE_NORM_QC_NO},
+	{0xFF80, UNICODE_NORM_QC_NO},
+	{0xFF81, UNICODE_NORM_QC_NO},
+	{0xFF82, UNICODE_NORM_QC_NO},
+	{0xFF83, UNICODE_NORM_QC_NO},
+	{0xFF84, UNICODE_NORM_QC_NO},
+	{0xFF85, UNICODE_NORM_QC_NO},
+	{0xFF86, UNICODE_NORM_QC_NO},
+	{0xFF87, UNICODE_NORM_QC_NO},
+	{0xFF88, UNICODE_NORM_QC_NO},
+	{0xFF89, UNICODE_NORM_QC_NO},
+	{0xFF8A, UNICODE_NORM_QC_NO},
+	{0xFF8B, UNICODE_NORM_QC_NO},
+	{0xFF8C, UNICODE_NORM_QC_NO},
+	{0xFF8D, UNICODE_NORM_QC_NO},
+	{0xFF8E, UNICODE_NORM_QC_NO},
+	{0xFF8F, UNICODE_NORM_QC_NO},
+	{0xFF90, UNICODE_NORM_QC_NO},
+	{0xFF91, UNICODE_NORM_QC_NO},
+	{0xFF92, UNICODE_NORM_QC_NO},
+	{0xFF93, UNICODE_NORM_QC_NO},
+	{0xFF94, UNICODE_NORM_QC_NO},
+	{0xFF95, UNICODE_NORM_QC_NO},
+	{0xFF96, UNICODE_NORM_QC_NO},
+	{0xFF97, UNICODE_NORM_QC_NO},
+	{0xFF98, UNICODE_NORM_QC_NO},
+	{0xFF99, UNICODE_NORM_QC_NO},
+	{0xFF9A, UNICODE_NORM_QC_NO},
+	{0xFF9B, UNICODE_NORM_QC_NO},
+	{0xFF9C, UNICODE_NORM_QC_NO},
+	{0xFF9D, UNICODE_NORM_QC_NO},
+	{0xFF9E, UNICODE_NORM_QC_NO},
+	{0xFF9F, UNICODE_NORM_QC_NO},
+	{0xFFA0, UNICODE_NORM_QC_NO},
+	{0xFFA1, UNICODE_NORM_QC_NO},
+	{0xFFA2, UNICODE_NORM_QC_NO},
+	{0xFFA3, UNICODE_NORM_QC_NO},
+	{0xFFA4, UNICODE_NORM_QC_NO},
+	{0xFFA5, UNICODE_NORM_QC_NO},
+	{0xFFA6, UNICODE_NORM_QC_NO},
+	{0xFFA7, UNICODE_NORM_QC_NO},
+	{0xFFA8, UNICODE_NORM_QC_NO},
+	{0xFFA9, UNICODE_NORM_QC_NO},
+	{0xFFAA, UNICODE_NORM_QC_NO},
+	{0xFFAB, UNICODE_NORM_QC_NO},
+	{0xFFAC, UNICODE_NORM_QC_NO},
+	{0xFFAD, UNICODE_NORM_QC_NO},
+	{0xFFAE, UNICODE_NORM_QC_NO},
+	{0xFFAF, UNICODE_NORM_QC_NO},
+	{0xFFB0, UNICODE_NORM_QC_NO},
+	{0xFFB1, UNICODE_NORM_QC_NO},
+	{0xFFB2, UNICODE_NORM_QC_NO},
+	{0xFFB3, UNICODE_NORM_QC_NO},
+	{0xFFB4, UNICODE_NORM_QC_NO},
+	{0xFFB5, UNICODE_NORM_QC_NO},
+	{0xFFB6, UNICODE_NORM_QC_NO},
+	{0xFFB7, UNICODE_NORM_QC_NO},
+	{0xFFB8, UNICODE_NORM_QC_NO},
+	{0xFFB9, UNICODE_NORM_QC_NO},
+	{0xFFBA, UNICODE_NORM_QC_NO},
+	{0xFFBB, UNICODE_NORM_QC_NO},
+	{0xFFBC, UNICODE_NORM_QC_NO},
+	{0xFFBD, UNICODE_NORM_QC_NO},
+	{0xFFBE, UNICODE_NORM_QC_NO},
+	{0xFFC2, UNICODE_NORM_QC_NO},
+	{0xFFC3, UNICODE_NORM_QC_NO},
+	{0xFFC4, UNICODE_NORM_QC_NO},
+	{0xFFC5, UNICODE_NORM_QC_NO},
+	{0xFFC6, UNICODE_NORM_QC_NO},
+	{0xFFC7, UNICODE_NORM_QC_NO},
+	{0xFFCA, UNICODE_NORM_QC_NO},
+	{0xFFCB, UNICODE_NORM_QC_NO},
+	{0xFFCC, UNICODE_NORM_QC_NO},
+	{0xFFCD, UNICODE_NORM_QC_NO},
+	{0xFFCE, UNICODE_NORM_QC_NO},
+	{0xFFCF, UNICODE_NORM_QC_NO},
+	{0xFFD2, UNICODE_NORM_QC_NO},
+	{0xFFD3, UNICODE_NORM_QC_NO},
+	{0xFFD4, UNICODE_NORM_QC_NO},
+	{0xFFD5, UNICODE_NORM_QC_NO},
+	{0xFFD6, UNICODE_NORM_QC_NO},
+	{0xFFD7, UNICODE_NORM_QC_NO},
+	{0xFFDA, UNICODE_NORM_QC_NO},
+	{0xFFDB, UNICODE_NORM_QC_NO},
+	{0xFFDC, UNICODE_NORM_QC_NO},
+	{0xFFE0, UNICODE_NORM_QC_NO},
+	{0xFFE1, UNICODE_NORM_QC_NO},
+	{0xFFE2, UNICODE_NORM_QC_NO},
+	{0xFFE3, UNICODE_NORM_QC_NO},
+	{0xFFE4, UNICODE_NORM_QC_NO},
+	{0xFFE5, UNICODE_NORM_QC_NO},
+	{0xFFE6, UNICODE_NORM_QC_NO},
+	{0xFFE8, UNICODE_NORM_QC_NO},
+	{0xFFE9, UNICODE_NORM_QC_NO},
+	{0xFFEA, UNICODE_NORM_QC_NO},
+	{0xFFEB, UNICODE_NORM_QC_NO},
+	{0xFFEC, UNICODE_NORM_QC_NO},
+	{0xFFED, UNICODE_NORM_QC_NO},
+	{0xFFEE, UNICODE_NORM_QC_NO},
+	{0x1109A, UNICODE_NORM_QC_NO},
+	{0x1109C, UNICODE_NORM_QC_NO},
+	{0x110AB, UNICODE_NORM_QC_NO},
+	{0x1112E, UNICODE_NORM_QC_NO},
+	{0x1112F, UNICODE_NORM_QC_NO},
+	{0x1134B, UNICODE_NORM_QC_NO},
+	{0x1134C, UNICODE_NORM_QC_NO},
+	{0x114BB, UNICODE_NORM_QC_NO},
+	{0x114BC, UNICODE_NORM_QC_NO},
+	{0x114BE, UNICODE_NORM_QC_NO},
+	{0x115BA, UNICODE_NORM_QC_NO},
+	{0x115BB, UNICODE_NORM_QC_NO},
+	{0x1D15E, UNICODE_NORM_QC_NO},
+	{0x1D15F, UNICODE_NORM_QC_NO},
+	{0x1D160, UNICODE_NORM_QC_NO},
+	{0x1D161, UNICODE_NORM_QC_NO},
+	{0x1D162, UNICODE_NORM_QC_NO},
+	{0x1D163, UNICODE_NORM_QC_NO},
+	{0x1D164, UNICODE_NORM_QC_NO},
+	{0x1D1BB, UNICODE_NORM_QC_NO},
+	{0x1D1BC, UNICODE_NORM_QC_NO},
+	{0x1D1BD, UNICODE_NORM_QC_NO},
+	{0x1D1BE, UNICODE_NORM_QC_NO},
+	{0x1D1BF, UNICODE_NORM_QC_NO},
+	{0x1D1C0, UNICODE_NORM_QC_NO},
+	{0x1D400, UNICODE_NORM_QC_NO},
+	{0x1D401, UNICODE_NORM_QC_NO},
+	{0x1D402, UNICODE_NORM_QC_NO},
+	{0x1D403, UNICODE_NORM_QC_NO},
+	{0x1D404, UNICODE_NORM_QC_NO},
+	{0x1D405, UNICODE_NORM_QC_NO},
+	{0x1D406, UNICODE_NORM_QC_NO},
+	{0x1D407, UNICODE_NORM_QC_NO},
+	{0x1D408, UNICODE_NORM_QC_NO},
+	{0x1D409, UNICODE_NORM_QC_NO},
+	{0x1D40A, UNICODE_NORM_QC_NO},
+	{0x1D40B, UNICODE_NORM_QC_NO},
+	{0x1D40C, UNICODE_NORM_QC_NO},
+	{0x1D40D, UNICODE_NORM_QC_NO},
+	{0x1D40E, UNICODE_NORM_QC_NO},
+	{0x1D40F, UNICODE_NORM_QC_NO},
+	{0x1D410, UNICODE_NORM_QC_NO},
+	{0x1D411, UNICODE_NORM_QC_NO},
+	{0x1D412, UNICODE_NORM_QC_NO},
+	{0x1D413, UNICODE_NORM_QC_NO},
+	{0x1D414, UNICODE_NORM_QC_NO},
+	{0x1D415, UNICODE_NORM_QC_NO},
+	{0x1D416, UNICODE_NORM_QC_NO},
+	{0x1D417, UNICODE_NORM_QC_NO},
+	{0x1D418, UNICODE_NORM_QC_NO},
+	{0x1D419, UNICODE_NORM_QC_NO},
+	{0x1D41A, UNICODE_NORM_QC_NO},
+	{0x1D41B, UNICODE_NORM_QC_NO},
+	{0x1D41C, UNICODE_NORM_QC_NO},
+	{0x1D41D, UNICODE_NORM_QC_NO},
+	{0x1D41E, UNICODE_NORM_QC_NO},
+	{0x1D41F, UNICODE_NORM_QC_NO},
+	{0x1D420, UNICODE_NORM_QC_NO},
+	{0x1D421, UNICODE_NORM_QC_NO},
+	{0x1D422, UNICODE_NORM_QC_NO},
+	{0x1D423, UNICODE_NORM_QC_NO},
+	{0x1D424, UNICODE_NORM_QC_NO},
+	{0x1D425, UNICODE_NORM_QC_NO},
+	{0x1D426, UNICODE_NORM_QC_NO},
+	{0x1D427, UNICODE_NORM_QC_NO},
+	{0x1D428, UNICODE_NORM_QC_NO},
+	{0x1D429, UNICODE_NORM_QC_NO},
+	{0x1D42A, UNICODE_NORM_QC_NO},
+	{0x1D42B, UNICODE_NORM_QC_NO},
+	{0x1D42C, UNICODE_NORM_QC_NO},
+	{0x1D42D, UNICODE_NORM_QC_NO},
+	{0x1D42E, UNICODE_NORM_QC_NO},
+	{0x1D42F, UNICODE_NORM_QC_NO},
+	{0x1D430, UNICODE_NORM_QC_NO},
+	{0x1D431, UNICODE_NORM_QC_NO},
+	{0x1D432, UNICODE_NORM_QC_NO},
+	{0x1D433, UNICODE_NORM_QC_NO},
+	{0x1D434, UNICODE_NORM_QC_NO},
+	{0x1D435, UNICODE_NORM_QC_NO},
+	{0x1D436, UNICODE_NORM_QC_NO},
+	{0x1D437, UNICODE_NORM_QC_NO},
+	{0x1D438, UNICODE_NORM_QC_NO},
+	{0x1D439, UNICODE_NORM_QC_NO},
+	{0x1D43A, UNICODE_NORM_QC_NO},
+	{0x1D43B, UNICODE_NORM_QC_NO},
+	{0x1D43C, UNICODE_NORM_QC_NO},
+	{0x1D43D, UNICODE_NORM_QC_NO},
+	{0x1D43E, UNICODE_NORM_QC_NO},
+	{0x1D43F, UNICODE_NORM_QC_NO},
+	{0x1D440, UNICODE_NORM_QC_NO},
+	{0x1D441, UNICODE_NORM_QC_NO},
+	{0x1D442, UNICODE_NORM_QC_NO},
+	{0x1D443, UNICODE_NORM_QC_NO},
+	{0x1D444, UNICODE_NORM_QC_NO},
+	{0x1D445, UNICODE_NORM_QC_NO},
+	{0x1D446, UNICODE_NORM_QC_NO},
+	{0x1D447, UNICODE_NORM_QC_NO},
+	{0x1D448, UNICODE_NORM_QC_NO},
+	{0x1D449, UNICODE_NORM_QC_NO},
+	{0x1D44A, UNICODE_NORM_QC_NO},
+	{0x1D44B, UNICODE_NORM_QC_NO},
+	{0x1D44C, UNICODE_NORM_QC_NO},
+	{0x1D44D, UNICODE_NORM_QC_NO},
+	{0x1D44E, UNICODE_NORM_QC_NO},
+	{0x1D44F, UNICODE_NORM_QC_NO},
+	{0x1D450, UNICODE_NORM_QC_NO},
+	{0x1D451, UNICODE_NORM_QC_NO},
+	{0x1D452, UNICODE_NORM_QC_NO},
+	{0x1D453, UNICODE_NORM_QC_NO},
+	{0x1D454, UNICODE_NORM_QC_NO},
+	{0x1D456, UNICODE_NORM_QC_NO},
+	{0x1D457, UNICODE_NORM_QC_NO},
+	{0x1D458, UNICODE_NORM_QC_NO},
+	{0x1D459, UNICODE_NORM_QC_NO},
+	{0x1D45A, UNICODE_NORM_QC_NO},
+	{0x1D45B, UNICODE_NORM_QC_NO},
+	{0x1D45C, UNICODE_NORM_QC_NO},
+	{0x1D45D, UNICODE_NORM_QC_NO},
+	{0x1D45E, UNICODE_NORM_QC_NO},
+	{0x1D45F, UNICODE_NORM_QC_NO},
+	{0x1D460, UNICODE_NORM_QC_NO},
+	{0x1D461, UNICODE_NORM_QC_NO},
+	{0x1D462, UNICODE_NORM_QC_NO},
+	{0x1D463, UNICODE_NORM_QC_NO},
+	{0x1D464, UNICODE_NORM_QC_NO},
+	{0x1D465, UNICODE_NORM_QC_NO},
+	{0x1D466, UNICODE_NORM_QC_NO},
+	{0x1D467, UNICODE_NORM_QC_NO},
+	{0x1D468, UNICODE_NORM_QC_NO},
+	{0x1D469, UNICODE_NORM_QC_NO},
+	{0x1D46A, UNICODE_NORM_QC_NO},
+	{0x1D46B, UNICODE_NORM_QC_NO},
+	{0x1D46C, UNICODE_NORM_QC_NO},
+	{0x1D46D, UNICODE_NORM_QC_NO},
+	{0x1D46E, UNICODE_NORM_QC_NO},
+	{0x1D46F, UNICODE_NORM_QC_NO},
+	{0x1D470, UNICODE_NORM_QC_NO},
+	{0x1D471, UNICODE_NORM_QC_NO},
+	{0x1D472, UNICODE_NORM_QC_NO},
+	{0x1D473, UNICODE_NORM_QC_NO},
+	{0x1D474, UNICODE_NORM_QC_NO},
+	{0x1D475, UNICODE_NORM_QC_NO},
+	{0x1D476, UNICODE_NORM_QC_NO},
+	{0x1D477, UNICODE_NORM_QC_NO},
+	{0x1D478, UNICODE_NORM_QC_NO},
+	{0x1D479, UNICODE_NORM_QC_NO},
+	{0x1D47A, UNICODE_NORM_QC_NO},
+	{0x1D47B, UNICODE_NORM_QC_NO},
+	{0x1D47C, UNICODE_NORM_QC_NO},
+	{0x1D47D, UNICODE_NORM_QC_NO},
+	{0x1D47E, UNICODE_NORM_QC_NO},
+	{0x1D47F, UNICODE_NORM_QC_NO},
+	{0x1D480, UNICODE_NORM_QC_NO},
+	{0x1D481, UNICODE_NORM_QC_NO},
+	{0x1D482, UNICODE_NORM_QC_NO},
+	{0x1D483, UNICODE_NORM_QC_NO},
+	{0x1D484, UNICODE_NORM_QC_NO},
+	{0x1D485, UNICODE_NORM_QC_NO},
+	{0x1D486, UNICODE_NORM_QC_NO},
+	{0x1D487, UNICODE_NORM_QC_NO},
+	{0x1D488, UNICODE_NORM_QC_NO},
+	{0x1D489, UNICODE_NORM_QC_NO},
+	{0x1D48A, UNICODE_NORM_QC_NO},
+	{0x1D48B, UNICODE_NORM_QC_NO},
+	{0x1D48C, UNICODE_NORM_QC_NO},
+	{0x1D48D, UNICODE_NORM_QC_NO},
+	{0x1D48E, UNICODE_NORM_QC_NO},
+	{0x1D48F, UNICODE_NORM_QC_NO},
+	{0x1D490, UNICODE_NORM_QC_NO},
+	{0x1D491, UNICODE_NORM_QC_NO},
+	{0x1D492, UNICODE_NORM_QC_NO},
+	{0x1D493, UNICODE_NORM_QC_NO},
+	{0x1D494, UNICODE_NORM_QC_NO},
+	{0x1D495, UNICODE_NORM_QC_NO},
+	{0x1D496, UNICODE_NORM_QC_NO},
+	{0x1D497, UNICODE_NORM_QC_NO},
+	{0x1D498, UNICODE_NORM_QC_NO},
+	{0x1D499, UNICODE_NORM_QC_NO},
+	{0x1D49A, UNICODE_NORM_QC_NO},
+	{0x1D49B, UNICODE_NORM_QC_NO},
+	{0x1D49C, UNICODE_NORM_QC_NO},
+	{0x1D49E, UNICODE_NORM_QC_NO},
+	{0x1D49F, UNICODE_NORM_QC_NO},
+	{0x1D4A2, UNICODE_NORM_QC_NO},
+	{0x1D4A5, UNICODE_NORM_QC_NO},
+	{0x1D4A6, UNICODE_NORM_QC_NO},
+	{0x1D4A9, UNICODE_NORM_QC_NO},
+	{0x1D4AA, UNICODE_NORM_QC_NO},
+	{0x1D4AB, UNICODE_NORM_QC_NO},
+	{0x1D4AC, UNICODE_NORM_QC_NO},
+	{0x1D4AE, UNICODE_NORM_QC_NO},
+	{0x1D4AF, UNICODE_NORM_QC_NO},
+	{0x1D4B0, UNICODE_NORM_QC_NO},
+	{0x1D4B1, UNICODE_NORM_QC_NO},
+	{0x1D4B2, UNICODE_NORM_QC_NO},
+	{0x1D4B3, UNICODE_NORM_QC_NO},
+	{0x1D4B4, UNICODE_NORM_QC_NO},
+	{0x1D4B5, UNICODE_NORM_QC_NO},
+	{0x1D4B6, UNICODE_NORM_QC_NO},
+	{0x1D4B7, UNICODE_NORM_QC_NO},
+	{0x1D4B8, UNICODE_NORM_QC_NO},
+	{0x1D4B9, UNICODE_NORM_QC_NO},
+	{0x1D4BB, UNICODE_NORM_QC_NO},
+	{0x1D4BD, UNICODE_NORM_QC_NO},
+	{0x1D4BE, UNICODE_NORM_QC_NO},
+	{0x1D4BF, UNICODE_NORM_QC_NO},
+	{0x1D4C0, UNICODE_NORM_QC_NO},
+	{0x1D4C1, UNICODE_NORM_QC_NO},
+	{0x1D4C2, UNICODE_NORM_QC_NO},
+	{0x1D4C3, UNICODE_NORM_QC_NO},
+	{0x1D4C5, UNICODE_NORM_QC_NO},
+	{0x1D4C6, UNICODE_NORM_QC_NO},
+	{0x1D4C7, UNICODE_NORM_QC_NO},
+	{0x1D4C8, UNICODE_NORM_QC_NO},
+	{0x1D4C9, UNICODE_NORM_QC_NO},
+	{0x1D4CA, UNICODE_NORM_QC_NO},
+	{0x1D4CB, UNICODE_NORM_QC_NO},
+	{0x1D4CC, UNICODE_NORM_QC_NO},
+	{0x1D4CD, UNICODE_NORM_QC_NO},
+	{0x1D4CE, UNICODE_NORM_QC_NO},
+	{0x1D4CF, UNICODE_NORM_QC_NO},
+	{0x1D4D0, UNICODE_NORM_QC_NO},
+	{0x1D4D1, UNICODE_NORM_QC_NO},
+	{0x1D4D2, UNICODE_NORM_QC_NO},
+	{0x1D4D3, UNICODE_NORM_QC_NO},
+	{0x1D4D4, UNICODE_NORM_QC_NO},
+	{0x1D4D5, UNICODE_NORM_QC_NO},
+	{0x1D4D6, UNICODE_NORM_QC_NO},
+	{0x1D4D7, UNICODE_NORM_QC_NO},
+	{0x1D4D8, UNICODE_NORM_QC_NO},
+	{0x1D4D9, UNICODE_NORM_QC_NO},
+	{0x1D4DA, UNICODE_NORM_QC_NO},
+	{0x1D4DB, UNICODE_NORM_QC_NO},
+	{0x1D4DC, UNICODE_NORM_QC_NO},
+	{0x1D4DD, UNICODE_NORM_QC_NO},
+	{0x1D4DE, UNICODE_NORM_QC_NO},
+	{0x1D4DF, UNICODE_NORM_QC_NO},
+	{0x1D4E0, UNICODE_NORM_QC_NO},
+	{0x1D4E1, UNICODE_NORM_QC_NO},
+	{0x1D4E2, UNICODE_NORM_QC_NO},
+	{0x1D4E3, UNICODE_NORM_QC_NO},
+	{0x1D4E4, UNICODE_NORM_QC_NO},
+	{0x1D4E5, UNICODE_NORM_QC_NO},
+	{0x1D4E6, UNICODE_NORM_QC_NO},
+	{0x1D4E7, UNICODE_NORM_QC_NO},
+	{0x1D4E8, UNICODE_NORM_QC_NO},
+	{0x1D4E9, UNICODE_NORM_QC_NO},
+	{0x1D4EA, UNICODE_NORM_QC_NO},
+	{0x1D4EB, UNICODE_NORM_QC_NO},
+	{0x1D4EC, UNICODE_NORM_QC_NO},
+	{0x1D4ED, UNICODE_NORM_QC_NO},
+	{0x1D4EE, UNICODE_NORM_QC_NO},
+	{0x1D4EF, UNICODE_NORM_QC_NO},
+	{0x1D4F0, UNICODE_NORM_QC_NO},
+	{0x1D4F1, UNICODE_NORM_QC_NO},
+	{0x1D4F2, UNICODE_NORM_QC_NO},
+	{0x1D4F3, UNICODE_NORM_QC_NO},
+	{0x1D4F4, UNICODE_NORM_QC_NO},
+	{0x1D4F5, UNICODE_NORM_QC_NO},
+	{0x1D4F6, UNICODE_NORM_QC_NO},
+	{0x1D4F7, UNICODE_NORM_QC_NO},
+	{0x1D4F8, UNICODE_NORM_QC_NO},
+	{0x1D4F9, UNICODE_NORM_QC_NO},
+	{0x1D4FA, UNICODE_NORM_QC_NO},
+	{0x1D4FB, UNICODE_NORM_QC_NO},
+	{0x1D4FC, UNICODE_NORM_QC_NO},
+	{0x1D4FD, UNICODE_NORM_QC_NO},
+	{0x1D4FE, UNICODE_NORM_QC_NO},
+	{0x1D4FF, UNICODE_NORM_QC_NO},
+	{0x1D500, UNICODE_NORM_QC_NO},
+	{0x1D501, UNICODE_NORM_QC_NO},
+	{0x1D502, UNICODE_NORM_QC_NO},
+	{0x1D503, UNICODE_NORM_QC_NO},
+	{0x1D504, UNICODE_NORM_QC_NO},
+	{0x1D505, UNICODE_NORM_QC_NO},
+	{0x1D507, UNICODE_NORM_QC_NO},
+	{0x1D508, UNICODE_NORM_QC_NO},
+	{0x1D509, UNICODE_NORM_QC_NO},
+	{0x1D50A, UNICODE_NORM_QC_NO},
+	{0x1D50D, UNICODE_NORM_QC_NO},
+	{0x1D50E, UNICODE_NORM_QC_NO},
+	{0x1D50F, UNICODE_NORM_QC_NO},
+	{0x1D510, UNICODE_NORM_QC_NO},
+	{0x1D511, UNICODE_NORM_QC_NO},
+	{0x1D512, UNICODE_NORM_QC_NO},
+	{0x1D513, UNICODE_NORM_QC_NO},
+	{0x1D514, UNICODE_NORM_QC_NO},
+	{0x1D516, UNICODE_NORM_QC_NO},
+	{0x1D517, UNICODE_NORM_QC_NO},
+	{0x1D518, UNICODE_NORM_QC_NO},
+	{0x1D519, UNICODE_NORM_QC_NO},
+	{0x1D51A, UNICODE_NORM_QC_NO},
+	{0x1D51B, UNICODE_NORM_QC_NO},
+	{0x1D51C, UNICODE_NORM_QC_NO},
+	{0x1D51E, UNICODE_NORM_QC_NO},
+	{0x1D51F, UNICODE_NORM_QC_NO},
+	{0x1D520, UNICODE_NORM_QC_NO},
+	{0x1D521, UNICODE_NORM_QC_NO},
+	{0x1D522, UNICODE_NORM_QC_NO},
+	{0x1D523, UNICODE_NORM_QC_NO},
+	{0x1D524, UNICODE_NORM_QC_NO},
+	{0x1D525, UNICODE_NORM_QC_NO},
+	{0x1D526, UNICODE_NORM_QC_NO},
+	{0x1D527, UNICODE_NORM_QC_NO},
+	{0x1D528, UNICODE_NORM_QC_NO},
+	{0x1D529, UNICODE_NORM_QC_NO},
+	{0x1D52A, UNICODE_NORM_QC_NO},
+	{0x1D52B, UNICODE_NORM_QC_NO},
+	{0x1D52C, UNICODE_NORM_QC_NO},
+	{0x1D52D, UNICODE_NORM_QC_NO},
+	{0x1D52E, UNICODE_NORM_QC_NO},
+	{0x1D52F, UNICODE_NORM_QC_NO},
+	{0x1D530, UNICODE_NORM_QC_NO},
+	{0x1D531, UNICODE_NORM_QC_NO},
+	{0x1D532, UNICODE_NORM_QC_NO},
+	{0x1D533, UNICODE_NORM_QC_NO},
+	{0x1D534, UNICODE_NORM_QC_NO},
+	{0x1D535, UNICODE_NORM_QC_NO},
+	{0x1D536, UNICODE_NORM_QC_NO},
+	{0x1D537, UNICODE_NORM_QC_NO},
+	{0x1D538, UNICODE_NORM_QC_NO},
+	{0x1D539, UNICODE_NORM_QC_NO},
+	{0x1D53B, UNICODE_NORM_QC_NO},
+	{0x1D53C, UNICODE_NORM_QC_NO},
+	{0x1D53D, UNICODE_NORM_QC_NO},
+	{0x1D53E, UNICODE_NORM_QC_NO},
+	{0x1D540, UNICODE_NORM_QC_NO},
+	{0x1D541, UNICODE_NORM_QC_NO},
+	{0x1D542, UNICODE_NORM_QC_NO},
+	{0x1D543, UNICODE_NORM_QC_NO},
+	{0x1D544, UNICODE_NORM_QC_NO},
+	{0x1D546, UNICODE_NORM_QC_NO},
+	{0x1D54A, UNICODE_NORM_QC_NO},
+	{0x1D54B, UNICODE_NORM_QC_NO},
+	{0x1D54C, UNICODE_NORM_QC_NO},
+	{0x1D54D, UNICODE_NORM_QC_NO},
+	{0x1D54E, UNICODE_NORM_QC_NO},
+	{0x1D54F, UNICODE_NORM_QC_NO},
+	{0x1D550, UNICODE_NORM_QC_NO},
+	{0x1D552, UNICODE_NORM_QC_NO},
+	{0x1D553, UNICODE_NORM_QC_NO},
+	{0x1D554, UNICODE_NORM_QC_NO},
+	{0x1D555, UNICODE_NORM_QC_NO},
+	{0x1D556, UNICODE_NORM_QC_NO},
+	{0x1D557, UNICODE_NORM_QC_NO},
+	{0x1D558, UNICODE_NORM_QC_NO},
+	{0x1D559, UNICODE_NORM_QC_NO},
+	{0x1D55A, UNICODE_NORM_QC_NO},
+	{0x1D55B, UNICODE_NORM_QC_NO},
+	{0x1D55C, UNICODE_NORM_QC_NO},
+	{0x1D55D, UNICODE_NORM_QC_NO},
+	{0x1D55E, UNICODE_NORM_QC_NO},
+	{0x1D55F, UNICODE_NORM_QC_NO},
+	{0x1D560, UNICODE_NORM_QC_NO},
+	{0x1D561, UNICODE_NORM_QC_NO},
+	{0x1D562, UNICODE_NORM_QC_NO},
+	{0x1D563, UNICODE_NORM_QC_NO},
+	{0x1D564, UNICODE_NORM_QC_NO},
+	{0x1D565, UNICODE_NORM_QC_NO},
+	{0x1D566, UNICODE_NORM_QC_NO},
+	{0x1D567, UNICODE_NORM_QC_NO},
+	{0x1D568, UNICODE_NORM_QC_NO},
+	{0x1D569, UNICODE_NORM_QC_NO},
+	{0x1D56A, UNICODE_NORM_QC_NO},
+	{0x1D56B, UNICODE_NORM_QC_NO},
+	{0x1D56C, UNICODE_NORM_QC_NO},
+	{0x1D56D, UNICODE_NORM_QC_NO},
+	{0x1D56E, UNICODE_NORM_QC_NO},
+	{0x1D56F, UNICODE_NORM_QC_NO},
+	{0x1D570, UNICODE_NORM_QC_NO},
+	{0x1D571, UNICODE_NORM_QC_NO},
+	{0x1D572, UNICODE_NORM_QC_NO},
+	{0x1D573, UNICODE_NORM_QC_NO},
+	{0x1D574, UNICODE_NORM_QC_NO},
+	{0x1D575, UNICODE_NORM_QC_NO},
+	{0x1D576, UNICODE_NORM_QC_NO},
+	{0x1D577, UNICODE_NORM_QC_NO},
+	{0x1D578, UNICODE_NORM_QC_NO},
+	{0x1D579, UNICODE_NORM_QC_NO},
+	{0x1D57A, UNICODE_NORM_QC_NO},
+	{0x1D57B, UNICODE_NORM_QC_NO},
+	{0x1D57C, UNICODE_NORM_QC_NO},
+	{0x1D57D, UNICODE_NORM_QC_NO},
+	{0x1D57E, UNICODE_NORM_QC_NO},
+	{0x1D57F, UNICODE_NORM_QC_NO},
+	{0x1D580, UNICODE_NORM_QC_NO},
+	{0x1D581, UNICODE_NORM_QC_NO},
+	{0x1D582, UNICODE_NORM_QC_NO},
+	{0x1D583, UNICODE_NORM_QC_NO},
+	{0x1D584, UNICODE_NORM_QC_NO},
+	{0x1D585, UNICODE_NORM_QC_NO},
+	{0x1D586, UNICODE_NORM_QC_NO},
+	{0x1D587, UNICODE_NORM_QC_NO},
+	{0x1D588, UNICODE_NORM_QC_NO},
+	{0x1D589, UNICODE_NORM_QC_NO},
+	{0x1D58A, UNICODE_NORM_QC_NO},
+	{0x1D58B, UNICODE_NORM_QC_NO},
+	{0x1D58C, UNICODE_NORM_QC_NO},
+	{0x1D58D, UNICODE_NORM_QC_NO},
+	{0x1D58E, UNICODE_NORM_QC_NO},
+	{0x1D58F, UNICODE_NORM_QC_NO},
+	{0x1D590, UNICODE_NORM_QC_NO},
+	{0x1D591, UNICODE_NORM_QC_NO},
+	{0x1D592, UNICODE_NORM_QC_NO},
+	{0x1D593, UNICODE_NORM_QC_NO},
+	{0x1D594, UNICODE_NORM_QC_NO},
+	{0x1D595, UNICODE_NORM_QC_NO},
+	{0x1D596, UNICODE_NORM_QC_NO},
+	{0x1D597, UNICODE_NORM_QC_NO},
+	{0x1D598, UNICODE_NORM_QC_NO},
+	{0x1D599, UNICODE_NORM_QC_NO},
+	{0x1D59A, UNICODE_NORM_QC_NO},
+	{0x1D59B, UNICODE_NORM_QC_NO},
+	{0x1D59C, UNICODE_NORM_QC_NO},
+	{0x1D59D, UNICODE_NORM_QC_NO},
+	{0x1D59E, UNICODE_NORM_QC_NO},
+	{0x1D59F, UNICODE_NORM_QC_NO},
+	{0x1D5A0, UNICODE_NORM_QC_NO},
+	{0x1D5A1, UNICODE_NORM_QC_NO},
+	{0x1D5A2, UNICODE_NORM_QC_NO},
+	{0x1D5A3, UNICODE_NORM_QC_NO},
+	{0x1D5A4, UNICODE_NORM_QC_NO},
+	{0x1D5A5, UNICODE_NORM_QC_NO},
+	{0x1D5A6, UNICODE_NORM_QC_NO},
+	{0x1D5A7, UNICODE_NORM_QC_NO},
+	{0x1D5A8, UNICODE_NORM_QC_NO},
+	{0x1D5A9, UNICODE_NORM_QC_NO},
+	{0x1D5AA, UNICODE_NORM_QC_NO},
+	{0x1D5AB, UNICODE_NORM_QC_NO},
+	{0x1D5AC, UNICODE_NORM_QC_NO},
+	{0x1D5AD, UNICODE_NORM_QC_NO},
+	{0x1D5AE, UNICODE_NORM_QC_NO},
+	{0x1D5AF, UNICODE_NORM_QC_NO},
+	{0x1D5B0, UNICODE_NORM_QC_NO},
+	{0x1D5B1, UNICODE_NORM_QC_NO},
+	{0x1D5B2, UNICODE_NORM_QC_NO},
+	{0x1D5B3, UNICODE_NORM_QC_NO},
+	{0x1D5B4, UNICODE_NORM_QC_NO},
+	{0x1D5B5, UNICODE_NORM_QC_NO},
+	{0x1D5B6, UNICODE_NORM_QC_NO},
+	{0x1D5B7, UNICODE_NORM_QC_NO},
+	{0x1D5B8, UNICODE_NORM_QC_NO},
+	{0x1D5B9, UNICODE_NORM_QC_NO},
+	{0x1D5BA, UNICODE_NORM_QC_NO},
+	{0x1D5BB, UNICODE_NORM_QC_NO},
+	{0x1D5BC, UNICODE_NORM_QC_NO},
+	{0x1D5BD, UNICODE_NORM_QC_NO},
+	{0x1D5BE, UNICODE_NORM_QC_NO},
+	{0x1D5BF, UNICODE_NORM_QC_NO},
+	{0x1D5C0, UNICODE_NORM_QC_NO},
+	{0x1D5C1, UNICODE_NORM_QC_NO},
+	{0x1D5C2, UNICODE_NORM_QC_NO},
+	{0x1D5C3, UNICODE_NORM_QC_NO},
+	{0x1D5C4, UNICODE_NORM_QC_NO},
+	{0x1D5C5, UNICODE_NORM_QC_NO},
+	{0x1D5C6, UNICODE_NORM_QC_NO},
+	{0x1D5C7, UNICODE_NORM_QC_NO},
+	{0x1D5C8, UNICODE_NORM_QC_NO},
+	{0x1D5C9, UNICODE_NORM_QC_NO},
+	{0x1D5CA, UNICODE_NORM_QC_NO},
+	{0x1D5CB, UNICODE_NORM_QC_NO},
+	{0x1D5CC, UNICODE_NORM_QC_NO},
+	{0x1D5CD, UNICODE_NORM_QC_NO},
+	{0x1D5CE, UNICODE_NORM_QC_NO},
+	{0x1D5CF, UNICODE_NORM_QC_NO},
+	{0x1D5D0, UNICODE_NORM_QC_NO},
+	{0x1D5D1, UNICODE_NORM_QC_NO},
+	{0x1D5D2, UNICODE_NORM_QC_NO},
+	{0x1D5D3, UNICODE_NORM_QC_NO},
+	{0x1D5D4, UNICODE_NORM_QC_NO},
+	{0x1D5D5, UNICODE_NORM_QC_NO},
+	{0x1D5D6, UNICODE_NORM_QC_NO},
+	{0x1D5D7, UNICODE_NORM_QC_NO},
+	{0x1D5D8, UNICODE_NORM_QC_NO},
+	{0x1D5D9, UNICODE_NORM_QC_NO},
+	{0x1D5DA, UNICODE_NORM_QC_NO},
+	{0x1D5DB, UNICODE_NORM_QC_NO},
+	{0x1D5DC, UNICODE_NORM_QC_NO},
+	{0x1D5DD, UNICODE_NORM_QC_NO},
+	{0x1D5DE, UNICODE_NORM_QC_NO},
+	{0x1D5DF, UNICODE_NORM_QC_NO},
+	{0x1D5E0, UNICODE_NORM_QC_NO},
+	{0x1D5E1, UNICODE_NORM_QC_NO},
+	{0x1D5E2, UNICODE_NORM_QC_NO},
+	{0x1D5E3, UNICODE_NORM_QC_NO},
+	{0x1D5E4, UNICODE_NORM_QC_NO},
+	{0x1D5E5, UNICODE_NORM_QC_NO},
+	{0x1D5E6, UNICODE_NORM_QC_NO},
+	{0x1D5E7, UNICODE_NORM_QC_NO},
+	{0x1D5E8, UNICODE_NORM_QC_NO},
+	{0x1D5E9, UNICODE_NORM_QC_NO},
+	{0x1D5EA, UNICODE_NORM_QC_NO},
+	{0x1D5EB, UNICODE_NORM_QC_NO},
+	{0x1D5EC, UNICODE_NORM_QC_NO},
+	{0x1D5ED, UNICODE_NORM_QC_NO},
+	{0x1D5EE, UNICODE_NORM_QC_NO},
+	{0x1D5EF, UNICODE_NORM_QC_NO},
+	{0x1D5F0, UNICODE_NORM_QC_NO},
+	{0x1D5F1, UNICODE_NORM_QC_NO},
+	{0x1D5F2, UNICODE_NORM_QC_NO},
+	{0x1D5F3, UNICODE_NORM_QC_NO},
+	{0x1D5F4, UNICODE_NORM_QC_NO},
+	{0x1D5F5, UNICODE_NORM_QC_NO},
+	{0x1D5F6, UNICODE_NORM_QC_NO},
+	{0x1D5F7, UNICODE_NORM_QC_NO},
+	{0x1D5F8, UNICODE_NORM_QC_NO},
+	{0x1D5F9, UNICODE_NORM_QC_NO},
+	{0x1D5FA, UNICODE_NORM_QC_NO},
+	{0x1D5FB, UNICODE_NORM_QC_NO},
+	{0x1D5FC, UNICODE_NORM_QC_NO},
+	{0x1D5FD, UNICODE_NORM_QC_NO},
+	{0x1D5FE, UNICODE_NORM_QC_NO},
+	{0x1D5FF, UNICODE_NORM_QC_NO},
+	{0x1D600, UNICODE_NORM_QC_NO},
+	{0x1D601, UNICODE_NORM_QC_NO},
+	{0x1D602, UNICODE_NORM_QC_NO},
+	{0x1D603, UNICODE_NORM_QC_NO},
+	{0x1D604, UNICODE_NORM_QC_NO},
+	{0x1D605, UNICODE_NORM_QC_NO},
+	{0x1D606, UNICODE_NORM_QC_NO},
+	{0x1D607, UNICODE_NORM_QC_NO},
+	{0x1D608, UNICODE_NORM_QC_NO},
+	{0x1D609, UNICODE_NORM_QC_NO},
+	{0x1D60A, UNICODE_NORM_QC_NO},
+	{0x1D60B, UNICODE_NORM_QC_NO},
+	{0x1D60C, UNICODE_NORM_QC_NO},
+	{0x1D60D, UNICODE_NORM_QC_NO},
+	{0x1D60E, UNICODE_NORM_QC_NO},
+	{0x1D60F, UNICODE_NORM_QC_NO},
+	{0x1D610, UNICODE_NORM_QC_NO},
+	{0x1D611, UNICODE_NORM_QC_NO},
+	{0x1D612, UNICODE_NORM_QC_NO},
+	{0x1D613, UNICODE_NORM_QC_NO},
+	{0x1D614, UNICODE_NORM_QC_NO},
+	{0x1D615, UNICODE_NORM_QC_NO},
+	{0x1D616, UNICODE_NORM_QC_NO},
+	{0x1D617, UNICODE_NORM_QC_NO},
+	{0x1D618, UNICODE_NORM_QC_NO},
+	{0x1D619, UNICODE_NORM_QC_NO},
+	{0x1D61A, UNICODE_NORM_QC_NO},
+	{0x1D61B, UNICODE_NORM_QC_NO},
+	{0x1D61C, UNICODE_NORM_QC_NO},
+	{0x1D61D, UNICODE_NORM_QC_NO},
+	{0x1D61E, UNICODE_NORM_QC_NO},
+	{0x1D61F, UNICODE_NORM_QC_NO},
+	{0x1D620, UNICODE_NORM_QC_NO},
+	{0x1D621, UNICODE_NORM_QC_NO},
+	{0x1D622, UNICODE_NORM_QC_NO},
+	{0x1D623, UNICODE_NORM_QC_NO},
+	{0x1D624, UNICODE_NORM_QC_NO},
+	{0x1D625, UNICODE_NORM_QC_NO},
+	{0x1D626, UNICODE_NORM_QC_NO},
+	{0x1D627, UNICODE_NORM_QC_NO},
+	{0x1D628, UNICODE_NORM_QC_NO},
+	{0x1D629, UNICODE_NORM_QC_NO},
+	{0x1D62A, UNICODE_NORM_QC_NO},
+	{0x1D62B, UNICODE_NORM_QC_NO},
+	{0x1D62C, UNICODE_NORM_QC_NO},
+	{0x1D62D, UNICODE_NORM_QC_NO},
+	{0x1D62E, UNICODE_NORM_QC_NO},
+	{0x1D62F, UNICODE_NORM_QC_NO},
+	{0x1D630, UNICODE_NORM_QC_NO},
+	{0x1D631, UNICODE_NORM_QC_NO},
+	{0x1D632, UNICODE_NORM_QC_NO},
+	{0x1D633, UNICODE_NORM_QC_NO},
+	{0x1D634, UNICODE_NORM_QC_NO},
+	{0x1D635, UNICODE_NORM_QC_NO},
+	{0x1D636, UNICODE_NORM_QC_NO},
+	{0x1D637, UNICODE_NORM_QC_NO},
+	{0x1D638, UNICODE_NORM_QC_NO},
+	{0x1D639, UNICODE_NORM_QC_NO},
+	{0x1D63A, UNICODE_NORM_QC_NO},
+	{0x1D63B, UNICODE_NORM_QC_NO},
+	{0x1D63C, UNICODE_NORM_QC_NO},
+	{0x1D63D, UNICODE_NORM_QC_NO},
+	{0x1D63E, UNICODE_NORM_QC_NO},
+	{0x1D63F, UNICODE_NORM_QC_NO},
+	{0x1D640, UNICODE_NORM_QC_NO},
+	{0x1D641, UNICODE_NORM_QC_NO},
+	{0x1D642, UNICODE_NORM_QC_NO},
+	{0x1D643, UNICODE_NORM_QC_NO},
+	{0x1D644, UNICODE_NORM_QC_NO},
+	{0x1D645, UNICODE_NORM_QC_NO},
+	{0x1D646, UNICODE_NORM_QC_NO},
+	{0x1D647, UNICODE_NORM_QC_NO},
+	{0x1D648, UNICODE_NORM_QC_NO},
+	{0x1D649, UNICODE_NORM_QC_NO},
+	{0x1D64A, UNICODE_NORM_QC_NO},
+	{0x1D64B, UNICODE_NORM_QC_NO},
+	{0x1D64C, UNICODE_NORM_QC_NO},
+	{0x1D64D, UNICODE_NORM_QC_NO},
+	{0x1D64E, UNICODE_NORM_QC_NO},
+	{0x1D64F, UNICODE_NORM_QC_NO},
+	{0x1D650, UNICODE_NORM_QC_NO},
+	{0x1D651, UNICODE_NORM_QC_NO},
+	{0x1D652, UNICODE_NORM_QC_NO},
+	{0x1D653, UNICODE_NORM_QC_NO},
+	{0x1D654, UNICODE_NORM_QC_NO},
+	{0x1D655, UNICODE_NORM_QC_NO},
+	{0x1D656, UNICODE_NORM_QC_NO},
+	{0x1D657, UNICODE_NORM_QC_NO},
+	{0x1D658, UNICODE_NORM_QC_NO},
+	{0x1D659, UNICODE_NORM_QC_NO},
+	{0x1D65A, UNICODE_NORM_QC_NO},
+	{0x1D65B, UNICODE_NORM_QC_NO},
+	{0x1D65C, UNICODE_NORM_QC_NO},
+	{0x1D65D, UNICODE_NORM_QC_NO},
+	{0x1D65E, UNICODE_NORM_QC_NO},
+	{0x1D65F, UNICODE_NORM_QC_NO},
+	{0x1D660, UNICODE_NORM_QC_NO},
+	{0x1D661, UNICODE_NORM_QC_NO},
+	{0x1D662, UNICODE_NORM_QC_NO},
+	{0x1D663, UNICODE_NORM_QC_NO},
+	{0x1D664, UNICODE_NORM_QC_NO},
+	{0x1D665, UNICODE_NORM_QC_NO},
+	{0x1D666, UNICODE_NORM_QC_NO},
+	{0x1D667, UNICODE_NORM_QC_NO},
+	{0x1D668, UNICODE_NORM_QC_NO},
+	{0x1D669, UNICODE_NORM_QC_NO},
+	{0x1D66A, UNICODE_NORM_QC_NO},
+	{0x1D66B, UNICODE_NORM_QC_NO},
+	{0x1D66C, UNICODE_NORM_QC_NO},
+	{0x1D66D, UNICODE_NORM_QC_NO},
+	{0x1D66E, UNICODE_NORM_QC_NO},
+	{0x1D66F, UNICODE_NORM_QC_NO},
+	{0x1D670, UNICODE_NORM_QC_NO},
+	{0x1D671, UNICODE_NORM_QC_NO},
+	{0x1D672, UNICODE_NORM_QC_NO},
+	{0x1D673, UNICODE_NORM_QC_NO},
+	{0x1D674, UNICODE_NORM_QC_NO},
+	{0x1D675, UNICODE_NORM_QC_NO},
+	{0x1D676, UNICODE_NORM_QC_NO},
+	{0x1D677, UNICODE_NORM_QC_NO},
+	{0x1D678, UNICODE_NORM_QC_NO},
+	{0x1D679, UNICODE_NORM_QC_NO},
+	{0x1D67A, UNICODE_NORM_QC_NO},
+	{0x1D67B, UNICODE_NORM_QC_NO},
+	{0x1D67C, UNICODE_NORM_QC_NO},
+	{0x1D67D, UNICODE_NORM_QC_NO},
+	{0x1D67E, UNICODE_NORM_QC_NO},
+	{0x1D67F, UNICODE_NORM_QC_NO},
+	{0x1D680, UNICODE_NORM_QC_NO},
+	{0x1D681, UNICODE_NORM_QC_NO},
+	{0x1D682, UNICODE_NORM_QC_NO},
+	{0x1D683, UNICODE_NORM_QC_NO},
+	{0x1D684, UNICODE_NORM_QC_NO},
+	{0x1D685, UNICODE_NORM_QC_NO},
+	{0x1D686, UNICODE_NORM_QC_NO},
+	{0x1D687, UNICODE_NORM_QC_NO},
+	{0x1D688, UNICODE_NORM_QC_NO},
+	{0x1D689, UNICODE_NORM_QC_NO},
+	{0x1D68A, UNICODE_NORM_QC_NO},
+	{0x1D68B, UNICODE_NORM_QC_NO},
+	{0x1D68C, UNICODE_NORM_QC_NO},
+	{0x1D68D, UNICODE_NORM_QC_NO},
+	{0x1D68E, UNICODE_NORM_QC_NO},
+	{0x1D68F, UNICODE_NORM_QC_NO},
+	{0x1D690, UNICODE_NORM_QC_NO},
+	{0x1D691, UNICODE_NORM_QC_NO},
+	{0x1D692, UNICODE_NORM_QC_NO},
+	{0x1D693, UNICODE_NORM_QC_NO},
+	{0x1D694, UNICODE_NORM_QC_NO},
+	{0x1D695, UNICODE_NORM_QC_NO},
+	{0x1D696, UNICODE_NORM_QC_NO},
+	{0x1D697, UNICODE_NORM_QC_NO},
+	{0x1D698, UNICODE_NORM_QC_NO},
+	{0x1D699, UNICODE_NORM_QC_NO},
+	{0x1D69A, UNICODE_NORM_QC_NO},
+	{0x1D69B, UNICODE_NORM_QC_NO},
+	{0x1D69C, UNICODE_NORM_QC_NO},
+	{0x1D69D, UNICODE_NORM_QC_NO},
+	{0x1D69E, UNICODE_NORM_QC_NO},
+	{0x1D69F, UNICODE_NORM_QC_NO},
+	{0x1D6A0, UNICODE_NORM_QC_NO},
+	{0x1D6A1, UNICODE_NORM_QC_NO},
+	{0x1D6A2, UNICODE_NORM_QC_NO},
+	{0x1D6A3, UNICODE_NORM_QC_NO},
+	{0x1D6A4, UNICODE_NORM_QC_NO},
+	{0x1D6A5, UNICODE_NORM_QC_NO},
+	{0x1D6A8, UNICODE_NORM_QC_NO},
+	{0x1D6A9, UNICODE_NORM_QC_NO},
+	{0x1D6AA, UNICODE_NORM_QC_NO},
+	{0x1D6AB, UNICODE_NORM_QC_NO},
+	{0x1D6AC, UNICODE_NORM_QC_NO},
+	{0x1D6AD, UNICODE_NORM_QC_NO},
+	{0x1D6AE, UNICODE_NORM_QC_NO},
+	{0x1D6AF, UNICODE_NORM_QC_NO},
+	{0x1D6B0, UNICODE_NORM_QC_NO},
+	{0x1D6B1, UNICODE_NORM_QC_NO},
+	{0x1D6B2, UNICODE_NORM_QC_NO},
+	{0x1D6B3, UNICODE_NORM_QC_NO},
+	{0x1D6B4, UNICODE_NORM_QC_NO},
+	{0x1D6B5, UNICODE_NORM_QC_NO},
+	{0x1D6B6, UNICODE_NORM_QC_NO},
+	{0x1D6B7, UNICODE_NORM_QC_NO},
+	{0x1D6B8, UNICODE_NORM_QC_NO},
+	{0x1D6B9, UNICODE_NORM_QC_NO},
+	{0x1D6BA, UNICODE_NORM_QC_NO},
+	{0x1D6BB, UNICODE_NORM_QC_NO},
+	{0x1D6BC, UNICODE_NORM_QC_NO},
+	{0x1D6BD, UNICODE_NORM_QC_NO},
+	{0x1D6BE, UNICODE_NORM_QC_NO},
+	{0x1D6BF, UNICODE_NORM_QC_NO},
+	{0x1D6C0, UNICODE_NORM_QC_NO},
+	{0x1D6C1, UNICODE_NORM_QC_NO},
+	{0x1D6C2, UNICODE_NORM_QC_NO},
+	{0x1D6C3, UNICODE_NORM_QC_NO},
+	{0x1D6C4, UNICODE_NORM_QC_NO},
+	{0x1D6C5, UNICODE_NORM_QC_NO},
+	{0x1D6C6, UNICODE_NORM_QC_NO},
+	{0x1D6C7, UNICODE_NORM_QC_NO},
+	{0x1D6C8, UNICODE_NORM_QC_NO},
+	{0x1D6C9, UNICODE_NORM_QC_NO},
+	{0x1D6CA, UNICODE_NORM_QC_NO},
+	{0x1D6CB, UNICODE_NORM_QC_NO},
+	{0x1D6CC, UNICODE_NORM_QC_NO},
+	{0x1D6CD, UNICODE_NORM_QC_NO},
+	{0x1D6CE, UNICODE_NORM_QC_NO},
+	{0x1D6CF, UNICODE_NORM_QC_NO},
+	{0x1D6D0, UNICODE_NORM_QC_NO},
+	{0x1D6D1, UNICODE_NORM_QC_NO},
+	{0x1D6D2, UNICODE_NORM_QC_NO},
+	{0x1D6D3, UNICODE_NORM_QC_NO},
+	{0x1D6D4, UNICODE_NORM_QC_NO},
+	{0x1D6D5, UNICODE_NORM_QC_NO},
+	{0x1D6D6, UNICODE_NORM_QC_NO},
+	{0x1D6D7, UNICODE_NORM_QC_NO},
+	{0x1D6D8, UNICODE_NORM_QC_NO},
+	{0x1D6D9, UNICODE_NORM_QC_NO},
+	{0x1D6DA, UNICODE_NORM_QC_NO},
+	{0x1D6DB, UNICODE_NORM_QC_NO},
+	{0x1D6DC, UNICODE_NORM_QC_NO},
+	{0x1D6DD, UNICODE_NORM_QC_NO},
+	{0x1D6DE, UNICODE_NORM_QC_NO},
+	{0x1D6DF, UNICODE_NORM_QC_NO},
+	{0x1D6E0, UNICODE_NORM_QC_NO},
+	{0x1D6E1, UNICODE_NORM_QC_NO},
+	{0x1D6E2, UNICODE_NORM_QC_NO},
+	{0x1D6E3, UNICODE_NORM_QC_NO},
+	{0x1D6E4, UNICODE_NORM_QC_NO},
+	{0x1D6E5, UNICODE_NORM_QC_NO},
+	{0x1D6E6, UNICODE_NORM_QC_NO},
+	{0x1D6E7, UNICODE_NORM_QC_NO},
+	{0x1D6E8, UNICODE_NORM_QC_NO},
+	{0x1D6E9, UNICODE_NORM_QC_NO},
+	{0x1D6EA, UNICODE_NORM_QC_NO},
+	{0x1D6EB, UNICODE_NORM_QC_NO},
+	{0x1D6EC, UNICODE_NORM_QC_NO},
+	{0x1D6ED, UNICODE_NORM_QC_NO},
+	{0x1D6EE, UNICODE_NORM_QC_NO},
+	{0x1D6EF, UNICODE_NORM_QC_NO},
+	{0x1D6F0, UNICODE_NORM_QC_NO},
+	{0x1D6F1, UNICODE_NORM_QC_NO},
+	{0x1D6F2, UNICODE_NORM_QC_NO},
+	{0x1D6F3, UNICODE_NORM_QC_NO},
+	{0x1D6F4, UNICODE_NORM_QC_NO},
+	{0x1D6F5, UNICODE_NORM_QC_NO},
+	{0x1D6F6, UNICODE_NORM_QC_NO},
+	{0x1D6F7, UNICODE_NORM_QC_NO},
+	{0x1D6F8, UNICODE_NORM_QC_NO},
+	{0x1D6F9, UNICODE_NORM_QC_NO},
+	{0x1D6FA, UNICODE_NORM_QC_NO},
+	{0x1D6FB, UNICODE_NORM_QC_NO},
+	{0x1D6FC, UNICODE_NORM_QC_NO},
+	{0x1D6FD, UNICODE_NORM_QC_NO},
+	{0x1D6FE, UNICODE_NORM_QC_NO},
+	{0x1D6FF, UNICODE_NORM_QC_NO},
+	{0x1D700, UNICODE_NORM_QC_NO},
+	{0x1D701, UNICODE_NORM_QC_NO},
+	{0x1D702, UNICODE_NORM_QC_NO},
+	{0x1D703, UNICODE_NORM_QC_NO},
+	{0x1D704, UNICODE_NORM_QC_NO},
+	{0x1D705, UNICODE_NORM_QC_NO},
+	{0x1D706, UNICODE_NORM_QC_NO},
+	{0x1D707, UNICODE_NORM_QC_NO},
+	{0x1D708, UNICODE_NORM_QC_NO},
+	{0x1D709, UNICODE_NORM_QC_NO},
+	{0x1D70A, UNICODE_NORM_QC_NO},
+	{0x1D70B, UNICODE_NORM_QC_NO},
+	{0x1D70C, UNICODE_NORM_QC_NO},
+	{0x1D70D, UNICODE_NORM_QC_NO},
+	{0x1D70E, UNICODE_NORM_QC_NO},
+	{0x1D70F, UNICODE_NORM_QC_NO},
+	{0x1D710, UNICODE_NORM_QC_NO},
+	{0x1D711, UNICODE_NORM_QC_NO},
+	{0x1D712, UNICODE_NORM_QC_NO},
+	{0x1D713, UNICODE_NORM_QC_NO},
+	{0x1D714, UNICODE_NORM_QC_NO},
+	{0x1D715, UNICODE_NORM_QC_NO},
+	{0x1D716, UNICODE_NORM_QC_NO},
+	{0x1D717, UNICODE_NORM_QC_NO},
+	{0x1D718, UNICODE_NORM_QC_NO},
+	{0x1D719, UNICODE_NORM_QC_NO},
+	{0x1D71A, UNICODE_NORM_QC_NO},
+	{0x1D71B, UNICODE_NORM_QC_NO},
+	{0x1D71C, UNICODE_NORM_QC_NO},
+	{0x1D71D, UNICODE_NORM_QC_NO},
+	{0x1D71E, UNICODE_NORM_QC_NO},
+	{0x1D71F, UNICODE_NORM_QC_NO},
+	{0x1D720, UNICODE_NORM_QC_NO},
+	{0x1D721, UNICODE_NORM_QC_NO},
+	{0x1D722, UNICODE_NORM_QC_NO},
+	{0x1D723, UNICODE_NORM_QC_NO},
+	{0x1D724, UNICODE_NORM_QC_NO},
+	{0x1D725, UNICODE_NORM_QC_NO},
+	{0x1D726, UNICODE_NORM_QC_NO},
+	{0x1D727, UNICODE_NORM_QC_NO},
+	{0x1D728, UNICODE_NORM_QC_NO},
+	{0x1D729, UNICODE_NORM_QC_NO},
+	{0x1D72A, UNICODE_NORM_QC_NO},
+	{0x1D72B, UNICODE_NORM_QC_NO},
+	{0x1D72C, UNICODE_NORM_QC_NO},
+	{0x1D72D, UNICODE_NORM_QC_NO},
+	{0x1D72E, UNICODE_NORM_QC_NO},
+	{0x1D72F, UNICODE_NORM_QC_NO},
+	{0x1D730, UNICODE_NORM_QC_NO},
+	{0x1D731, UNICODE_NORM_QC_NO},
+	{0x1D732, UNICODE_NORM_QC_NO},
+	{0x1D733, UNICODE_NORM_QC_NO},
+	{0x1D734, UNICODE_NORM_QC_NO},
+	{0x1D735, UNICODE_NORM_QC_NO},
+	{0x1D736, UNICODE_NORM_QC_NO},
+	{0x1D737, UNICODE_NORM_QC_NO},
+	{0x1D738, UNICODE_NORM_QC_NO},
+	{0x1D739, UNICODE_NORM_QC_NO},
+	{0x1D73A, UNICODE_NORM_QC_NO},
+	{0x1D73B, UNICODE_NORM_QC_NO},
+	{0x1D73C, UNICODE_NORM_QC_NO},
+	{0x1D73D, UNICODE_NORM_QC_NO},
+	{0x1D73E, UNICODE_NORM_QC_NO},
+	{0x1D73F, UNICODE_NORM_QC_NO},
+	{0x1D740, UNICODE_NORM_QC_NO},
+	{0x1D741, UNICODE_NORM_QC_NO},
+	{0x1D742, UNICODE_NORM_QC_NO},
+	{0x1D743, UNICODE_NORM_QC_NO},
+	{0x1D744, UNICODE_NORM_QC_NO},
+	{0x1D745, UNICODE_NORM_QC_NO},
+	{0x1D746, UNICODE_NORM_QC_NO},
+	{0x1D747, UNICODE_NORM_QC_NO},
+	{0x1D748, UNICODE_NORM_QC_NO},
+	{0x1D749, UNICODE_NORM_QC_NO},
+	{0x1D74A, UNICODE_NORM_QC_NO},
+	{0x1D74B, UNICODE_NORM_QC_NO},
+	{0x1D74C, UNICODE_NORM_QC_NO},
+	{0x1D74D, UNICODE_NORM_QC_NO},
+	{0x1D74E, UNICODE_NORM_QC_NO},
+	{0x1D74F, UNICODE_NORM_QC_NO},
+	{0x1D750, UNICODE_NORM_QC_NO},
+	{0x1D751, UNICODE_NORM_QC_NO},
+	{0x1D752, UNICODE_NORM_QC_NO},
+	{0x1D753, UNICODE_NORM_QC_NO},
+	{0x1D754, UNICODE_NORM_QC_NO},
+	{0x1D755, UNICODE_NORM_QC_NO},
+	{0x1D756, UNICODE_NORM_QC_NO},
+	{0x1D757, UNICODE_NORM_QC_NO},
+	{0x1D758, UNICODE_NORM_QC_NO},
+	{0x1D759, UNICODE_NORM_QC_NO},
+	{0x1D75A, UNICODE_NORM_QC_NO},
+	{0x1D75B, UNICODE_NORM_QC_NO},
+	{0x1D75C, UNICODE_NORM_QC_NO},
+	{0x1D75D, UNICODE_NORM_QC_NO},
+	{0x1D75E, UNICODE_NORM_QC_NO},
+	{0x1D75F, UNICODE_NORM_QC_NO},
+	{0x1D760, UNICODE_NORM_QC_NO},
+	{0x1D761, UNICODE_NORM_QC_NO},
+	{0x1D762, UNICODE_NORM_QC_NO},
+	{0x1D763, UNICODE_NORM_QC_NO},
+	{0x1D764, UNICODE_NORM_QC_NO},
+	{0x1D765, UNICODE_NORM_QC_NO},
+	{0x1D766, UNICODE_NORM_QC_NO},
+	{0x1D767, UNICODE_NORM_QC_NO},
+	{0x1D768, UNICODE_NORM_QC_NO},
+	{0x1D769, UNICODE_NORM_QC_NO},
+	{0x1D76A, UNICODE_NORM_QC_NO},
+	{0x1D76B, UNICODE_NORM_QC_NO},
+	{0x1D76C, UNICODE_NORM_QC_NO},
+	{0x1D76D, UNICODE_NORM_QC_NO},
+	{0x1D76E, UNICODE_NORM_QC_NO},
+	{0x1D76F, UNICODE_NORM_QC_NO},
+	{0x1D770, UNICODE_NORM_QC_NO},
+	{0x1D771, UNICODE_NORM_QC_NO},
+	{0x1D772, UNICODE_NORM_QC_NO},
+	{0x1D773, UNICODE_NORM_QC_NO},
+	{0x1D774, UNICODE_NORM_QC_NO},
+	{0x1D775, UNICODE_NORM_QC_NO},
+	{0x1D776, UNICODE_NORM_QC_NO},
+	{0x1D777, UNICODE_NORM_QC_NO},
+	{0x1D778, UNICODE_NORM_QC_NO},
+	{0x1D779, UNICODE_NORM_QC_NO},
+	{0x1D77A, UNICODE_NORM_QC_NO},
+	{0x1D77B, UNICODE_NORM_QC_NO},
+	{0x1D77C, UNICODE_NORM_QC_NO},
+	{0x1D77D, UNICODE_NORM_QC_NO},
+	{0x1D77E, UNICODE_NORM_QC_NO},
+	{0x1D77F, UNICODE_NORM_QC_NO},
+	{0x1D780, UNICODE_NORM_QC_NO},
+	{0x1D781, UNICODE_NORM_QC_NO},
+	{0x1D782, UNICODE_NORM_QC_NO},
+	{0x1D783, UNICODE_NORM_QC_NO},
+	{0x1D784, UNICODE_NORM_QC_NO},
+	{0x1D785, UNICODE_NORM_QC_NO},
+	{0x1D786, UNICODE_NORM_QC_NO},
+	{0x1D787, UNICODE_NORM_QC_NO},
+	{0x1D788, UNICODE_NORM_QC_NO},
+	{0x1D789, UNICODE_NORM_QC_NO},
+	{0x1D78A, UNICODE_NORM_QC_NO},
+	{0x1D78B, UNICODE_NORM_QC_NO},
+	{0x1D78C, UNICODE_NORM_QC_NO},
+	{0x1D78D, UNICODE_NORM_QC_NO},
+	{0x1D78E, UNICODE_NORM_QC_NO},
+	{0x1D78F, UNICODE_NORM_QC_NO},
+	{0x1D790, UNICODE_NORM_QC_NO},
+	{0x1D791, UNICODE_NORM_QC_NO},
+	{0x1D792, UNICODE_NORM_QC_NO},
+	{0x1D793, UNICODE_NORM_QC_NO},
+	{0x1D794, UNICODE_NORM_QC_NO},
+	{0x1D795, UNICODE_NORM_QC_NO},
+	{0x1D796, UNICODE_NORM_QC_NO},
+	{0x1D797, UNICODE_NORM_QC_NO},
+	{0x1D798, UNICODE_NORM_QC_NO},
+	{0x1D799, UNICODE_NORM_QC_NO},
+	{0x1D79A, UNICODE_NORM_QC_NO},
+	{0x1D79B, UNICODE_NORM_QC_NO},
+	{0x1D79C, UNICODE_NORM_QC_NO},
+	{0x1D79D, UNICODE_NORM_QC_NO},
+	{0x1D79E, UNICODE_NORM_QC_NO},
+	{0x1D79F, UNICODE_NORM_QC_NO},
+	{0x1D7A0, UNICODE_NORM_QC_NO},
+	{0x1D7A1, UNICODE_NORM_QC_NO},
+	{0x1D7A2, UNICODE_NORM_QC_NO},
+	{0x1D7A3, UNICODE_NORM_QC_NO},
+	{0x1D7A4, UNICODE_NORM_QC_NO},
+	{0x1D7A5, UNICODE_NORM_QC_NO},
+	{0x1D7A6, UNICODE_NORM_QC_NO},
+	{0x1D7A7, UNICODE_NORM_QC_NO},
+	{0x1D7A8, UNICODE_NORM_QC_NO},
+	{0x1D7A9, UNICODE_NORM_QC_NO},
+	{0x1D7AA, UNICODE_NORM_QC_NO},
+	{0x1D7AB, UNICODE_NORM_QC_NO},
+	{0x1D7AC, UNICODE_NORM_QC_NO},
+	{0x1D7AD, UNICODE_NORM_QC_NO},
+	{0x1D7AE, UNICODE_NORM_QC_NO},
+	{0x1D7AF, UNICODE_NORM_QC_NO},
+	{0x1D7B0, UNICODE_NORM_QC_NO},
+	{0x1D7B1, UNICODE_NORM_QC_NO},
+	{0x1D7B2, UNICODE_NORM_QC_NO},
+	{0x1D7B3, UNICODE_NORM_QC_NO},
+	{0x1D7B4, UNICODE_NORM_QC_NO},
+	{0x1D7B5, UNICODE_NORM_QC_NO},
+	{0x1D7B6, UNICODE_NORM_QC_NO},
+	{0x1D7B7, UNICODE_NORM_QC_NO},
+	{0x1D7B8, UNICODE_NORM_QC_NO},
+	{0x1D7B9, UNICODE_NORM_QC_NO},
+	{0x1D7BA, UNICODE_NORM_QC_NO},
+	{0x1D7BB, UNICODE_NORM_QC_NO},
+	{0x1D7BC, UNICODE_NORM_QC_NO},
+	{0x1D7BD, UNICODE_NORM_QC_NO},
+	{0x1D7BE, UNICODE_NORM_QC_NO},
+	{0x1D7BF, UNICODE_NORM_QC_NO},
+	{0x1D7C0, UNICODE_NORM_QC_NO},
+	{0x1D7C1, UNICODE_NORM_QC_NO},
+	{0x1D7C2, UNICODE_NORM_QC_NO},
+	{0x1D7C3, UNICODE_NORM_QC_NO},
+	{0x1D7C4, UNICODE_NORM_QC_NO},
+	{0x1D7C5, UNICODE_NORM_QC_NO},
+	{0x1D7C6, UNICODE_NORM_QC_NO},
+	{0x1D7C7, UNICODE_NORM_QC_NO},
+	{0x1D7C8, UNICODE_NORM_QC_NO},
+	{0x1D7C9, UNICODE_NORM_QC_NO},
+	{0x1D7CA, UNICODE_NORM_QC_NO},
+	{0x1D7CB, UNICODE_NORM_QC_NO},
+	{0x1D7CE, UNICODE_NORM_QC_NO},
+	{0x1D7CF, UNICODE_NORM_QC_NO},
+	{0x1D7D0, UNICODE_NORM_QC_NO},
+	{0x1D7D1, UNICODE_NORM_QC_NO},
+	{0x1D7D2, UNICODE_NORM_QC_NO},
+	{0x1D7D3, UNICODE_NORM_QC_NO},
+	{0x1D7D4, UNICODE_NORM_QC_NO},
+	{0x1D7D5, UNICODE_NORM_QC_NO},
+	{0x1D7D6, UNICODE_NORM_QC_NO},
+	{0x1D7D7, UNICODE_NORM_QC_NO},
+	{0x1D7D8, UNICODE_NORM_QC_NO},
+	{0x1D7D9, UNICODE_NORM_QC_NO},
+	{0x1D7DA, UNICODE_NORM_QC_NO},
+	{0x1D7DB, UNICODE_NORM_QC_NO},
+	{0x1D7DC, UNICODE_NORM_QC_NO},
+	{0x1D7DD, UNICODE_NORM_QC_NO},
+	{0x1D7DE, UNICODE_NORM_QC_NO},
+	{0x1D7DF, UNICODE_NORM_QC_NO},
+	{0x1D7E0, UNICODE_NORM_QC_NO},
+	{0x1D7E1, UNICODE_NORM_QC_NO},
+	{0x1D7E2, UNICODE_NORM_QC_NO},
+	{0x1D7E3, UNICODE_NORM_QC_NO},
+	{0x1D7E4, UNICODE_NORM_QC_NO},
+	{0x1D7E5, UNICODE_NORM_QC_NO},
+	{0x1D7E6, UNICODE_NORM_QC_NO},
+	{0x1D7E7, UNICODE_NORM_QC_NO},
+	{0x1D7E8, UNICODE_NORM_QC_NO},
+	{0x1D7E9, UNICODE_NORM_QC_NO},
+	{0x1D7EA, UNICODE_NORM_QC_NO},
+	{0x1D7EB, UNICODE_NORM_QC_NO},
+	{0x1D7EC, UNICODE_NORM_QC_NO},
+	{0x1D7ED, UNICODE_NORM_QC_NO},
+	{0x1D7EE, UNICODE_NORM_QC_NO},
+	{0x1D7EF, UNICODE_NORM_QC_NO},
+	{0x1D7F0, UNICODE_NORM_QC_NO},
+	{0x1D7F1, UNICODE_NORM_QC_NO},
+	{0x1D7F2, UNICODE_NORM_QC_NO},
+	{0x1D7F3, UNICODE_NORM_QC_NO},
+	{0x1D7F4, UNICODE_NORM_QC_NO},
+	{0x1D7F5, UNICODE_NORM_QC_NO},
+	{0x1D7F6, UNICODE_NORM_QC_NO},
+	{0x1D7F7, UNICODE_NORM_QC_NO},
+	{0x1D7F8, UNICODE_NORM_QC_NO},
+	{0x1D7F9, UNICODE_NORM_QC_NO},
+	{0x1D7FA, UNICODE_NORM_QC_NO},
+	{0x1D7FB, UNICODE_NORM_QC_NO},
+	{0x1D7FC, UNICODE_NORM_QC_NO},
+	{0x1D7FD, UNICODE_NORM_QC_NO},
+	{0x1D7FE, UNICODE_NORM_QC_NO},
+	{0x1D7FF, UNICODE_NORM_QC_NO},
+	{0x1EE00, UNICODE_NORM_QC_NO},
+	{0x1EE01, UNICODE_NORM_QC_NO},
+	{0x1EE02, UNICODE_NORM_QC_NO},
+	{0x1EE03, UNICODE_NORM_QC_NO},
+	{0x1EE05, UNICODE_NORM_QC_NO},
+	{0x1EE06, UNICODE_NORM_QC_NO},
+	{0x1EE07, UNICODE_NORM_QC_NO},
+	{0x1EE08, UNICODE_NORM_QC_NO},
+	{0x1EE09, UNICODE_NORM_QC_NO},
+	{0x1EE0A, UNICODE_NORM_QC_NO},
+	{0x1EE0B, UNICODE_NORM_QC_NO},
+	{0x1EE0C, UNICODE_NORM_QC_NO},
+	{0x1EE0D, UNICODE_NORM_QC_NO},
+	{0x1EE0E, UNICODE_NORM_QC_NO},
+	{0x1EE0F, UNICODE_NORM_QC_NO},
+	{0x1EE10, UNICODE_NORM_QC_NO},
+	{0x1EE11, UNICODE_NORM_QC_NO},
+	{0x1EE12, UNICODE_NORM_QC_NO},
+	{0x1EE13, UNICODE_NORM_QC_NO},
+	{0x1EE14, UNICODE_NORM_QC_NO},
+	{0x1EE15, UNICODE_NORM_QC_NO},
+	{0x1EE16, UNICODE_NORM_QC_NO},
+	{0x1EE17, UNICODE_NORM_QC_NO},
+	{0x1EE18, UNICODE_NORM_QC_NO},
+	{0x1EE19, UNICODE_NORM_QC_NO},
+	{0x1EE1A, UNICODE_NORM_QC_NO},
+	{0x1EE1B, UNICODE_NORM_QC_NO},
+	{0x1EE1C, UNICODE_NORM_QC_NO},
+	{0x1EE1D, UNICODE_NORM_QC_NO},
+	{0x1EE1E, UNICODE_NORM_QC_NO},
+	{0x1EE1F, UNICODE_NORM_QC_NO},
+	{0x1EE21, UNICODE_NORM_QC_NO},
+	{0x1EE22, UNICODE_NORM_QC_NO},
+	{0x1EE24, UNICODE_NORM_QC_NO},
+	{0x1EE27, UNICODE_NORM_QC_NO},
+	{0x1EE29, UNICODE_NORM_QC_NO},
+	{0x1EE2A, UNICODE_NORM_QC_NO},
+	{0x1EE2B, UNICODE_NORM_QC_NO},
+	{0x1EE2C, UNICODE_NORM_QC_NO},
+	{0x1EE2D, UNICODE_NORM_QC_NO},
+	{0x1EE2E, UNICODE_NORM_QC_NO},
+	{0x1EE2F, UNICODE_NORM_QC_NO},
+	{0x1EE30, UNICODE_NORM_QC_NO},
+	{0x1EE31, UNICODE_NORM_QC_NO},
+	{0x1EE32, UNICODE_NORM_QC_NO},
+	{0x1EE34, UNICODE_NORM_QC_NO},
+	{0x1EE35, UNICODE_NORM_QC_NO},
+	{0x1EE36, UNICODE_NORM_QC_NO},
+	{0x1EE37, UNICODE_NORM_QC_NO},
+	{0x1EE39, UNICODE_NORM_QC_NO},
+	{0x1EE3B, UNICODE_NORM_QC_NO},
+	{0x1EE42, UNICODE_NORM_QC_NO},
+	{0x1EE47, UNICODE_NORM_QC_NO},
+	{0x1EE49, UNICODE_NORM_QC_NO},
+	{0x1EE4B, UNICODE_NORM_QC_NO},
+	{0x1EE4D, UNICODE_NORM_QC_NO},
+	{0x1EE4E, UNICODE_NORM_QC_NO},
+	{0x1EE4F, UNICODE_NORM_QC_NO},
+	{0x1EE51, UNICODE_NORM_QC_NO},
+	{0x1EE52, UNICODE_NORM_QC_NO},
+	{0x1EE54, UNICODE_NORM_QC_NO},
+	{0x1EE57, UNICODE_NORM_QC_NO},
+	{0x1EE59, UNICODE_NORM_QC_NO},
+	{0x1EE5B, UNICODE_NORM_QC_NO},
+	{0x1EE5D, UNICODE_NORM_QC_NO},
+	{0x1EE5F, UNICODE_NORM_QC_NO},
+	{0x1EE61, UNICODE_NORM_QC_NO},
+	{0x1EE62, UNICODE_NORM_QC_NO},
+	{0x1EE64, UNICODE_NORM_QC_NO},
+	{0x1EE67, UNICODE_NORM_QC_NO},
+	{0x1EE68, UNICODE_NORM_QC_NO},
+	{0x1EE69, UNICODE_NORM_QC_NO},
+	{0x1EE6A, UNICODE_NORM_QC_NO},
+	{0x1EE6C, UNICODE_NORM_QC_NO},
+	{0x1EE6D, UNICODE_NORM_QC_NO},
+	{0x1EE6E, UNICODE_NORM_QC_NO},
+	{0x1EE6F, UNICODE_NORM_QC_NO},
+	{0x1EE70, UNICODE_NORM_QC_NO},
+	{0x1EE71, UNICODE_NORM_QC_NO},
+	{0x1EE72, UNICODE_NORM_QC_NO},
+	{0x1EE74, UNICODE_NORM_QC_NO},
+	{0x1EE75, UNICODE_NORM_QC_NO},
+	{0x1EE76, UNICODE_NORM_QC_NO},
+	{0x1EE77, UNICODE_NORM_QC_NO},
+	{0x1EE79, UNICODE_NORM_QC_NO},
+	{0x1EE7A, UNICODE_NORM_QC_NO},
+	{0x1EE7B, UNICODE_NORM_QC_NO},
+	{0x1EE7C, UNICODE_NORM_QC_NO},
+	{0x1EE7E, UNICODE_NORM_QC_NO},
+	{0x1EE80, UNICODE_NORM_QC_NO},
+	{0x1EE81, UNICODE_NORM_QC_NO},
+	{0x1EE82, UNICODE_NORM_QC_NO},
+	{0x1EE83, UNICODE_NORM_QC_NO},
+	{0x1EE84, UNICODE_NORM_QC_NO},
+	{0x1EE85, UNICODE_NORM_QC_NO},
+	{0x1EE86, UNICODE_NORM_QC_NO},
+	{0x1EE87, UNICODE_NORM_QC_NO},
+	{0x1EE88, UNICODE_NORM_QC_NO},
+	{0x1EE89, UNICODE_NORM_QC_NO},
+	{0x1EE8B, UNICODE_NORM_QC_NO},
+	{0x1EE8C, UNICODE_NORM_QC_NO},
+	{0x1EE8D, UNICODE_NORM_QC_NO},
+	{0x1EE8E, UNICODE_NORM_QC_NO},
+	{0x1EE8F, UNICODE_NORM_QC_NO},
+	{0x1EE90, UNICODE_NORM_QC_NO},
+	{0x1EE91, UNICODE_NORM_QC_NO},
+	{0x1EE92, UNICODE_NORM_QC_NO},
+	{0x1EE93, UNICODE_NORM_QC_NO},
+	{0x1EE94, UNICODE_NORM_QC_NO},
+	{0x1EE95, UNICODE_NORM_QC_NO},
+	{0x1EE96, UNICODE_NORM_QC_NO},
+	{0x1EE97, UNICODE_NORM_QC_NO},
+	{0x1EE98, UNICODE_NORM_QC_NO},
+	{0x1EE99, UNICODE_NORM_QC_NO},
+	{0x1EE9A, UNICODE_NORM_QC_NO},
+	{0x1EE9B, UNICODE_NORM_QC_NO},
+	{0x1EEA1, UNICODE_NORM_QC_NO},
+	{0x1EEA2, UNICODE_NORM_QC_NO},
+	{0x1EEA3, UNICODE_NORM_QC_NO},
+	{0x1EEA5, UNICODE_NORM_QC_NO},
+	{0x1EEA6, UNICODE_NORM_QC_NO},
+	{0x1EEA7, UNICODE_NORM_QC_NO},
+	{0x1EEA8, UNICODE_NORM_QC_NO},
+	{0x1EEA9, UNICODE_NORM_QC_NO},
+	{0x1EEAB, UNICODE_NORM_QC_NO},
+	{0x1EEAC, UNICODE_NORM_QC_NO},
+	{0x1EEAD, UNICODE_NORM_QC_NO},
+	{0x1EEAE, UNICODE_NORM_QC_NO},
+	{0x1EEAF, UNICODE_NORM_QC_NO},
+	{0x1EEB0, UNICODE_NORM_QC_NO},
+	{0x1EEB1, UNICODE_NORM_QC_NO},
+	{0x1EEB2, UNICODE_NORM_QC_NO},
+	{0x1EEB3, UNICODE_NORM_QC_NO},
+	{0x1EEB4, UNICODE_NORM_QC_NO},
+	{0x1EEB5, UNICODE_NORM_QC_NO},
+	{0x1EEB6, UNICODE_NORM_QC_NO},
+	{0x1EEB7, UNICODE_NORM_QC_NO},
+	{0x1EEB8, UNICODE_NORM_QC_NO},
+	{0x1EEB9, UNICODE_NORM_QC_NO},
+	{0x1EEBA, UNICODE_NORM_QC_NO},
+	{0x1EEBB, UNICODE_NORM_QC_NO},
+	{0x1F100, UNICODE_NORM_QC_NO},
+	{0x1F101, UNICODE_NORM_QC_NO},
+	{0x1F102, UNICODE_NORM_QC_NO},
+	{0x1F103, UNICODE_NORM_QC_NO},
+	{0x1F104, UNICODE_NORM_QC_NO},
+	{0x1F105, UNICODE_NORM_QC_NO},
+	{0x1F106, UNICODE_NORM_QC_NO},
+	{0x1F107, UNICODE_NORM_QC_NO},
+	{0x1F108, UNICODE_NORM_QC_NO},
+	{0x1F109, UNICODE_NORM_QC_NO},
+	{0x1F10A, UNICODE_NORM_QC_NO},
+	{0x1F110, UNICODE_NORM_QC_NO},
+	{0x1F111, UNICODE_NORM_QC_NO},
+	{0x1F112, UNICODE_NORM_QC_NO},
+	{0x1F113, UNICODE_NORM_QC_NO},
+	{0x1F114, UNICODE_NORM_QC_NO},
+	{0x1F115, UNICODE_NORM_QC_NO},
+	{0x1F116, UNICODE_NORM_QC_NO},
+	{0x1F117, UNICODE_NORM_QC_NO},
+	{0x1F118, UNICODE_NORM_QC_NO},
+	{0x1F119, UNICODE_NORM_QC_NO},
+	{0x1F11A, UNICODE_NORM_QC_NO},
+	{0x1F11B, UNICODE_NORM_QC_NO},
+	{0x1F11C, UNICODE_NORM_QC_NO},
+	{0x1F11D, UNICODE_NORM_QC_NO},
+	{0x1F11E, UNICODE_NORM_QC_NO},
+	{0x1F11F, UNICODE_NORM_QC_NO},
+	{0x1F120, UNICODE_NORM_QC_NO},
+	{0x1F121, UNICODE_NORM_QC_NO},
+	{0x1F122, UNICODE_NORM_QC_NO},
+	{0x1F123, UNICODE_NORM_QC_NO},
+	{0x1F124, UNICODE_NORM_QC_NO},
+	{0x1F125, UNICODE_NORM_QC_NO},
+	{0x1F126, UNICODE_NORM_QC_NO},
+	{0x1F127, UNICODE_NORM_QC_NO},
+	{0x1F128, UNICODE_NORM_QC_NO},
+	{0x1F129, UNICODE_NORM_QC_NO},
+	{0x1F12A, UNICODE_NORM_QC_NO},
+	{0x1F12B, UNICODE_NORM_QC_NO},
+	{0x1F12C, UNICODE_NORM_QC_NO},
+	{0x1F12D, UNICODE_NORM_QC_NO},
+	{0x1F12E, UNICODE_NORM_QC_NO},
+	{0x1F130, UNICODE_NORM_QC_NO},
+	{0x1F131, UNICODE_NORM_QC_NO},
+	{0x1F132, UNICODE_NORM_QC_NO},
+	{0x1F133, UNICODE_NORM_QC_NO},
+	{0x1F134, UNICODE_NORM_QC_NO},
+	{0x1F135, UNICODE_NORM_QC_NO},
+	{0x1F136, UNICODE_NORM_QC_NO},
+	{0x1F137, UNICODE_NORM_QC_NO},
+	{0x1F138, UNICODE_NORM_QC_NO},
+	{0x1F139, UNICODE_NORM_QC_NO},
+	{0x1F13A, UNICODE_NORM_QC_NO},
+	{0x1F13B, UNICODE_NORM_QC_NO},
+	{0x1F13C, UNICODE_NORM_QC_NO},
+	{0x1F13D, UNICODE_NORM_QC_NO},
+	{0x1F13E, UNICODE_NORM_QC_NO},
+	{0x1F13F, UNICODE_NORM_QC_NO},
+	{0x1F140, UNICODE_NORM_QC_NO},
+	{0x1F141, UNICODE_NORM_QC_NO},
+	{0x1F142, UNICODE_NORM_QC_NO},
+	{0x1F143, UNICODE_NORM_QC_NO},
+	{0x1F144, UNICODE_NORM_QC_NO},
+	{0x1F145, UNICODE_NORM_QC_NO},
+	{0x1F146, UNICODE_NORM_QC_NO},
+	{0x1F147, UNICODE_NORM_QC_NO},
+	{0x1F148, UNICODE_NORM_QC_NO},
+	{0x1F149, UNICODE_NORM_QC_NO},
+	{0x1F14A, UNICODE_NORM_QC_NO},
+	{0x1F14B, UNICODE_NORM_QC_NO},
+	{0x1F14C, UNICODE_NORM_QC_NO},
+	{0x1F14D, UNICODE_NORM_QC_NO},
+	{0x1F14E, UNICODE_NORM_QC_NO},
+	{0x1F14F, UNICODE_NORM_QC_NO},
+	{0x1F16A, UNICODE_NORM_QC_NO},
+	{0x1F16B, UNICODE_NORM_QC_NO},
+	{0x1F16C, UNICODE_NORM_QC_NO},
+	{0x1F190, UNICODE_NORM_QC_NO},
+	{0x1F200, UNICODE_NORM_QC_NO},
+	{0x1F201, UNICODE_NORM_QC_NO},
+	{0x1F202, UNICODE_NORM_QC_NO},
+	{0x1F210, UNICODE_NORM_QC_NO},
+	{0x1F211, UNICODE_NORM_QC_NO},
+	{0x1F212, UNICODE_NORM_QC_NO},
+	{0x1F213, UNICODE_NORM_QC_NO},
+	{0x1F214, UNICODE_NORM_QC_NO},
+	{0x1F215, UNICODE_NORM_QC_NO},
+	{0x1F216, UNICODE_NORM_QC_NO},
+	{0x1F217, UNICODE_NORM_QC_NO},
+	{0x1F218, UNICODE_NORM_QC_NO},
+	{0x1F219, UNICODE_NORM_QC_NO},
+	{0x1F21A, UNICODE_NORM_QC_NO},
+	{0x1F21B, UNICODE_NORM_QC_NO},
+	{0x1F21C, UNICODE_NORM_QC_NO},
+	{0x1F21D, UNICODE_NORM_QC_NO},
+	{0x1F21E, UNICODE_NORM_QC_NO},
+	{0x1F21F, UNICODE_NORM_QC_NO},
+	{0x1F220, UNICODE_NORM_QC_NO},
+	{0x1F221, UNICODE_NORM_QC_NO},
+	{0x1F222, UNICODE_NORM_QC_NO},
+	{0x1F223, UNICODE_NORM_QC_NO},
+	{0x1F224, UNICODE_NORM_QC_NO},
+	{0x1F225, UNICODE_NORM_QC_NO},
+	{0x1F226, UNICODE_NORM_QC_NO},
+	{0x1F227, UNICODE_NORM_QC_NO},
+	{0x1F228, UNICODE_NORM_QC_NO},
+	{0x1F229, UNICODE_NORM_QC_NO},
+	{0x1F22A, UNICODE_NORM_QC_NO},
+	{0x1F22B, UNICODE_NORM_QC_NO},
+	{0x1F22C, UNICODE_NORM_QC_NO},
+	{0x1F22D, UNICODE_NORM_QC_NO},
+	{0x1F22E, UNICODE_NORM_QC_NO},
+	{0x1F22F, UNICODE_NORM_QC_NO},
+	{0x1F230, UNICODE_NORM_QC_NO},
+	{0x1F231, UNICODE_NORM_QC_NO},
+	{0x1F232, UNICODE_NORM_QC_NO},
+	{0x1F233, UNICODE_NORM_QC_NO},
+	{0x1F234, UNICODE_NORM_QC_NO},
+	{0x1F235, UNICODE_NORM_QC_NO},
+	{0x1F236, UNICODE_NORM_QC_NO},
+	{0x1F237, UNICODE_NORM_QC_NO},
+	{0x1F238, UNICODE_NORM_QC_NO},
+	{0x1F239, UNICODE_NORM_QC_NO},
+	{0x1F23A, UNICODE_NORM_QC_NO},
+	{0x1F23B, UNICODE_NORM_QC_NO},
+	{0x1F240, UNICODE_NORM_QC_NO},
+	{0x1F241, UNICODE_NORM_QC_NO},
+	{0x1F242, UNICODE_NORM_QC_NO},
+	{0x1F243, UNICODE_NORM_QC_NO},
+	{0x1F244, UNICODE_NORM_QC_NO},
+	{0x1F245, UNICODE_NORM_QC_NO},
+	{0x1F246, UNICODE_NORM_QC_NO},
+	{0x1F247, UNICODE_NORM_QC_NO},
+	{0x1F248, UNICODE_NORM_QC_NO},
+	{0x1F250, UNICODE_NORM_QC_NO},
+	{0x1F251, UNICODE_NORM_QC_NO},
+	{0x2F800, UNICODE_NORM_QC_NO},
+	{0x2F801, UNICODE_NORM_QC_NO},
+	{0x2F802, UNICODE_NORM_QC_NO},
+	{0x2F803, UNICODE_NORM_QC_NO},
+	{0x2F804, UNICODE_NORM_QC_NO},
+	{0x2F805, UNICODE_NORM_QC_NO},
+	{0x2F806, UNICODE_NORM_QC_NO},
+	{0x2F807, UNICODE_NORM_QC_NO},
+	{0x2F808, UNICODE_NORM_QC_NO},
+	{0x2F809, UNICODE_NORM_QC_NO},
+	{0x2F80A, UNICODE_NORM_QC_NO},
+	{0x2F80B, UNICODE_NORM_QC_NO},
+	{0x2F80C, UNICODE_NORM_QC_NO},
+	{0x2F80D, UNICODE_NORM_QC_NO},
+	{0x2F80E, UNICODE_NORM_QC_NO},
+	{0x2F80F, UNICODE_NORM_QC_NO},
+	{0x2F810, UNICODE_NORM_QC_NO},
+	{0x2F811, UNICODE_NORM_QC_NO},
+	{0x2F812, UNICODE_NORM_QC_NO},
+	{0x2F813, UNICODE_NORM_QC_NO},
+	{0x2F814, UNICODE_NORM_QC_NO},
+	{0x2F815, UNICODE_NORM_QC_NO},
+	{0x2F816, UNICODE_NORM_QC_NO},
+	{0x2F817, UNICODE_NORM_QC_NO},
+	{0x2F818, UNICODE_NORM_QC_NO},
+	{0x2F819, UNICODE_NORM_QC_NO},
+	{0x2F81A, UNICODE_NORM_QC_NO},
+	{0x2F81B, UNICODE_NORM_QC_NO},
+	{0x2F81C, UNICODE_NORM_QC_NO},
+	{0x2F81D, UNICODE_NORM_QC_NO},
+	{0x2F81E, UNICODE_NORM_QC_NO},
+	{0x2F81F, UNICODE_NORM_QC_NO},
+	{0x2F820, UNICODE_NORM_QC_NO},
+	{0x2F821, UNICODE_NORM_QC_NO},
+	{0x2F822, UNICODE_NORM_QC_NO},
+	{0x2F823, UNICODE_NORM_QC_NO},
+	{0x2F824, UNICODE_NORM_QC_NO},
+	{0x2F825, UNICODE_NORM_QC_NO},
+	{0x2F826, UNICODE_NORM_QC_NO},
+	{0x2F827, UNICODE_NORM_QC_NO},
+	{0x2F828, UNICODE_NORM_QC_NO},
+	{0x2F829, UNICODE_NORM_QC_NO},
+	{0x2F82A, UNICODE_NORM_QC_NO},
+	{0x2F82B, UNICODE_NORM_QC_NO},
+	{0x2F82C, UNICODE_NORM_QC_NO},
+	{0x2F82D, UNICODE_NORM_QC_NO},
+	{0x2F82E, UNICODE_NORM_QC_NO},
+	{0x2F82F, UNICODE_NORM_QC_NO},
+	{0x2F830, UNICODE_NORM_QC_NO},
+	{0x2F831, UNICODE_NORM_QC_NO},
+	{0x2F832, UNICODE_NORM_QC_NO},
+	{0x2F833, UNICODE_NORM_QC_NO},
+	{0x2F834, UNICODE_NORM_QC_NO},
+	{0x2F835, UNICODE_NORM_QC_NO},
+	{0x2F836, UNICODE_NORM_QC_NO},
+	{0x2F837, UNICODE_NORM_QC_NO},
+	{0x2F838, UNICODE_NORM_QC_NO},
+	{0x2F839, UNICODE_NORM_QC_NO},
+	{0x2F83A, UNICODE_NORM_QC_NO},
+	{0x2F83B, UNICODE_NORM_QC_NO},
+	{0x2F83C, UNICODE_NORM_QC_NO},
+	{0x2F83D, UNICODE_NORM_QC_NO},
+	{0x2F83E, UNICODE_NORM_QC_NO},
+	{0x2F83F, UNICODE_NORM_QC_NO},
+	{0x2F840, UNICODE_NORM_QC_NO},
+	{0x2F841, UNICODE_NORM_QC_NO},
+	{0x2F842, UNICODE_NORM_QC_NO},
+	{0x2F843, UNICODE_NORM_QC_NO},
+	{0x2F844, UNICODE_NORM_QC_NO},
+	{0x2F845, UNICODE_NORM_QC_NO},
+	{0x2F846, UNICODE_NORM_QC_NO},
+	{0x2F847, UNICODE_NORM_QC_NO},
+	{0x2F848, UNICODE_NORM_QC_NO},
+	{0x2F849, UNICODE_NORM_QC_NO},
+	{0x2F84A, UNICODE_NORM_QC_NO},
+	{0x2F84B, UNICODE_NORM_QC_NO},
+	{0x2F84C, UNICODE_NORM_QC_NO},
+	{0x2F84D, UNICODE_NORM_QC_NO},
+	{0x2F84E, UNICODE_NORM_QC_NO},
+	{0x2F84F, UNICODE_NORM_QC_NO},
+	{0x2F850, UNICODE_NORM_QC_NO},
+	{0x2F851, UNICODE_NORM_QC_NO},
+	{0x2F852, UNICODE_NORM_QC_NO},
+	{0x2F853, UNICODE_NORM_QC_NO},
+	{0x2F854, UNICODE_NORM_QC_NO},
+	{0x2F855, UNICODE_NORM_QC_NO},
+	{0x2F856, UNICODE_NORM_QC_NO},
+	{0x2F857, UNICODE_NORM_QC_NO},
+	{0x2F858, UNICODE_NORM_QC_NO},
+	{0x2F859, UNICODE_NORM_QC_NO},
+	{0x2F85A, UNICODE_NORM_QC_NO},
+	{0x2F85B, UNICODE_NORM_QC_NO},
+	{0x2F85C, UNICODE_NORM_QC_NO},
+	{0x2F85D, UNICODE_NORM_QC_NO},
+	{0x2F85E, UNICODE_NORM_QC_NO},
+	{0x2F85F, UNICODE_NORM_QC_NO},
+	{0x2F860, UNICODE_NORM_QC_NO},
+	{0x2F861, UNICODE_NORM_QC_NO},
+	{0x2F862, UNICODE_NORM_QC_NO},
+	{0x2F863, UNICODE_NORM_QC_NO},
+	{0x2F864, UNICODE_NORM_QC_NO},
+	{0x2F865, UNICODE_NORM_QC_NO},
+	{0x2F866, UNICODE_NORM_QC_NO},
+	{0x2F867, UNICODE_NORM_QC_NO},
+	{0x2F868, UNICODE_NORM_QC_NO},
+	{0x2F869, UNICODE_NORM_QC_NO},
+	{0x2F86A, UNICODE_NORM_QC_NO},
+	{0x2F86B, UNICODE_NORM_QC_NO},
+	{0x2F86C, UNICODE_NORM_QC_NO},
+	{0x2F86D, UNICODE_NORM_QC_NO},
+	{0x2F86E, UNICODE_NORM_QC_NO},
+	{0x2F86F, UNICODE_NORM_QC_NO},
+	{0x2F870, UNICODE_NORM_QC_NO},
+	{0x2F871, UNICODE_NORM_QC_NO},
+	{0x2F872, UNICODE_NORM_QC_NO},
+	{0x2F873, UNICODE_NORM_QC_NO},
+	{0x2F874, UNICODE_NORM_QC_NO},
+	{0x2F875, UNICODE_NORM_QC_NO},
+	{0x2F876, UNICODE_NORM_QC_NO},
+	{0x2F877, UNICODE_NORM_QC_NO},
+	{0x2F878, UNICODE_NORM_QC_NO},
+	{0x2F879, UNICODE_NORM_QC_NO},
+	{0x2F87A, UNICODE_NORM_QC_NO},
+	{0x2F87B, UNICODE_NORM_QC_NO},
+	{0x2F87C, UNICODE_NORM_QC_NO},
+	{0x2F87D, UNICODE_NORM_QC_NO},
+	{0x2F87E, UNICODE_NORM_QC_NO},
+	{0x2F87F, UNICODE_NORM_QC_NO},
+	{0x2F880, UNICODE_NORM_QC_NO},
+	{0x2F881, UNICODE_NORM_QC_NO},
+	{0x2F882, UNICODE_NORM_QC_NO},
+	{0x2F883, UNICODE_NORM_QC_NO},
+	{0x2F884, UNICODE_NORM_QC_NO},
+	{0x2F885, UNICODE_NORM_QC_NO},
+	{0x2F886, UNICODE_NORM_QC_NO},
+	{0x2F887, UNICODE_NORM_QC_NO},
+	{0x2F888, UNICODE_NORM_QC_NO},
+	{0x2F889, UNICODE_NORM_QC_NO},
+	{0x2F88A, UNICODE_NORM_QC_NO},
+	{0x2F88B, UNICODE_NORM_QC_NO},
+	{0x2F88C, UNICODE_NORM_QC_NO},
+	{0x2F88D, UNICODE_NORM_QC_NO},
+	{0x2F88E, UNICODE_NORM_QC_NO},
+	{0x2F88F, UNICODE_NORM_QC_NO},
+	{0x2F890, UNICODE_NORM_QC_NO},
+	{0x2F891, UNICODE_NORM_QC_NO},
+	{0x2F892, UNICODE_NORM_QC_NO},
+	{0x2F893, UNICODE_NORM_QC_NO},
+	{0x2F894, UNICODE_NORM_QC_NO},
+	{0x2F895, UNICODE_NORM_QC_NO},
+	{0x2F896, UNICODE_NORM_QC_NO},
+	{0x2F897, UNICODE_NORM_QC_NO},
+	{0x2F898, UNICODE_NORM_QC_NO},
+	{0x2F899, UNICODE_NORM_QC_NO},
+	{0x2F89A, UNICODE_NORM_QC_NO},
+	{0x2F89B, UNICODE_NORM_QC_NO},
+	{0x2F89C, UNICODE_NORM_QC_NO},
+	{0x2F89D, UNICODE_NORM_QC_NO},
+	{0x2F89E, UNICODE_NORM_QC_NO},
+	{0x2F89F, UNICODE_NORM_QC_NO},
+	{0x2F8A0, UNICODE_NORM_QC_NO},
+	{0x2F8A1, UNICODE_NORM_QC_NO},
+	{0x2F8A2, UNICODE_NORM_QC_NO},
+	{0x2F8A3, UNICODE_NORM_QC_NO},
+	{0x2F8A4, UNICODE_NORM_QC_NO},
+	{0x2F8A5, UNICODE_NORM_QC_NO},
+	{0x2F8A6, UNICODE_NORM_QC_NO},
+	{0x2F8A7, UNICODE_NORM_QC_NO},
+	{0x2F8A8, UNICODE_NORM_QC_NO},
+	{0x2F8A9, UNICODE_NORM_QC_NO},
+	{0x2F8AA, UNICODE_NORM_QC_NO},
+	{0x2F8AB, UNICODE_NORM_QC_NO},
+	{0x2F8AC, UNICODE_NORM_QC_NO},
+	{0x2F8AD, UNICODE_NORM_QC_NO},
+	{0x2F8AE, UNICODE_NORM_QC_NO},
+	{0x2F8AF, UNICODE_NORM_QC_NO},
+	{0x2F8B0, UNICODE_NORM_QC_NO},
+	{0x2F8B1, UNICODE_NORM_QC_NO},
+	{0x2F8B2, UNICODE_NORM_QC_NO},
+	{0x2F8B3, UNICODE_NORM_QC_NO},
+	{0x2F8B4, UNICODE_NORM_QC_NO},
+	{0x2F8B5, UNICODE_NORM_QC_NO},
+	{0x2F8B6, UNICODE_NORM_QC_NO},
+	{0x2F8B7, UNICODE_NORM_QC_NO},
+	{0x2F8B8, UNICODE_NORM_QC_NO},
+	{0x2F8B9, UNICODE_NORM_QC_NO},
+	{0x2F8BA, UNICODE_NORM_QC_NO},
+	{0x2F8BB, UNICODE_NORM_QC_NO},
+	{0x2F8BC, UNICODE_NORM_QC_NO},
+	{0x2F8BD, UNICODE_NORM_QC_NO},
+	{0x2F8BE, UNICODE_NORM_QC_NO},
+	{0x2F8BF, UNICODE_NORM_QC_NO},
+	{0x2F8C0, UNICODE_NORM_QC_NO},
+	{0x2F8C1, UNICODE_NORM_QC_NO},
+	{0x2F8C2, UNICODE_NORM_QC_NO},
+	{0x2F8C3, UNICODE_NORM_QC_NO},
+	{0x2F8C4, UNICODE_NORM_QC_NO},
+	{0x2F8C5, UNICODE_NORM_QC_NO},
+	{0x2F8C6, UNICODE_NORM_QC_NO},
+	{0x2F8C7, UNICODE_NORM_QC_NO},
+	{0x2F8C8, UNICODE_NORM_QC_NO},
+	{0x2F8C9, UNICODE_NORM_QC_NO},
+	{0x2F8CA, UNICODE_NORM_QC_NO},
+	{0x2F8CB, UNICODE_NORM_QC_NO},
+	{0x2F8CC, UNICODE_NORM_QC_NO},
+	{0x2F8CD, UNICODE_NORM_QC_NO},
+	{0x2F8CE, UNICODE_NORM_QC_NO},
+	{0x2F8CF, UNICODE_NORM_QC_NO},
+	{0x2F8D0, UNICODE_NORM_QC_NO},
+	{0x2F8D1, UNICODE_NORM_QC_NO},
+	{0x2F8D2, UNICODE_NORM_QC_NO},
+	{0x2F8D3, UNICODE_NORM_QC_NO},
+	{0x2F8D4, UNICODE_NORM_QC_NO},
+	{0x2F8D5, UNICODE_NORM_QC_NO},
+	{0x2F8D6, UNICODE_NORM_QC_NO},
+	{0x2F8D7, UNICODE_NORM_QC_NO},
+	{0x2F8D8, UNICODE_NORM_QC_NO},
+	{0x2F8D9, UNICODE_NORM_QC_NO},
+	{0x2F8DA, UNICODE_NORM_QC_NO},
+	{0x2F8DB, UNICODE_NORM_QC_NO},
+	{0x2F8DC, UNICODE_NORM_QC_NO},
+	{0x2F8DD, UNICODE_NORM_QC_NO},
+	{0x2F8DE, UNICODE_NORM_QC_NO},
+	{0x2F8DF, UNICODE_NORM_QC_NO},
+	{0x2F8E0, UNICODE_NORM_QC_NO},
+	{0x2F8E1, UNICODE_NORM_QC_NO},
+	{0x2F8E2, UNICODE_NORM_QC_NO},
+	{0x2F8E3, UNICODE_NORM_QC_NO},
+	{0x2F8E4, UNICODE_NORM_QC_NO},
+	{0x2F8E5, UNICODE_NORM_QC_NO},
+	{0x2F8E6, UNICODE_NORM_QC_NO},
+	{0x2F8E7, UNICODE_NORM_QC_NO},
+	{0x2F8E8, UNICODE_NORM_QC_NO},
+	{0x2F8E9, UNICODE_NORM_QC_NO},
+	{0x2F8EA, UNICODE_NORM_QC_NO},
+	{0x2F8EB, UNICODE_NORM_QC_NO},
+	{0x2F8EC, UNICODE_NORM_QC_NO},
+	{0x2F8ED, UNICODE_NORM_QC_NO},
+	{0x2F8EE, UNICODE_NORM_QC_NO},
+	{0x2F8EF, UNICODE_NORM_QC_NO},
+	{0x2F8F0, UNICODE_NORM_QC_NO},
+	{0x2F8F1, UNICODE_NORM_QC_NO},
+	{0x2F8F2, UNICODE_NORM_QC_NO},
+	{0x2F8F3, UNICODE_NORM_QC_NO},
+	{0x2F8F4, UNICODE_NORM_QC_NO},
+	{0x2F8F5, UNICODE_NORM_QC_NO},
+	{0x2F8F6, UNICODE_NORM_QC_NO},
+	{0x2F8F7, UNICODE_NORM_QC_NO},
+	{0x2F8F8, UNICODE_NORM_QC_NO},
+	{0x2F8F9, UNICODE_NORM_QC_NO},
+	{0x2F8FA, UNICODE_NORM_QC_NO},
+	{0x2F8FB, UNICODE_NORM_QC_NO},
+	{0x2F8FC, UNICODE_NORM_QC_NO},
+	{0x2F8FD, UNICODE_NORM_QC_NO},
+	{0x2F8FE, UNICODE_NORM_QC_NO},
+	{0x2F8FF, UNICODE_NORM_QC_NO},
+	{0x2F900, UNICODE_NORM_QC_NO},
+	{0x2F901, UNICODE_NORM_QC_NO},
+	{0x2F902, UNICODE_NORM_QC_NO},
+	{0x2F903, UNICODE_NORM_QC_NO},
+	{0x2F904, UNICODE_NORM_QC_NO},
+	{0x2F905, UNICODE_NORM_QC_NO},
+	{0x2F906, UNICODE_NORM_QC_NO},
+	{0x2F907, UNICODE_NORM_QC_NO},
+	{0x2F908, UNICODE_NORM_QC_NO},
+	{0x2F909, UNICODE_NORM_QC_NO},
+	{0x2F90A, UNICODE_NORM_QC_NO},
+	{0x2F90B, UNICODE_NORM_QC_NO},
+	{0x2F90C, UNICODE_NORM_QC_NO},
+	{0x2F90D, UNICODE_NORM_QC_NO},
+	{0x2F90E, UNICODE_NORM_QC_NO},
+	{0x2F90F, UNICODE_NORM_QC_NO},
+	{0x2F910, UNICODE_NORM_QC_NO},
+	{0x2F911, UNICODE_NORM_QC_NO},
+	{0x2F912, UNICODE_NORM_QC_NO},
+	{0x2F913, UNICODE_NORM_QC_NO},
+	{0x2F914, UNICODE_NORM_QC_NO},
+	{0x2F915, UNICODE_NORM_QC_NO},
+	{0x2F916, UNICODE_NORM_QC_NO},
+	{0x2F917, UNICODE_NORM_QC_NO},
+	{0x2F918, UNICODE_NORM_QC_NO},
+	{0x2F919, UNICODE_NORM_QC_NO},
+	{0x2F91A, UNICODE_NORM_QC_NO},
+	{0x2F91B, UNICODE_NORM_QC_NO},
+	{0x2F91C, UNICODE_NORM_QC_NO},
+	{0x2F91D, UNICODE_NORM_QC_NO},
+	{0x2F91E, UNICODE_NORM_QC_NO},
+	{0x2F91F, UNICODE_NORM_QC_NO},
+	{0x2F920, UNICODE_NORM_QC_NO},
+	{0x2F921, UNICODE_NORM_QC_NO},
+	{0x2F922, UNICODE_NORM_QC_NO},
+	{0x2F923, UNICODE_NORM_QC_NO},
+	{0x2F924, UNICODE_NORM_QC_NO},
+	{0x2F925, UNICODE_NORM_QC_NO},
+	{0x2F926, UNICODE_NORM_QC_NO},
+	{0x2F927, UNICODE_NORM_QC_NO},
+	{0x2F928, UNICODE_NORM_QC_NO},
+	{0x2F929, UNICODE_NORM_QC_NO},
+	{0x2F92A, UNICODE_NORM_QC_NO},
+	{0x2F92B, UNICODE_NORM_QC_NO},
+	{0x2F92C, UNICODE_NORM_QC_NO},
+	{0x2F92D, UNICODE_NORM_QC_NO},
+	{0x2F92E, UNICODE_NORM_QC_NO},
+	{0x2F92F, UNICODE_NORM_QC_NO},
+	{0x2F930, UNICODE_NORM_QC_NO},
+	{0x2F931, UNICODE_NORM_QC_NO},
+	{0x2F932, UNICODE_NORM_QC_NO},
+	{0x2F933, UNICODE_NORM_QC_NO},
+	{0x2F934, UNICODE_NORM_QC_NO},
+	{0x2F935, UNICODE_NORM_QC_NO},
+	{0x2F936, UNICODE_NORM_QC_NO},
+	{0x2F937, UNICODE_NORM_QC_NO},
+	{0x2F938, UNICODE_NORM_QC_NO},
+	{0x2F939, UNICODE_NORM_QC_NO},
+	{0x2F93A, UNICODE_NORM_QC_NO},
+	{0x2F93B, UNICODE_NORM_QC_NO},
+	{0x2F93C, UNICODE_NORM_QC_NO},
+	{0x2F93D, UNICODE_NORM_QC_NO},
+	{0x2F93E, UNICODE_NORM_QC_NO},
+	{0x2F93F, UNICODE_NORM_QC_NO},
+	{0x2F940, UNICODE_NORM_QC_NO},
+	{0x2F941, UNICODE_NORM_QC_NO},
+	{0x2F942, UNICODE_NORM_QC_NO},
+	{0x2F943, UNICODE_NORM_QC_NO},
+	{0x2F944, UNICODE_NORM_QC_NO},
+	{0x2F945, UNICODE_NORM_QC_NO},
+	{0x2F946, UNICODE_NORM_QC_NO},
+	{0x2F947, UNICODE_NORM_QC_NO},
+	{0x2F948, UNICODE_NORM_QC_NO},
+	{0x2F949, UNICODE_NORM_QC_NO},
+	{0x2F94A, UNICODE_NORM_QC_NO},
+	{0x2F94B, UNICODE_NORM_QC_NO},
+	{0x2F94C, UNICODE_NORM_QC_NO},
+	{0x2F94D, UNICODE_NORM_QC_NO},
+	{0x2F94E, UNICODE_NORM_QC_NO},
+	{0x2F94F, UNICODE_NORM_QC_NO},
+	{0x2F950, UNICODE_NORM_QC_NO},
+	{0x2F951, UNICODE_NORM_QC_NO},
+	{0x2F952, UNICODE_NORM_QC_NO},
+	{0x2F953, UNICODE_NORM_QC_NO},
+	{0x2F954, UNICODE_NORM_QC_NO},
+	{0x2F955, UNICODE_NORM_QC_NO},
+	{0x2F956, UNICODE_NORM_QC_NO},
+	{0x2F957, UNICODE_NORM_QC_NO},
+	{0x2F958, UNICODE_NORM_QC_NO},
+	{0x2F959, UNICODE_NORM_QC_NO},
+	{0x2F95A, UNICODE_NORM_QC_NO},
+	{0x2F95B, UNICODE_NORM_QC_NO},
+	{0x2F95C, UNICODE_NORM_QC_NO},
+	{0x2F95D, UNICODE_NORM_QC_NO},
+	{0x2F95E, UNICODE_NORM_QC_NO},
+	{0x2F95F, UNICODE_NORM_QC_NO},
+	{0x2F960, UNICODE_NORM_QC_NO},
+	{0x2F961, UNICODE_NORM_QC_NO},
+	{0x2F962, UNICODE_NORM_QC_NO},
+	{0x2F963, UNICODE_NORM_QC_NO},
+	{0x2F964, UNICODE_NORM_QC_NO},
+	{0x2F965, UNICODE_NORM_QC_NO},
+	{0x2F966, UNICODE_NORM_QC_NO},
+	{0x2F967, UNICODE_NORM_QC_NO},
+	{0x2F968, UNICODE_NORM_QC_NO},
+	{0x2F969, UNICODE_NORM_QC_NO},
+	{0x2F96A, UNICODE_NORM_QC_NO},
+	{0x2F96B, UNICODE_NORM_QC_NO},
+	{0x2F96C, UNICODE_NORM_QC_NO},
+	{0x2F96D, UNICODE_NORM_QC_NO},
+	{0x2F96E, UNICODE_NORM_QC_NO},
+	{0x2F96F, UNICODE_NORM_QC_NO},
+	{0x2F970, UNICODE_NORM_QC_NO},
+	{0x2F971, UNICODE_NORM_QC_NO},
+	{0x2F972, UNICODE_NORM_QC_NO},
+	{0x2F973, UNICODE_NORM_QC_NO},
+	{0x2F974, UNICODE_NORM_QC_NO},
+	{0x2F975, UNICODE_NORM_QC_NO},
+	{0x2F976, UNICODE_NORM_QC_NO},
+	{0x2F977, UNICODE_NORM_QC_NO},
+	{0x2F978, UNICODE_NORM_QC_NO},
+	{0x2F979, UNICODE_NORM_QC_NO},
+	{0x2F97A, UNICODE_NORM_QC_NO},
+	{0x2F97B, UNICODE_NORM_QC_NO},
+	{0x2F97C, UNICODE_NORM_QC_NO},
+	{0x2F97D, UNICODE_NORM_QC_NO},
+	{0x2F97E, UNICODE_NORM_QC_NO},
+	{0x2F97F, UNICODE_NORM_QC_NO},
+	{0x2F980, UNICODE_NORM_QC_NO},
+	{0x2F981, UNICODE_NORM_QC_NO},
+	{0x2F982, UNICODE_NORM_QC_NO},
+	{0x2F983, UNICODE_NORM_QC_NO},
+	{0x2F984, UNICODE_NORM_QC_NO},
+	{0x2F985, UNICODE_NORM_QC_NO},
+	{0x2F986, UNICODE_NORM_QC_NO},
+	{0x2F987, UNICODE_NORM_QC_NO},
+	{0x2F988, UNICODE_NORM_QC_NO},
+	{0x2F989, UNICODE_NORM_QC_NO},
+	{0x2F98A, UNICODE_NORM_QC_NO},
+	{0x2F98B, UNICODE_NORM_QC_NO},
+	{0x2F98C, UNICODE_NORM_QC_NO},
+	{0x2F98D, UNICODE_NORM_QC_NO},
+	{0x2F98E, UNICODE_NORM_QC_NO},
+	{0x2F98F, UNICODE_NORM_QC_NO},
+	{0x2F990, UNICODE_NORM_QC_NO},
+	{0x2F991, UNICODE_NORM_QC_NO},
+	{0x2F992, UNICODE_NORM_QC_NO},
+	{0x2F993, UNICODE_NORM_QC_NO},
+	{0x2F994, UNICODE_NORM_QC_NO},
+	{0x2F995, UNICODE_NORM_QC_NO},
+	{0x2F996, UNICODE_NORM_QC_NO},
+	{0x2F997, UNICODE_NORM_QC_NO},
+	{0x2F998, UNICODE_NORM_QC_NO},
+	{0x2F999, UNICODE_NORM_QC_NO},
+	{0x2F99A, UNICODE_NORM_QC_NO},
+	{0x2F99B, UNICODE_NORM_QC_NO},
+	{0x2F99C, UNICODE_NORM_QC_NO},
+	{0x2F99D, UNICODE_NORM_QC_NO},
+	{0x2F99E, UNICODE_NORM_QC_NO},
+	{0x2F99F, UNICODE_NORM_QC_NO},
+	{0x2F9A0, UNICODE_NORM_QC_NO},
+	{0x2F9A1, UNICODE_NORM_QC_NO},
+	{0x2F9A2, UNICODE_NORM_QC_NO},
+	{0x2F9A3, UNICODE_NORM_QC_NO},
+	{0x2F9A4, UNICODE_NORM_QC_NO},
+	{0x2F9A5, UNICODE_NORM_QC_NO},
+	{0x2F9A6, UNICODE_NORM_QC_NO},
+	{0x2F9A7, UNICODE_NORM_QC_NO},
+	{0x2F9A8, UNICODE_NORM_QC_NO},
+	{0x2F9A9, UNICODE_NORM_QC_NO},
+	{0x2F9AA, UNICODE_NORM_QC_NO},
+	{0x2F9AB, UNICODE_NORM_QC_NO},
+	{0x2F9AC, UNICODE_NORM_QC_NO},
+	{0x2F9AD, UNICODE_NORM_QC_NO},
+	{0x2F9AE, UNICODE_NORM_QC_NO},
+	{0x2F9AF, UNICODE_NORM_QC_NO},
+	{0x2F9B0, UNICODE_NORM_QC_NO},
+	{0x2F9B1, UNICODE_NORM_QC_NO},
+	{0x2F9B2, UNICODE_NORM_QC_NO},
+	{0x2F9B3, UNICODE_NORM_QC_NO},
+	{0x2F9B4, UNICODE_NORM_QC_NO},
+	{0x2F9B5, UNICODE_NORM_QC_NO},
+	{0x2F9B6, UNICODE_NORM_QC_NO},
+	{0x2F9B7, UNICODE_NORM_QC_NO},
+	{0x2F9B8, UNICODE_NORM_QC_NO},
+	{0x2F9B9, UNICODE_NORM_QC_NO},
+	{0x2F9BA, UNICODE_NORM_QC_NO},
+	{0x2F9BB, UNICODE_NORM_QC_NO},
+	{0x2F9BC, UNICODE_NORM_QC_NO},
+	{0x2F9BD, UNICODE_NORM_QC_NO},
+	{0x2F9BE, UNICODE_NORM_QC_NO},
+	{0x2F9BF, UNICODE_NORM_QC_NO},
+	{0x2F9C0, UNICODE_NORM_QC_NO},
+	{0x2F9C1, UNICODE_NORM_QC_NO},
+	{0x2F9C2, UNICODE_NORM_QC_NO},
+	{0x2F9C3, UNICODE_NORM_QC_NO},
+	{0x2F9C4, UNICODE_NORM_QC_NO},
+	{0x2F9C5, UNICODE_NORM_QC_NO},
+	{0x2F9C6, UNICODE_NORM_QC_NO},
+	{0x2F9C7, UNICODE_NORM_QC_NO},
+	{0x2F9C8, UNICODE_NORM_QC_NO},
+	{0x2F9C9, UNICODE_NORM_QC_NO},
+	{0x2F9CA, UNICODE_NORM_QC_NO},
+	{0x2F9CB, UNICODE_NORM_QC_NO},
+	{0x2F9CC, UNICODE_NORM_QC_NO},
+	{0x2F9CD, UNICODE_NORM_QC_NO},
+	{0x2F9CE, UNICODE_NORM_QC_NO},
+	{0x2F9CF, UNICODE_NORM_QC_NO},
+	{0x2F9D0, UNICODE_NORM_QC_NO},
+	{0x2F9D1, UNICODE_NORM_QC_NO},
+	{0x2F9D2, UNICODE_NORM_QC_NO},
+	{0x2F9D3, UNICODE_NORM_QC_NO},
+	{0x2F9D4, UNICODE_NORM_QC_NO},
+	{0x2F9D5, UNICODE_NORM_QC_NO},
+	{0x2F9D6, UNICODE_NORM_QC_NO},
+	{0x2F9D7, UNICODE_NORM_QC_NO},
+	{0x2F9D8, UNICODE_NORM_QC_NO},
+	{0x2F9D9, UNICODE_NORM_QC_NO},
+	{0x2F9DA, UNICODE_NORM_QC_NO},
+	{0x2F9DB, UNICODE_NORM_QC_NO},
+	{0x2F9DC, UNICODE_NORM_QC_NO},
+	{0x2F9DD, UNICODE_NORM_QC_NO},
+	{0x2F9DE, UNICODE_NORM_QC_NO},
+	{0x2F9DF, UNICODE_NORM_QC_NO},
+	{0x2F9E0, UNICODE_NORM_QC_NO},
+	{0x2F9E1, UNICODE_NORM_QC_NO},
+	{0x2F9E2, UNICODE_NORM_QC_NO},
+	{0x2F9E3, UNICODE_NORM_QC_NO},
+	{0x2F9E4, UNICODE_NORM_QC_NO},
+	{0x2F9E5, UNICODE_NORM_QC_NO},
+	{0x2F9E6, UNICODE_NORM_QC_NO},
+	{0x2F9E7, UNICODE_NORM_QC_NO},
+	{0x2F9E8, UNICODE_NORM_QC_NO},
+	{0x2F9E9, UNICODE_NORM_QC_NO},
+	{0x2F9EA, UNICODE_NORM_QC_NO},
+	{0x2F9EB, UNICODE_NORM_QC_NO},
+	{0x2F9EC, UNICODE_NORM_QC_NO},
+	{0x2F9ED, UNICODE_NORM_QC_NO},
+	{0x2F9EE, UNICODE_NORM_QC_NO},
+	{0x2F9EF, UNICODE_NORM_QC_NO},
+	{0x2F9F0, UNICODE_NORM_QC_NO},
+	{0x2F9F1, UNICODE_NORM_QC_NO},
+	{0x2F9F2, UNICODE_NORM_QC_NO},
+	{0x2F9F3, UNICODE_NORM_QC_NO},
+	{0x2F9F4, UNICODE_NORM_QC_NO},
+	{0x2F9F5, UNICODE_NORM_QC_NO},
+	{0x2F9F6, UNICODE_NORM_QC_NO},
+	{0x2F9F7, UNICODE_NORM_QC_NO},
+	{0x2F9F8, UNICODE_NORM_QC_NO},
+	{0x2F9F9, UNICODE_NORM_QC_NO},
+	{0x2F9FA, UNICODE_NORM_QC_NO},
+	{0x2F9FB, UNICODE_NORM_QC_NO},
+	{0x2F9FC, UNICODE_NORM_QC_NO},
+	{0x2F9FD, UNICODE_NORM_QC_NO},
+	{0x2F9FE, UNICODE_NORM_QC_NO},
+	{0x2F9FF, UNICODE_NORM_QC_NO},
+	{0x2FA00, UNICODE_NORM_QC_NO},
+	{0x2FA01, UNICODE_NORM_QC_NO},
+	{0x2FA02, UNICODE_NORM_QC_NO},
+	{0x2FA03, UNICODE_NORM_QC_NO},
+	{0x2FA04, UNICODE_NORM_QC_NO},
+	{0x2FA05, UNICODE_NORM_QC_NO},
+	{0x2FA06, UNICODE_NORM_QC_NO},
+	{0x2FA07, UNICODE_NORM_QC_NO},
+	{0x2FA08, UNICODE_NORM_QC_NO},
+	{0x2FA09, UNICODE_NORM_QC_NO},
+	{0x2FA0A, UNICODE_NORM_QC_NO},
+	{0x2FA0B, UNICODE_NORM_QC_NO},
+	{0x2FA0C, UNICODE_NORM_QC_NO},
+	{0x2FA0D, UNICODE_NORM_QC_NO},
+	{0x2FA0E, UNICODE_NORM_QC_NO},
+	{0x2FA0F, UNICODE_NORM_QC_NO},
+	{0x2FA10, UNICODE_NORM_QC_NO},
+	{0x2FA11, UNICODE_NORM_QC_NO},
+	{0x2FA12, UNICODE_NORM_QC_NO},
+	{0x2FA13, UNICODE_NORM_QC_NO},
+	{0x2FA14, UNICODE_NORM_QC_NO},
+	{0x2FA15, UNICODE_NORM_QC_NO},
+	{0x2FA16, UNICODE_NORM_QC_NO},
+	{0x2FA17, UNICODE_NORM_QC_NO},
+	{0x2FA18, UNICODE_NORM_QC_NO},
+	{0x2FA19, UNICODE_NORM_QC_NO},
+	{0x2FA1A, UNICODE_NORM_QC_NO},
+	{0x2FA1B, UNICODE_NORM_QC_NO},
+	{0x2FA1C, UNICODE_NORM_QC_NO},
+	{0x2FA1D, UNICODE_NORM_QC_NO},
+};
diff --git a/src/include/parser/kwlist.h b/src/include/parser/kwlist.h
index b1184c2d15..08f22ce211 100644
--- a/src/include/parser/kwlist.h
+++ b/src/include/parser/kwlist.h
@@ -260,8 +260,14 @@ PG_KEYWORD("natural", NATURAL, TYPE_FUNC_NAME_KEYWORD)
 PG_KEYWORD("nchar", NCHAR, COL_NAME_KEYWORD)
 PG_KEYWORD("new", NEW, UNRESERVED_KEYWORD)
 PG_KEYWORD("next", NEXT, UNRESERVED_KEYWORD)
+PG_KEYWORD("nfc", NFC, UNRESERVED_KEYWORD)
+PG_KEYWORD("nfd", NFD, UNRESERVED_KEYWORD)
+PG_KEYWORD("nfkc", NFKC, UNRESERVED_KEYWORD)
+PG_KEYWORD("nfkd", NFKD, UNRESERVED_KEYWORD)
 PG_KEYWORD("no", NO, UNRESERVED_KEYWORD)
 PG_KEYWORD("none", NONE, COL_NAME_KEYWORD)
+PG_KEYWORD("normalize", NORMALIZE, COL_NAME_KEYWORD)
+PG_KEYWORD("normalized", NORMALIZED, UNRESERVED_KEYWORD)
 PG_KEYWORD("not", NOT, RESERVED_KEYWORD)
 PG_KEYWORD("nothing", NOTHING, UNRESERVED_KEYWORD)
 PG_KEYWORD("notify", NOTIFY, UNRESERVED_KEYWORD)
diff --git a/src/test/regress/expected/unicode.out b/src/test/regress/expected/unicode.out
new file mode 100644
index 0000000000..2a1e903696
--- /dev/null
+++ b/src/test/regress/expected/unicode.out
@@ -0,0 +1,81 @@
+SELECT getdatabaseencoding() <> 'UTF8' AS skip_test \gset
+\if :skip_test
+\quit
+\endif
+SELECT U&'\0061\0308bc' <> U&'\00E4bc' COLLATE "C" AS sanity_check;
+ sanity_check 
+--------------
+ t
+(1 row)
+
+SELECT normalize(U&'\0061\0308\24D1c') = U&'\00E4\24D1c' COLLATE "C" AS test_default;
+ test_default 
+--------------
+ t
+(1 row)
+
+SELECT normalize(U&'\0061\0308\24D1c', NFC) = U&'\00E4\24D1c' COLLATE "C" AS test_nfc;
+ test_nfc 
+----------
+ t
+(1 row)
+
+SELECT normalize(U&'\00E4bc', NFC) = U&'\00E4bc' COLLATE "C" AS test_nfc_idem;
+ test_nfc_idem 
+---------------
+ t
+(1 row)
+
+SELECT normalize(U&'\00E4\24D1c', NFD) = U&'\0061\0308\24D1c' COLLATE "C" AS test_nfd;
+ test_nfd 
+----------
+ t
+(1 row)
+
+SELECT normalize(U&'\0061\0308\24D1c', NFKC) = U&'\00E4bc' COLLATE "C" AS test_nfkc;
+ test_nfkc 
+-----------
+ t
+(1 row)
+
+SELECT normalize(U&'\00E4\24D1c', NFKD) = U&'\0061\0308bc' COLLATE "C" AS test_nfkd;
+ test_nfkd 
+-----------
+ t
+(1 row)
+
+SELECT "normalize"('abc', 'def');  -- run-time error
+ERROR:  invalid normalization form: def
+SELECT U&'\00E4\24D1c' IS NORMALIZED AS test_default;
+ test_default 
+--------------
+ t
+(1 row)
+
+SELECT U&'\00E4\24D1c' IS NFC NORMALIZED AS test_nfc;
+ test_nfc 
+----------
+ t
+(1 row)
+
+SELECT num, val,
+    val IS NFC NORMALIZED AS NFC,
+    val IS NFD NORMALIZED AS NFD,
+    val IS NFKC NORMALIZED AS NFKC,
+    val IS NFKD NORMALIZED AS NFKD
+FROM
+  (VALUES (1, U&'\00E4bc'),
+          (2, U&'\0061\0308bc'),
+          (3, U&'\00E4\24D1c'),
+          (4, U&'\0061\0308\24D1c')) vals (num, val)
+ORDER BY num;
+ num | val | nfc | nfd | nfkc | nfkd 
+-----+-----+-----+-----+------+------
+   1 | äbc | t   | f   | t    | f
+   2 | äbc | f   | t   | f    | t
+   3 | äⓑc | t   | f   | f    | f
+   4 | äⓑc | f   | t   | f    | f
+(4 rows)
+
+SELECT is_normalized('abc', 'def');  -- run-time error
+ERROR:  invalid normalization form: def
diff --git a/src/test/regress/expected/unicode_1.out b/src/test/regress/expected/unicode_1.out
new file mode 100644
index 0000000000..8505c4fa55
--- /dev/null
+++ b/src/test/regress/expected/unicode_1.out
@@ -0,0 +1,3 @@
+SELECT getdatabaseencoding() <> 'UTF8' AS skip_test \gset
+\if :skip_test
+\quit
diff --git a/src/test/regress/parallel_schedule b/src/test/regress/parallel_schedule
index d2b17dd3ea..a98dba7b2f 100644
--- a/src/test/regress/parallel_schedule
+++ b/src/test/regress/parallel_schedule
@@ -27,7 +27,7 @@ test: strings numerology point lseg line box path polygon circle date time timet
 # geometry depends on point, lseg, box, path, polygon and circle
 # horology depends on interval, timetz, timestamp, timestamptz
 # ----------
-test: geometry horology regex oidjoins type_sanity opr_sanity misc_sanity comments expressions
+test: geometry horology regex oidjoins type_sanity opr_sanity misc_sanity comments expressions unicode
 
 # ----------
 # These four each depend on the previous one
diff --git a/src/test/regress/serial_schedule b/src/test/regress/serial_schedule
index acba391332..3f66e0b859 100644
--- a/src/test/regress/serial_schedule
+++ b/src/test/regress/serial_schedule
@@ -49,6 +49,7 @@ test: opr_sanity
 test: misc_sanity
 test: comments
 test: expressions
+test: unicode
 test: create_function_1
 test: create_type
 test: create_table
diff --git a/src/test/regress/sql/unicode.sql b/src/test/regress/sql/unicode.sql
new file mode 100644
index 0000000000..ccfc6fa77a
--- /dev/null
+++ b/src/test/regress/sql/unicode.sql
@@ -0,0 +1,32 @@
+SELECT getdatabaseencoding() <> 'UTF8' AS skip_test \gset
+\if :skip_test
+\quit
+\endif
+
+SELECT U&'\0061\0308bc' <> U&'\00E4bc' COLLATE "C" AS sanity_check;
+
+SELECT normalize(U&'\0061\0308\24D1c') = U&'\00E4\24D1c' COLLATE "C" AS test_default;
+SELECT normalize(U&'\0061\0308\24D1c', NFC) = U&'\00E4\24D1c' COLLATE "C" AS test_nfc;
+SELECT normalize(U&'\00E4bc', NFC) = U&'\00E4bc' COLLATE "C" AS test_nfc_idem;
+SELECT normalize(U&'\00E4\24D1c', NFD) = U&'\0061\0308\24D1c' COLLATE "C" AS test_nfd;
+SELECT normalize(U&'\0061\0308\24D1c', NFKC) = U&'\00E4bc' COLLATE "C" AS test_nfkc;
+SELECT normalize(U&'\00E4\24D1c', NFKD) = U&'\0061\0308bc' COLLATE "C" AS test_nfkd;
+
+SELECT "normalize"('abc', 'def');  -- run-time error
+
+SELECT U&'\00E4\24D1c' IS NORMALIZED AS test_default;
+SELECT U&'\00E4\24D1c' IS NFC NORMALIZED AS test_nfc;
+
+SELECT num, val,
+    val IS NFC NORMALIZED AS NFC,
+    val IS NFD NORMALIZED AS NFD,
+    val IS NFKC NORMALIZED AS NFKC,
+    val IS NFKD NORMALIZED AS NFKD
+FROM
+  (VALUES (1, U&'\00E4bc'),
+          (2, U&'\0061\0308bc'),
+          (3, U&'\00E4\24D1c'),
+          (4, U&'\0061\0308\24D1c')) vals (num, val)
+ORDER BY num;
+
+SELECT is_normalized('abc', 'def');  -- run-time error
-- 
2.25.0

